/********************************************************************************
 * @(#)regxc2361e.xml	1.6
 * 
 * Origin: xc2000_f-series_sfr_201102.xml
 * Rev: 2011-02
 * Device: XC22xxI XC23xxE XC27x8X
 * Family: XC2000
 * 
 * Copyright 2008-2011 Altium BV
 *
 * Define the following macros to exclude part of the
 * list of defined registers and register bits
 *
 *
 * This header file contains definitions for registers outside
 * DPP3. These register cannot safely be accessed using _near
 * addressing mode. For this reason, they are defined as
 * _far volatile unsigned int (*<address>);
 *
 * If a DPPx register is allocated to point to the required areas,
 * these registers can also be accessed using near addressing mode.
 * To enable this, define the following macro to the allocated DPP
 * register to convert the far addresses to near address on a
 * per-page basis:
 *
 *	PAGE_3FF_REGISTERS_NEAR               Memory range 0xFFC000 - 0xFFFFFF
 *	PAGE_081_REGISTERS_NEAR               Memory range 0x204000 - 0x207FFF
 *	PAGE_080_REGISTERS_NEAR               Memory range 0x200000 - 0x203FFF
 *
********************************************************************************/

#ifndef REGXC2361E_INC
#define REGXC2361E_INC

#define _FIX_DPP(dpp,pof)	( ( (unsigned int) dpp<<14 ) | ( (unsigned int) pof & 0x3FFF ) )

#ifdef PAGE_3FF_REGISTERS_NEAR
# if _MODEL == 't' || _MODEL == 's'
#  define _PAGE_3FF_MEM_TYPE(addr)       ((unsigned volatile int _near*)_FIX_DPP(PAGE_3FF_REGISTERS_NEAR,addr))
#  if   PAGE_3FF_REGISTERS_NEAR < 0 || PAGE_3FF_REGISTERS_NEAR > 2
#   error "PAGE_3FF_REGISTERS_NEAR is not defined to a valid DPP register"
#  endif
# else
#  if PAGE_3FF_REGISTERS_NEAR == 1
#    define _PAGE_3FF_MEM_TYPE(addr)    ((unsigned volatile int _xnear*)_FIX_DPP(1,addr))
#  elif PAGE_3FF_REGISTERS_NEAR == 2
#    define _PAGE_3FF_MEM_TYPE(addr)    ((unsigned volatile int _near*)_FIX_DPP(2,addr))
#  else
#   error "PAGE_3FF_REGISTERS_NEAR is not defined to a valid DPP register"
#  endif
# endif
#else
# define _PAGE_3FF_MEM_TYPE(addr)       ((unsigned volatile int _far *)addr)
#endif

#ifdef PAGE_081_REGISTERS_NEAR
# if _MODEL == 't' || _MODEL == 's'
#  define _PAGE_081_MEM_TYPE(addr)       ((unsigned volatile int _near*)_FIX_DPP(PAGE_081_REGISTERS_NEAR,addr))
#  if   PAGE_081_REGISTERS_NEAR < 0 || PAGE_081_REGISTERS_NEAR > 2
#   error "PAGE_081_REGISTERS_NEAR is not defined to a valid DPP register"
#  endif
# else
#  if PAGE_081_REGISTERS_NEAR == 1
#    define _PAGE_081_MEM_TYPE(addr)    ((unsigned volatile int _xnear*)_FIX_DPP(1,addr))
#  elif PAGE_081_REGISTERS_NEAR == 2
#    define _PAGE_081_MEM_TYPE(addr)    ((unsigned volatile int _near*)_FIX_DPP(2,addr))
#  else
#   error "PAGE_081_REGISTERS_NEAR is not defined to a valid DPP register"
#  endif
# endif
#else
# define _PAGE_081_MEM_TYPE(addr)       ((unsigned volatile int _far *)addr)
#endif

#ifdef PAGE_080_REGISTERS_NEAR
# if _MODEL == 't' || _MODEL == 's'
#  define _PAGE_080_MEM_TYPE(addr)       ((unsigned volatile int _near*)_FIX_DPP(PAGE_080_REGISTERS_NEAR,addr))
#  if   PAGE_080_REGISTERS_NEAR < 0 || PAGE_080_REGISTERS_NEAR > 2
#   error "PAGE_080_REGISTERS_NEAR is not defined to a valid DPP register"
#  endif
# else
#  if PAGE_080_REGISTERS_NEAR == 1
#    define _PAGE_080_MEM_TYPE(addr)    ((unsigned volatile int _xnear*)_FIX_DPP(1,addr))
#  elif PAGE_080_REGISTERS_NEAR == 2
#    define _PAGE_080_MEM_TYPE(addr)    ((unsigned volatile int _near*)_FIX_DPP(2,addr))
#  else
#   error "PAGE_080_REGISTERS_NEAR is not defined to a valid DPP register"
#  endif
# endif
#else
# define _PAGE_080_MEM_TYPE(addr)       ((unsigned volatile int _far *)addr)
#endif


/********************************************************************************
 * FLASH registers
********************************************************************************/
#ifndef REGXC2361E_NOFLASH

#define IMB_IMBCTRL     (*(_PAGE_3FF_MEM_TYPE(0xFFFF00))) /* IMB Control Low */

#define IMBCTRL         IMB_IMBCTRL

#define IMB_IMBCTRH     (*(_PAGE_3FF_MEM_TYPE(0xFFFF02))) /* IMB Control High */

#define IMBCTRH         IMB_IMBCTRH

#define IMB_INTCTR      (*(_PAGE_3FF_MEM_TYPE(0xFFFF04))) /* Interrupt Control */


#define IMB_FSR_BUSY    (*(_PAGE_3FF_MEM_TYPE(0xFFFF06))) /* Flash State Busy */


#define IMB_FSR_OP      (*(_PAGE_3FF_MEM_TYPE(0xFFFF08))) /* Flash State Operations */


#define IMB_FSR_PROT    (*(_PAGE_3FF_MEM_TYPE(0xFFFF0A))) /* Flash State Protection */


#define IMB_MAR0        (*(_PAGE_3FF_MEM_TYPE(0xFFFF0C))) /* Margin Control 0 */


#define IMB_PROCON0     (*(_PAGE_3FF_MEM_TYPE(0xFFFF10))) /* Protection Configuration 0 */


#define IMB_PROCON1     (*(_PAGE_3FF_MEM_TYPE(0xFFFF12))) /* Protection Configuration 1 */


#define IMB_PROCON2     (*(_PAGE_3FF_MEM_TYPE(0xFFFF14))) /* Protection Configuration 2 */


#define IMB_PROCON3     (*(_PAGE_3FF_MEM_TYPE(0xFFFF16))) /* Protection Configuration 3 */


#define IMB_PROCON4     (*(_PAGE_3FF_MEM_TYPE(0xFFFF18))) /* Protection Configuration. */


#define IMB_ECC_TRAP    (*(_PAGE_3FF_MEM_TYPE(0xFFFF20))) /* ECC Trap Control */


#define IMB_ECC_STAT    (*(_PAGE_3FF_MEM_TYPE(0xFFFF22))) /* ECC Status */

_esfr MEM_KSCCFG;                       /* Memory Subsystem KSCCFG */

_sfr FL_KSCCFG;                         /* Flash Kernel State Con. */

_sfr SBRAM_RADD;                        /* SBRAM Read Address Register */

_sfr SBRAM_WADD;                        /* SBRAM Write Address Register */

_sfr SBRAM_DATA0;                       /* SBRAM Data Register 0 */

_sfr SBRAM_DATA1;                       /* SBRAM Data Register 1 */

#endif /* REGXC2361E_NOFLASH */

/********************************************************************************
 * MCHK
********************************************************************************/
#ifndef REGXC2361E_NOMCHK

_sfr MCHK_ID;                           /* Module Identification Register */

_sfr MCHK_IR;                           /* Input Register */

_esfr MCHK_RRL;                         /* Result Register Low */

_esfr MCHK_RRH;                         /* Result Register High */

_sfr MCHK_COUNT;                        /* Count Register */

_esfr MCHK_TPRL;                        /* Tap Polynomial Register Low */

_esfr MCHK_TPRH;                        /* Tap Polynomial Register High */

#endif /* REGXC2361E_NOMCHK */

/********************************************************************************
 * Core Registers
********************************************************************************/
#ifndef REGXC2361E_NOCPU

_sfr CPUCON1;                           /* CPU Control Register 1 */

_sfr CPUCON2;                           /* CPU Control Register 2 */

_sfr CP;                                /* Context Pointer */

_sfr CSP;                               /* Code Segment Pointer */

_sfr DPP0;                              /* Data Page Pointer 0 */

_sfr DPP1;                              /* Data Page Pointer 1 */

_sfr DPP2;                              /* Data Page Pointer 2 */

_sfr DPP3;                              /* Data Page Pointer 3 */

_esfr QR0;                              /* Offset Register */

_esfr QR1;                              /* Offset Register */

_sfr IDX0;                              /* Address Pointer */

_sfr IDX1;                              /* Address Pointer */

_esfr QX0;                              /* Offset Register */

_esfr QX1;                              /* Offset Register */

_sfr SP;                                /* Stack Pointer */

_sfr SPSEG;                             /* Stack Pointer Segment */

_sfr STKOV;                             /* Stack Overflow Register */

_sfr STKUN;                             /* Stack Underflow Register */

_sfr PSW;                               /* Process Status Word */
_sfrbit PSW_N;                          /* PSW.0: Negative Result */
_sfrbit PSW_C;                          /* PSW.1: Carry Flag */
_sfrbit PSW_V;                          /* PSW.2: Overflow Result */
_sfrbit PSW_Z;                          /* PSW.3: Zero Flag */
_sfrbit PSW_E;                          /* PSW.4: End of Table Flag */
_sfrbit PSW_PL0;                        /* PSW.5: Protection Level selection 0 */
_sfrbit PSW_USR0;                       /* PSW.6: User General Purpose Flag */
_sfrbit PSW_USR1;                       /* PSW.7: User General Purpose Flag */
_sfrbit PSW_HLDEN_PL1;                  /* PSW.10: HOLD Enable / Protection Level selection 1 */
_sfrbit PSW_IEN;                        /* PSW.11: Interrupt Enable Control Bit */

#define N               PSW_N
#define C               PSW_C
#define V               PSW_V
#define Z               PSW_Z
#define E               PSW_E
#define MULIP           PSW_HLDEN_PL1
#define USR0            PSW_USR0
#define USR1            PSW_USR1
#define HLDEN           PSW_HLDEN_PL1
#define IEN             PSW_IEN

_sfr MDH;                               /* Multiply/Devide High Register */

_sfr MDL;                               /* Multiply/Devide Low Register */

_sfr MDC;                               /* Multiply/Devide Control Register */
_sfrbit MDC_MDRIU;                      /* MDC.4: Multiply/Devide Register in Use */

#define MDRIU           MDC_MDRIU

_sfr MCW;                               /* MAC Control Word */
_sfrbit MCW_MS;                         /* MCW.9: Saturation Mode Control */
_sfrbit MCW_MP;                         /* MCW.10: One-bit Scaler Control */

#define MS              MCW_MS
#define MP              MCW_MP

_sfr MAL;                               /* Accumulator Low Word */

_sfr MAH;                               /* Accumulator High Word */

_sfr MSW;                               /* MAC Status Word */
_sfrbit MSW_MN;                         /* MSW.8: Negative Result */
_sfrbit MSW_MZ;                         /* MSW.9: Zero Flag */
_sfrbit MSW_MC;                         /* MSW.10: Carry Flag */
_sfrbit MSW_MSV;                        /* MSW.11: Sticky Overflow Flag */
_sfrbit MSW_ME;                         /* MSW.12: MAC Extension Flag */
_sfrbit MSW_MSL;                        /* MSW.13: Sticky Limit Flag */
_sfrbit MSW_MV;                         /* MSW.14: Overflow Flag */

#define MN              MSW_MN
#define MZ              MSW_MZ
#define MC              MSW_MC
#define MSV             MSW_MSV
#define ME              MSW_ME
#define MSL             MSW_MSL
#define MV              MSW_MV

_sfr MRW;                               /* MAC Repeater Word */

_sfr ZEROS;                             /* Zeros Register */

_sfr ONES;                              /* Ones Register */

_esfr CPUID;                            /* CPU Identification Register */

#endif /* REGXC2361E_NOCPU */

/********************************************************************************
 * ICACHE
********************************************************************************/
#ifndef REGXC2361E_NOICACHE

_xsfr ICACHE_CTRL;                      /* ICACHE Control Register */

_xsfr ICACHE_EDCON;                     /* ICACHE Error Detection Control Register */

_xsfr ICACHE_DACON;                     /* ICACHE Data Access Control Register */

_xsfr ICACHE_RADD;                      /* ICACHE Read Address Register */

_xsfr ICACHE_WADD;                      /* ICACHE Write Address Register */

_xsfr ICACHE_DATA0;                     /* ICACHE Data Field Register */

_xsfr ICACHE_DATA1;                     /* ICACHE Data Field Register */

_xsfr ICACHE_DATA2;                     /* ICACHE Data Field Register */

_xsfr ICACHE_DATA3;                     /* ICACHE Data Field Register */

_xsfr ICACHE_DATA4;                     /* ICACHE Data Field Register */

_xsfr ICACHE_DATA5;                     /* ICACHE Data Field Register */

_xsfr ICACHE_DATA6;                     /* ICACHE Data Field Register */

_xsfr ICACHE_DATA7;                     /* ICACHE Data Field Register */

_xsfr ICACHE_ECCLH;                     /* ICACHE ECC Data Register */

_xsfr ICACHE_TAG;                       /* ICACHE TAG Register */

_xsfr ICACHE_HMCON;                     /* ICACHE Hit-Miss Control Register */

_xsfr ICACHE_HIT;                       /* ICACHE Hit Counter Register */

_xsfr ICACHE_MISS;                      /* ICACHE Miss Counter Register */

#endif /* REGXC2361E_NOICACHE */

/********************************************************************************
 * Interrupt registers
********************************************************************************/
#ifndef REGXC2361E_NOINTERRUPT

_sfr VECSEG;                            /* Vector Segment Pointer */

_xsfr FINT0CSP;                         /* Fast Interrupt Control 0 */

_xsfr FINT1CSP;                         /* Fast Interrupt Control 1 */

_xsfr FINT0ADDR;                        /* Fast Interrupt Address 0 */

_xsfr FINT1ADDR;                        /* Fast Interrupt Address 1 */

_xsfr BNKSEL0;                          /* Register Bank Selection 0 */

_xsfr BNKSEL1;                          /* Register Bank Selection 1 */

_xsfr BNKSEL2;                          /* Register Bank Selection 2 */

_xsfr BNKSEL3;                          /* Register Bank Selection 3 */

_sfr TFR;                               /* Trap Flag Register */
_sfrbit TFR_ILLOPA;                     /* TFR.2: Illegal word operand access */
_sfrbit TFR_PRTFLT;                     /* TFR.3: Protection Fault */
_sfrbit TFR_ACER;                       /* TFR.4: Memory Access Error */
_sfrbit TFR_UNDOPC;                     /* TFR.7: Undefined Opcode */
_sfrbit TFR_MPX;                        /* TFR.8: Memory Protection Execute */
_sfrbit TFR_MPW;                        /* TFR.9: Memory Protection Write */
_sfrbit TFR_MPR;                        /* TFR.10: Memory Protection Read */
_sfrbit TFR_SR1;                        /* TFR.11: System request flag 1 */
_sfrbit TFR_SOFTBRK;                    /* TFR.12: Software Break */
_sfrbit TFR_STKUF;                      /* TFR.13: Stack underflow flag */
_sfrbit TFR_STKOF;                      /* TFR.14: Stack overflow flag */
_sfrbit TFR_SR0;                        /* TFR.15: System request flag 0 */

_xsfr SRCP0;                            /* PEC Source Pointer 0 */

_xsfr SRCP1;                            /* PEC Source Pointer 1 */

_xsfr SRCP2;                            /* PEC Source Pointer 2 */

_xsfr SRCP3;                            /* PEC Source Pointer 3 */

_xsfr SRCP4;                            /* PEC Source Pointer 4 */

_xsfr SRCP5;                            /* PEC Source Pointer 5 */

_xsfr SRCP6;                            /* PEC Source Pointer 6 */

_xsfr SRCP7;                            /* PEC Source Pointer 7 */

_xsfr SRCP8;                            /* PEC Source Pointer 8 */

_xsfr SRCP9;                            /* PEC Source Pointer 9 */

_xsfr SRCP10;                           /* PEC Source Pointer 10 */

_xsfr SRCP11;                           /* PEC Source Pointer 11 */

_xsfr SRCP12;                           /* PEC Source Pointer 12 */

_xsfr SRCP13;                           /* PEC Source Pointer 13 */

_xsfr SRCP14;                           /* PEC Source Pointer 14 */

_xsfr SRCP15;                           /* PEC Source Pointer 15 */

_xsfr DSTP0;                            /* PEC Destination Pointer 0 */

_xsfr DSTP1;                            /* PEC Destination Pointer 1 */

_xsfr DSTP2;                            /* PEC Destination Pointer 2 */

_xsfr DSTP3;                            /* PEC Destination Pointer 3 */

_xsfr DSTP4;                            /* PEC Destination Pointer 4 */

_xsfr DSTP5;                            /* PEC Destination Pointer 5 */

_xsfr DSTP6;                            /* PEC Destination Pointer 6 */

_xsfr DSTP7;                            /* PEC Destination Pointer 7 */

_xsfr DSTP8;                            /* PEC Destination Pointer 8 */

_xsfr DSTP9;                            /* PEC Destination Pointer 9 */

_xsfr DSTP10;                           /* PEC Destination Pointer 10 */

_xsfr DSTP11;                           /* PEC Destination Pointer 11 */

_xsfr DSTP12;                           /* PEC Destination Pointer 12 */

_xsfr DSTP13;                           /* PEC Destination Pointer 13 */

_xsfr DSTP14;                           /* PEC Destination Pointer 14 */

_xsfr DSTP15;                           /* PEC Destination Pointer 15 */

_xsfr PECSEG0;                          /* PEC Segment Pointer 0 */

_xsfr PECSEG1;                          /* PEC Segment Pointer 1 */

_xsfr PECSEG2;                          /* PEC Segment Pointer 2 */

_xsfr PECSEG3;                          /* PEC Segment Pointer 3 */

_xsfr PECSEG4;                          /* PEC Segment Pointer 4 */

_xsfr PECSEG5;                          /* PEC Segment Pointer 5 */

_xsfr PECSEG6;                          /* PEC Segment Pointer 6 */

_xsfr PECSEG7;                          /* PEC Segment Pointer 7 */

_xsfr PECSEG8;                          /* PEC Segment Pointer 8 */

_xsfr PECSEG9;                          /* PEC Segment Pointer 9 */

_xsfr PECSEG10;                         /* PEC Segment Pointer 10 */

_xsfr PECSEG11;                         /* PEC Segment Pointer 11 */

_xsfr PECSEG12;                         /* PEC Segment Pointer 12 */

_xsfr PECSEG13;                         /* PEC Segment Pointer 13 */

_xsfr PECSEG14;                         /* PEC Segment Pointer 14 */

_xsfr PECSEG15;                         /* PEC Segment Pointer 15 */

_sfr PECC0;                             /* PEC Channel Control 0 */

_sfr PECC1;                             /* PEC Channel Control 1 */

_sfr PECC2;                             /* PEC Channel Control 2 */

_sfr PECC3;                             /* PEC Channel Control 3 */

_sfr PECC4;                             /* PEC Channel Control 4 */

_sfr PECC5;                             /* PEC Channel Control 5 */

_sfr PECC6;                             /* PEC Channel Control 6 */

_sfr PECC7;                             /* PEC Channel Control 7 */

_xsfr PECC8;                            /* PEC Channel Control 8 */

_xsfr PECC9;                            /* PEC Channel Control 9 */

_xsfr PECC10;                           /* PEC Channel Control 10 */

_xsfr PECC11;                           /* PEC Channel Control 11 */

_xsfr PECC12;                           /* PEC Channel Control 12 */

_xsfr PECC13;                           /* PEC Channel Control 13 */

_xsfr PECC14;                           /* PEC Channel Control 14 */

_xsfr PECC15;                           /* PEC Channel Control 15 */

_xsfr PECXC0;                           /* PEC Extended Count Register 0 */

_xsfr PECXC2;                           /* PEC Extended Count Register 2 */

_xsfr PECXC4;                           /* PEC Extended Count Register 4 */

_xsfr PECXC6;                           /* PEC Extended Count Register 6 */

_xsfr PECXC8;                           /* PEC Extended Count Register 8 */

_xsfr PECXC10;                          /* PEC Extended Count Register 10 */

_xsfr PECXC12;                          /* PEC Extended Count Register 12 */

_xsfr PECXC14;                          /* PEC Extended Count Register 14 */

_esfr EOPIC;                            /* End Of PEC Interrupt Control */
_esfrbit EOPIC_EOPIE;                   /* EOPIC.6: Interrupt Enable Control Bit */
_esfrbit EOPIC_EOPIR;                   /* EOPIC.7: Interrupt Request Flag */
_esfrbit EOPIC_GPX;                     /* EOPIC.8: Group Priority Extension */

_sfr PECISNC;                           /* PEC Interrupt Sub Node Control */
_sfrbit PECISNC_C0IE;                   /* PECISNC.0: Interrupt Sub Node Enable Control Bit of PEC Channel x It is recommended to clear an interrupt request flag (CxIR) before setting the respective enable flag (CxIE). Otherwise, former requests still pending will immediately trigger an interrupt request after setting the enable bit. */
_sfrbit PECISNC_C0IR;                   /* PECISNC.1: Interrupt Sub Node Request Flag of PEC Channel x */
_sfrbit PECISNC_C1IE;                   /* PECISNC.2: Interrupt Sub Node Enable Control Bit of PEC Channel x It is recommended to clear an interrupt request flag (CxIR) before setting the respective enable flag (CxIE). Otherwise, former requests still pending will immediately trigger an interrupt request after setting the enable bit. */
_sfrbit PECISNC_C1IR;                   /* PECISNC.3: Interrupt Sub Node Request Flag of PEC Channel x */
_sfrbit PECISNC_C2IE;                   /* PECISNC.4: Interrupt Sub Node Enable Control Bit of PEC Channel x It is recommended to clear an interrupt request flag (CxIR) before setting the respective enable flag (CxIE). Otherwise, former requests still pending will immediately trigger an interrupt request after setting the enable bit. */
_sfrbit PECISNC_C2IR;                   /* PECISNC.5: Interrupt Sub Node Request Flag of PEC Channel x */
_sfrbit PECISNC_C3IE;                   /* PECISNC.6: Interrupt Sub Node Enable Control Bit of PEC Channel x It is recommended to clear an interrupt request flag (CxIR) before setting the respective enable flag (CxIE). Otherwise, former requests still pending will immediately trigger an interrupt request after setting the enable bit. */
_sfrbit PECISNC_C3IR;                   /* PECISNC.7: Interrupt Sub Node Request Flag of PEC Channel x */
_sfrbit PECISNC_C4IE;                   /* PECISNC.8: Interrupt Sub Node Enable Control Bit of PEC Channel x It is recommended to clear an interrupt request flag (CxIR) before setting the respective enable flag (CxIE). Otherwise, former requests still pending will immediately trigger an interrupt request after setting the enable bit. */
_sfrbit PECISNC_C4IR;                   /* PECISNC.9: Interrupt Sub Node Request Flag of PEC Channel x */
_sfrbit PECISNC_C5IE;                   /* PECISNC.10: Interrupt Sub Node Enable Control Bit of PEC Channel x It is recommended to clear an interrupt request flag (CxIR) before setting the respective enable flag (CxIE). Otherwise, former requests still pending will immediately trigger an interrupt request after setting the enable bit. */
_sfrbit PECISNC_C5IR;                   /* PECISNC.11: Interrupt Sub Node Request Flag of PEC Channel x */
_sfrbit PECISNC_C6IE;                   /* PECISNC.12: Interrupt Sub Node Enable Control Bit of PEC Channel x It is recommended to clear an interrupt request flag (CxIR) before setting the respective enable flag (CxIE). Otherwise, former requests still pending will immediately trigger an interrupt request after setting the enable bit. */
_sfrbit PECISNC_C6IR;                   /* PECISNC.13: Interrupt Sub Node Request Flag of PEC Channel x */
_sfrbit PECISNC_C7IE;                   /* PECISNC.14: Interrupt Sub Node Enable Control Bit of PEC Channel x It is recommended to clear an interrupt request flag (CxIR) before setting the respective enable flag (CxIE). Otherwise, former requests still pending will immediately trigger an interrupt request after setting the enable bit. */
_sfrbit PECISNC_C7IR;                   /* PECISNC.15: Interrupt Sub Node Request Flag of PEC Channel x */

_sfr PECXISNC;                          /* PEC Interrupt Sub Node Control */
_sfrbit PECXISNC_C8IE;                  /* PECXISNC.0: Interrupt Sub Node Enable Control Bit of PEC Channel x It is recommended to clear an interrupt request flag (CxIR) before setting the respective enable flag (CxIE). Otherwise, former requests still pending will immediately trigger an interrupt request after setting the enable bit. */
_sfrbit PECXISNC_C8IR;                  /* PECXISNC.1: Interrupt Sub Node Request Flag of PEC Channel x */
_sfrbit PECXISNC_C9IE;                  /* PECXISNC.2: Interrupt Sub Node Enable Control Bit of PEC Channel x It is recommended to clear an interrupt request flag (CxIR) before setting the respective enable flag (CxIE). Otherwise, former requests still pending will immediately trigger an interrupt request after setting the enable bit. */
_sfrbit PECXISNC_C9IR;                  /* PECXISNC.3: Interrupt Sub Node Request Flag of PEC Channel x */
_sfrbit PECXISNC_C10IE;                 /* PECXISNC.4: Interrupt Sub Node Enable Control Bit of PEC Channel x It is recommended to clear an interrupt request flag (CxIR) before setting the respective enable flag (CxIE). Otherwise, former requests still pending will immediately trigger an interrupt request after setting the enable bit. */
_sfrbit PECXISNC_C10IR;                 /* PECXISNC.5: Interrupt Sub Node Request Flag of PEC Channel x */
_sfrbit PECXISNC_C11IE;                 /* PECXISNC.6: Interrupt Sub Node Enable Control Bit of PEC Channel x It is recommended to clear an interrupt request flag (CxIR) before setting the respective enable flag (CxIE). Otherwise, former requests still pending will immediately trigger an interrupt request after setting the enable bit. */
_sfrbit PECXISNC_C11IR;                 /* PECXISNC.7: Interrupt Sub Node Request Flag of PEC Channel x */
_sfrbit PECXISNC_C12IE;                 /* PECXISNC.8: Interrupt Sub Node Enable Control Bit of PEC Channel x It is recommended to clear an interrupt request flag (CxIR) before setting the respective enable flag (CxIE). Otherwise, former requests still pending will immediately trigger an interrupt request after setting the enable bit. */
_sfrbit PECXISNC_C12IR;                 /* PECXISNC.9: Interrupt Sub Node Request Flag of PEC Channel x */
_sfrbit PECXISNC_C13IE;                 /* PECXISNC.10: Interrupt Sub Node Enable Control Bit of PEC Channel x It is recommended to clear an interrupt request flag (CxIR) before setting the respective enable flag (CxIE). Otherwise, former requests still pending will immediately trigger an interrupt request after setting the enable bit. */
_sfrbit PECXISNC_C13IR;                 /* PECXISNC.11: Interrupt Sub Node Request Flag of PEC Channel x */
_sfrbit PECXISNC_C14IE;                 /* PECXISNC.12: Interrupt Sub Node Enable Control Bit of PEC Channel x It is recommended to clear an interrupt request flag (CxIR) before setting the respective enable flag (CxIE). Otherwise, former requests still pending will immediately trigger an interrupt request after setting the enable bit. */
_sfrbit PECXISNC_C14IR;                 /* PECXISNC.13: Interrupt Sub Node Request Flag of PEC Channel x */
_sfrbit PECXISNC_C15IE;                 /* PECXISNC.14: Interrupt Sub Node Enable Control Bit of PEC Channel x It is recommended to clear an interrupt request flag (CxIR) before setting the respective enable flag (CxIE). Otherwise, former requests still pending will immediately trigger an interrupt request after setting the enable bit. */
_sfrbit PECXISNC_C15IR;                 /* PECXISNC.15: Interrupt Sub Node Request Flag of PEC Channel x */

_sfr SCU_ISSR;                          /* Interrupt Source Select Register */
_sfrbit SCU_ISSR_ISS0;                  /* SCU_ISSR.0: Interrupt Source Select for CC2_CC16IC */
_sfrbit SCU_ISSR_ISS1;                  /* SCU_ISSR.1: Interrupt Source Select for CC2_CC17IC */
_sfrbit SCU_ISSR_ISS2;                  /* SCU_ISSR.2: Interrupt Source Select for CC2_CC18IC */
_sfrbit SCU_ISSR_ISS3;                  /* SCU_ISSR.3: Interrupt Source Select for CC2_CC19IC */
_sfrbit SCU_ISSR_ISS4;                  /* SCU_ISSR.4: Interrupt Source Select for CC2_CC20IC */
_sfrbit SCU_ISSR_ISS5;                  /* SCU_ISSR.5: Interrupt Source Select for CC2_CC21IC */
_sfrbit SCU_ISSR_ISS6;                  /* SCU_ISSR.6: Interrupt Source Select for CC2_CC22IC */
_sfrbit SCU_ISSR_ISS7;                  /* SCU_ISSR.7: Interrupt Source Select for CC2_CC23IC */
_sfrbit SCU_ISSR_ISS8;                  /* SCU_ISSR.8: Interrupt Source Select for CC2_CC24IC */
_sfrbit SCU_ISSR_ISS9;                  /* SCU_ISSR.9: Interrupt Source Select for CC2_CC25IC */
_sfrbit SCU_ISSR_ISS10;                 /* SCU_ISSR.10: Interrupt Source Select for CC2_CC26IC */
_sfrbit SCU_ISSR_ISS11;                 /* SCU_ISSR.11: Interrupt Source Select for CC2_CC27IC */
_sfrbit SCU_ISSR_ISS12;                 /* SCU_ISSR.12: Interrupt Source Select for CC2_CC28IC */
_sfrbit SCU_ISSR_ISS13;                 /* SCU_ISSR.13: Interrupt Source Select for CC2_CC29IC */
_sfrbit SCU_ISSR_ISS14;                 /* SCU_ISSR.14: Interrupt Source Select for CC2_CC30IC */
_sfrbit SCU_ISSR_ISS15;                 /* SCU_ISSR.15: Interrupt Source Select for CC2_CC31IC */

_sfr ADC_0IC;                           /* ADC Interrupt Control 0 */
_sfrbit ADC_0IC_IE;                     /* ADC_0IC.6: Interrupt Enable Control Bit */
_sfrbit ADC_0IC_IR;                     /* ADC_0IC.7: Interrupt Request Flag */
_sfrbit ADC_0IC_GPX;                    /* ADC_0IC.8: Group Priority Extension */

_sfr ADC_1IC;                           /* ADC Interrupt Control 1 */
_sfrbit ADC_1IC_IE;                     /* ADC_1IC.6: Interrupt Enable Control Bit */
_sfrbit ADC_1IC_IR;                     /* ADC_1IC.7: Interrupt Request Flag */
_sfrbit ADC_1IC_GPX;                    /* ADC_1IC.8: Group Priority Extension */

_sfr ADC_2IC;                           /* ADC Interrupt Control 2 */
_sfrbit ADC_2IC_IE;                     /* ADC_2IC.6: Interrupt Enable Control Bit */
_sfrbit ADC_2IC_IR;                     /* ADC_2IC.7: Interrupt Request Flag */
_sfrbit ADC_2IC_GPX;                    /* ADC_2IC.8: Group Priority Extension */

_sfr ADC_3IC;                           /* ADC Interrupt Control 3 */
_sfrbit ADC_3IC_IE;                     /* ADC_3IC.6: Interrupt Enable Control Bit */
_sfrbit ADC_3IC_IR;                     /* ADC_3IC.7: Interrupt Request Flag */
_sfrbit ADC_3IC_GPX;                    /* ADC_3IC.8: Group Priority Extension */

_sfr ADC_4IC;                           /* ADC Interrupt Control 4 */
_sfrbit ADC_4IC_IE;                     /* ADC_4IC.6: Interrupt Enable Control Bit */
_sfrbit ADC_4IC_IR;                     /* ADC_4IC.7: Interrupt Request Flag */
_sfrbit ADC_4IC_GPX;                    /* ADC_4IC.8: Group Priority Extension */

_sfr ADC_5IC;                           /* ADC Interrupt Control 5 */
_sfrbit ADC_5IC_IE;                     /* ADC_5IC.6: Interrupt Enable Control Bit */
_sfrbit ADC_5IC_IR;                     /* ADC_5IC.7: Interrupt Request Flag */
_sfrbit ADC_5IC_GPX;                    /* ADC_5IC.8: Group Priority Extension */

_sfr ADC_6IC;                           /* ADC Interrupt Control 6 */
_sfrbit ADC_6IC_IE;                     /* ADC_6IC.6: Interrupt Enable Control Bit */
_sfrbit ADC_6IC_IR;                     /* ADC_6IC.7: Interrupt Request Flag */
_sfrbit ADC_6IC_GPX;                    /* ADC_6IC.8: Group Priority Extension */

_sfr ADC_7IC;                           /* ADC Interrupt Control 7 */
_sfrbit ADC_7IC_IE;                     /* ADC_7IC.6: Interrupt Enable Control Bit */
_sfrbit ADC_7IC_IR;                     /* ADC_7IC.7: Interrupt Request Flag */
_sfrbit ADC_7IC_GPX;                    /* ADC_7IC.8: Group Priority Extension */

_esfr CAN_0IC;                          /* CAN Interrupt Control 0 */
_esfrbit CAN_0IC_IE;                    /* CAN_0IC.6: Interrupt Enable Control Bit */
_esfrbit CAN_0IC_IR;                    /* CAN_0IC.7: Interrupt Request Flag */
_esfrbit CAN_0IC_GPX;                   /* CAN_0IC.8: Group Priority Extension */

_esfr CAN_1IC;                          /* CAN Interrupt Control 1 */
_esfrbit CAN_1IC_IE;                    /* CAN_1IC.6: Interrupt Enable Control Bit */
_esfrbit CAN_1IC_IR;                    /* CAN_1IC.7: Interrupt Request Flag */
_esfrbit CAN_1IC_GPX;                   /* CAN_1IC.8: Group Priority Extension */

_esfr CAN_2IC;                          /* CAN Interrupt Control 2 */
_esfrbit CAN_2IC_IE;                    /* CAN_2IC.6: Interrupt Enable Control Bit */
_esfrbit CAN_2IC_IR;                    /* CAN_2IC.7: Interrupt Request Flag */
_esfrbit CAN_2IC_GPX;                   /* CAN_2IC.8: Group Priority Extension */

_esfr CAN_3IC;                          /* CAN Interrupt Control 3 */
_esfrbit CAN_3IC_IE;                    /* CAN_3IC.6: Interrupt Enable Control Bit */
_esfrbit CAN_3IC_IR;                    /* CAN_3IC.7: Interrupt Request Flag */
_esfrbit CAN_3IC_GPX;                   /* CAN_3IC.8: Group Priority Extension */

_esfr CAN_4IC;                          /* CAN Interrupt Control 4 */
_esfrbit CAN_4IC_IE;                    /* CAN_4IC.6: Interrupt Enable Control Bit */
_esfrbit CAN_4IC_IR;                    /* CAN_4IC.7: Interrupt Request Flag */
_esfrbit CAN_4IC_GPX;                   /* CAN_4IC.8: Group Priority Extension */

_esfr CAN_5IC;                          /* CAN Interrupt Control 5 */
_esfrbit CAN_5IC_IE;                    /* CAN_5IC.6: Interrupt Enable Control Bit */
_esfrbit CAN_5IC_IR;                    /* CAN_5IC.7: Interrupt Request Flag */
_esfrbit CAN_5IC_GPX;                   /* CAN_5IC.8: Group Priority Extension */

_esfr CAN_6IC;                          /* CAN Interrupt Control 6 */
_esfrbit CAN_6IC_IE;                    /* CAN_6IC.6: Interrupt Enable Control Bit */
_esfrbit CAN_6IC_IR;                    /* CAN_6IC.7: Interrupt Request Flag */
_esfrbit CAN_6IC_GPX;                   /* CAN_6IC.8: Group Priority Extension */

_esfr CAN_7IC;                          /* CAN Interrupt Control 7 */
_esfrbit CAN_7IC_IE;                    /* CAN_7IC.6: Interrupt Enable Control Bit */
_esfrbit CAN_7IC_IR;                    /* CAN_7IC.7: Interrupt Request Flag */
_esfrbit CAN_7IC_GPX;                   /* CAN_7IC.8: Group Priority Extension */

_esfr CAN_8IC;                          /* CAN Interrupt Control 8 */
_esfrbit CAN_8IC_IE;                    /* CAN_8IC.6: Interrupt Enable Control Bit */
_esfrbit CAN_8IC_IR;                    /* CAN_8IC.7: Interrupt Request Flag */
_esfrbit CAN_8IC_GPX;                   /* CAN_8IC.8: Group Priority Extension */

_esfr CAN_9IC;                          /* CAN Interrupt Control 9 */
_esfrbit CAN_9IC_IE;                    /* CAN_9IC.6: Interrupt Enable Control Bit */
_esfrbit CAN_9IC_IR;                    /* CAN_9IC.7: Interrupt Request Flag */
_esfrbit CAN_9IC_GPX;                   /* CAN_9IC.8: Group Priority Extension */

_esfr CAN_10IC;                         /* CAN Interrupt Control 10 */
_esfrbit CAN_10IC_IE;                   /* CAN_10IC.6: Interrupt Enable Control Bit */
_esfrbit CAN_10IC_IR;                   /* CAN_10IC.7: Interrupt Request Flag */
_esfrbit CAN_10IC_GPX;                  /* CAN_10IC.8: Group Priority Extension */

_esfr CAN_11IC;                         /* CAN Interrupt Control 11 */
_esfrbit CAN_11IC_IE;                   /* CAN_11IC.6: Interrupt Enable Control Bit */
_esfrbit CAN_11IC_IR;                   /* CAN_11IC.7: Interrupt Request Flag */
_esfrbit CAN_11IC_GPX;                  /* CAN_11IC.8: Group Priority Extension */

_esfr CAN_12IC;                         /* CAN Interrupt Control 12 */
_esfrbit CAN_12IC_IE;                   /* CAN_12IC.6: Interrupt Enable Control Bit */
_esfrbit CAN_12IC_IR;                   /* CAN_12IC.7: Interrupt Request Flag */
_esfrbit CAN_12IC_GPX;                  /* CAN_12IC.8: Group Priority Extension */

_esfr CAN_13IC;                         /* CAN Interrupt Control 13 */
_esfrbit CAN_13IC_IE;                   /* CAN_13IC.6: Interrupt Enable Control Bit */
_esfrbit CAN_13IC_IR;                   /* CAN_13IC.7: Interrupt Request Flag */
_esfrbit CAN_13IC_GPX;                  /* CAN_13IC.8: Group Priority Extension */

_esfr CAN_14IC;                         /* CAN Interrupt Control 14 */
_esfrbit CAN_14IC_IE;                   /* CAN_14IC.6: Interrupt Enable Control Bit */
_esfrbit CAN_14IC_IR;                   /* CAN_14IC.7: Interrupt Request Flag */
_esfrbit CAN_14IC_GPX;                  /* CAN_14IC.8: Group Priority Extension */

_esfr CAN_15IC;                         /* CAN Interrupt Control 15 */
_esfrbit CAN_15IC_IE;                   /* CAN_15IC.6: Interrupt Enable Control Bit */
_esfrbit CAN_15IC_IR;                   /* CAN_15IC.7: Interrupt Request Flag */
_esfrbit CAN_15IC_GPX;                  /* CAN_15IC.8: Group Priority Extension */

_esfr FR_0IC;                           /* FlexRay Interrupt Control 0 */
_esfrbit FR_0IC_IE;                     /* FR_0IC.6: Interrupt Enable Control Bit */
_esfrbit FR_0IC_IR;                     /* FR_0IC.7: Interrupt Request Flag */
_esfrbit FR_0IC_GPX;                    /* FR_0IC.8: Group Priority Extension */

_esfr FR_1IC;                           /* FlexRay Interrupt Control 1 */
_esfrbit FR_1IC_IE;                     /* FR_1IC.6: Interrupt Enable Control Bit */
_esfrbit FR_1IC_IR;                     /* FR_1IC.7: Interrupt Request Flag */
_esfrbit FR_1IC_GPX;                    /* FR_1IC.8: Group Priority Extension */

_esfr FR_2IC;                           /* FlexRay Interrupt Control 2 */
_esfrbit FR_2IC_IE;                     /* FR_2IC.6: Interrupt Enable Control Bit */
_esfrbit FR_2IC_IR;                     /* FR_2IC.7: Interrupt Request Flag */
_esfrbit FR_2IC_GPX;                    /* FR_2IC.8: Group Priority Extension */

_esfr FR_3IC;                           /* FlexRay Interrupt Control 3 */
_esfrbit FR_3IC_IE;                     /* FR_3IC.6: Interrupt Enable Control Bit */
_esfrbit FR_3IC_IR;                     /* FR_3IC.7: Interrupt Request Flag */
_esfrbit FR_3IC_GPX;                    /* FR_3IC.8: Group Priority Extension */

_esfr FR_4IC;                           /* FlexRay Interrupt Control 4 */
_esfrbit FR_4IC_IE;                     /* FR_4IC.6: Interrupt Enable Control Bit */
_esfrbit FR_4IC_IR;                     /* FR_4IC.7: Interrupt Request Flag */
_esfrbit FR_4IC_GPX;                    /* FR_4IC.8: Group Priority Extension */

_sfr FR_5IC;                            /* FlexRay Interrupt Control 5 */
_sfrbit FR_5IC_IE;                      /* FR_5IC.6: Interrupt Enable Control Bit */
_sfrbit FR_5IC_IR;                      /* FR_5IC.7: Interrupt Request Flag */
_sfrbit FR_5IC_GPX;                     /* FR_5IC.8: Group Priority Extension */

_sfr FR_6IC;                            /* FlexRay Interrupt Control 6 */
_sfrbit FR_6IC_IE;                      /* FR_6IC.6: Interrupt Enable Control Bit */
_sfrbit FR_6IC_IR;                      /* FR_6IC.7: Interrupt Request Flag */
_sfrbit FR_6IC_GPX;                     /* FR_6IC.8: Group Priority Extension */

_sfr FR_7IC;                            /* FlexRay Interrupt Control 7 */
_sfrbit FR_7IC_IE;                      /* FR_7IC.6: Interrupt Enable Control Bit */
_sfrbit FR_7IC_IR;                      /* FR_7IC.7: Interrupt Request Flag */
_sfrbit FR_7IC_GPX;                     /* FR_7IC.8: Group Priority Extension */

_sfr FR_8IC;                            /* FlexRay Interrupt Control 8 */
_sfrbit FR_8IC_IE;                      /* FR_8IC.6: Interrupt Enable Control Bit */
_sfrbit FR_8IC_IR;                      /* FR_8IC.7: Interrupt Request Flag */
_sfrbit FR_8IC_GPX;                     /* FR_8IC.8: Group Priority Extension */

_sfr FR_9IC;                            /* FlexRay Interrupt Control 9 */
_sfrbit FR_9IC_IE;                      /* FR_9IC.6: Interrupt Enable Control Bit */
_sfrbit FR_9IC_IR;                      /* FR_9IC.7: Interrupt Request Flag */
_sfrbit FR_9IC_GPX;                     /* FR_9IC.8: Group Priority Extension */

_esfr U0C0_0IC;                         /* USIC0 Channel 0 IC 0 */
_esfrbit U0C0_0IC_IE;                   /* U0C0_0IC.6: Interrupt Enable Control Bit */
_esfrbit U0C0_0IC_IR;                   /* U0C0_0IC.7: Interrupt Request Flag */
_esfrbit U0C0_0IC_GPX;                  /* U0C0_0IC.8: Group Priority Extension */

_esfr U0C0_1IC;                         /* USIC0 Channel 0 IC 1 */
_esfrbit U0C0_1IC_IE;                   /* U0C0_1IC.6: Interrupt Enable Control Bit */
_esfrbit U0C0_1IC_IR;                   /* U0C0_1IC.7: Interrupt Request Flag */
_esfrbit U0C0_1IC_GPX;                  /* U0C0_1IC.8: Group Priority Extension */

_esfr U0C0_2IC;                         /* USIC0 Channel 0 IC 2 */
_esfrbit U0C0_2IC_IE;                   /* U0C0_2IC.6: Interrupt Enable Control Bit */
_esfrbit U0C0_2IC_IR;                   /* U0C0_2IC.7: Interrupt Request Flag */
_esfrbit U0C0_2IC_GPX;                  /* U0C0_2IC.8: Group Priority Extension */

_esfr U0C1_0IC;                         /* USIC0 Channel 1 IC 0 */
_esfrbit U0C1_0IC_IE;                   /* U0C1_0IC.6: Interrupt Enable Control Bit */
_esfrbit U0C1_0IC_IR;                   /* U0C1_0IC.7: Interrupt Request Flag */
_esfrbit U0C1_0IC_GPX;                  /* U0C1_0IC.8: Group Priority Extension */

_esfr U0C1_1IC;                         /* USIC0 Channel 1 IC 1 */
_esfrbit U0C1_1IC_IE;                   /* U0C1_1IC.6: Interrupt Enable Control Bit */
_esfrbit U0C1_1IC_IR;                   /* U0C1_1IC.7: Interrupt Request Flag */
_esfrbit U0C1_1IC_GPX;                  /* U0C1_1IC.8: Group Priority Extension */

_esfr U0C1_2IC;                         /* USIC0 Channel 1 IC 2 */
_esfrbit U0C1_2IC_IE;                   /* U0C1_2IC.6: Interrupt Enable Control Bit */
_esfrbit U0C1_2IC_IR;                   /* U0C1_2IC.7: Interrupt Request Flag */
_esfrbit U0C1_2IC_GPX;                  /* U0C1_2IC.8: Group Priority Extension */

_esfr U1C0_0IC;                         /* USIC1 Channel 0 IC 0 */
_esfrbit U1C0_0IC_IE;                   /* U1C0_0IC.6: Interrupt Enable Control Bit */
_esfrbit U1C0_0IC_IR;                   /* U1C0_0IC.7: Interrupt Request Flag */
_esfrbit U1C0_0IC_GPX;                  /* U1C0_0IC.8: Group Priority Extension */

_esfr U1C0_1IC;                         /* USIC1 Channel 0 IC 1 */
_esfrbit U1C0_1IC_IE;                   /* U1C0_1IC.6: Interrupt Enable Control Bit */
_esfrbit U1C0_1IC_IR;                   /* U1C0_1IC.7: Interrupt Request Flag */
_esfrbit U1C0_1IC_GPX;                  /* U1C0_1IC.8: Group Priority Extension */

_esfr U1C0_2IC;                         /* USIC1 Channel 0 IC 2 */
_esfrbit U1C0_2IC_IE;                   /* U1C0_2IC.6: Interrupt Enable Control Bit */
_esfrbit U1C0_2IC_IR;                   /* U1C0_2IC.7: Interrupt Request Flag */
_esfrbit U1C0_2IC_GPX;                  /* U1C0_2IC.8: Group Priority Extension */

_esfr U1C1_0IC;                         /* USIC1 Channel 1 IC 0 */
_esfrbit U1C1_0IC_IE;                   /* U1C1_0IC.6: Interrupt Enable Control Bit */
_esfrbit U1C1_0IC_IR;                   /* U1C1_0IC.7: Interrupt Request Flag */
_esfrbit U1C1_0IC_GPX;                  /* U1C1_0IC.8: Group Priority Extension */

_esfr U1C1_1IC;                         /* USIC1 Channel 1 IC 1 */
_esfrbit U1C1_1IC_IE;                   /* U1C1_1IC.6: Interrupt Enable Control Bit */
_esfrbit U1C1_1IC_IR;                   /* U1C1_1IC.7: Interrupt Request Flag */
_esfrbit U1C1_1IC_GPX;                  /* U1C1_1IC.8: Group Priority Extension */

_esfr U1C1_2IC;                         /* USIC1 Channel 1 IC 2 */
_esfrbit U1C1_2IC_IE;                   /* U1C1_2IC.6: Interrupt Enable Control Bit */
_esfrbit U1C1_2IC_IR;                   /* U1C1_2IC.7: Interrupt Request Flag */
_esfrbit U1C1_2IC_GPX;                  /* U1C1_2IC.8: Group Priority Extension */

_esfr U2C0_0IC;                         /* USIC2 Channel 0 IC 0 */
_esfrbit U2C0_0IC_IE;                   /* U2C0_0IC.6: Interrupt Enable Control Bit */
_esfrbit U2C0_0IC_IR;                   /* U2C0_0IC.7: Interrupt Request Flag */
_esfrbit U2C0_0IC_GPX;                  /* U2C0_0IC.8: Group Priority Extension */

_esfr U2C0_1IC;                         /* USIC2 Channel 0 IC 1 */
_esfrbit U2C0_1IC_IE;                   /* U2C0_1IC.6: Interrupt Enable Control Bit */
_esfrbit U2C0_1IC_IR;                   /* U2C0_1IC.7: Interrupt Request Flag */
_esfrbit U2C0_1IC_GPX;                  /* U2C0_1IC.8: Group Priority Extension */

_esfr U2C0_2IC;                         /* USIC2 Channel 0 IC 2 */
_esfrbit U2C0_2IC_IE;                   /* U2C0_2IC.6: Interrupt Enable Control Bit */
_esfrbit U2C0_2IC_IR;                   /* U2C0_2IC.7: Interrupt Request Flag */
_esfrbit U2C0_2IC_GPX;                  /* U2C0_2IC.8: Group Priority Extension */

_esfr U2C1_0IC;                         /* USIC2 Channel 1 IC 0 */
_esfrbit U2C1_0IC_IE;                   /* U2C1_0IC.6: Interrupt Enable Control Bit */
_esfrbit U2C1_0IC_IR;                   /* U2C1_0IC.7: Interrupt Request Flag */
_esfrbit U2C1_0IC_GPX;                  /* U2C1_0IC.8: Group Priority Extension */

_esfr U2C1_1IC;                         /* USIC2 Channel 1 IC 1 */
_esfrbit U2C1_1IC_IE;                   /* U2C1_1IC.6: Interrupt Enable Control Bit */
_esfrbit U2C1_1IC_IR;                   /* U2C1_1IC.7: Interrupt Request Flag */
_esfrbit U2C1_1IC_GPX;                  /* U2C1_1IC.8: Group Priority Extension */

_esfr U2C1_2IC;                         /* USIC2 Channel 1 IC 2 */
_esfrbit U2C1_2IC_IE;                   /* U2C1_2IC.6: Interrupt Enable Control Bit */
_esfrbit U2C1_2IC_IR;                   /* U2C1_2IC.7: Interrupt Request Flag */
_esfrbit U2C1_2IC_GPX;                  /* U2C1_2IC.8: Group Priority Extension */

_esfr U3C0_0IC;                         /* USIC3 Channel 0 IC 0 */
_esfrbit U3C0_0IC_IE;                   /* U3C0_0IC.6: Interrupt Enable Control Bit */
_esfrbit U3C0_0IC_IR;                   /* U3C0_0IC.7: Interrupt Request Flag */
_esfrbit U3C0_0IC_GPX;                  /* U3C0_0IC.8: Group Priority Extension */

_esfr U3C0_1IC;                         /* USIC3 Channel 0 IC 1 */
_esfrbit U3C0_1IC_IE;                   /* U3C0_1IC.6: Interrupt Enable Control Bit */
_esfrbit U3C0_1IC_IR;                   /* U3C0_1IC.7: Interrupt Request Flag */
_esfrbit U3C0_1IC_GPX;                  /* U3C0_1IC.8: Group Priority Extension */

_esfr U3C0_2IC;                         /* USIC3 Channel 0 IC 2 */
_esfrbit U3C0_2IC_IE;                   /* U3C0_2IC.6: Interrupt Enable Control Bit */
_esfrbit U3C0_2IC_IR;                   /* U3C0_2IC.7: Interrupt Request Flag */
_esfrbit U3C0_2IC_GPX;                  /* U3C0_2IC.8: Group Priority Extension */

_esfr U3C1_0IC;                         /* USIC3 Channel 1 IC 0 */
_esfrbit U3C1_0IC_IE;                   /* U3C1_0IC.6: Interrupt Enable Control Bit */
_esfrbit U3C1_0IC_IR;                   /* U3C1_0IC.7: Interrupt Request Flag */
_esfrbit U3C1_0IC_GPX;                  /* U3C1_0IC.8: Group Priority Extension */

_esfr U3C1_1IC;                         /* USIC3 Channel 1 IC 1 */
_esfrbit U3C1_1IC_IE;                   /* U3C1_1IC.6: Interrupt Enable Control Bit */
_esfrbit U3C1_1IC_IR;                   /* U3C1_1IC.7: Interrupt Request Flag */
_esfrbit U3C1_1IC_GPX;                  /* U3C1_1IC.8: Group Priority Extension */

_esfr U3C1_2IC;                         /* USIC3 Channel 1 IC 2 */
_esfrbit U3C1_2IC_IE;                   /* U3C1_2IC.6: Interrupt Enable Control Bit */
_esfrbit U3C1_2IC_IR;                   /* U3C1_2IC.7: Interrupt Request Flag */
_esfrbit U3C1_2IC_GPX;                  /* U3C1_2IC.8: Group Priority Extension */

_esfr U4C0_0IC;                         /* USIC4 Channel 0 IC 0 */
_esfrbit U4C0_0IC_IE;                   /* U4C0_0IC.6: Interrupt Enable Control Bit */
_esfrbit U4C0_0IC_IR;                   /* U4C0_0IC.7: Interrupt Request Flag */
_esfrbit U4C0_0IC_GPX;                  /* U4C0_0IC.8: Group Priority Extension */

_esfr U4C0_1IC;                         /* USIC4 Channel 0 IC 1 */
_esfrbit U4C0_1IC_IE;                   /* U4C0_1IC.6: Interrupt Enable Control Bit */
_esfrbit U4C0_1IC_IR;                   /* U4C0_1IC.7: Interrupt Request Flag */
_esfrbit U4C0_1IC_GPX;                  /* U4C0_1IC.8: Group Priority Extension */

_esfr U4C0_2IC;                         /* USIC4 Channel 0 IC 2 */
_esfrbit U4C0_2IC_IE;                   /* U4C0_2IC.6: Interrupt Enable Control Bit */
_esfrbit U4C0_2IC_IR;                   /* U4C0_2IC.7: Interrupt Request Flag */
_esfrbit U4C0_2IC_GPX;                  /* U4C0_2IC.8: Group Priority Extension */

_esfr U4C1_0IC;                         /* USIC4 Channel 1 IC 0 */
_esfrbit U4C1_0IC_IE;                   /* U4C1_0IC.6: Interrupt Enable Control Bit */
_esfrbit U4C1_0IC_IR;                   /* U4C1_0IC.7: Interrupt Request Flag */
_esfrbit U4C1_0IC_GPX;                  /* U4C1_0IC.8: Group Priority Extension */

_esfr U4C1_1IC;                         /* USIC4 Channel 1 IC 1 */
_esfrbit U4C1_1IC_IE;                   /* U4C1_1IC.6: Interrupt Enable Control Bit */
_esfrbit U4C1_1IC_IR;                   /* U4C1_1IC.7: Interrupt Request Flag */
_esfrbit U4C1_1IC_GPX;                  /* U4C1_1IC.8: Group Priority Extension */

_esfr U4C1_2IC;                         /* USIC4 Channel 1 IC 2 */
_esfrbit U4C1_2IC_IE;                   /* U4C1_2IC.6: Interrupt Enable Control Bit */
_esfrbit U4C1_2IC_IR;                   /* U4C1_2IC.7: Interrupt Request Flag */
_esfrbit U4C1_2IC_GPX;                  /* U4C1_2IC.8: Group Priority Extension */

_esfr CCU60_0IC;                        /* CCU60 Interrupt Control 0 */
_esfrbit CCU60_0IC_IE;                  /* CCU60_0IC.6: Interrupt Enable Control Bit */
_esfrbit CCU60_0IC_IR;                  /* CCU60_0IC.7: Interrupt Request Flag */
_esfrbit CCU60_0IC_GPX;                 /* CCU60_0IC.8: Group Priority Extension */

_esfr CCU60_1IC;                        /* CCU60 Interrupt Control 1 */
_esfrbit CCU60_1IC_IE;                  /* CCU60_1IC.6: Interrupt Enable Control Bit */
_esfrbit CCU60_1IC_IR;                  /* CCU60_1IC.7: Interrupt Request Flag */
_esfrbit CCU60_1IC_GPX;                 /* CCU60_1IC.8: Group Priority Extension */

_esfr CCU60_2IC;                        /* CCU60 Interrupt Control 2 */
_esfrbit CCU60_2IC_IE;                  /* CCU60_2IC.6: Interrupt Enable Control Bit */
_esfrbit CCU60_2IC_IR;                  /* CCU60_2IC.7: Interrupt Request Flag */
_esfrbit CCU60_2IC_GPX;                 /* CCU60_2IC.8: Group Priority Extension */

_esfr CCU60_3IC;                        /* CCU60 Interrupt Control 3 */
_esfrbit CCU60_3IC_IE;                  /* CCU60_3IC.6: Interrupt Enable Control Bit */
_esfrbit CCU60_3IC_IR;                  /* CCU60_3IC.7: Interrupt Request Flag */
_esfrbit CCU60_3IC_GPX;                 /* CCU60_3IC.8: Group Priority Extension */

_esfr CCU61_0IC;                        /* CCU61 Interrupt Control 0 */
_esfrbit CCU61_0IC_IE;                  /* CCU61_0IC.6: Interrupt Enable Control Bit */
_esfrbit CCU61_0IC_IR;                  /* CCU61_0IC.7: Interrupt Request Flag */
_esfrbit CCU61_0IC_GPX;                 /* CCU61_0IC.8: Group Priority Extension */

_esfr CCU61_1IC;                        /* CCU61 Interrupt Control 1 */
_esfrbit CCU61_1IC_IE;                  /* CCU61_1IC.6: Interrupt Enable Control Bit */
_esfrbit CCU61_1IC_IR;                  /* CCU61_1IC.7: Interrupt Request Flag */
_esfrbit CCU61_1IC_GPX;                 /* CCU61_1IC.8: Group Priority Extension */

_esfr CCU61_2IC;                        /* CCU61 Interrupt Control 2 */
_esfrbit CCU61_2IC_IE;                  /* CCU61_2IC.6: Interrupt Enable Control Bit */
_esfrbit CCU61_2IC_IR;                  /* CCU61_2IC.7: Interrupt Request Flag */
_esfrbit CCU61_2IC_GPX;                 /* CCU61_2IC.8: Group Priority Extension */

_esfr CCU61_3IC;                        /* CCU61 Interrupt Control 3 */
_esfrbit CCU61_3IC_IE;                  /* CCU61_3IC.6: Interrupt Enable Control Bit */
_esfrbit CCU61_3IC_IR;                  /* CCU61_3IC.7: Interrupt Request Flag */
_esfrbit CCU61_3IC_GPX;                 /* CCU61_3IC.8: Group Priority Extension */

_esfr CCU62_0IC;                        /* CCU62 Interrupt Control 0 */
_esfrbit CCU62_0IC_IE;                  /* CCU62_0IC.6: Interrupt Enable Control Bit */
_esfrbit CCU62_0IC_IR;                  /* CCU62_0IC.7: Interrupt Request Flag */
_esfrbit CCU62_0IC_GPX;                 /* CCU62_0IC.8: Group Priority Extension */

_esfr CCU62_1IC;                        /* CCU62 Interrupt Control 1 */
_esfrbit CCU62_1IC_IE;                  /* CCU62_1IC.6: Interrupt Enable Control Bit */
_esfrbit CCU62_1IC_IR;                  /* CCU62_1IC.7: Interrupt Request Flag */
_esfrbit CCU62_1IC_GPX;                 /* CCU62_1IC.8: Group Priority Extension */

_esfr CCU62_2IC;                        /* CCU62 Interrupt Control 2 */
_esfrbit CCU62_2IC_IE;                  /* CCU62_2IC.6: Interrupt Enable Control Bit */
_esfrbit CCU62_2IC_IR;                  /* CCU62_2IC.7: Interrupt Request Flag */
_esfrbit CCU62_2IC_GPX;                 /* CCU62_2IC.8: Group Priority Extension */

_esfr CCU62_3IC;                        /* CCU62 Interrupt Control 3 */
_esfrbit CCU62_3IC_IE;                  /* CCU62_3IC.6: Interrupt Enable Control Bit */
_esfrbit CCU62_3IC_IR;                  /* CCU62_3IC.7: Interrupt Request Flag */
_esfrbit CCU62_3IC_GPX;                 /* CCU62_3IC.8: Group Priority Extension */

_esfr CCU63_0IC;                        /* CCU63 Interrupt Control 0 */
_esfrbit CCU63_0IC_IE;                  /* CCU63_0IC.6: Interrupt Enable Control Bit */
_esfrbit CCU63_0IC_IR;                  /* CCU63_0IC.7: Interrupt Request Flag */
_esfrbit CCU63_0IC_GPX;                 /* CCU63_0IC.8: Group Priority Extension */

_esfr CCU63_1IC;                        /* CCU63 Interrupt Control 1 */
_esfrbit CCU63_1IC_IE;                  /* CCU63_1IC.6: Interrupt Enable Control Bit */
_esfrbit CCU63_1IC_IR;                  /* CCU63_1IC.7: Interrupt Request Flag */
_esfrbit CCU63_1IC_GPX;                 /* CCU63_1IC.8: Group Priority Extension */

_esfr CCU63_2IC;                        /* CCU63 Interrupt Control 2 */
_esfrbit CCU63_2IC_IE;                  /* CCU63_2IC.6: Interrupt Enable Control Bit */
_esfrbit CCU63_2IC_IR;                  /* CCU63_2IC.7: Interrupt Request Flag */
_esfrbit CCU63_2IC_GPX;                 /* CCU63_2IC.8: Group Priority Extension */

_esfr CCU63_3IC;                        /* CCU63 Interrupt Control 3 */
_esfrbit CCU63_3IC_IE;                  /* CCU63_3IC.6: Interrupt Enable Control Bit */
_esfrbit CCU63_3IC_IR;                  /* CCU63_3IC.7: Interrupt Request Flag */
_esfrbit CCU63_3IC_GPX;                 /* CCU63_3IC.8: Group Priority Extension */

_sfr GPT12E_T2IC;                       /* GPT12 TIMER 2 IC */
_sfrbit GPT12E_T2IC_IE;                 /* GPT12E_T2IC.6: <GPT12E_T2IC_IE> */
_sfrbit GPT12E_T2IC_IR;                 /* GPT12E_T2IC.7: <GPT12E_T2IC_IR> */
_sfrbit GPT12E_T2IC_GPX;                /* GPT12E_T2IC.8: <GPT12E_T2IC_GPX> */

#define T2IC            GPT12E_T2IC

_sfr GPT12E_T3IC;                       /* GPT12 TIMER 3 IC */
_sfrbit GPT12E_T3IC_IE;                 /* GPT12E_T3IC.6: <GPT12E_T3IC_IE> */
_sfrbit GPT12E_T3IC_IR;                 /* GPT12E_T3IC.7: <GPT12E_T3IC_IR> */
_sfrbit GPT12E_T3IC_GPX;                /* GPT12E_T3IC.8: <GPT12E_T3IC_GPX> */

#define T3IC            GPT12E_T3IC

_sfr GPT12E_T4IC;                       /* GPT12 TIMER 4 IC */
_sfrbit GPT12E_T4IC_IE;                 /* GPT12E_T4IC.6: <GPT12E_T4IC_IE> */
_sfrbit GPT12E_T4IC_IR;                 /* GPT12E_T4IC.7: <GPT12E_T4IC_IR> */
_sfrbit GPT12E_T4IC_GPX;                /* GPT12E_T4IC.8: <GPT12E_T4IC_GPX> */

#define T4IC            GPT12E_T4IC

_sfr GPT12E_T5IC;                       /* GPT12 TIMER 5 IC */
_sfrbit GPT12E_T5IC_IE;                 /* GPT12E_T5IC.6: <GPT12E_T5IC_IE> */
_sfrbit GPT12E_T5IC_IR;                 /* GPT12E_T5IC.7: <GPT12E_T5IC_IR> */
_sfrbit GPT12E_T5IC_GPX;                /* GPT12E_T5IC.8: <GPT12E_T5IC_GPX> */

#define T5IC            GPT12E_T5IC

_sfr GPT12E_T6IC;                       /* GPT12 TIMER 6 IC */
_sfrbit GPT12E_T6IC_IE;                 /* GPT12E_T6IC.6: <GPT12E_T6IC_IE> */
_sfrbit GPT12E_T6IC_IR;                 /* GPT12E_T6IC.7: <GPT12E_T6IC_IR> */
_sfrbit GPT12E_T6IC_GPX;                /* GPT12E_T6IC.8: <GPT12E_T6IC_GPX> */

#define T6IC            GPT12E_T6IC

_sfr GPT12E_CRIC;                       /* GPT12 CAPREL IC */
_sfrbit GPT12E_CRIC_IE;                 /* GPT12E_CRIC.6: <GPT12E_CRIC_IE> */
_sfrbit GPT12E_CRIC_IR;                 /* GPT12E_CRIC.7: <GPT12E_CRIC_IR> */
_sfrbit GPT12E_CRIC_GPX;                /* GPT12E_CRIC.8: <GPT12E_CRIC_GPX> */

#define CRIC            GPT12E_CRIC

_sfr CC2_T7IC;                          /* CAPCOM TIMER 7 IC */
_sfrbit CC2_T7IC_IE;                    /* CC2_T7IC.6: <CC2_T7IC_IE> */
_sfrbit CC2_T7IC_IR;                    /* CC2_T7IC.7: <CC2_T7IC_IR> */
_sfrbit CC2_T7IC_GPX;                   /* CC2_T7IC.8: <CC2_T7IC_GPX> */

#define T7IC            CC2_T7IC

_sfr CC2_T8IC;                          /* CAPCOM TIMER 8 IC */
_sfrbit CC2_T8IC_IE;                    /* CC2_T8IC.6: <CC2_T8IC_IE> */
_sfrbit CC2_T8IC_IR;                    /* CC2_T8IC.7: <CC2_T8IC_IR> */
_sfrbit CC2_T8IC_GPX;                   /* CC2_T8IC.8: <CC2_T8IC_GPX> */

#define T8IC            CC2_T8IC

_esfr CC2_CC16IC;                       /* CAPCOM Interrupt Control 16 */
_esfrbit CC2_CC16IC_IE;                 /* CC2_CC16IC.6: Interrupt Enable Control Bit */
_esfrbit CC2_CC16IC_IR;                 /* CC2_CC16IC.7: Interrupt Request Flag */
_esfrbit CC2_CC16IC_GPX;                /* CC2_CC16IC.8: Group Priority Extension */

_esfr CC2_CC17IC;                       /* CAPCOM Interrupt Control 17 */
_esfrbit CC2_CC17IC_IE;                 /* CC2_CC17IC.6: Interrupt Enable Control Bit */
_esfrbit CC2_CC17IC_IR;                 /* CC2_CC17IC.7: Interrupt Request Flag */
_esfrbit CC2_CC17IC_GPX;                /* CC2_CC17IC.8: Group Priority Extension */

_esfr CC2_CC18IC;                       /* CAPCOM Interrupt Control 18 */
_esfrbit CC2_CC18IC_IE;                 /* CC2_CC18IC.6: Interrupt Enable Control Bit */
_esfrbit CC2_CC18IC_IR;                 /* CC2_CC18IC.7: Interrupt Request Flag */
_esfrbit CC2_CC18IC_GPX;                /* CC2_CC18IC.8: Group Priority Extension */

_esfr CC2_CC19IC;                       /* CAPCOM Interrupt Control 19 */
_esfrbit CC2_CC19IC_IE;                 /* CC2_CC19IC.6: Interrupt Enable Control Bit */
_esfrbit CC2_CC19IC_IR;                 /* CC2_CC19IC.7: Interrupt Request Flag */
_esfrbit CC2_CC19IC_GPX;                /* CC2_CC19IC.8: Group Priority Extension */

_esfr CC2_CC20IC;                       /* CAPCOM Interrupt Control 20 */
_esfrbit CC2_CC20IC_IE;                 /* CC2_CC20IC.6: Interrupt Enable Control Bit */
_esfrbit CC2_CC20IC_IR;                 /* CC2_CC20IC.7: Interrupt Request Flag */
_esfrbit CC2_CC20IC_GPX;                /* CC2_CC20IC.8: Group Priority Extension */

_esfr CC2_CC21IC;                       /* CAPCOM Interrupt Control 21 */
_esfrbit CC2_CC21IC_IE;                 /* CC2_CC21IC.6: Interrupt Enable Control Bit */
_esfrbit CC2_CC21IC_IR;                 /* CC2_CC21IC.7: Interrupt Request Flag */
_esfrbit CC2_CC21IC_GPX;                /* CC2_CC21IC.8: Group Priority Extension */

_esfr CC2_CC22IC;                       /* CAPCOM Interrupt Control 22 */
_esfrbit CC2_CC22IC_IE;                 /* CC2_CC22IC.6: Interrupt Enable Control Bit */
_esfrbit CC2_CC22IC_IR;                 /* CC2_CC22IC.7: Interrupt Request Flag */
_esfrbit CC2_CC22IC_GPX;                /* CC2_CC22IC.8: Group Priority Extension */

_esfr CC2_CC23IC;                       /* CAPCOM Interrupt Control 23 */
_esfrbit CC2_CC23IC_IE;                 /* CC2_CC23IC.6: Interrupt Enable Control Bit */
_esfrbit CC2_CC23IC_IR;                 /* CC2_CC23IC.7: Interrupt Request Flag */
_esfrbit CC2_CC23IC_GPX;                /* CC2_CC23IC.8: Group Priority Extension */

_esfr CC2_CC24IC;                       /* CAPCOM Interrupt Control 24 */
_esfrbit CC2_CC24IC_IE;                 /* CC2_CC24IC.6: Interrupt Enable Control Bit */
_esfrbit CC2_CC24IC_IR;                 /* CC2_CC24IC.7: Interrupt Request Flag */
_esfrbit CC2_CC24IC_GPX;                /* CC2_CC24IC.8: Group Priority Extension */

_esfr CC2_CC25IC;                       /* CAPCOM Interrupt Control 25 */
_esfrbit CC2_CC25IC_IE;                 /* CC2_CC25IC.6: Interrupt Enable Control Bit */
_esfrbit CC2_CC25IC_IR;                 /* CC2_CC25IC.7: Interrupt Request Flag */
_esfrbit CC2_CC25IC_GPX;                /* CC2_CC25IC.8: Group Priority Extension */

_esfr CC2_CC26IC;                       /* CAPCOM Interrupt Control 26 */
_esfrbit CC2_CC26IC_IE;                 /* CC2_CC26IC.6: Interrupt Enable Control Bit */
_esfrbit CC2_CC26IC_IR;                 /* CC2_CC26IC.7: Interrupt Request Flag */
_esfrbit CC2_CC26IC_GPX;                /* CC2_CC26IC.8: Group Priority Extension */

_esfr CC2_CC27IC;                       /* CAPCOM Interrupt Control 27 */
_esfrbit CC2_CC27IC_IE;                 /* CC2_CC27IC.6: Interrupt Enable Control Bit */
_esfrbit CC2_CC27IC_IR;                 /* CC2_CC27IC.7: Interrupt Request Flag */
_esfrbit CC2_CC27IC_GPX;                /* CC2_CC27IC.8: Group Priority Extension */

_esfr CC2_CC28IC;                       /* CAPCOM Interrupt Control 28 */
_esfrbit CC2_CC28IC_IE;                 /* CC2_CC28IC.6: Interrupt Enable Control Bit */
_esfrbit CC2_CC28IC_IR;                 /* CC2_CC28IC.7: Interrupt Request Flag */
_esfrbit CC2_CC28IC_GPX;                /* CC2_CC28IC.8: Group Priority Extension */

_esfr CC2_CC29IC;                       /* CAPCOM Interrupt Control 29 */
_esfrbit CC2_CC29IC_IE;                 /* CC2_CC29IC.6: Interrupt Enable Control Bit */
_esfrbit CC2_CC29IC_IR;                 /* CC2_CC29IC.7: Interrupt Request Flag */
_esfrbit CC2_CC29IC_GPX;                /* CC2_CC29IC.8: Group Priority Extension */

_esfr CC2_CC30IC;                       /* CAPCOM Interrupt Control 30 */
_esfrbit CC2_CC30IC_IE;                 /* CC2_CC30IC.6: Interrupt Enable Control Bit */
_esfrbit CC2_CC30IC_IR;                 /* CC2_CC30IC.7: Interrupt Request Flag */
_esfrbit CC2_CC30IC_GPX;                /* CC2_CC30IC.8: Group Priority Extension */

_esfr CC2_CC31IC;                       /* CAPCOM Interrupt Control 31 */
_esfrbit CC2_CC31IC_IE;                 /* CC2_CC31IC.6: Interrupt Enable Control Bit */
_esfrbit CC2_CC31IC_IR;                 /* CC2_CC31IC.7: Interrupt Request Flag */
_esfrbit CC2_CC31IC_GPX;                /* CC2_CC31IC.8: Group Priority Extension */

_esfr RTC_IC;                           /* Real Time Clock IC */
_esfrbit RTC_IC_IE;                     /* RTC_IC.6: Interrupt Enable Control Bit */
_esfrbit RTC_IC_IR;                     /* RTC_IC.7: Interrupt Request Flag */
_esfrbit RTC_IC_GPX;                    /* RTC_IC.8: Group Priority Extension */

_esfr ERU_0IC;                          /* External Request Unit 0 IC */
_esfrbit ERU_0IC_IE;                    /* ERU_0IC.6: Interrupt Enable Control Bit */
_esfrbit ERU_0IC_IR;                    /* ERU_0IC.7: Interrupt Request Flag */
_esfrbit ERU_0IC_GPX;                   /* ERU_0IC.8: Group Priority Extension */

_esfr ERU_1IC;                          /* External Request Unit 2 IC */
_esfrbit ERU_1IC_IE;                    /* ERU_1IC.6: Interrupt Enable Control Bit */
_esfrbit ERU_1IC_IR;                    /* ERU_1IC.7: Interrupt Request Flag */
_esfrbit ERU_1IC_GPX;                   /* ERU_1IC.8: Group Priority Extension */

_esfr ERU_2IC;                          /* External Request Unit 2 IC */
_esfrbit ERU_2IC_IE;                    /* ERU_2IC.6: Interrupt Enable Control Bit */
_esfrbit ERU_2IC_IR;                    /* ERU_2IC.7: Interrupt Request Flag */
_esfrbit ERU_2IC_GPX;                   /* ERU_2IC.8: Group Priority Extension */

_esfr ERU_3IC;                          /* External Request Unit 3 IC */
_esfrbit ERU_3IC_IE;                    /* ERU_3IC.6: Interrupt Enable Control Bit */
_esfrbit ERU_3IC_IR;                    /* ERU_3IC.7: Interrupt Request Flag */
_esfrbit ERU_3IC_GPX;                   /* ERU_3IC.8: Group Priority Extension */

_esfr SCU_0IC;                          /* SCU Interrupt 0 IC */
_esfrbit SCU_0IC_IE;                    /* SCU_0IC.6: Interrupt Enable Control Bit */
_esfrbit SCU_0IC_IR;                    /* SCU_0IC.7: Interrupt Request Flag */
_esfrbit SCU_0IC_GPX;                   /* SCU_0IC.8: Group Priority Extension */

_esfr SCU_1IC;                          /* SCU Interrupt 1 IC */
_esfrbit SCU_1IC_IE;                    /* SCU_1IC.6: Interrupt Enable Control Bit */
_esfrbit SCU_1IC_IR;                    /* SCU_1IC.7: Interrupt Request Flag */
_esfrbit SCU_1IC_GPX;                   /* SCU_1IC.8: Group Priority Extension */

#endif /* REGXC2361E_NOINTERRUPT */

/********************************************************************************
 * MPU
********************************************************************************/
#ifndef REGXC2361E_NOMPU

_sfr MPU_PM0;                           /* Protection Mode Register 0 */
_sfrbit MPU_PM0_PROTEN;                 /* MPU_PM0.0: Protection Enable bit */
_sfrbit MPU_PM0_XEA;                    /* MPU_PM0.1: Execute Enable */
_sfrbit MPU_PM0_REA;                    /* MPU_PM0.2: Read Enable */
_sfrbit MPU_PM0_WEA;                    /* MPU_PM0.3: Write Enable */
_sfrbit MPU_PM0_L0EA;                   /* MPU_PM0.4: Level 0 Enable */
_sfrbit MPU_PM0_L1EA;                   /* MPU_PM0.5: Level 1 Enable */
_sfrbit MPU_PM0_L2EA;                   /* MPU_PM0.6: Level 2 Enable */
_sfrbit MPU_PM0_L3EA;                   /* MPU_PM0.7: Level 3 Enable */
_sfrbit MPU_PM0_XEB;                    /* MPU_PM0.9: Execute Enable */
_sfrbit MPU_PM0_REB;                    /* MPU_PM0.10: Read Enable */
_sfrbit MPU_PM0_WEB;                    /* MPU_PM0.11: Write Enable */
_sfrbit MPU_PM0_L0EB;                   /* MPU_PM0.12: Level 0 Enable */
_sfrbit MPU_PM0_L1EB;                   /* MPU_PM0.13: Level 1 Enable */
_sfrbit MPU_PM0_L2EB;                   /* MPU_PM0.14: Level 2 Enable */
_sfrbit MPU_PM0_L3EB;                   /* MPU_PM0.15: Level 3 Enable */

_sfr MPU_PM1;                           /* Protection Mode Register 1 */
_sfrbit MPU_PM1_XEA;                    /* MPU_PM1.1: Execute Enable */
_sfrbit MPU_PM1_REA;                    /* MPU_PM1.2: Read Enable */
_sfrbit MPU_PM1_WEA;                    /* MPU_PM1.3: Write Enable */
_sfrbit MPU_PM1_L0EA;                   /* MPU_PM1.4: Level 0 Enable */
_sfrbit MPU_PM1_L1EA;                   /* MPU_PM1.5: Level 1 Enable */
_sfrbit MPU_PM1_L2EA;                   /* MPU_PM1.6: Level 2 Enable */
_sfrbit MPU_PM1_L3EA;                   /* MPU_PM1.7: Level 3 Enable */
_sfrbit MPU_PM1_XEB;                    /* MPU_PM1.9: Execute Enable */
_sfrbit MPU_PM1_REB;                    /* MPU_PM1.10: Read Enable */
_sfrbit MPU_PM1_WEB;                    /* MPU_PM1.11: Write Enable */
_sfrbit MPU_PM1_L0EB;                   /* MPU_PM1.12: Level 0 Enable */
_sfrbit MPU_PM1_L1EB;                   /* MPU_PM1.13: Level 1 Enable */
_sfrbit MPU_PM1_L2EB;                   /* MPU_PM1.14: Level 2 Enable */
_sfrbit MPU_PM1_L3EB;                   /* MPU_PM1.15: Level 3 Enable */

_sfr MPU_PM2;                           /* Protection Mode Register 2 */
_sfrbit MPU_PM2_XEA;                    /* MPU_PM2.1: Execute Enable */
_sfrbit MPU_PM2_REA;                    /* MPU_PM2.2: Read Enable */
_sfrbit MPU_PM2_WEA;                    /* MPU_PM2.3: Write Enable */
_sfrbit MPU_PM2_L0EA;                   /* MPU_PM2.4: Level 0 Enable */
_sfrbit MPU_PM2_L1EA;                   /* MPU_PM2.5: Level 1 Enable */
_sfrbit MPU_PM2_L2EA;                   /* MPU_PM2.6: Level 2 Enable */
_sfrbit MPU_PM2_L3EA;                   /* MPU_PM2.7: Level 3 Enable */
_sfrbit MPU_PM2_XEB;                    /* MPU_PM2.9: Execute Enable */
_sfrbit MPU_PM2_REB;                    /* MPU_PM2.10: Read Enable */
_sfrbit MPU_PM2_WEB;                    /* MPU_PM2.11: Write Enable */
_sfrbit MPU_PM2_L0EB;                   /* MPU_PM2.12: Level 0 Enable */
_sfrbit MPU_PM2_L1EB;                   /* MPU_PM2.13: Level 1 Enable */
_sfrbit MPU_PM2_L2EB;                   /* MPU_PM2.14: Level 2 Enable */
_sfrbit MPU_PM2_L3EB;                   /* MPU_PM2.15: Level 3 Enable */

_sfr MPU_PM3;                           /* Protection Mode Register 3 */
_sfrbit MPU_PM3_XEA;                    /* MPU_PM3.1: Execute Enable */
_sfrbit MPU_PM3_REA;                    /* MPU_PM3.2: Read Enable */
_sfrbit MPU_PM3_WEA;                    /* MPU_PM3.3: Write Enable */
_sfrbit MPU_PM3_L0EA;                   /* MPU_PM3.4: Level 0 Enable */
_sfrbit MPU_PM3_L1EA;                   /* MPU_PM3.5: Level 1 Enable */
_sfrbit MPU_PM3_L2EA;                   /* MPU_PM3.6: Level 2 Enable */
_sfrbit MPU_PM3_L3EA;                   /* MPU_PM3.7: Level 3 Enable */
_sfrbit MPU_PM3_XEB;                    /* MPU_PM3.9: Execute Enable */
_sfrbit MPU_PM3_REB;                    /* MPU_PM3.10: Read Enable */
_sfrbit MPU_PM3_WEB;                    /* MPU_PM3.11: Write Enable */
_sfrbit MPU_PM3_L0EB;                   /* MPU_PM3.12: Level 0 Enable */
_sfrbit MPU_PM3_L1EB;                   /* MPU_PM3.13: Level 1 Enable */
_sfrbit MPU_PM3_L2EB;                   /* MPU_PM3.14: Level 2 Enable */
_sfrbit MPU_PM3_L3EB;                   /* MPU_PM3.15: Level 3 Enable */

_sfr MPU_PM4;                           /* Protection Mode Register 4 */
_sfrbit MPU_PM4_XEA;                    /* MPU_PM4.1: Execute Enable */
_sfrbit MPU_PM4_REA;                    /* MPU_PM4.2: Read Enable */
_sfrbit MPU_PM4_WEA;                    /* MPU_PM4.3: Write Enable */
_sfrbit MPU_PM4_L0EA;                   /* MPU_PM4.4: Level 0 Enable */
_sfrbit MPU_PM4_L1EA;                   /* MPU_PM4.5: Level 1 Enable */
_sfrbit MPU_PM4_L2EA;                   /* MPU_PM4.6: Level 2 Enable */
_sfrbit MPU_PM4_L3EA;                   /* MPU_PM4.7: Level 3 Enable */
_sfrbit MPU_PM4_XEB;                    /* MPU_PM4.9: Execute Enable */
_sfrbit MPU_PM4_REB;                    /* MPU_PM4.10: Read Enable */
_sfrbit MPU_PM4_WEB;                    /* MPU_PM4.11: Write Enable */
_sfrbit MPU_PM4_L0EB;                   /* MPU_PM4.12: Level 0 Enable */
_sfrbit MPU_PM4_L1EB;                   /* MPU_PM4.13: Level 1 Enable */
_sfrbit MPU_PM4_L2EB;                   /* MPU_PM4.14: Level 2 Enable */
_sfrbit MPU_PM4_L3EB;                   /* MPU_PM4.15: Level 3 Enable */

_sfr MPU_PM5;                           /* Protection Mode Register 5 */
_sfrbit MPU_PM5_XEA;                    /* MPU_PM5.1: Execute Enable */
_sfrbit MPU_PM5_REA;                    /* MPU_PM5.2: Read Enable */
_sfrbit MPU_PM5_WEA;                    /* MPU_PM5.3: Write Enable */
_sfrbit MPU_PM5_L0EA;                   /* MPU_PM5.4: Level 0 Enable */
_sfrbit MPU_PM5_L1EA;                   /* MPU_PM5.5: Level 1 Enable */
_sfrbit MPU_PM5_L2EA;                   /* MPU_PM5.6: Level 2 Enable */
_sfrbit MPU_PM5_L3EA;                   /* MPU_PM5.7: Level 3 Enable */
_sfrbit MPU_PM5_XEB;                    /* MPU_PM5.9: Execute Enable */
_sfrbit MPU_PM5_REB;                    /* MPU_PM5.10: Read Enable */
_sfrbit MPU_PM5_WEB;                    /* MPU_PM5.11: Write Enable */
_sfrbit MPU_PM5_L0EB;                   /* MPU_PM5.12: Level 0 Enable */
_sfrbit MPU_PM5_L1EB;                   /* MPU_PM5.13: Level 1 Enable */
_sfrbit MPU_PM5_L2EB;                   /* MPU_PM5.14: Level 2 Enable */
_sfrbit MPU_PM5_L3EB;                   /* MPU_PM5.15: Level 3 Enable */

_sfr MPU_PRD;                           /* Protection Range Data */

_sfr MPU_PRA;                           /* Protection Range Address */
_sfrbit MPU_PRA_WWA;                    /* MPU_PRA.6: Write Wrap Around Status */
_sfrbit MPU_PRA_WMOD;                   /* MPU_PRA.7: Auto increment Write Mode */
_sfrbit MPU_PRA_RWA;                    /* MPU_PRA.14: Read Wrap Around Status */
_sfrbit MPU_PRA_RMOD;                   /* MPU_PRA.15: Auto increment Read Mode */

#endif /* REGXC2361E_NOMPU */

/********************************************************************************
 * System Control Unit
********************************************************************************/
#ifndef REGXC2361E_NOSCU

_esfr SCU_WUOSCCON;                     /* Wake-up OSC Control Register */
_esfrbit SCU_WUOSCCON_DIS;              /* SCU_WUOSCCON.4: Clock Disable */

_esfr SCU_HPOSCCON;                     /* High Precision OSC Control Register */
_esfrbit SCU_HPOSCCON_PLLV;             /* SCU_HPOSCCON.0: Oscillator for PLL Valid Status Bit */
_esfrbit SCU_HPOSCCON_OSCWDTRST;        /* SCU_HPOSCCON.1: Oscillator Watchdog Reset */
_esfrbit SCU_HPOSCCON_X1D;              /* SCU_HPOSCCON.6: XTAL1 Data Value */
_esfrbit SCU_HPOSCCON_X1DEN;            /* SCU_HPOSCCON.7: XTAL1 Data Enable */
_esfrbit SCU_HPOSCCON_SHBY;             /* SCU_HPOSCCON.8: Shaper Bypass */
_esfrbit SCU_HPOSCCON_EMCLKEN;          /* SCU_HPOSCCON.9: OSCWDT Emergency System Clock Source Select Enable */
_esfrbit SCU_HPOSCCON_EMFINDISEN;       /* SCU_HPOSCCON.10: Emergency Input Clock Disconnect Enable */
_esfrbit SCU_HPOSCCON_OSC2L1;           /* SCU_HPOSCCON.11: OSC_HP Not Usable Frequency Event */
_esfrbit SCU_HPOSCCON_OSC2L0;           /* SCU_HPOSCCON.12: OSC_HP Usable Frequency Event */

_esfr SCU_PLLOSCCON;                    /* PLL OSC Control Register */
_esfrbit SCU_PLLOSCCON_OSCPD;           /* SCU_PLLOSCCON.0: Clock Source Power Saving Mode */

_esfr SCU_PLLSTAT;                      /* PLL Status Register */

_esfr SCU_STATCLR1;                     /* PLL Status Clear 1 Register */

_esfr SCU_PLLCON0;                      /* PLL Configuration 0 Register */
_esfrbit SCU_PLLCON0_VCOBY;             /* SCU_PLLCON0.0: VCO Bypass */
_esfrbit SCU_PLLCON0_VCOPWD;            /* SCU_PLLCON0.1: VCO Power Saving Mode */
_esfrbit SCU_PLLCON0_REGENCLR;          /* SCU_PLLCON0.4: Power Regulator Enable Clear */
_esfrbit SCU_PLLCON0_REGENSET;          /* SCU_PLLCON0.5: Power Regulator Enable Set */
_esfrbit SCU_PLLCON0_NACK;              /* SCU_PLLCON0.15: N-Divider Ready Acknowledge */

_esfr SCU_PLLCON1;                      /* PLL Configuration 1 Register */
_esfrbit SCU_PLLCON1_PLLPWD;            /* SCU_PLLCON1.0: PLL Power Saving Mode */
_esfrbit SCU_PLLCON1_OSCSEL;            /* SCU_PLLCON1.1: Oscillator Input Selection */
_esfrbit SCU_PLLCON1_RESLD;             /* SCU_PLLCON1.2: Restart VCO Lock Detection */
_esfrbit SCU_PLLCON1_AOSCSEL;           /* SCU_PLLCON1.3: Asynchronous Oscillator Input Selection */
_esfrbit SCU_PLLCON1_EMCLKEN;           /* SCU_PLLCON1.5: VCOLCK Emergency System Clock Source Select Enable */
_esfrbit SCU_PLLCON1_EMFINDISEN;        /* SCU_PLLCON1.6: Emergency Input Clock Disconnect Enable */
_esfrbit SCU_PLLCON1_PACK;              /* SCU_PLLCON1.15: P-Divider Ready Acknowledge */

_esfr SCU_PLLCON2;                      /* PLL Configuration 2 Register */
_esfrbit SCU_PLLCON2_K1ACK;             /* SCU_PLLCON2.15: K1-Divider Ready AcknowledgePlease refer to the Programmer’s Guide for a description of the proper handling. */

_esfr SCU_PLLCON3;                      /* PLL Configuration 3 Register */
_esfrbit SCU_PLLCON3_K2ACK;             /* SCU_PLLCON3.15: K2-Divider Ready AcknowledgePlease refer to the Programmer’s Guide for a description of the proper handling. */

_esfr SCU_PLLFRSTAT;                    /* PLL_FR Status Register */

_esfr SCU_FRSTATCLR1;                   /* PLL_FR Status Clear 1 Register */

_sfr SCU_PLLFRCON0;                     /* PLL_FR Configuration 0 Register */

_sfr SCU_PLLFRCON1;                     /* PLL_FR Configuration 1 Register */

_sfr SCU_PLLFRCON2;                     /* PLL_FR Configuration 2Register */

_sfr SCU_PLLFRCON3;                     /* PLL_FR Configuration 3 Register */

_sfr SCU_SYSCON0;                       /* System Control 0 Register */
_sfrbit SCU_SYSCON0_EMCLKSELEN;         /* SCU_SYSCON0.6: Emergency Clock Select Enable */
_sfrbit SCU_SYSCON0_EMSOSC;             /* SCU_SYSCON0.12: OSCWDT Emergency Event Source Status */
_sfrbit SCU_SYSCON0_EMSVCO;             /* SCU_SYSCON0.13: VCOLCK Emergency Event Source Status */
_sfrbit SCU_SYSCON0_SELSTAT;            /* SCU_SYSCON0.15: Clock Select Status */

#define SYSCON0         SCU_SYSCON0

_esfr SCU_STATCLR0;                     /* Status Clear 0 Register */

_sfr SCU_RTCCLKCON;                     /* RTC Clock Control Register */
_sfrbit SCU_RTCCLKCON_RTCCM;            /* SCU_RTCCLKCON.2: RTC Clocking Mode */

_sfr SCU_EXTCON;                        /* External Clock Control Register */
_sfrbit SCU_EXTCON_EN;                  /* SCU_EXTCON.0: External Clock Enable */
_sfrbit SCU_EXTCON_FOTL;                /* SCU_EXTCON.6: Frequency Output Toggle Latch */
_sfrbit SCU_EXTCON_FOSS;                /* SCU_EXTCON.14: Frequency Output Signal Select */
_sfrbit SCU_EXTCON_FOEN;                /* SCU_EXTCON.15: Frequency Output Enable */

_esfr SCU_STMREL;                       /* STM Reload Register */

_esfr SCU_STMCON;                       /* STM Control Register */
_esfrbit SCU_STMCON_RUN;                /* SCU_STMCON.0: Run Control */

_esfr SCU_WUTREL;                       /* Wake-up Timer Reload Register */

_esfr SCU_WUCR;                         /* Wake-up Control Register */
_esfrbit SCU_WUCR_CLRTRG;               /* SCU_WUCR.7: Clear Bit WUTRG */
_esfrbit SCU_WUCR_RUN;                  /* SCU_WUCR.8: Run Indicator */
_esfrbit SCU_WUCR_AON;                  /* SCU_WUCR.9: Auto-Start Indicator */
_esfrbit SCU_WUCR_ASP;                  /* SCU_WUCR.10: Auto-Stop Indicator */
_esfrbit SCU_WUCR_TTSTAT;               /* SCU_WUCR.14: Trim Trigger Status */
_esfrbit SCU_WUCR_WUTRG;                /* SCU_WUCR.15: WUT Trigger Indicator */

_esfr SCU_RSTSTAT0;                     /* Reset Status 0 Register */

_esfr SCU_RSTSTAT1;                     /* Reset Status 1 Register */

_esfr SCU_RSTSTAT2;                     /* Reset Status 2 Register */

_esfr SCU_RSTCON0;                      /* Reset Configuration 0 Register */

_esfr SCU_RSTCON1;                      /* Reset Configuration 1 Register */

_esfr SCU_RSTCNTCON;                    /* Reset Counter Control Register */

_esfr SCU_SWRSTCON;                     /* Software Reset Control Register */

_sfr SCU_ESREXCON1;                     /* ESR1 External Control Register */
_sfrbit SCU_ESREXCON1_ESREN;            /* SCU_ESREXCON1.0: ESRy Pin Enable */
_sfrbit SCU_ESREXCON1_ESRIN0EN;         /* SCU_ESREXCON1.1: ESR Input X Enable */
_sfrbit SCU_ESREXCON1_ESRIN1EN;         /* SCU_ESREXCON1.2: ESR Input X Enable */
_sfrbit SCU_ESREXCON1_ESRIN2EN;         /* SCU_ESREXCON1.3: ESR Input X Enable */
_sfrbit SCU_ESREXCON1_ESRIN3EN;         /* SCU_ESREXCON1.4: ESR Input X Enable */
_sfrbit SCU_ESREXCON1_ESRIN4EN;         /* SCU_ESREXCON1.5: ESR Input X Enable */
_sfrbit SCU_ESREXCON1_ESRIN5EN;         /* SCU_ESREXCON1.6: ESR Input X Enable */
_sfrbit SCU_ESREXCON1_ESRIN6EN;         /* SCU_ESREXCON1.7: ESR Input X Enable */
_sfrbit SCU_ESREXCON1_ESRIN7EN;         /* SCU_ESREXCON1.8: ESR Input X Enable */
_sfrbit SCU_ESREXCON1_ESRIN8EN;         /* SCU_ESREXCON1.9: ESR Input X Enable */
_sfrbit SCU_ESREXCON1_ESRIN9EN;         /* SCU_ESREXCON1.10: ESR Input X Enable */
_sfrbit SCU_ESREXCON1_ESRIN10EN;        /* SCU_ESREXCON1.11: ESR Input X Enable */
_sfrbit SCU_ESREXCON1_ESRIN11EN;        /* SCU_ESREXCON1.12: ESR Input X Enable */
_sfrbit SCU_ESREXCON1_ESRIN12EN;        /* SCU_ESREXCON1.13: ESR Input 12 Enable */
_sfrbit SCU_ESREXCON1_ESRNIN10EN;       /* SCU_ESREXCON1.14: Negated ESR Input 10 Enable */
_sfrbit SCU_ESREXCON1_ESRNIN11EN;       /* SCU_ESREXCON1.15: Negated ESR Input 11 Enable */

_sfr SCU_ESREXCON2;                     /* ESR2 External Control Register */
_sfrbit SCU_ESREXCON2_ESREN;            /* SCU_ESREXCON2.0: ESRy Pin Enable */
_sfrbit SCU_ESREXCON2_ESRIN0EN;         /* SCU_ESREXCON2.1: ESR Input X Enable */
_sfrbit SCU_ESREXCON2_ESRIN1EN;         /* SCU_ESREXCON2.2: ESR Input X Enable */
_sfrbit SCU_ESREXCON2_ESRIN2EN;         /* SCU_ESREXCON2.3: ESR Input X Enable */
_sfrbit SCU_ESREXCON2_ESRIN3EN;         /* SCU_ESREXCON2.4: ESR Input X Enable */
_sfrbit SCU_ESREXCON2_ESRIN4EN;         /* SCU_ESREXCON2.5: ESR Input X Enable */
_sfrbit SCU_ESREXCON2_ESRIN5EN;         /* SCU_ESREXCON2.6: ESR Input X Enable */
_sfrbit SCU_ESREXCON2_ESRIN6EN;         /* SCU_ESREXCON2.7: ESR Input X Enable */
_sfrbit SCU_ESREXCON2_ESRIN7EN;         /* SCU_ESREXCON2.8: ESR Input X Enable */
_sfrbit SCU_ESREXCON2_ESRIN8EN;         /* SCU_ESREXCON2.9: ESR Input X Enable */
_sfrbit SCU_ESREXCON2_ESRIN9EN;         /* SCU_ESREXCON2.10: ESR Input X Enable */
_sfrbit SCU_ESREXCON2_ESRIN10EN;        /* SCU_ESREXCON2.11: ESR Input X Enable */
_sfrbit SCU_ESREXCON2_ESRIN11EN;        /* SCU_ESREXCON2.12: ESR Input X Enable */
_sfrbit SCU_ESREXCON2_ESRIN12EN;        /* SCU_ESREXCON2.13: ESR Input 12 Enable */
_sfrbit SCU_ESREXCON2_ESRNIN10EN;       /* SCU_ESREXCON2.14: Negated ESR Input 10 Enable */
_sfrbit SCU_ESREXCON2_ESRNIN11EN;       /* SCU_ESREXCON2.15: Negated ESR Input 11 Enable */

_sfr SCU_ESREXSTAT1;                    /* ESR1 External Status Register */
_sfrbit SCU_ESREXSTAT1_ESR;             /* SCU_ESREXSTAT1.0: Input ESRy Status */
_sfrbit SCU_ESREXSTAT1_IN0;             /* SCU_ESREXSTAT1.1: Input x Status */
_sfrbit SCU_ESREXSTAT1_IN1;             /* SCU_ESREXSTAT1.2: Input x Status */
_sfrbit SCU_ESREXSTAT1_IN2;             /* SCU_ESREXSTAT1.3: Input x Status */
_sfrbit SCU_ESREXSTAT1_IN3;             /* SCU_ESREXSTAT1.4: Input x Status */
_sfrbit SCU_ESREXSTAT1_IN4;             /* SCU_ESREXSTAT1.5: Input x Status */
_sfrbit SCU_ESREXSTAT1_IN5;             /* SCU_ESREXSTAT1.6: Input x Status */
_sfrbit SCU_ESREXSTAT1_IN6;             /* SCU_ESREXSTAT1.7: Input x Status */
_sfrbit SCU_ESREXSTAT1_IN7;             /* SCU_ESREXSTAT1.8: Input x Status */
_sfrbit SCU_ESREXSTAT1_IN8;             /* SCU_ESREXSTAT1.9: Input x Status */
_sfrbit SCU_ESREXSTAT1_IN9;             /* SCU_ESREXSTAT1.10: Input x Status */
_sfrbit SCU_ESREXSTAT1_IN10;            /* SCU_ESREXSTAT1.11: Input x Status */
_sfrbit SCU_ESREXSTAT1_IN11;            /* SCU_ESREXSTAT1.12: Input x Status */

_sfr SCU_ESREXSTAT2;                    /* ESR2 External Status Register */
_sfrbit SCU_ESREXSTAT2_ESR;             /* SCU_ESREXSTAT2.0: Input ESRy Status */
_sfrbit SCU_ESREXSTAT2_IN0;             /* SCU_ESREXSTAT2.1: Input x Status */
_sfrbit SCU_ESREXSTAT2_IN1;             /* SCU_ESREXSTAT2.2: Input x Status */
_sfrbit SCU_ESREXSTAT2_IN2;             /* SCU_ESREXSTAT2.3: Input x Status */
_sfrbit SCU_ESREXSTAT2_IN3;             /* SCU_ESREXSTAT2.4: Input x Status */
_sfrbit SCU_ESREXSTAT2_IN4;             /* SCU_ESREXSTAT2.5: Input x Status */
_sfrbit SCU_ESREXSTAT2_IN5;             /* SCU_ESREXSTAT2.6: Input x Status */
_sfrbit SCU_ESREXSTAT2_IN6;             /* SCU_ESREXSTAT2.7: Input x Status */
_sfrbit SCU_ESREXSTAT2_IN7;             /* SCU_ESREXSTAT2.8: Input x Status */
_sfrbit SCU_ESREXSTAT2_IN8;             /* SCU_ESREXSTAT2.9: Input x Status */
_sfrbit SCU_ESREXSTAT2_IN9;             /* SCU_ESREXSTAT2.10: Input x Status */
_sfrbit SCU_ESREXSTAT2_IN10;            /* SCU_ESREXSTAT2.11: Input x Status */
_sfrbit SCU_ESREXSTAT2_IN11;            /* SCU_ESREXSTAT2.12: Input x Status */

_sfr SCU_CLRESREXSTAT1;                 /* Clear ESR1 External Status Register */
_sfrbit SCU_CLRESREXSTAT1_ESR;          /* SCU_CLRESREXSTAT1.0: Clear Input ESRy Status */
_sfrbit SCU_CLRESREXSTAT1_IN0;          /* SCU_CLRESREXSTAT1.1: Clear Input x Status */
_sfrbit SCU_CLRESREXSTAT1_IN1;          /* SCU_CLRESREXSTAT1.2: Clear Input x Status */
_sfrbit SCU_CLRESREXSTAT1_IN2;          /* SCU_CLRESREXSTAT1.3: Clear Input x Status */
_sfrbit SCU_CLRESREXSTAT1_IN3;          /* SCU_CLRESREXSTAT1.4: Clear Input x Status */
_sfrbit SCU_CLRESREXSTAT1_IN4;          /* SCU_CLRESREXSTAT1.5: Clear Input x Status */
_sfrbit SCU_CLRESREXSTAT1_IN5;          /* SCU_CLRESREXSTAT1.6: Clear Input x Status */
_sfrbit SCU_CLRESREXSTAT1_IN6;          /* SCU_CLRESREXSTAT1.7: Clear Input x Status */
_sfrbit SCU_CLRESREXSTAT1_IN7;          /* SCU_CLRESREXSTAT1.8: Clear Input x Status */
_sfrbit SCU_CLRESREXSTAT1_IN8;          /* SCU_CLRESREXSTAT1.9: Clear Input x Status */
_sfrbit SCU_CLRESREXSTAT1_IN9;          /* SCU_CLRESREXSTAT1.10: Clear Input x Status */
_sfrbit SCU_CLRESREXSTAT1_IN10;         /* SCU_CLRESREXSTAT1.11: Clear Input x Status */
_sfrbit SCU_CLRESREXSTAT1_IN11;         /* SCU_CLRESREXSTAT1.12: Clear Input x Status */

_sfr SCU_CLRESREXSTAT2;                 /* Clear ESR2 External Status Register */
_sfrbit SCU_CLRESREXSTAT2_ESR;          /* SCU_CLRESREXSTAT2.0: Clear Input ESRy Status */
_sfrbit SCU_CLRESREXSTAT2_IN0;          /* SCU_CLRESREXSTAT2.1: Clear Input x Status */
_sfrbit SCU_CLRESREXSTAT2_IN1;          /* SCU_CLRESREXSTAT2.2: Clear Input x Status */
_sfrbit SCU_CLRESREXSTAT2_IN2;          /* SCU_CLRESREXSTAT2.3: Clear Input x Status */
_sfrbit SCU_CLRESREXSTAT2_IN3;          /* SCU_CLRESREXSTAT2.4: Clear Input x Status */
_sfrbit SCU_CLRESREXSTAT2_IN4;          /* SCU_CLRESREXSTAT2.5: Clear Input x Status */
_sfrbit SCU_CLRESREXSTAT2_IN5;          /* SCU_CLRESREXSTAT2.6: Clear Input x Status */
_sfrbit SCU_CLRESREXSTAT2_IN6;          /* SCU_CLRESREXSTAT2.7: Clear Input x Status */
_sfrbit SCU_CLRESREXSTAT2_IN7;          /* SCU_CLRESREXSTAT2.8: Clear Input x Status */
_sfrbit SCU_CLRESREXSTAT2_IN8;          /* SCU_CLRESREXSTAT2.9: Clear Input x Status */
_sfrbit SCU_CLRESREXSTAT2_IN9;          /* SCU_CLRESREXSTAT2.10: Clear Input x Status */
_sfrbit SCU_CLRESREXSTAT2_IN10;         /* SCU_CLRESREXSTAT2.11: Clear Input x Status */
_sfrbit SCU_CLRESREXSTAT2_IN11;         /* SCU_CLRESREXSTAT2.12: Clear Input x Status */

_esfr SCU_ESRCFG0;                      /* ESR0 Configuration Register */
_esfrbit SCU_ESRCFG0_DFEN;              /* SCU_ESRCFG0.4: Digital Filter Enable */
_esfrbit SCU_ESRCFG0_OUT;               /* SCU_ESRCFG0.5: Data Output */
_esfrbit SCU_ESRCFG0_IN;                /* SCU_ESRCFG0.6: Data Input */

_esfr SCU_ESRCFG1;                      /* ESR1 Configuration Register */
_esfrbit SCU_ESRCFG1_DFEN;              /* SCU_ESRCFG1.4: Digital Filter Enable */
_esfrbit SCU_ESRCFG1_OUT;               /* SCU_ESRCFG1.5: Data Output */
_esfrbit SCU_ESRCFG1_IN;                /* SCU_ESRCFG1.6: Data Input */

_esfr SCU_ESRCFG2;                      /* ESR2 Configuration Register */
_esfrbit SCU_ESRCFG2_DFEN;              /* SCU_ESRCFG2.4: Digital Filter Enable */
_esfrbit SCU_ESRCFG2_OUT;               /* SCU_ESRCFG2.5: Data Output */
_esfrbit SCU_ESRCFG2_IN;                /* SCU_ESRCFG2.6: Data Input */

_esfr SCU_ESRDAT;                       /* ESR Data Register */

_esfr SCU_SWDCON0;                      /* SWD Control 0 Register */

_esfr SCU_SWDCON1;                      /* SWD Control 1 Register */

_esfr SCU_PVC1CON0;                     /* PVC_1 Control Step 0 Register */

_xsfr SCU_PVCMCON0;                     /* PVC_M Control Step 0 Register MEM */

_esfr SCU_EVR1CON0;                     /* EVR_1 Control 0 Register */

_esfr SCU_EVR1SET10V;                   /* EVR_1 Setting for 1.0V Register */

_esfr SCU_EVR1SET15VLP;                 /* EVR_1 Setting for 1.5V LP Register */

_esfr SCU_EVR1SET15VHP;                 /* EVR_1 Setting for 1.5V HP Register */

_esfr SCU_EVRMCON0;                     /* EVR_M Control 0 Register */

_esfr SCU_EVRMCON1;                     /* EVR_M Control 1 Register */

_esfr SCU_EVRMSET10V;                   /* EVR_M Setting for 1.0V Register */

_esfr SCU_EVRMSET15VLP;                 /* EVR_M Setting for 1.5V LP Register */

_esfr SCU_EVRMSET15VHP;                 /* EVR_M Setting for 1.5V HP Register */

_sfr SCU_SEQCON;                        /* Sequence Control Register */

_sfr SCU_PSCSTAT;                       /* PSC Status Register */

_sfr SCU_STEP0;                         /* Step 0 Register */

_sfr SCU_SEQASTEP1;                     /* Sequence Step 1 for Set A Register */

_sfr SCU_SEQASTEP2;                     /* Sequence Step 2 for Set A Register */

_sfr SCU_SEQASTEP3;                     /* Sequence Step 3 for Set A Register */

_sfr SCU_SEQASTEP4;                     /* Sequence Step 4 for Set A Register */

_sfr SCU_SEQASTEP5;                     /* Sequence Step 5 for Set A Register */

_sfr SCU_SEQASTEP6;                     /* Sequence Step 6 for Set A Register */

_sfr SCU_SEQBSTEP1;                     /* Sequence Step 1 for Set B Register */

_sfr SCU_SEQBSTEP2;                     /* Sequence Step 2 for Set B Register */

_sfr SCU_SEQBSTEP3;                     /* Sequence Step 3 for Set B Register */

_sfr SCU_SEQBSTEP4;                     /* Sequence Step 4 for Set B Register */

_sfr SCU_SEQBSTEP5;                     /* Sequence Step 5 for Set B Register */

_sfr SCU_SEQBSTEP6;                     /* Sequence Step 6 for Set B Register */

_esfr SCU_PVC1CONA1;                    /* PVC_1 Control for Step 1 Set A Register */

_esfr SCU_PVC1CONA2;                    /* PVC_1 Control for Step 2 Set A Register */

_esfr SCU_PVC1CONA3;                    /* PVC_1 Control for Step 3 Set A Register */

_esfr SCU_PVC1CONA4;                    /* PVC_1 Control for Step 4 Set A Register */

_esfr SCU_PVC1CONA5;                    /* PVC_1 Control for Step 5 Set A Register */

_esfr SCU_PVC1CONA6;                    /* PVC_1 Control for Step 6 Set A Register */

_xsfr SCU_PVCMCONA1;                    /* PVC_M Control for Step 1 Set A Register MEM */

_xsfr SCU_PVCMCONA2;                    /* PVC_M Control for Step 2 Set A Register MEM */

_xsfr SCU_PVCMCONA3;                    /* PVC_M Control for Step 3 Set A Register MEM */

_xsfr SCU_PVCMCONA4;                    /* PVC_M Control for Step 4 Set A Register MEM */

_xsfr SCU_PVCMCONA5;                    /* PVC_M Control for Step 5 Set A Register MEM */

_xsfr SCU_PVCMCONA6;                    /* PVC_M Control for Step 6 Set A Register MEM */

_esfr SCU_PVC1CONB1;                    /* PVC_1 Control for Step 1 Set B Register */

_esfr SCU_PVC1CONB2;                    /* PVC_1 Control for Step 2 Set B Register */

_esfr SCU_PVC1CONB3;                    /* PVC_1 Control for Step 3 Set B Register */

_esfr SCU_PVC1CONB4;                    /* PVC_1 Control for Step 4 Set B Register */

_esfr SCU_PVC1CONB5;                    /* PVC_1 Control for Step 5 Set B Register */

_esfr SCU_PVC1CONB6;                    /* PVC_1 Control for Step 6 Set B Register */

_xsfr SCU_PVCMCONB1;                    /* PVC_M Control for Step 1 Set B Register MEM */

_xsfr SCU_PVCMCONB2;                    /* PVC_M Control for Step 2 Set B Register MEM */

_xsfr SCU_PVCMCONB3;                    /* PVC_M Control for Step 3 Set B Register MEM */

_xsfr SCU_PVCMCONB4;                    /* PVC_M Control for Step 4 Set B Register MEM */

_xsfr SCU_PVCMCONB5;                    /* PVC_M Control for Step 5 Set B Register MEM */

_xsfr SCU_PVCMCONB6;                    /* PVC_M Control for Step 6 Set B Register MEM */

_sfr SCU_GSCSWREQ;                      /* GSC Software Request Register */
_sfrbit SCU_GSCSWREQ_SWTRG1;            /* SCU_GSCSWREQ.0: Software Trigger 1 (SW1) */
_sfrbit SCU_GSCSWREQ_SWTRG2;            /* SCU_GSCSWREQ.1: Software Trigger 2 (SW2) */

_sfr SCU_GSCEN;                         /* GSC Enable Register */
_sfrbit SCU_GSCEN_PSCBEXEN;             /* SCU_GSCEN.0: PSC Sequence B Exit Request Trigger Enable */
_sfrbit SCU_GSCEN_PSCBENEN;             /* SCU_GSCEN.1: PSC Sequence B Entry Request Trigger Enable */
_sfrbit SCU_GSCEN_PSCAEXEN;             /* SCU_GSCEN.2: PSC Sequence A Exit Request Trigger Enable */
_sfrbit SCU_GSCEN_PSCAENEN;             /* SCU_GSCEN.3: PSC Sequence A Entry Request Trigger Enable */
_sfrbit SCU_GSCEN_OCDSEXEN;             /* SCU_GSCEN.4: OCDS Exit Request Trigger Enable */
_sfrbit SCU_GSCEN_ESR0EN;               /* SCU_GSCEN.5: ESR0 Request Trigger Enable */
_sfrbit SCU_GSCEN_ESR1EN;               /* SCU_GSCEN.6: ESR1 Request Trigger Enable */
_sfrbit SCU_GSCEN_ESR2EN;               /* SCU_GSCEN.7: ESR2 Request Trigger Enable */
_sfrbit SCU_GSCEN_WUTEN;                /* SCU_GSCEN.8: WUT Request Trigger Enable */
_sfrbit SCU_GSCEN_ITCEN;                /* SCU_GSCEN.9: ITC Request Trigger Enable */
_sfrbit SCU_GSCEN_GPTEN;                /* SCU_GSCEN.10: GTP12E Request Trigger Enable */
_sfrbit SCU_GSCEN_SW1EN;                /* SCU_GSCEN.11: Software 1 Request Trigger Enable */
_sfrbit SCU_GSCEN_SW2EN;                /* SCU_GSCEN.12: Software 2 Request Trigger Enable */
_sfrbit SCU_GSCEN_OCDSENEN;             /* SCU_GSCEN.14: OCDS Entry Request Trigger Enable */

_sfr SCU_GSCSTAT;                       /* GSC Status Register */
_sfrbit SCU_GSCSTAT_ERR;                /* SCU_GSCSTAT.8: Error Status Flag */
_sfrbit SCU_GSCSTAT_PEN;                /* SCU_GSCSTAT.9: Command Pending Flag */

_sfr SCU_GSCPERSTATEN;                  /* GSC Peripheral Status Enable Register */
_sfrbit SCU_GSCPERSTATEN_ADC;           /* SCU_GSCPERSTATEN.0: ADC Acknowledge Enable */
_sfrbit SCU_GSCPERSTATEN_GPT12E;        /* SCU_GSCPERSTATEN.1: GPT12E Acknowledge Enable */
_sfrbit SCU_GSCPERSTATEN_CC2;           /* SCU_GSCPERSTATEN.3: CC2 Acknowledge Enable */
_sfrbit SCU_GSCPERSTATEN_MCAN;          /* SCU_GSCPERSTATEN.4: MultiCAN Acknowledge Enable */
_sfrbit SCU_GSCPERSTATEN_CCU60;         /* SCU_GSCPERSTATEN.5: CCU60 Acknowledge Enable */
_sfrbit SCU_GSCPERSTATEN_CCU61;         /* SCU_GSCPERSTATEN.6: CCU61 Acknowledge Enable */
_sfrbit SCU_GSCPERSTATEN_CCU62;         /* SCU_GSCPERSTATEN.7: CCU62 Acknowledge Enable */
_sfrbit SCU_GSCPERSTATEN_CCU63;         /* SCU_GSCPERSTATEN.8: CCU63 Acknowledge Enable */
_sfrbit SCU_GSCPERSTATEN_RTC;           /* SCU_GSCPERSTATEN.9: RTC Acknowledge Enable */
_sfrbit SCU_GSCPERSTATEN_MEM;           /* SCU_GSCPERSTATEN.10: C166SV2 Subsystem Acknowledge Enable */
_sfrbit SCU_GSCPERSTATEN_FL;            /* SCU_GSCPERSTATEN.11: Flash Acknowledge Enable */
_sfrbit SCU_GSCPERSTATEN_USIC0;         /* SCU_GSCPERSTATEN.12: USIC0 Acknowledge Enable */
_sfrbit SCU_GSCPERSTATEN_USIC1;         /* SCU_GSCPERSTATEN.13: USIC1 Acknowledge Enable */
_sfrbit SCU_GSCPERSTATEN_USIC2;         /* SCU_GSCPERSTATEN.14: USIC2 Acknowledge Enable */
_sfrbit SCU_GSCPERSTATEN_USIC3;         /* SCU_GSCPERSTATEN.15: USIC3 Acknowledge Enable */

_sfr SCU_GSCPERSTATEN1;                 /* GSC Peripheral Status Enable 1 Register */
_sfrbit SCU_GSCPERSTATEN1_USIC4;        /* SCU_GSCPERSTATEN1.0: USIC4 Acknowledge Enable */
_sfrbit SCU_GSCPERSTATEN1_FR;           /* SCU_GSCPERSTATEN1.2: FlexRay Acknowledge Enable */

_sfr SCU_GSCPERSTAT;                    /* GSC Peripheral Status Register */
_sfrbit SCU_GSCPERSTAT_ADC;             /* SCU_GSCPERSTAT.0: ADC Acknowledge Status */
_sfrbit SCU_GSCPERSTAT_GPT12E;          /* SCU_GSCPERSTAT.1: GPT12E Acknowledge Status */
_sfrbit SCU_GSCPERSTAT_CC2;             /* SCU_GSCPERSTAT.3: CC2 Acknowledge Status */
_sfrbit SCU_GSCPERSTAT_MCAN;            /* SCU_GSCPERSTAT.4: MultiCAN Acknowledge Status */
_sfrbit SCU_GSCPERSTAT_CCU60;           /* SCU_GSCPERSTAT.5: CCU60 Acknowledge Status */
_sfrbit SCU_GSCPERSTAT_CCU61;           /* SCU_GSCPERSTAT.6: CCU61 Acknowledge Status */
_sfrbit SCU_GSCPERSTAT_CCU62;           /* SCU_GSCPERSTAT.7: CCU62 Acknowledge Status */
_sfrbit SCU_GSCPERSTAT_CCU63;           /* SCU_GSCPERSTAT.8: CCU63 Acknowledge Status */
_sfrbit SCU_GSCPERSTAT_RTC;             /* SCU_GSCPERSTAT.9: RTC Acknowledge Status */
_sfrbit SCU_GSCPERSTAT_MEM;             /* SCU_GSCPERSTAT.10: C166SV2 Subsystem Acknowledge Status */
_sfrbit SCU_GSCPERSTAT_FL;              /* SCU_GSCPERSTAT.11: Flash Acknowledge Status */
_sfrbit SCU_GSCPERSTAT_USIC0;           /* SCU_GSCPERSTAT.12: USIC0 Acknowledge Status */
_sfrbit SCU_GSCPERSTAT_USIC1;           /* SCU_GSCPERSTAT.13: USIC1 Acknowledge Status */
_sfrbit SCU_GSCPERSTAT_USIC2;           /* SCU_GSCPERSTAT.14: USIC2 Acknowledge Status */
_sfrbit SCU_GSCPERSTAT_USIC3;           /* SCU_GSCPERSTAT.15: USIC3 Acknowledge Status */

_sfr SCU_GSCPERSTAT1;                   /* GSC Peripheral Status Register */

_xsfr SCU_STSTAT;                       /* Start-up Status Register */

_esfr SCU_EXISEL;                       /* External Input Select Register */

#define EXISEL          SCU_EXISEL

_esfr SCU_EXICON0;                      /* External Input Control 0 Register */

_esfr SCU_EXICON1;                      /* External Input Control 1 Register */

_esfr SCU_EXICON2;                      /* External Input Control 2 Register */

_esfr SCU_EXICON3;                      /* External Input Control 3 Register */

_sfr SCU_EXOCON0;                       /* External Output Trigger Control 0 Register */

_sfr SCU_EXOCON1;                       /* External Output Trigger Control 1 Register */

_sfr SCU_EXOCON2;                       /* External Output Trigger Control 2 Register */

_sfr SCU_EXOCON3;                       /* External Output Trigger Control 3 Register */

_sfr SCU_INTSTAT;                       /* Interrupt Status Register */
_sfrbit SCU_INTSTAT_SWDI1;              /* SCU_INTSTAT.0: SWD Interrupt Request Flag 1 */
_sfrbit SCU_INTSTAT_SWDI2;              /* SCU_INTSTAT.1: SWD Interrupt Request Flag 2 */
_sfrbit SCU_INTSTAT_PVCMI1;             /* SCU_INTSTAT.2: PVC_M Interrupt Request Flag 1 */
_sfrbit SCU_INTSTAT_PVCMI2;             /* SCU_INTSTAT.3: PVC_M Interrupt Request Flag 2 */
_sfrbit SCU_INTSTAT_PVC1I1;             /* SCU_INTSTAT.4: PVC_1 Interrupt Request Flag 1 */
_sfrbit SCU_INTSTAT_PVC1I2;             /* SCU_INTSTAT.5: PVC_1 Interrupt Request Flag 2 */
_sfrbit SCU_INTSTAT_WUTI;               /* SCU_INTSTAT.6: Wake-up Timer Trim Interrupt Request Flag */
_sfrbit SCU_INTSTAT_WUI;                /* SCU_INTSTAT.7: Wake-up Timer Interrupt Request Flag */
_sfrbit SCU_INTSTAT_WDTI;               /* SCU_INTSTAT.8: Watchdog Timer Interrupt Request Flag */
_sfrbit SCU_INTSTAT_GSCI;               /* SCU_INTSTAT.9: GSC Interrupt Request Flag */
_sfrbit SCU_INTSTAT_STM0I;              /* SCU_INTSTAT.10: STM Interrupt 0 Request Flag */
_sfrbit SCU_INTSTAT_STM1I;              /* SCU_INTSTAT.11: STM Interrupt 1 Request Flag */
_sfrbit SCU_INTSTAT_MCHKI;              /* SCU_INTSTAT.12: MCHK Interrupt Request Flag */
_sfrbit SCU_INTSTAT_PFI;                /* SCU_INTSTAT.13: Program Flash Interrupt Request Flag */

_sfr SCU_INTCLR;                        /* Interrupt Clear Register */

_sfr SCU_INTSET;                        /* Interrupt Set Register */

_sfr SCU_INTDIS;                        /* Interrupt Disable Register */

_sfr SCU_INTNP0;                        /* Interrupt Node Pointer 0 Register */

_sfr SCU_INTNP1;                        /* Interrupt Node Pointer 1 Register */

_sfr SCU_DMPMIT;                        /* DMP_M Interrupt and Trap Trigger Register */

_sfr SCU_DMPMITCLR;                     /* DMP_M Interrupt and Trap Clear Register */

_esfr SCU_TCCR;                         /* Temperature Compensation Control Register */
_esfrbit SCU_TCCR_TCE;                  /* SCU_TCCR.7: Temperature Compensation Enable */

_esfr SCU_TCLR;                         /* Temperature Comp. Level Register */

_esfr SCU_WDTREL;                       /* WDT Reload Register */

#define WDTREL          SCU_WDTREL

_esfr SCU_WDTCS;                        /* WDT Control and Status Register */

#define WDTCS           SCU_WDTCS

_esfr SCU_WDTTIM;                       /* WDT Timer Register */

_sfr SCU_TRAPSTAT;                      /* Trap Status Register */
_sfrbit SCU_TRAPSTAT_FAT;               /* SCU_TRAPSTAT.0: Flash Access Trap Request Flag */
_sfrbit SCU_TRAPSTAT_ESR0T;             /* SCU_TRAPSTAT.1: ESR0 Trap Request Flag */
_sfrbit SCU_TRAPSTAT_ESR1T;             /* SCU_TRAPSTAT.2: ESR1 Trap Request Flag */
_sfrbit SCU_TRAPSTAT_ESR2T;             /* SCU_TRAPSTAT.3: ESR2 Trap Request Flag */
_sfrbit SCU_TRAPSTAT_OSCWDTT;           /* SCU_TRAPSTAT.4: OSCWDT Trap Request Flag */
_sfrbit SCU_TRAPSTAT_RAT;               /* SCU_TRAPSTAT.5: Register Access Trap Request Flag */
_sfrbit SCU_TRAPSTAT_PET;               /* SCU_TRAPSTAT.6: Parity Error Trap Request Flag */
_sfrbit SCU_TRAPSTAT_VCOLCKT;           /* SCU_TRAPSTAT.7: VCOLCK Trap Request Flag */
_sfrbit SCU_TRAPSTAT_ECCT;              /* SCU_TRAPSTAT.8: ECC Error Trap Request Flag */
_sfrbit SCU_TRAPSTAT_FRVCOLCKT;         /* SCU_TRAPSTAT.9: FRVCOLCK Trap Request Flag */

_sfr SCU_TRAPCLR;                       /* Trap Clear Register */

_sfr SCU_TRAPSET;                       /* Trap Set Register */

_sfr SCU_TRAPDIS;                       /* Trap Disable Register */

_sfr SCU_TRAPNP;                        /* Trap Node Pointer Register */

_sfr SCU_TRAPNP1;                       /* Trap Node Pointer 1 Register */

_esfr SCU_MCHKCON;                      /* Memory Checking Control Register */

_esfr SCU_PEEN;                         /* Parity Error Enable Register */

_esfr SCU_PECON;                        /* Parity Error Control Register */

_esfr SCU_PMTPR;                        /* Parity Memory Test Pattern Register */

_esfr SCU_PMTSR;                        /* Parity Memory Test Select Register */

_esfr SCU_ECCCON;                       /* ECC Control Register */

_esfr SCU_ECCSTAT;                      /* ECC Status Register */

_esfr SCU_ECCCLRSTAT;                   /* ECC Clear Status Register */

_esfr SCU_SLC;                          /* Security Level Command Register */

#define SLC             SCU_SLC

_esfr SCU_SLS;                          /* Security Level Status Register */

_sfr SCU_SYSCON1;                       /* System Control 1 Register */
_sfrbit SCU_SYSCON1_OCDSEN;             /* SCU_SYSCON1.2: OCDS/Cerberus Enable */
_sfrbit SCU_SYSCON1_GLCCST;             /* SCU_SYSCON1.3: Global CAPCOM Start */

#define SYSCON1         SCU_SYSCON1

_esfr SCU_IDMANUF;                      /* Manufacturer Identification Register */

_esfr SCU_IDCHIP;                       /* Chip Identification Register */

_esfr SCU_IDMEM;                        /* Program Memory Identification Register */

_esfr SCU_IDPROG;                       /* Programming Voltage Id. Register */

_sfr SCU_IDDMPM;                        /* DMP_M Module Identification Register */

_sfr SCU_IDDMP1;                        /* DMP_1 Module Identification Register */

_sfr SCU_MKMEM0;                        /* Marker Memory 0 Register */

_sfr SCU_MKMEM1;                        /* Marker Memory 1 Register */

_esfr SCU_STMEM0;                       /* Startup Memory 0 Register */

#endif /* REGXC2361E_NOSCU */

/********************************************************************************
 * PORTS
********************************************************************************/
#ifndef REGXC2361E_NOPORTS

_xsfr P0_POCON;                         /* Port 0 Output Control Register */

_xsfr P1_POCON;                         /* Port 1 Output Control Register */

_xsfr P2_POCON;                         /* Port 2 Output Control Register */

_xsfr P3_POCON;                         /* Port 3 Output Control Register */

_xsfr P4_POCON;                         /* Port 4 Output Control Register */

_xsfr P6_POCON;                         /* Port 6 Output Control Register */

_xsfr P7_POCON;                         /* Port 7 Output Control Register */

_xsfr P8_POCON;                         /* Port 8 Output Control Register */

_xsfr P9_POCON;                         /* Port 9 Output Control Register */

_xsfr P10_POCON;                        /* Port 10 Output Control Register */

_xsfr P11_POCON;                        /* Port 11 Output Control Register */

_sfr P0_OUT;                            /* Port 0 Output Register */
_sfrbit P0_OUT_P0;                      /* P0_OUT.0: Port Output Bit x */
_sfrbit P0_OUT_P1;                      /* P0_OUT.1: Port Output Bit x */
_sfrbit P0_OUT_P2;                      /* P0_OUT.2: Port Output Bit x */
_sfrbit P0_OUT_P3;                      /* P0_OUT.3: Port Output Bit x */
_sfrbit P0_OUT_P4;                      /* P0_OUT.4: Port Output Bit x */
_sfrbit P0_OUT_P5;                      /* P0_OUT.5: Port Output Bit x */
_sfrbit P0_OUT_P6;                      /* P0_OUT.6: Port Output Bit x */
_sfrbit P0_OUT_P7;                      /* P0_OUT.7: Port Output Bit x */
_sfrbit P0_OUT_P8;                      /* P0_OUT.8: Port Output Bit x */
_sfrbit P0_OUT_P9;                      /* P0_OUT.9: Port Output Bit x */
_sfrbit P0_OUT_P10;                     /* P0_OUT.10: Port Output Bit x */
_sfrbit P0_OUT_P11;                     /* P0_OUT.11: Port Output Bit x */
_sfrbit P0_OUT_P12;                     /* P0_OUT.12: Port Output Bit x */
_sfrbit P0_OUT_P13;                     /* P0_OUT.13: Port Output Bit x */
_sfrbit P0_OUT_P14;                     /* P0_OUT.14: Port Output Bit x */
_sfrbit P0_OUT_P15;                     /* P0_OUT.15: Port Output Bit x */

_sfr P1_OUT;                            /* Port 1 Output Register */
_sfrbit P1_OUT_P0;                      /* P1_OUT.0: Port Output Bit x */
_sfrbit P1_OUT_P1;                      /* P1_OUT.1: Port Output Bit x */
_sfrbit P1_OUT_P2;                      /* P1_OUT.2: Port Output Bit x */
_sfrbit P1_OUT_P3;                      /* P1_OUT.3: Port Output Bit x */
_sfrbit P1_OUT_P4;                      /* P1_OUT.4: Port Output Bit x */
_sfrbit P1_OUT_P5;                      /* P1_OUT.5: Port Output Bit x */
_sfrbit P1_OUT_P6;                      /* P1_OUT.6: Port Output Bit x */
_sfrbit P1_OUT_P7;                      /* P1_OUT.7: Port Output Bit x */
_sfrbit P1_OUT_P8;                      /* P1_OUT.8: Port Output Bit x */
_sfrbit P1_OUT_P9;                      /* P1_OUT.9: Port Output Bit x */
_sfrbit P1_OUT_P10;                     /* P1_OUT.10: Port Output Bit x */
_sfrbit P1_OUT_P11;                     /* P1_OUT.11: Port Output Bit x */
_sfrbit P1_OUT_P12;                     /* P1_OUT.12: Port Output Bit x */
_sfrbit P1_OUT_P13;                     /* P1_OUT.13: Port Output Bit x */
_sfrbit P1_OUT_P14;                     /* P1_OUT.14: Port Output Bit x */
_sfrbit P1_OUT_P15;                     /* P1_OUT.15: Port Output Bit x */

_sfr P2_OUT;                            /* Port 2 Output Register */
_sfrbit P2_OUT_P0;                      /* P2_OUT.0: Port Output Bit x */
_sfrbit P2_OUT_P1;                      /* P2_OUT.1: Port Output Bit x */
_sfrbit P2_OUT_P2;                      /* P2_OUT.2: Port Output Bit x */
_sfrbit P2_OUT_P3;                      /* P2_OUT.3: Port Output Bit x */
_sfrbit P2_OUT_P4;                      /* P2_OUT.4: Port Output Bit x */
_sfrbit P2_OUT_P5;                      /* P2_OUT.5: Port Output Bit x */
_sfrbit P2_OUT_P6;                      /* P2_OUT.6: Port Output Bit x */
_sfrbit P2_OUT_P7;                      /* P2_OUT.7: Port Output Bit x */
_sfrbit P2_OUT_P8;                      /* P2_OUT.8: Port Output Bit x */
_sfrbit P2_OUT_P9;                      /* P2_OUT.9: Port Output Bit x */
_sfrbit P2_OUT_P10;                     /* P2_OUT.10: Port Output Bit x */
_sfrbit P2_OUT_P11;                     /* P2_OUT.11: Port Output Bit x */
_sfrbit P2_OUT_P12;                     /* P2_OUT.12: Port Output Bit x */
_sfrbit P2_OUT_P13;                     /* P2_OUT.13: Port Output Bit x */
_sfrbit P2_OUT_P14;                     /* P2_OUT.14: Port Output Bit x */
_sfrbit P2_OUT_P15;                     /* P2_OUT.15: Port Output Bit x */

_sfr P3_OUT;                            /* Port 3 Output Register */
_sfrbit P3_OUT_P0;                      /* P3_OUT.0: Port Output Bit x */
_sfrbit P3_OUT_P1;                      /* P3_OUT.1: Port Output Bit x */
_sfrbit P3_OUT_P2;                      /* P3_OUT.2: Port Output Bit x */
_sfrbit P3_OUT_P3;                      /* P3_OUT.3: Port Output Bit x */
_sfrbit P3_OUT_P4;                      /* P3_OUT.4: Port Output Bit x */
_sfrbit P3_OUT_P5;                      /* P3_OUT.5: Port Output Bit x */
_sfrbit P3_OUT_P6;                      /* P3_OUT.6: Port Output Bit x */
_sfrbit P3_OUT_P7;                      /* P3_OUT.7: Port Output Bit x */
_sfrbit P3_OUT_P8;                      /* P3_OUT.8: Port Output Bit x */
_sfrbit P3_OUT_P9;                      /* P3_OUT.9: Port Output Bit x */
_sfrbit P3_OUT_P10;                     /* P3_OUT.10: Port Output Bit x */
_sfrbit P3_OUT_P11;                     /* P3_OUT.11: Port Output Bit x */
_sfrbit P3_OUT_P12;                     /* P3_OUT.12: Port Output Bit x */
_sfrbit P3_OUT_P13;                     /* P3_OUT.13: Port Output Bit x */
_sfrbit P3_OUT_P14;                     /* P3_OUT.14: Port Output Bit x */
_sfrbit P3_OUT_P15;                     /* P3_OUT.15: Port Output Bit x */

_sfr P4_OUT;                            /* Port 4 Output Register */
_sfrbit P4_OUT_P0;                      /* P4_OUT.0: Port Output Bit x */
_sfrbit P4_OUT_P1;                      /* P4_OUT.1: Port Output Bit x */
_sfrbit P4_OUT_P2;                      /* P4_OUT.2: Port Output Bit x */
_sfrbit P4_OUT_P3;                      /* P4_OUT.3: Port Output Bit x */
_sfrbit P4_OUT_P4;                      /* P4_OUT.4: Port Output Bit x */
_sfrbit P4_OUT_P5;                      /* P4_OUT.5: Port Output Bit x */
_sfrbit P4_OUT_P6;                      /* P4_OUT.6: Port Output Bit x */
_sfrbit P4_OUT_P7;                      /* P4_OUT.7: Port Output Bit x */
_sfrbit P4_OUT_P8;                      /* P4_OUT.8: Port Output Bit x */
_sfrbit P4_OUT_P9;                      /* P4_OUT.9: Port Output Bit x */
_sfrbit P4_OUT_P10;                     /* P4_OUT.10: Port Output Bit x */
_sfrbit P4_OUT_P11;                     /* P4_OUT.11: Port Output Bit x */
_sfrbit P4_OUT_P12;                     /* P4_OUT.12: Port Output Bit x */
_sfrbit P4_OUT_P13;                     /* P4_OUT.13: Port Output Bit x */
_sfrbit P4_OUT_P14;                     /* P4_OUT.14: Port Output Bit x */
_sfrbit P4_OUT_P15;                     /* P4_OUT.15: Port Output Bit x */

_sfr P6_OUT;                            /* Port 6 Output Register */
_sfrbit P6_OUT_P0;                      /* P6_OUT.0: Port Output Bit x */
_sfrbit P6_OUT_P1;                      /* P6_OUT.1: Port Output Bit x */
_sfrbit P6_OUT_P2;                      /* P6_OUT.2: Port Output Bit x */
_sfrbit P6_OUT_P3;                      /* P6_OUT.3: Port Output Bit x */
_sfrbit P6_OUT_P4;                      /* P6_OUT.4: Port Output Bit x */
_sfrbit P6_OUT_P5;                      /* P6_OUT.5: Port Output Bit x */
_sfrbit P6_OUT_P6;                      /* P6_OUT.6: Port Output Bit x */
_sfrbit P6_OUT_P7;                      /* P6_OUT.7: Port Output Bit x */
_sfrbit P6_OUT_P8;                      /* P6_OUT.8: Port Output Bit x */
_sfrbit P6_OUT_P9;                      /* P6_OUT.9: Port Output Bit x */
_sfrbit P6_OUT_P10;                     /* P6_OUT.10: Port Output Bit x */
_sfrbit P6_OUT_P11;                     /* P6_OUT.11: Port Output Bit x */
_sfrbit P6_OUT_P12;                     /* P6_OUT.12: Port Output Bit x */
_sfrbit P6_OUT_P13;                     /* P6_OUT.13: Port Output Bit x */
_sfrbit P6_OUT_P14;                     /* P6_OUT.14: Port Output Bit x */
_sfrbit P6_OUT_P15;                     /* P6_OUT.15: Port Output Bit x */

_sfr P7_OUT;                            /* Port 7 Output Register */
_sfrbit P7_OUT_P0;                      /* P7_OUT.0: Port Output Bit x */
_sfrbit P7_OUT_P1;                      /* P7_OUT.1: Port Output Bit x */
_sfrbit P7_OUT_P2;                      /* P7_OUT.2: Port Output Bit x */
_sfrbit P7_OUT_P3;                      /* P7_OUT.3: Port Output Bit x */
_sfrbit P7_OUT_P4;                      /* P7_OUT.4: Port Output Bit x */
_sfrbit P7_OUT_P5;                      /* P7_OUT.5: Port Output Bit x */
_sfrbit P7_OUT_P6;                      /* P7_OUT.6: Port Output Bit x */
_sfrbit P7_OUT_P7;                      /* P7_OUT.7: Port Output Bit x */
_sfrbit P7_OUT_P8;                      /* P7_OUT.8: Port Output Bit x */
_sfrbit P7_OUT_P9;                      /* P7_OUT.9: Port Output Bit x */
_sfrbit P7_OUT_P10;                     /* P7_OUT.10: Port Output Bit x */
_sfrbit P7_OUT_P11;                     /* P7_OUT.11: Port Output Bit x */
_sfrbit P7_OUT_P12;                     /* P7_OUT.12: Port Output Bit x */
_sfrbit P7_OUT_P13;                     /* P7_OUT.13: Port Output Bit x */
_sfrbit P7_OUT_P14;                     /* P7_OUT.14: Port Output Bit x */
_sfrbit P7_OUT_P15;                     /* P7_OUT.15: Port Output Bit x */

_sfr P8_OUT;                            /* Port 8 Output Register */
_sfrbit P8_OUT_P0;                      /* P8_OUT.0: Port Output Bit x */
_sfrbit P8_OUT_P1;                      /* P8_OUT.1: Port Output Bit x */
_sfrbit P8_OUT_P2;                      /* P8_OUT.2: Port Output Bit x */
_sfrbit P8_OUT_P3;                      /* P8_OUT.3: Port Output Bit x */
_sfrbit P8_OUT_P4;                      /* P8_OUT.4: Port Output Bit x */
_sfrbit P8_OUT_P5;                      /* P8_OUT.5: Port Output Bit x */
_sfrbit P8_OUT_P6;                      /* P8_OUT.6: Port Output Bit x */
_sfrbit P8_OUT_P7;                      /* P8_OUT.7: Port Output Bit x */
_sfrbit P8_OUT_P8;                      /* P8_OUT.8: Port Output Bit x */
_sfrbit P8_OUT_P9;                      /* P8_OUT.9: Port Output Bit x */
_sfrbit P8_OUT_P10;                     /* P8_OUT.10: Port Output Bit x */
_sfrbit P8_OUT_P11;                     /* P8_OUT.11: Port Output Bit x */
_sfrbit P8_OUT_P12;                     /* P8_OUT.12: Port Output Bit x */
_sfrbit P8_OUT_P13;                     /* P8_OUT.13: Port Output Bit x */
_sfrbit P8_OUT_P14;                     /* P8_OUT.14: Port Output Bit x */
_sfrbit P8_OUT_P15;                     /* P8_OUT.15: Port Output Bit x */

_sfr P9_OUT;                            /* Port 9 Output Register */
_sfrbit P9_OUT_P0;                      /* P9_OUT.0: Port Output Bit x */
_sfrbit P9_OUT_P1;                      /* P9_OUT.1: Port Output Bit x */
_sfrbit P9_OUT_P2;                      /* P9_OUT.2: Port Output Bit x */
_sfrbit P9_OUT_P3;                      /* P9_OUT.3: Port Output Bit x */
_sfrbit P9_OUT_P4;                      /* P9_OUT.4: Port Output Bit x */
_sfrbit P9_OUT_P5;                      /* P9_OUT.5: Port Output Bit x */
_sfrbit P9_OUT_P6;                      /* P9_OUT.6: Port Output Bit x */
_sfrbit P9_OUT_P7;                      /* P9_OUT.7: Port Output Bit x */
_sfrbit P9_OUT_P8;                      /* P9_OUT.8: Port Output Bit x */
_sfrbit P9_OUT_P9;                      /* P9_OUT.9: Port Output Bit x */
_sfrbit P9_OUT_P10;                     /* P9_OUT.10: Port Output Bit x */
_sfrbit P9_OUT_P11;                     /* P9_OUT.11: Port Output Bit x */
_sfrbit P9_OUT_P12;                     /* P9_OUT.12: Port Output Bit x */
_sfrbit P9_OUT_P13;                     /* P9_OUT.13: Port Output Bit x */
_sfrbit P9_OUT_P14;                     /* P9_OUT.14: Port Output Bit x */
_sfrbit P9_OUT_P15;                     /* P9_OUT.15: Port Output Bit x */

_sfr P10_OUT;                           /* Port 10 Output Register */
_sfrbit P10_OUT_P0;                     /* P10_OUT.0: Port Output Bit x */
_sfrbit P10_OUT_P1;                     /* P10_OUT.1: Port Output Bit x */
_sfrbit P10_OUT_P2;                     /* P10_OUT.2: Port Output Bit x */
_sfrbit P10_OUT_P3;                     /* P10_OUT.3: Port Output Bit x */
_sfrbit P10_OUT_P4;                     /* P10_OUT.4: Port Output Bit x */
_sfrbit P10_OUT_P5;                     /* P10_OUT.5: Port Output Bit x */
_sfrbit P10_OUT_P6;                     /* P10_OUT.6: Port Output Bit x */
_sfrbit P10_OUT_P7;                     /* P10_OUT.7: Port Output Bit x */
_sfrbit P10_OUT_P8;                     /* P10_OUT.8: Port Output Bit x */
_sfrbit P10_OUT_P9;                     /* P10_OUT.9: Port Output Bit x */
_sfrbit P10_OUT_P10;                    /* P10_OUT.10: Port Output Bit x */
_sfrbit P10_OUT_P11;                    /* P10_OUT.11: Port Output Bit x */
_sfrbit P10_OUT_P12;                    /* P10_OUT.12: Port Output Bit x */
_sfrbit P10_OUT_P13;                    /* P10_OUT.13: Port Output Bit x */
_sfrbit P10_OUT_P14;                    /* P10_OUT.14: Port Output Bit x */
_sfrbit P10_OUT_P15;                    /* P10_OUT.15: Port Output Bit x */

_sfr P11_OUT;                           /* Port 11 Output Register */
_sfrbit P11_OUT_P0;                     /* P11_OUT.0: Port Output Bit x */
_sfrbit P11_OUT_P1;                     /* P11_OUT.1: Port Output Bit x */
_sfrbit P11_OUT_P2;                     /* P11_OUT.2: Port Output Bit x */
_sfrbit P11_OUT_P3;                     /* P11_OUT.3: Port Output Bit x */
_sfrbit P11_OUT_P4;                     /* P11_OUT.4: Port Output Bit x */
_sfrbit P11_OUT_P5;                     /* P11_OUT.5: Port Output Bit x */
_sfrbit P11_OUT_P6;                     /* P11_OUT.6: Port Output Bit x */
_sfrbit P11_OUT_P7;                     /* P11_OUT.7: Port Output Bit x */
_sfrbit P11_OUT_P8;                     /* P11_OUT.8: Port Output Bit x */
_sfrbit P11_OUT_P9;                     /* P11_OUT.9: Port Output Bit x */
_sfrbit P11_OUT_P10;                    /* P11_OUT.10: Port Output Bit x */
_sfrbit P11_OUT_P11;                    /* P11_OUT.11: Port Output Bit x */
_sfrbit P11_OUT_P12;                    /* P11_OUT.12: Port Output Bit x */
_sfrbit P11_OUT_P13;                    /* P11_OUT.13: Port Output Bit x */
_sfrbit P11_OUT_P14;                    /* P11_OUT.14: Port Output Bit x */
_sfrbit P11_OUT_P15;                    /* P11_OUT.15: Port Output Bit x */

_xsfr P2_OMRH;                          /* Port 2 Output Modification Register High */

_xsfr P10_OMRH;                         /* Port 10 Output Modification Register High */

_xsfr P0_OMRL;                          /* Port 0 Output Modification Register Low */

_xsfr P1_OMRL;                          /* Port 1 Output Modification Register Low */

_xsfr P2_OMRL;                          /* Port 2 Output Modification Register Low */

_xsfr P3_OMRL;                          /* Port 3 Output Modification Register Low */

_xsfr P4_OMRL;                          /* Port 4 Output Modification Register Low */

_xsfr P6_OMRL;                          /* Port 6 Output Modification Register Low */

_xsfr P7_OMRL;                          /* Port 7 Output Modification Register Low */

_xsfr P8_OMRL;                          /* Port 8 Output Modification Register Low */

_xsfr P9_OMRL;                          /* Port 9 Output Modification Register Low */

_xsfr P10_OMRL;                         /* Port 10 Output Modification Register Low */

_xsfr P11_OMRL;                         /* Port 11 Output Modification Register Low */

_sfr P0_IN;                             /* Port 0 Input Register */
_sfrbit P0_IN_P0;                       /* P0_IN.0: Port Input Bit x */
_sfrbit P0_IN_P1;                       /* P0_IN.1: Port Input Bit x */
_sfrbit P0_IN_P2;                       /* P0_IN.2: Port Input Bit x */
_sfrbit P0_IN_P3;                       /* P0_IN.3: Port Input Bit x */
_sfrbit P0_IN_P4;                       /* P0_IN.4: Port Input Bit x */
_sfrbit P0_IN_P5;                       /* P0_IN.5: Port Input Bit x */
_sfrbit P0_IN_P6;                       /* P0_IN.6: Port Input Bit x */
_sfrbit P0_IN_P7;                       /* P0_IN.7: Port Input Bit x */
_sfrbit P0_IN_P8;                       /* P0_IN.8: Port Input Bit x */
_sfrbit P0_IN_P9;                       /* P0_IN.9: Port Input Bit x */
_sfrbit P0_IN_P10;                      /* P0_IN.10: Port Input Bit x */
_sfrbit P0_IN_P11;                      /* P0_IN.11: Port Input Bit x */
_sfrbit P0_IN_P12;                      /* P0_IN.12: Port Input Bit x */
_sfrbit P0_IN_P13;                      /* P0_IN.13: Port Input Bit x */
_sfrbit P0_IN_P14;                      /* P0_IN.14: Port Input Bit x */
_sfrbit P0_IN_P15;                      /* P0_IN.15: Port Input Bit x */

_sfr P1_IN;                             /* Port 1 Input Register */
_sfrbit P1_IN_P0;                       /* P1_IN.0: Port Input Bit x */
_sfrbit P1_IN_P1;                       /* P1_IN.1: Port Input Bit x */
_sfrbit P1_IN_P2;                       /* P1_IN.2: Port Input Bit x */
_sfrbit P1_IN_P3;                       /* P1_IN.3: Port Input Bit x */
_sfrbit P1_IN_P4;                       /* P1_IN.4: Port Input Bit x */
_sfrbit P1_IN_P5;                       /* P1_IN.5: Port Input Bit x */
_sfrbit P1_IN_P6;                       /* P1_IN.6: Port Input Bit x */
_sfrbit P1_IN_P7;                       /* P1_IN.7: Port Input Bit x */
_sfrbit P1_IN_P8;                       /* P1_IN.8: Port Input Bit x */
_sfrbit P1_IN_P9;                       /* P1_IN.9: Port Input Bit x */
_sfrbit P1_IN_P10;                      /* P1_IN.10: Port Input Bit x */
_sfrbit P1_IN_P11;                      /* P1_IN.11: Port Input Bit x */
_sfrbit P1_IN_P12;                      /* P1_IN.12: Port Input Bit x */
_sfrbit P1_IN_P13;                      /* P1_IN.13: Port Input Bit x */
_sfrbit P1_IN_P14;                      /* P1_IN.14: Port Input Bit x */
_sfrbit P1_IN_P15;                      /* P1_IN.15: Port Input Bit x */

_sfr P2_IN;                             /* Port 2 Input Register */
_sfrbit P2_IN_P0;                       /* P2_IN.0: Port Input Bit x */
_sfrbit P2_IN_P1;                       /* P2_IN.1: Port Input Bit x */
_sfrbit P2_IN_P2;                       /* P2_IN.2: Port Input Bit x */
_sfrbit P2_IN_P3;                       /* P2_IN.3: Port Input Bit x */
_sfrbit P2_IN_P4;                       /* P2_IN.4: Port Input Bit x */
_sfrbit P2_IN_P5;                       /* P2_IN.5: Port Input Bit x */
_sfrbit P2_IN_P6;                       /* P2_IN.6: Port Input Bit x */
_sfrbit P2_IN_P7;                       /* P2_IN.7: Port Input Bit x */
_sfrbit P2_IN_P8;                       /* P2_IN.8: Port Input Bit x */
_sfrbit P2_IN_P9;                       /* P2_IN.9: Port Input Bit x */
_sfrbit P2_IN_P10;                      /* P2_IN.10: Port Input Bit x */
_sfrbit P2_IN_P11;                      /* P2_IN.11: Port Input Bit x */
_sfrbit P2_IN_P12;                      /* P2_IN.12: Port Input Bit x */
_sfrbit P2_IN_P13;                      /* P2_IN.13: Port Input Bit x */
_sfrbit P2_IN_P14;                      /* P2_IN.14: Port Input Bit x */
_sfrbit P2_IN_P15;                      /* P2_IN.15: Port Input Bit x */

_sfr P3_IN;                             /* Port 3 Input Register */
_sfrbit P3_IN_P0;                       /* P3_IN.0: Port Input Bit x */
_sfrbit P3_IN_P1;                       /* P3_IN.1: Port Input Bit x */
_sfrbit P3_IN_P2;                       /* P3_IN.2: Port Input Bit x */
_sfrbit P3_IN_P3;                       /* P3_IN.3: Port Input Bit x */
_sfrbit P3_IN_P4;                       /* P3_IN.4: Port Input Bit x */
_sfrbit P3_IN_P5;                       /* P3_IN.5: Port Input Bit x */
_sfrbit P3_IN_P6;                       /* P3_IN.6: Port Input Bit x */
_sfrbit P3_IN_P7;                       /* P3_IN.7: Port Input Bit x */
_sfrbit P3_IN_P8;                       /* P3_IN.8: Port Input Bit x */
_sfrbit P3_IN_P9;                       /* P3_IN.9: Port Input Bit x */
_sfrbit P3_IN_P10;                      /* P3_IN.10: Port Input Bit x */
_sfrbit P3_IN_P11;                      /* P3_IN.11: Port Input Bit x */
_sfrbit P3_IN_P12;                      /* P3_IN.12: Port Input Bit x */
_sfrbit P3_IN_P13;                      /* P3_IN.13: Port Input Bit x */
_sfrbit P3_IN_P14;                      /* P3_IN.14: Port Input Bit x */
_sfrbit P3_IN_P15;                      /* P3_IN.15: Port Input Bit x */

_sfr P4_IN;                             /* Port 4 Input Register */
_sfrbit P4_IN_P0;                       /* P4_IN.0: Port Input Bit x */
_sfrbit P4_IN_P1;                       /* P4_IN.1: Port Input Bit x */
_sfrbit P4_IN_P2;                       /* P4_IN.2: Port Input Bit x */
_sfrbit P4_IN_P3;                       /* P4_IN.3: Port Input Bit x */
_sfrbit P4_IN_P4;                       /* P4_IN.4: Port Input Bit x */
_sfrbit P4_IN_P5;                       /* P4_IN.5: Port Input Bit x */
_sfrbit P4_IN_P6;                       /* P4_IN.6: Port Input Bit x */
_sfrbit P4_IN_P7;                       /* P4_IN.7: Port Input Bit x */
_sfrbit P4_IN_P8;                       /* P4_IN.8: Port Input Bit x */
_sfrbit P4_IN_P9;                       /* P4_IN.9: Port Input Bit x */
_sfrbit P4_IN_P10;                      /* P4_IN.10: Port Input Bit x */
_sfrbit P4_IN_P11;                      /* P4_IN.11: Port Input Bit x */
_sfrbit P4_IN_P12;                      /* P4_IN.12: Port Input Bit x */
_sfrbit P4_IN_P13;                      /* P4_IN.13: Port Input Bit x */
_sfrbit P4_IN_P14;                      /* P4_IN.14: Port Input Bit x */
_sfrbit P4_IN_P15;                      /* P4_IN.15: Port Input Bit x */

_sfr P5_IN;                             /* Port 5 Input Register */
_sfrbit P5_IN_P0;                       /* P5_IN.0: Port Input Bit x */
_sfrbit P5_IN_P1;                       /* P5_IN.1: Port Input Bit x */
_sfrbit P5_IN_P2;                       /* P5_IN.2: Port Input Bit x */
_sfrbit P5_IN_P3;                       /* P5_IN.3: Port Input Bit x */
_sfrbit P5_IN_P4;                       /* P5_IN.4: Port Input Bit x */
_sfrbit P5_IN_P5;                       /* P5_IN.5: Port Input Bit x */
_sfrbit P5_IN_P6;                       /* P5_IN.6: Port Input Bit x */
_sfrbit P5_IN_P7;                       /* P5_IN.7: Port Input Bit x */
_sfrbit P5_IN_P8;                       /* P5_IN.8: Port Input Bit x */
_sfrbit P5_IN_P9;                       /* P5_IN.9: Port Input Bit x */
_sfrbit P5_IN_P10;                      /* P5_IN.10: Port Input Bit x */
_sfrbit P5_IN_P11;                      /* P5_IN.11: Port Input Bit x */
_sfrbit P5_IN_P12;                      /* P5_IN.12: Port Input Bit x */
_sfrbit P5_IN_P13;                      /* P5_IN.13: Port Input Bit x */
_sfrbit P5_IN_P14;                      /* P5_IN.14: Port Input Bit x */
_sfrbit P5_IN_P15;                      /* P5_IN.15: Port Input Bit x */

_sfr P6_IN;                             /* Port 6 Input Register */
_sfrbit P6_IN_P0;                       /* P6_IN.0: Port Input Bit x */
_sfrbit P6_IN_P1;                       /* P6_IN.1: Port Input Bit x */
_sfrbit P6_IN_P2;                       /* P6_IN.2: Port Input Bit x */
_sfrbit P6_IN_P3;                       /* P6_IN.3: Port Input Bit x */
_sfrbit P6_IN_P4;                       /* P6_IN.4: Port Input Bit x */
_sfrbit P6_IN_P5;                       /* P6_IN.5: Port Input Bit x */
_sfrbit P6_IN_P6;                       /* P6_IN.6: Port Input Bit x */
_sfrbit P6_IN_P7;                       /* P6_IN.7: Port Input Bit x */
_sfrbit P6_IN_P8;                       /* P6_IN.8: Port Input Bit x */
_sfrbit P6_IN_P9;                       /* P6_IN.9: Port Input Bit x */
_sfrbit P6_IN_P10;                      /* P6_IN.10: Port Input Bit x */
_sfrbit P6_IN_P11;                      /* P6_IN.11: Port Input Bit x */
_sfrbit P6_IN_P12;                      /* P6_IN.12: Port Input Bit x */
_sfrbit P6_IN_P13;                      /* P6_IN.13: Port Input Bit x */
_sfrbit P6_IN_P14;                      /* P6_IN.14: Port Input Bit x */
_sfrbit P6_IN_P15;                      /* P6_IN.15: Port Input Bit x */

_sfr P7_IN;                             /* Port 7 Input Register */
_sfrbit P7_IN_P0;                       /* P7_IN.0: Port Input Bit x */
_sfrbit P7_IN_P1;                       /* P7_IN.1: Port Input Bit x */
_sfrbit P7_IN_P2;                       /* P7_IN.2: Port Input Bit x */
_sfrbit P7_IN_P3;                       /* P7_IN.3: Port Input Bit x */
_sfrbit P7_IN_P4;                       /* P7_IN.4: Port Input Bit x */
_sfrbit P7_IN_P5;                       /* P7_IN.5: Port Input Bit x */
_sfrbit P7_IN_P6;                       /* P7_IN.6: Port Input Bit x */
_sfrbit P7_IN_P7;                       /* P7_IN.7: Port Input Bit x */
_sfrbit P7_IN_P8;                       /* P7_IN.8: Port Input Bit x */
_sfrbit P7_IN_P9;                       /* P7_IN.9: Port Input Bit x */
_sfrbit P7_IN_P10;                      /* P7_IN.10: Port Input Bit x */
_sfrbit P7_IN_P11;                      /* P7_IN.11: Port Input Bit x */
_sfrbit P7_IN_P12;                      /* P7_IN.12: Port Input Bit x */
_sfrbit P7_IN_P13;                      /* P7_IN.13: Port Input Bit x */
_sfrbit P7_IN_P14;                      /* P7_IN.14: Port Input Bit x */
_sfrbit P7_IN_P15;                      /* P7_IN.15: Port Input Bit x */

_sfr P8_IN;                             /* Port 8 Input Register */
_sfrbit P8_IN_P0;                       /* P8_IN.0: Port Input Bit x */
_sfrbit P8_IN_P1;                       /* P8_IN.1: Port Input Bit x */
_sfrbit P8_IN_P2;                       /* P8_IN.2: Port Input Bit x */
_sfrbit P8_IN_P3;                       /* P8_IN.3: Port Input Bit x */
_sfrbit P8_IN_P4;                       /* P8_IN.4: Port Input Bit x */
_sfrbit P8_IN_P5;                       /* P8_IN.5: Port Input Bit x */
_sfrbit P8_IN_P6;                       /* P8_IN.6: Port Input Bit x */
_sfrbit P8_IN_P7;                       /* P8_IN.7: Port Input Bit x */
_sfrbit P8_IN_P8;                       /* P8_IN.8: Port Input Bit x */
_sfrbit P8_IN_P9;                       /* P8_IN.9: Port Input Bit x */
_sfrbit P8_IN_P10;                      /* P8_IN.10: Port Input Bit x */
_sfrbit P8_IN_P11;                      /* P8_IN.11: Port Input Bit x */
_sfrbit P8_IN_P12;                      /* P8_IN.12: Port Input Bit x */
_sfrbit P8_IN_P13;                      /* P8_IN.13: Port Input Bit x */
_sfrbit P8_IN_P14;                      /* P8_IN.14: Port Input Bit x */
_sfrbit P8_IN_P15;                      /* P8_IN.15: Port Input Bit x */

_sfr P9_IN;                             /* Port 9 Input Register */
_sfrbit P9_IN_P0;                       /* P9_IN.0: Port Input Bit x */
_sfrbit P9_IN_P1;                       /* P9_IN.1: Port Input Bit x */
_sfrbit P9_IN_P2;                       /* P9_IN.2: Port Input Bit x */
_sfrbit P9_IN_P3;                       /* P9_IN.3: Port Input Bit x */
_sfrbit P9_IN_P4;                       /* P9_IN.4: Port Input Bit x */
_sfrbit P9_IN_P5;                       /* P9_IN.5: Port Input Bit x */
_sfrbit P9_IN_P6;                       /* P9_IN.6: Port Input Bit x */
_sfrbit P9_IN_P7;                       /* P9_IN.7: Port Input Bit x */
_sfrbit P9_IN_P8;                       /* P9_IN.8: Port Input Bit x */
_sfrbit P9_IN_P9;                       /* P9_IN.9: Port Input Bit x */
_sfrbit P9_IN_P10;                      /* P9_IN.10: Port Input Bit x */
_sfrbit P9_IN_P11;                      /* P9_IN.11: Port Input Bit x */
_sfrbit P9_IN_P12;                      /* P9_IN.12: Port Input Bit x */
_sfrbit P9_IN_P13;                      /* P9_IN.13: Port Input Bit x */
_sfrbit P9_IN_P14;                      /* P9_IN.14: Port Input Bit x */
_sfrbit P9_IN_P15;                      /* P9_IN.15: Port Input Bit x */

_sfr P10_IN;                            /* Port 10 Input Register */
_sfrbit P10_IN_P0;                      /* P10_IN.0: Port Input Bit x */
_sfrbit P10_IN_P1;                      /* P10_IN.1: Port Input Bit x */
_sfrbit P10_IN_P2;                      /* P10_IN.2: Port Input Bit x */
_sfrbit P10_IN_P3;                      /* P10_IN.3: Port Input Bit x */
_sfrbit P10_IN_P4;                      /* P10_IN.4: Port Input Bit x */
_sfrbit P10_IN_P5;                      /* P10_IN.5: Port Input Bit x */
_sfrbit P10_IN_P6;                      /* P10_IN.6: Port Input Bit x */
_sfrbit P10_IN_P7;                      /* P10_IN.7: Port Input Bit x */
_sfrbit P10_IN_P8;                      /* P10_IN.8: Port Input Bit x */
_sfrbit P10_IN_P9;                      /* P10_IN.9: Port Input Bit x */
_sfrbit P10_IN_P10;                     /* P10_IN.10: Port Input Bit x */
_sfrbit P10_IN_P11;                     /* P10_IN.11: Port Input Bit x */
_sfrbit P10_IN_P12;                     /* P10_IN.12: Port Input Bit x */
_sfrbit P10_IN_P13;                     /* P10_IN.13: Port Input Bit x */
_sfrbit P10_IN_P14;                     /* P10_IN.14: Port Input Bit x */
_sfrbit P10_IN_P15;                     /* P10_IN.15: Port Input Bit x */

_sfr P11_IN;                            /* Port 11 Input Register */
_sfrbit P11_IN_P0;                      /* P11_IN.0: Port Input Bit x */
_sfrbit P11_IN_P1;                      /* P11_IN.1: Port Input Bit x */
_sfrbit P11_IN_P2;                      /* P11_IN.2: Port Input Bit x */
_sfrbit P11_IN_P3;                      /* P11_IN.3: Port Input Bit x */
_sfrbit P11_IN_P4;                      /* P11_IN.4: Port Input Bit x */
_sfrbit P11_IN_P5;                      /* P11_IN.5: Port Input Bit x */
_sfrbit P11_IN_P6;                      /* P11_IN.6: Port Input Bit x */
_sfrbit P11_IN_P7;                      /* P11_IN.7: Port Input Bit x */
_sfrbit P11_IN_P8;                      /* P11_IN.8: Port Input Bit x */
_sfrbit P11_IN_P9;                      /* P11_IN.9: Port Input Bit x */
_sfrbit P11_IN_P10;                     /* P11_IN.10: Port Input Bit x */
_sfrbit P11_IN_P11;                     /* P11_IN.11: Port Input Bit x */
_sfrbit P11_IN_P12;                     /* P11_IN.12: Port Input Bit x */
_sfrbit P11_IN_P13;                     /* P11_IN.13: Port Input Bit x */
_sfrbit P11_IN_P14;                     /* P11_IN.14: Port Input Bit x */
_sfrbit P11_IN_P15;                     /* P11_IN.15: Port Input Bit x */

_sfr P15_IN;                            /* Port 15 Input Register */
_sfrbit P15_IN_P0;                      /* P15_IN.0: Port Input Bit x */
_sfrbit P15_IN_P1;                      /* P15_IN.1: Port Input Bit x */
_sfrbit P15_IN_P2;                      /* P15_IN.2: Port Input Bit x */
_sfrbit P15_IN_P3;                      /* P15_IN.3: Port Input Bit x */
_sfrbit P15_IN_P4;                      /* P15_IN.4: Port Input Bit x */
_sfrbit P15_IN_P5;                      /* P15_IN.5: Port Input Bit x */
_sfrbit P15_IN_P6;                      /* P15_IN.6: Port Input Bit x */
_sfrbit P15_IN_P7;                      /* P15_IN.7: Port Input Bit x */
_sfrbit P15_IN_P8;                      /* P15_IN.8: Port Input Bit x */
_sfrbit P15_IN_P9;                      /* P15_IN.9: Port Input Bit x */
_sfrbit P15_IN_P10;                     /* P15_IN.10: Port Input Bit x */
_sfrbit P15_IN_P11;                     /* P15_IN.11: Port Input Bit x */
_sfrbit P15_IN_P12;                     /* P15_IN.12: Port Input Bit x */
_sfrbit P15_IN_P13;                     /* P15_IN.13: Port Input Bit x */
_sfrbit P15_IN_P14;                     /* P15_IN.14: Port Input Bit x */
_sfrbit P15_IN_P15;                     /* P15_IN.15: Port Input Bit x */

_xsfr P0_IOCR00;                        /* Port 0 Input/Output Control Register 00 */

_xsfr P0_IOCR01;                        /* Port 0 Input/Output Control Register 01 */

_xsfr P0_IOCR02;                        /* Port 0 Input/Output Control Register 02 */

_xsfr P0_IOCR03;                        /* Port 0 Input/Output Control Register 03 */

_xsfr P0_IOCR04;                        /* Port 0 Input/Output Control Register 04 */

_xsfr P0_IOCR05;                        /* Port 0 Input/Output Control Register 05 */

_xsfr P0_IOCR06;                        /* Port 0 Input/Output Control Register 06 */

_xsfr P0_IOCR07;                        /* Port 0 Input/Output Control Register 07 */

_xsfr P1_IOCR00;                        /* Port 1 Input/Output Control Register 00 */

_xsfr P1_IOCR01;                        /* Port 1 Input/Output Control Register 01 */

_xsfr P1_IOCR02;                        /* Port 1 Input/Output Control Register 02 */

_xsfr P1_IOCR03;                        /* Port 1 Input/Output Control Register 03 */

_xsfr P1_IOCR04;                        /* Port 1 Input/Output Control Register 04 */

_xsfr P1_IOCR05;                        /* Port 1 Input/Output Control Register 05 */

_xsfr P1_IOCR06;                        /* Port 1 Input/Output Control Register 06 */

_xsfr P1_IOCR07;                        /* Port 1 Input/Output Control Register 07 */

_xsfr P2_IOCR00;                        /* Port 2 Input/Output Control Register 00 */

_xsfr P2_IOCR01;                        /* Port 2 Input/Output Control Register 01 */

_xsfr P2_IOCR02;                        /* Port 2 Input/Output Control Register 02 */

_xsfr P2_IOCR03;                        /* Port 2 Input/Output Control Register 03 */

_xsfr P2_IOCR04;                        /* Port 2 Input/Output Control Register 04 */

_xsfr P2_IOCR05;                        /* Port 2 Input/Output Control Register 05 */

_xsfr P2_IOCR06;                        /* Port 2 Input/Output Control Register 06 */

_xsfr P2_IOCR07;                        /* Port 2 Input/Output Control Register 07 */

_xsfr P2_IOCR08;                        /* Port 2 Input/Output Control Register 08 */

_xsfr P2_IOCR09;                        /* Port 2 Input/Output Control Register 09 */

_xsfr P2_IOCR10;                        /* Port 2 Input/Output Control Register 10 */

_xsfr P2_IOCR11;                        /* Port 2 Input/Output Control Register 11 */

_xsfr P2_IOCR12;                        /* Port 2 Input/Output Control Register 12 */

_xsfr P2_IOCR13;                        /* Port 2 Input/Output Control Register 13 */

_xsfr P3_IOCR00;                        /* Port 3 Input/Output Control Register 00 */

_xsfr P3_IOCR01;                        /* Port 3 Input/Output Control Register 01 */

_xsfr P3_IOCR02;                        /* Port 3 Input/Output Control Register 02 */

_xsfr P3_IOCR03;                        /* Port 3 Input/Output Control Register 03 */

_xsfr P3_IOCR04;                        /* Port 3 Input/Output Control Register 04 */

_xsfr P3_IOCR05;                        /* Port 3 Input/Output Control Register 05 */

_xsfr P3_IOCR06;                        /* Port 3 Input/Output Control Register 06 */

_xsfr P3_IOCR07;                        /* Port 3 Input/Output Control Register 07 */

_xsfr P4_IOCR00;                        /* Port 4 Input/Output Control Register 00 */

_xsfr P4_IOCR01;                        /* Port 4 Input/Output Control Register 01 */

_xsfr P4_IOCR02;                        /* Port 4 Input/Output Control Register 02 */

_xsfr P4_IOCR03;                        /* Port 4 Input/Output Control Register 03 */

_xsfr P4_IOCR04;                        /* Port 4 Input/Output Control Register 04 */

_xsfr P4_IOCR05;                        /* Port 4 Input/Output Control Register 05 */

_xsfr P4_IOCR06;                        /* Port 4 Input/Output Control Register 06 */

_xsfr P4_IOCR07;                        /* Port 4 Input/Output Control Register 07 */

_xsfr P6_IOCR00;                        /* Port 6 Input/Output Control Register 00 */

_xsfr P6_IOCR01;                        /* Port 6 Input/Output Control Register 01 */

_xsfr P6_IOCR02;                        /* Port 6 Input/Output Control Register 02 */

_xsfr P6_IOCR03;                        /* Port 6 Input/Output Control Register 03 */

_xsfr P7_IOCR00;                        /* Port 7 Input/Output Control Register 00 */

_xsfr P7_IOCR01;                        /* Port 7 Input/Output Control Register 01 */

_xsfr P7_IOCR02;                        /* Port 7 Input/Output Control Register 02 */

_xsfr P7_IOCR03;                        /* Port 7 Input/Output Control Register 03 */

_xsfr P7_IOCR04;                        /* Port 7 Input/Output Control Register 04 */

_xsfr P8_IOCR01;                        /* Port 8 Input/Output Control Register 01 */

_xsfr P8_IOCR02;                        /* Port 8 Input/Output Control Register 02 */

_xsfr P8_IOCR03;                        /* Port 8 Input/Output Control Register 03 */

_xsfr P8_IOCR04;                        /* Port 8 Input/Output Control Register 04 */

_xsfr P8_IOCR05;                        /* Port 8 Input/Output Control Register 05 */

_xsfr P8_IOCR06;                        /* Port 8 Input/Output Control Register 06 */

_xsfr P9_IOCR00;                        /* Port 9 Input/Output Control Register 00 */

_xsfr P9_IOCR01;                        /* Port 9 Input/Output Control Register 01 */

_xsfr P9_IOCR02;                        /* Port 9 Input/Output Control Register 02 */

_xsfr P9_IOCR03;                        /* Port 9 Input/Output Control Register 03 */

_xsfr P9_IOCR04;                        /* Port 9 Input/Output Control Register 04 */

_xsfr P9_IOCR05;                        /* Port 9 Input/Output Control Register 05 */

_xsfr P9_IOCR06;                        /* Port 9 Input/Output Control Register 06 */

_xsfr P9_IOCR07;                        /* Port 9 Input/Output Control Register 07 */

_xsfr P10_IOCR00;                       /* Port 10 Input/Output Control Register 00 */

_xsfr P10_IOCR01;                       /* Port 10 Input/Output Control Register 01 */

_xsfr P10_IOCR02;                       /* Port 10 Input/Output Control Register 02 */

_xsfr P10_IOCR03;                       /* Port 10 Input/Output Control Register 03 */

_xsfr P10_IOCR04;                       /* Port 10 Input/Output Control Register 04 */

_xsfr P10_IOCR05;                       /* Port 10 Input/Output Control Register 05 */

_xsfr P10_IOCR06;                       /* Port 10 Input/Output Control Register 06 */

_xsfr P10_IOCR07;                       /* Port 10 Input/Output Control Register 07 */

_xsfr P10_IOCR08;                       /* Port 10 Input/Output Control Register 08 */

_xsfr P10_IOCR09;                       /* Port 10 Input/Output Control Register 09 */

_xsfr P10_IOCR10;                       /* Port 10 Input/Output Control Register 10 */

_xsfr P10_IOCR11;                       /* Port 10 Input/Output Control Register 11 */

_xsfr P10_IOCR12;                       /* Port 10 Input/Output Control Register 12 */

_xsfr P10_IOCR13;                       /* Port 10 Input/Output Control Register 13 */

_xsfr P10_IOCR14;                       /* Port 10 Input/Output Control Register 14 */

_xsfr P10_IOCR15;                       /* Port 10 Input/Output Control Register 15 */

_xsfr P11_IOCR00;                       /* Port 11 Input/Output Control Register 00 */

_xsfr P11_IOCR01;                       /* Port 11 Input/Output Control Register 01 */

_xsfr P11_IOCR02;                       /* Port 11 Input/Output Control Register 02 */

_xsfr P11_IOCR03;                       /* Port 11 Input/Output Control Register 03 */

_xsfr P11_IOCR04;                       /* Port 11 Input/Output Control Register 04 */

_xsfr P11_IOCR05;                       /* Port 11 Input/Output Control Register 05 */

_sfr P5_DIDIS;                          /* Port 5 Digital Input Disable Register */

_sfr P6_DIDIS;                          /* Port 6 Digital IO Disable Register */

_sfr P15_DIDIS;                         /* Port 15 Digital Input Disable Register */

#endif /* REGXC2361E_NOPORTS */

/********************************************************************************
 * External Bus Controller Registers
********************************************************************************/
#ifndef REGXC2361E_NOEBC

_xsfr EBC_EBCMOD0;                      /* External Bus Controller Mode Register 0 */

#define EBCMOD0         EBC_EBCMOD0

_xsfr EBC_EBCMOD1;                      /* External Bus Controller Mode Register 1 */

#define EBCMOD1         EBC_EBCMOD1

_xsfr EBC_TCONCS0;                      /* CS0 Timing Configuration */

#define TCONCS0         EBC_TCONCS0

_xsfr EBC_TCONCS1;                      /* CS1 Timing Configuration */

#define TCONCS1         EBC_TCONCS1

_xsfr EBC_TCONCS2;                      /* CS2 Timing Configuration */

#define TCONCS2         EBC_TCONCS2

_xsfr EBC_TCONCS3;                      /* CS3 Timing Configuration */

#define TCONCS3         EBC_TCONCS3

_xsfr EBC_TCONCS4;                      /* CS4 Timing Configuration */

#define TCONCS4         EBC_TCONCS4

_xsfr EBC_FCONCS0;                      /* CS0 Function Configuration */

#define FCONCS0         EBC_FCONCS0

_xsfr EBC_FCONCS1;                      /* CS1 Function Configuration */

#define FCONCS1         EBC_FCONCS1

_xsfr EBC_FCONCS2;                      /* CS2 Function Configuration */

#define FCONCS2         EBC_FCONCS2

_xsfr EBC_FCONCS3;                      /* CS3 Function Configuration */

#define FCONCS3         EBC_FCONCS3

_xsfr EBC_FCONCS4;                      /* CS4 Function Configuration */

#define FCONCS4         EBC_FCONCS4

_xsfr EBC_ADDRSEL1;                     /* CS1 Address Size and Range */

#define ADDRSEL1        EBC_ADDRSEL1

_xsfr EBC_ADDRSEL2;                     /* CS2 Address Size and Range */

#define ADDRSEL2        EBC_ADDRSEL2

_xsfr EBC_ADDRSEL3;                     /* CS3 Address Size and Range */

#define ADDRSEL3        EBC_ADDRSEL3

_xsfr EBC_ADDRSEL4;                     /* CS4 Address Size and Range */

#define ADDRSEL4        EBC_ADDRSEL4

#endif /* REGXC2361E_NOEBC */

/********************************************************************************
 * On-Chip Debugging Interface Control Registers
********************************************************************************/
#ifndef REGXC2361E_NOOCDS

_esfr DEXEVT;                           /* Break Pin Event Control Register */

_esfr DSWEVT;                           /* Software Debug Event Control Register */

_esfr DTREVT;                           /* Hardware Trigger Event Control Register */

_esfr DBGSR;                            /* Debug Status Register */

_esfr DTIDR;                            /* Task ID Register */

_esfr CMADR;                            /* Monitor target ADdress register */

_esfr CMCTR;                            /* Monitor Control and Break Level register */

_esfr DCMPSP;                           /* Data Compare Select Programming register */

_esfr DCMPDP;                           /* Data Compare Data Programming register */

_esfr RWDATA;                           /* Data Register in RW Mode */

_esfr COMDATA;                          /* Data Register in Communication Mode */

_esfr IOSR;                             /* Status and Control Register */

_esfr DBGPRR;                           /* Debug Pin Routing Register */

#endif /* REGXC2361E_NOOCDS */

/********************************************************************************
 * GPT12
********************************************************************************/
#ifndef REGXC2361E_NOGPT12

_sfr GPT12E_T2;                         /* Timer 2 */

#define T2              GPT12E_T2

_sfr GPT12E_T3;                         /* Timer 3 */

#define T3              GPT12E_T3

_sfr GPT12E_T4;                         /* Timer 4 */

#define T4              GPT12E_T4

_sfr GPT12E_T3CON;                      /* Timer 3 Control Register */
_sfrbit GPT12E_T3CON_T3R;               /* GPT12E_T3CON.6: <GPT12E_T3CON_T3R> */
_sfrbit GPT12E_T3CON_T3UD;              /* GPT12E_T3CON.7: <GPT12E_T3CON_T3UD> */
_sfrbit GPT12E_T3CON_T3UDE;             /* GPT12E_T3CON.8: <GPT12E_T3CON_T3UDE> */
_sfrbit GPT12E_T3CON_T3OE;              /* GPT12E_T3CON.9: <GPT12E_T3CON_T3OE> */
_sfrbit GPT12E_T3CON_T3OTL;             /* GPT12E_T3CON.10: <GPT12E_T3CON_T3OTL> */
_sfrbit GPT12E_T3CON_T3EDGE;            /* GPT12E_T3CON.13: <GPT12E_T3CON_T3EDGE> */
_sfrbit GPT12E_T3CON_T3CHDIR;           /* GPT12E_T3CON.14: <GPT12E_T3CON_T3CHDIR> */
_sfrbit GPT12E_T3CON_T3RDIR;            /* GPT12E_T3CON.15: <GPT12E_T3CON_T3RDIR> */

#define T3R             GPT12E_T3CON_T3R
#define T3CON           GPT12E_T3CON

_sfr GPT12E_T2CON;                      /* Timer 2 Control Register */
_sfrbit GPT12E_T2CON_T2R;               /* GPT12E_T2CON.6: <GPT12E_T2CON_T2R> */
_sfrbit GPT12E_T2CON_T2UD;              /* GPT12E_T2CON.7: <GPT12E_T2CON_T2UD> */
_sfrbit GPT12E_T2CON_T2UDE;             /* GPT12E_T2CON.8: <GPT12E_T2CON_T2UDE> */
_sfrbit GPT12E_T2CON_T2RC;              /* GPT12E_T2CON.9: <GPT12E_T2CON_T2RC> */
_sfrbit GPT12E_T2CON_T2IRDIS;           /* GPT12E_T2CON.12: <GPT12E_T2CON_T2IRDIS> */
_sfrbit GPT12E_T2CON_T2EDGE;            /* GPT12E_T2CON.13: <GPT12E_T2CON_T2EDGE> */
_sfrbit GPT12E_T2CON_T2CHDIR;           /* GPT12E_T2CON.14: <GPT12E_T2CON_T2CHDIR> */
_sfrbit GPT12E_T2CON_T2RDIR;            /* GPT12E_T2CON.15: <GPT12E_T2CON_T2RDIR> */

#define T2R             GPT12E_T2CON_T2R
#define T2CON           GPT12E_T2CON

_sfr GPT12E_T4CON;                      /* Timer 4 Control Register */
_sfrbit GPT12E_T4CON_T4R;               /* GPT12E_T4CON.6: <GPT12E_T4CON_T4R> */
_sfrbit GPT12E_T4CON_T4UD;              /* GPT12E_T4CON.7: <GPT12E_T4CON_T4UD> */
_sfrbit GPT12E_T4CON_T4UDE;             /* GPT12E_T4CON.8: <GPT12E_T4CON_T4UDE> */
_sfrbit GPT12E_T4CON_T4RC;              /* GPT12E_T4CON.9: <GPT12E_T4CON_T4RC> */
_sfrbit GPT12E_T4CON_CLRT2EN;           /* GPT12E_T4CON.10: <GPT12E_T4CON_CLRT2EN> */
_sfrbit GPT12E_T4CON_CLRT3EN;           /* GPT12E_T4CON.11: <GPT12E_T4CON_CLRT3EN> */
_sfrbit GPT12E_T4CON_T4IRDIS;           /* GPT12E_T4CON.12: <GPT12E_T4CON_T4IRDIS> */
_sfrbit GPT12E_T4CON_T4EDGE;            /* GPT12E_T4CON.13: <GPT12E_T4CON_T4EDGE> */
_sfrbit GPT12E_T4CON_T4CHDIR;           /* GPT12E_T4CON.14: <GPT12E_T4CON_T4CHDIR> */
_sfrbit GPT12E_T4CON_T4RDIR;            /* GPT12E_T4CON.15: <GPT12E_T4CON_T4RDIR> */

#define T4R             GPT12E_T4CON_T4R
#define T4CON           GPT12E_T4CON

_sfr GPT12E_T5;                         /* Timer 5 */

#define T5              GPT12E_T5

_sfr GPT12E_T6;                         /* Timer 6 */

#define T6              GPT12E_T6

_sfr GPT12E_CAPREL;                     /* Capture/Reload Register */

#define CAPREL          GPT12E_CAPREL

_sfr GPT12E_T6CON;                      /* Timer 6 Control Register */
_sfrbit GPT12E_T6CON_T6R;               /* GPT12E_T6CON.6: <GPT12E_T6CON_T6R> */
_sfrbit GPT12E_T6CON_T6UD;              /* GPT12E_T6CON.7: <GPT12E_T6CON_T6UD> */
_sfrbit GPT12E_T6CON_T6UDE;             /* GPT12E_T6CON.8: <GPT12E_T6CON_T6UDE> */
_sfrbit GPT12E_T6CON_T6OE;              /* GPT12E_T6CON.9: <GPT12E_T6CON_T6OE> */
_sfrbit GPT12E_T6CON_T6OTL;             /* GPT12E_T6CON.10: <GPT12E_T6CON_T6OTL> */
_sfrbit GPT12E_T6CON_T6CLR;             /* GPT12E_T6CON.14: <GPT12E_T6CON_T6CLR> */
_sfrbit GPT12E_T6CON_T6SR;              /* GPT12E_T6CON.15: <GPT12E_T6CON_T6SR> */

#define T6R             GPT12E_T6CON_T6R
#define T6CON           GPT12E_T6CON

_sfr GPT12E_T5CON;                      /* Timer 5 Control Register */
_sfrbit GPT12E_T5CON_T5R;               /* GPT12E_T5CON.6: <GPT12E_T5CON_T5R> */
_sfrbit GPT12E_T5CON_T5UD;              /* GPT12E_T5CON.7: <GPT12E_T5CON_T5UD> */
_sfrbit GPT12E_T5CON_T5UDE;             /* GPT12E_T5CON.8: <GPT12E_T5CON_T5UDE> */
_sfrbit GPT12E_T5CON_T5RC;              /* GPT12E_T5CON.9: <GPT12E_T5CON_T5RC> */
_sfrbit GPT12E_T5CON_CT3;               /* GPT12E_T5CON.10: <GPT12E_T5CON_CT3> */
_sfrbit GPT12E_T5CON_T5CLR;             /* GPT12E_T5CON.14: <GPT12E_T5CON_T5CLR> */
_sfrbit GPT12E_T5CON_T5SC;              /* GPT12E_T5CON.15: <GPT12E_T5CON_T5SC> */

#define T5R             GPT12E_T5CON_T5R
#define T5CON           GPT12E_T5CON

_sfr GPT12E_PISEL;                      /* Port Input Select Register */

_sfr GPT12E_ID;                         /* GPT12E Module Identification Register */

_sfr GPT12E_KSCCFG;                     /* Kernel State Configuration Register */

#endif /* REGXC2361E_NOGPT12 */

/********************************************************************************
 * Analog/Digital Convertor Control Registers
********************************************************************************/
#ifndef REGXC2361E_NOADC

_xsfr ADC0_KSCFG;                       /* Kernel State Configuration Register */

_xsfr ADC0_ID;                          /* Module Identification Register */

_xsfr ADC0_GLOBCTR;                     /* Global Control Register */

_xsfr ADC0_GLOBCFG;                     /* Global Configuration Register */

_xsfr ADC0_GLOBSTR;                     /* Global Status Register */

_xsfr ADC0_CRMR1;                       /* Conversion Request 1 Mode Register */

_xsfr ADC0_CRCR1;                       /* Conversion Request 1 Control Register */

_xsfr ADC0_CRPR1;                       /* Conversion Request 1 Pending Register */

_xsfr ADC0_QMR0;                        /* Queue 0 Mode Register */

_xsfr ADC0_QMR2;                        /* Queue 2 Mode Register */

_xsfr ADC0_QSR0;                        /* Queue 0 Status Register */

_xsfr ADC0_QSR2;                        /* Queue 2 Status Register */

_xsfr ADC0_QINR0;                       /* Queue 0 Input Register */

_xsfr ADC0_QINR2;                       /* Queue 2 Input Register */

_xsfr ADC0_Q0R0;                        /* Queue 0 Register 0 */

_xsfr ADC0_Q0R2;                        /* Queue 2 Register 0 */

_xsfr ADC0_RSIR0;                       /* Request Source 0 Input Register */

_xsfr ADC0_RSIR1;                       /* Request Source 1 Input Register */

_xsfr ADC0_RSIR2;                       /* Request Source 2 Input Register */

_xsfr ADC0_ASENR;                       /* Arbitration Slot Enable Register */

_xsfr ADC0_RSPR0;                       /* Request Source Priority Register 0 */

_xsfr ADC0_CHCTR0;                      /* Channel 0 Control Register */

_xsfr ADC0_CHCTR1;                      /* Channel 1 Control Register */

_xsfr ADC0_CHCTR2;                      /* Channel 2 Control Register */

_xsfr ADC0_CHCTR3;                      /* Channel 3 Control Register */

_xsfr ADC0_CHCTR4;                      /* Channel 4 Control Register */

_xsfr ADC0_CHCTR5;                      /* Channel 5 Control Register */

_xsfr ADC0_CHCTR6;                      /* Channel 6 Control Register */

_xsfr ADC0_CHCTR7;                      /* Channel 7 Control Register */

_xsfr ADC0_CHCTR8;                      /* Channel 8 Control Register */

_xsfr ADC0_CHCTR9;                      /* Channel 9 Control Register */

_xsfr ADC0_CHCTR10;                     /* Channel 10 Control Register */

_xsfr ADC0_CHCTR11;                     /* Channel 11 Control Register */

_xsfr ADC0_CHCTR12;                     /* Channel 12 Control Register */

_xsfr ADC0_CHCTR13;                     /* Channel 13 Control Register */

_xsfr ADC0_CHCTR14;                     /* Channel 14 Control Register */

_xsfr ADC0_CHCTR15;                     /* Channel 15 Control Register */

_xsfr ADC0_INPCR0;                      /* Input Class Register 0 */

_xsfr ADC0_INPCR1;                      /* Input Class Register 1 */

_xsfr ADC0_LCBR0;                       /* Limit Check Boundary Register 0 */

_xsfr ADC0_LCBR1;                       /* Limit Check Boundary Register 1 */

_xsfr ADC0_LCBR2;                       /* Limit Check Boundary Register 2 */

_xsfr ADC0_LCBR3;                       /* Limit Check Boundary Register 3 */

_xsfr ADC0_ALR0;                        /* Alias Register 0 */

_xsfr ADC0_RESR0;                       /* Result Register 0 */

_xsfr ADC0_RESR1;                       /* Result Register 1 */

_xsfr ADC0_RESR2;                       /* Result Register 2 */

_xsfr ADC0_RESR3;                       /* Result Register 3 */

_xsfr ADC0_RESR4;                       /* Result Register 4 */

_xsfr ADC0_RESR5;                       /* Result Register 5 */

_xsfr ADC0_RESR6;                       /* Result Register 6 */

_xsfr ADC0_RESR7;                       /* Result Register 7 */

_xsfr ADC0_RESRV0;                      /* Result Register 0, View V */

_xsfr ADC0_RESRV1;                      /* Result Register 1, View V */

_xsfr ADC0_RESRV2;                      /* Result Register 2, View V */

_xsfr ADC0_RESRV3;                      /* Result Register 3, View V */

_xsfr ADC0_RESRV4;                      /* Result Register 4, View V */

_xsfr ADC0_RESRV5;                      /* Result Register 5, View V */

_xsfr ADC0_RESRV6;                      /* Result Register 6, View V */

_xsfr ADC0_RESRV7;                      /* Result Register 7, View V */

_xsfr ADC0_RESRA0;                      /* Result Register 0, View A */

_xsfr ADC0_RESRA1;                      /* Result Register 1, View A */

_xsfr ADC0_RESRA2;                      /* Result Register 2, View A */

_xsfr ADC0_RESRA3;                      /* Result Register 3, View A */

_xsfr ADC0_RESRA4;                      /* Result Register 4, View A */

_xsfr ADC0_RESRA5;                      /* Result Register 5, View A */

_xsfr ADC0_RESRA6;                      /* Result Register 6, View A */

_xsfr ADC0_RESRA7;                      /* Result Register 7, View A */

_xsfr ADC0_RESRAV0;                     /* Result Register 0, View AV */

_xsfr ADC0_RESRAV1;                     /* Result Register 1, View AV */

_xsfr ADC0_RESRAV2;                     /* Result Register 2, View AV */

_xsfr ADC0_RESRAV3;                     /* Result Register 3, View AV */

_xsfr ADC0_RESRAV4;                     /* Result Register 4, View AV */

_xsfr ADC0_RESRAV5;                     /* Result Register 5, View AV */

_xsfr ADC0_RESRAV6;                     /* Result Register 6, View AV */

_xsfr ADC0_RESRAV7;                     /* Result Register 7, View AV */

_xsfr ADC0_RSSR;                        /* Result Status Shadow Register */

_xsfr ADC0_RCR0;                        /* Result Control Register 0 */

_xsfr ADC0_RCR1;                        /* Result Control Register 1 */

_xsfr ADC0_RCR2;                        /* Result Control Register 2 */

_xsfr ADC0_RCR3;                        /* Result Control Register 3 */

_xsfr ADC0_RCR4;                        /* Result Control Register 4 */

_xsfr ADC0_RCR5;                        /* Result Control Register 5 */

_xsfr ADC0_RCR6;                        /* Result Control Register 6 */

_xsfr ADC0_RCR7;                        /* Result Control Register 7 */

_xsfr ADC0_VFR;                         /* Valid Flag Register */

_xsfr ADC0_FCR0;                        /* Filter 0 Control Register */

_xsfr ADC0_FCR1;                        /* Filter 1 Control Register */

_xsfr ADC0_SRF0;                        /* Status Register Filter 0 */

_xsfr ADC0_SRF1;                        /* Status Register Filter 1 */

_xsfr ADC0_CRRL0;                       /* Filter 0 Current Result Low Reg. */

_xsfr ADC0_CRRL1;                       /* Filter 1 Current Result Low Reg. */

_xsfr ADC0_CRRH0;                       /* Filter 0 Current Result High Reg. */

_xsfr ADC0_CRRH1;                       /* Filter 1 Current Result High Reg. */

_xsfr ADC0_IRR10;                       /* Filter 0 Intermediate Result Reg. 1 */

_xsfr ADC0_IRR20;                       /* Filter 0 Intermediate Result Reg. 2 */

_xsfr ADC0_IRR30;                       /* Filter 0 Intermediate Result Reg. 3 */

_xsfr ADC0_IRR11L;                      /* Filter 1 Intermediate Result Reg. 1 Low */

_xsfr ADC0_IRR11H;                      /* Filter 1 Intermediate Result Reg. 1 High */

_xsfr ADC0_FRR0;                        /* Filter 0 Final Result Register */

_xsfr ADC0_FRR1;                        /* Filter 1 Final Result Register */

_xsfr ADC0_SFRR1;                       /* Filter 1 Shifted Final Result Register */

_xsfr ADC0_SYNCTR;                      /* Synchronization Control Register */

_xsfr ADC0_BWDENR;                      /* Broken Wire Detection Enable Reg. */

_xsfr ADC0_BWDCFGR;                     /* Broken Wire Detection Configuration Register */

_xsfr ADC0_EMENR;                       /* External Multiplexer Enable Register */

_xsfr ADC0_EMCTR;                       /* External Multiplexer Control Register */

_xsfr ADC0_EVINFR;                      /* Event Indication Flag Register */

_xsfr ADC0_EVINCR;                      /* Event Indication Clear Register */

_xsfr ADC0_CHINFR;                      /* Channel Event Indication Flag Register */

_xsfr ADC0_CHINCR;                      /* Channel Event Indication Clear Register */

_xsfr ADC0_EVINPR0;                     /* Event Interrupt Node Pointer Register 0 */

_xsfr ADC0_EVINPR8;                     /* Event Interrupt Node Pointer Register 8 */

_xsfr ADC0_EVINPR12;                    /* Event Interrupt Node Pointer Register 12 */

_xsfr ADC0_CHINPR0;                     /* Channel Intr. Node Pointer Reg. 0 */

_xsfr ADC0_CHINPR4;                     /* Channel Intr. Node Pointer Reg. 4 */

_xsfr ADC0_CHINPR8;                     /* Channel Intr. Node Pointer Reg. 8 */

_xsfr ADC0_CHINPR12;                    /* Channel Interrupt Node Pointer Register 12 */

_xsfr ADC1_ID;                          /* Module Identification Register */

_xsfr ADC1_GLOBCTR;                     /* Global Control Register */

_xsfr ADC1_GLOBCFG;                     /* Global Configuration Register */

_xsfr ADC1_GLOBSTR;                     /* Global Status Register */

_xsfr ADC1_CRMR1;                       /* Conversion Request 1 Mode Register */

_xsfr ADC1_CRCR1;                       /* Conversion Request 1 Control Register */

_xsfr ADC1_CRPR1;                       /* Conversion Request 1 Pending Register */

_xsfr ADC1_QMR0;                        /* Queue 0 Mode Register */

_xsfr ADC1_QMR2;                        /* Queue 2 Mode Register */

_xsfr ADC1_QSR0;                        /* Queue 0 Status Register */

_xsfr ADC1_QSR2;                        /* Queue 2 Status Register */

_xsfr ADC1_QINR0;                       /* Queue 0 Input Register */

_xsfr ADC1_QINR2;                       /* Queue 2 Input Register */

_xsfr ADC1_Q0R0;                        /* Queue 0 Register 0 */

_xsfr ADC1_Q0R2;                        /* Queue 2 Register 0 */

_xsfr ADC1_RSIR0;                       /* Request Source 0 Input Register */

_xsfr ADC1_RSIR1;                       /* Request Source 1 Input Register */

_xsfr ADC1_RSIR2;                       /* Request Source 2 Input Register */

_xsfr ADC1_ASENR;                       /* Arbitration Slot Enable Register */

_xsfr ADC1_RSPR0;                       /* Request Source Priority Register 0 */

_xsfr ADC1_CHCTR0;                      /* Channel 0 Control Register */

_xsfr ADC1_CHCTR1;                      /* Channel 1 Control Register */

_xsfr ADC1_CHCTR2;                      /* Channel 2 Control Register */

_xsfr ADC1_CHCTR3;                      /* Channel 3 Control Register */

_xsfr ADC1_CHCTR4;                      /* Channel 4 Control Register */

_xsfr ADC1_CHCTR5;                      /* Channel 5 Control Register */

_xsfr ADC1_CHCTR6;                      /* Channel 6 Control Register */

_xsfr ADC1_CHCTR7;                      /* Channel 7 Control Register */

_xsfr ADC1_CHCTR8;                      /* Channel 8 Control Register */

_xsfr ADC1_CHCTR9;                      /* Channel 9 Control Register */

_xsfr ADC1_CHCTR10;                     /* Channel 10 Control Register */

_xsfr ADC1_CHCTR11;                     /* Channel 11 Control Register */

_xsfr ADC1_CHCTR12;                     /* Channel 12 Control Register */

_xsfr ADC1_CHCTR13;                     /* Channel 13 Control Register */

_xsfr ADC1_CHCTR14;                     /* Channel 14 Control Register */

_xsfr ADC1_CHCTR15;                     /* Channel 15 Control Register */

_xsfr ADC1_INPCR0;                      /* Input Class Register 0 */

_xsfr ADC1_INPCR1;                      /* Input Class Register 1 */

_xsfr ADC1_LCBR0;                       /* Limit Check Boundary Register 0 */

_xsfr ADC1_LCBR1;                       /* Limit Check Boundary Register 1 */

_xsfr ADC1_LCBR2;                       /* Limit Check Boundary Register 2 */

_xsfr ADC1_LCBR3;                       /* Limit Check Boundary Register 3 */

_xsfr ADC1_ALR0;                        /* Alias Register 0 */

_xsfr ADC1_RESR0;                       /* Result Register 0 */

_xsfr ADC1_RESR1;                       /* Result Register 1 */

_xsfr ADC1_RESR2;                       /* Result Register 2 */

_xsfr ADC1_RESR3;                       /* Result Register 3 */

_xsfr ADC1_RESR4;                       /* Result Register 4 */

_xsfr ADC1_RESR5;                       /* Result Register 5 */

_xsfr ADC1_RESR6;                       /* Result Register 6 */

_xsfr ADC1_RESR7;                       /* Result Register 7 */

_xsfr ADC1_RESRV0;                      /* Result Register 0, View V */

_xsfr ADC1_RESRV1;                      /* Result Register 1, View V */

_xsfr ADC1_RESRV2;                      /* Result Register 2, View V */

_xsfr ADC1_RESRV3;                      /* Result Register 3, View V */

_xsfr ADC1_RESRV4;                      /* Result Register 4, View V */

_xsfr ADC1_RESRV5;                      /* Result Register 5, View V */

_xsfr ADC1_RESRV6;                      /* Result Register 6, View V */

_xsfr ADC1_RESRV7;                      /* Result Register 7, View V */

_xsfr ADC1_RESRA0;                      /* Result Register 0, View A */

_xsfr ADC1_RESRA1;                      /* Result Register 1, View A */

_xsfr ADC1_RESRA2;                      /* Result Register 2, View A */

_xsfr ADC1_RESRA3;                      /* Result Register 3, View A */

_xsfr ADC1_RESRA4;                      /* Result Register 4, View A */

_xsfr ADC1_RESRA5;                      /* Result Register 5, View A */

_xsfr ADC1_RESRA6;                      /* Result Register 6, View A */

_xsfr ADC1_RESRA7;                      /* Result Register 7, View A */

_xsfr ADC1_RESRAV0;                     /* Result Register 0, View AV */

_xsfr ADC1_RESRAV1;                     /* Result Register 1, View AV */

_xsfr ADC1_RESRAV2;                     /* Result Register 2, View AV */

_xsfr ADC1_RESRAV3;                     /* Result Register 3, View AV */

_xsfr ADC1_RESRAV4;                     /* Result Register 4, View AV */

_xsfr ADC1_RESRAV5;                     /* Result Register 5, View AV */

_xsfr ADC1_RESRAV6;                     /* Result Register 6, View AV */

_xsfr ADC1_RESRAV7;                     /* Result Register 7, View AV */

_xsfr ADC1_RSSR;                        /* Result Status Shadow Register */

_xsfr ADC1_RCR0;                        /* Result Control Register 0 */

_xsfr ADC1_RCR1;                        /* Result Control Register 1 */

_xsfr ADC1_RCR2;                        /* Result Control Register 2 */

_xsfr ADC1_RCR3;                        /* Result Control Register 3 */

_xsfr ADC1_RCR4;                        /* Result Control Register 4 */

_xsfr ADC1_RCR5;                        /* Result Control Register 5 */

_xsfr ADC1_RCR6;                        /* Result Control Register 6 */

_xsfr ADC1_RCR7;                        /* Result Control Register 7 */

_xsfr ADC1_VFR;                         /* Valid Flag Register */

_xsfr ADC1_FCR0;                        /* Filter 0 Control Register */

_xsfr ADC1_FCR1;                        /* Filter 1 Control Register */

_xsfr ADC1_SRF0;                        /* Status Register Filter 0 */

_xsfr ADC1_SRF1;                        /* Status Register Filter 1 */

_xsfr ADC1_CRRL0;                       /* Filter 0 Current Result Low Reg. */

_xsfr ADC1_CRRL1;                       /* Filter 1 Current Result Low Reg. */

_xsfr ADC1_CRRH0;                       /* Filter 0 Current Result High Reg. */

_xsfr ADC1_CRRH1;                       /* Filter 1 Current Result High Reg. */

_xsfr ADC1_IRR10;                       /* Filter 0 Intermediate Result Reg. 1 */

_xsfr ADC1_IRR20;                       /* Filter 0 Intermediate Result Reg. 2 */

_xsfr ADC1_IRR30;                       /* Filter 0 Intermediate Result Reg. 3 */

_xsfr ADC1_IRR11L;                      /* Filter 1 Intermediate Result Reg. 1 Low */

_xsfr ADC1_IRR11H;                      /* Filter 1 Intermediate Result Reg. 1 High */

_xsfr ADC1_FRR0;                        /* Filter 0 Final Result Register */

_xsfr ADC1_FRR1;                        /* Filter 1 Final Result Register */

_xsfr ADC1_SFRR1;                       /* Filter 1 Shifted Final Result Register */

_xsfr ADC1_SYNCTR;                      /* Synchronization Control Register */

_xsfr ADC1_BWDENR;                      /* Broken Wire Detection Enable Reg. */

_xsfr ADC1_BWDCFGR;                     /* Broken Wire Detection Configuration Register */

_xsfr ADC1_EMENR;                       /* External Multiplexer Enable Register */

_xsfr ADC1_EMCTR;                       /* External Multiplexer Control Register */

_xsfr ADC1_EVINFR;                      /* Event Indication Flag Register */

_xsfr ADC1_EVINCR;                      /* Event Indication Clear Register */

_xsfr ADC1_CHINFR;                      /* Channel Event Indication Flag Register */

_xsfr ADC1_CHINCR;                      /* Channel Event Indication Clear Register */

_xsfr ADC1_EVINPR0;                     /* Event Interrupt Node Pointer Register 0 */

_xsfr ADC1_EVINPR8;                     /* Event Interrupt Node Pointer Register 8 */

_xsfr ADC1_EVINPR12;                    /* Event Interrupt Node Pointer Register 12 */

_xsfr ADC1_CHINPR0;                     /* Channel Intr. Node Pointer Reg. 0 */

_xsfr ADC1_CHINPR4;                     /* Channel Intr. Node Pointer Reg. 4 */

_xsfr ADC1_CHINPR8;                     /* Channel Intr. Node Pointer Reg. 8 */

_xsfr ADC1_CHINPR12;                    /* Channel Interrupt Node Pointer Register 12 */

#endif /* REGXC2361E_NOADC */

/********************************************************************************
 * RTC
********************************************************************************/
#ifndef REGXC2361E_NORTC

_esfr RTC_CON;                          /* RTC Control Register */
_esfrbit RTC_CON_RUN;                   /* RTC_CON.0: RTC Run Bit */
_esfrbit RTC_CON_PRE;                   /* RTC_CON.1: RTC Input Source Prescaler (8:1) Enable */
_esfrbit RTC_CON_T14DEC;                /* RTC_CON.2: Decrement Timer T14 Value */
_esfrbit RTC_CON_T14INC;                /* RTC_CON.3: Increment Timer T14 Value */
_esfrbit RTC_CON_REFCLK;                /* RTC_CON.4: RTC Input Source Prescaler (32:1) Disable */
_esfrbit RTC_CON_ACCPOS;                /* RTC_CON.15: RTC Register Access Possible */

_esfr RTC_T14;                          /* T14 Count Register */

_esfr RTC_T14REL;                       /* T14 Reload Register */

_esfr RTC_RTCH;                         /* RTC Timer High Register */

_esfr RTC_RTCL;                         /* RTC Timer Low Register */

_esfr RTC_RELH;                         /* RTC Reload High Register */

_esfr RTC_RELL;                         /* RTC Reload Low Register */

_esfr RTC_ISNC;                         /* RTC Interrupt Subnode Ctrl. Reg. */
_esfrbit RTC_ISNC_T14IE;                /* RTC_ISNC.0: T14 Overflow Interrupt Enable Control Bit */
_esfrbit RTC_ISNC_T14IR;                /* RTC_ISNC.1: T14 Overflow Interrupt Request Flag */
_esfrbit RTC_ISNC_CNT0IE;               /* RTC_ISNC.2: Section CNTx Interrupt Enable Control Bit */
_esfrbit RTC_ISNC_CNT0IR;               /* RTC_ISNC.3: Section CNTx Interrupt Request Flag */
_esfrbit RTC_ISNC_CNT1IE;               /* RTC_ISNC.4: Section CNTx Interrupt Enable Control Bit */
_esfrbit RTC_ISNC_CNT1IR;               /* RTC_ISNC.5: Section CNTx Interrupt Request Flag */
_esfrbit RTC_ISNC_CNT2IE;               /* RTC_ISNC.6: Section CNTx Interrupt Enable Control Bit */
_esfrbit RTC_ISNC_CNT2IR;               /* RTC_ISNC.7: Section CNTx Interrupt Request Flag */
_esfrbit RTC_ISNC_CNT3IE;               /* RTC_ISNC.8: Section CNTx Interrupt Enable Control Bit */
_esfrbit RTC_ISNC_CNT3IR;               /* RTC_ISNC.9: Section CNTx Interrupt Request Flag */

_esfr RTC_KSCCFG;                       /* RTC Kernel State Configuration Register */

_sfr RTC_ID;                            /* RTC Identification Register MEM */

#endif /* REGXC2361E_NORTC */

/********************************************************************************
 * Capture/Compare 2 Control Registers
********************************************************************************/
#ifndef REGXC2361E_NOCAPCOM2

_sfr CC2_ID;                            /* CAPCOM2 Identification Register MEM */

_esfr CC2_T7;                           /* CAPCOM2 Timer 7 Register */

_esfr CC2_T8;                           /* CAPCOM2 Timer 8 Register */

_esfr CC2_T7REL;                        /* CAPCOM2 Timer 7 Reload Register */

_esfr CC2_T8REL;                        /* CAPCOM2 Timer 8 Reload Register */

_sfr CC2_T78CON;                        /* CAPCOM2 Timer 7/8 Control Register */
_sfrbit CC2_T78CON_T7M;                 /* CC2_T78CON.3: Timer / Counter x Mode Selection */
_sfrbit CC2_T78CON_T7R;                 /* CC2_T78CON.6: Timer / Counter x Run Control */
_sfrbit CC2_T78CON_T8M;                 /* CC2_T78CON.11: Timer / Counter x Mode Selection */
_sfrbit CC2_T78CON_T8R;                 /* CC2_T78CON.14: Timer / Counter x Run Control */

_sfr CC2_CC16;                          /* CAPCOM2 Capture/Compare Register 16 */

_sfr CC2_CC17;                          /* CAPCOM2 Capture/Compare Register 17 */

_sfr CC2_CC18;                          /* CAPCOM2 Capture/Compare Register 18 */

_sfr CC2_CC19;                          /* CAPCOM2 Capture/Compare Register 19 */

_sfr CC2_CC20;                          /* CAPCOM2 Capture/Compare Register 20 */

_sfr CC2_CC21;                          /* CAPCOM2 Capture/Compare Register 21 */

_sfr CC2_CC22;                          /* CAPCOM2 Capture/Compare Register 22 */

_sfr CC2_CC23;                          /* CAPCOM2 Capture/Compare Register 23 */

_sfr CC2_CC24;                          /* CAPCOM2 Capture/Compare Register 24 */

_sfr CC2_CC25;                          /* CAPCOM2 Capture/Compare Register 25 */

_sfr CC2_CC26;                          /* CAPCOM2 Capture/Compare Register 26 */

_sfr CC2_CC27;                          /* CAPCOM2 Capture/Compare Register 27 */

_sfr CC2_CC28;                          /* CAPCOM2 Capture/Compare Register 28 */

_sfr CC2_CC29;                          /* CAPCOM2 Capture/Compare Register 29 */

_sfr CC2_CC30;                          /* CAPCOM2 Capture/Compare Register 30 */

_sfr CC2_CC31;                          /* CAPCOM2 Capture/Compare Register 31 */

_sfr CC2_M4;                            /* CAPCOM2 Mode Control Register 4 */
_sfrbit CC2_M4_ACC16;                   /* CC2_M4.3: Allocation Bit for CAPCOM Register CCy (y = 16-19) */
_sfrbit CC2_M4_ACC17;                   /* CC2_M4.7: Allocation Bit for CAPCOM Register CCy (y = 16-19) */
_sfrbit CC2_M4_ACC18;                   /* CC2_M4.11: Allocation Bit for CAPCOM Register CCy (y = 16-19) */
_sfrbit CC2_M4_ACC19;                   /* CC2_M4.15: Allocation Bit for CAPCOM Register CCy (y = 16-19) */

_sfr CC2_M5;                            /* CAPCOM2 Mode Control Register 5 */
_sfrbit CC2_M5_ACC20;                   /* CC2_M5.3: Allocation Bit for CAPCOM Register CCy (y = 20-23) */
_sfrbit CC2_M5_ACC21;                   /* CC2_M5.7: Allocation Bit for CAPCOM Register CCy (y = 20-23) */
_sfrbit CC2_M5_ACC22;                   /* CC2_M5.11: Allocation Bit for CAPCOM Register CCy (y = 20-23) */
_sfrbit CC2_M5_ACC23;                   /* CC2_M5.15: Allocation Bit for CAPCOM Register CCy (y = 20-23) */

_sfr CC2_M6;                            /* CAPCOM2 Mode Control Register 6 */
_sfrbit CC2_M6_ACC24;                   /* CC2_M6.3: Allocation Bit for CAPCOM Register CCy (y = 24-28) */
_sfrbit CC2_M6_ACC25;                   /* CC2_M6.7: Allocation Bit for CAPCOM Register CCy (y = 24-28) */
_sfrbit CC2_M6_ACC26;                   /* CC2_M6.11: Allocation Bit for CAPCOM Register CCy (y = 24-28) */
_sfrbit CC2_M6_ACC27;                   /* CC2_M6.15: Allocation Bit for CAPCOM Register CCy (y = 24-28) */

_sfr CC2_M7;                            /* CAPCOM2 Mode Control Register 7 */
_sfrbit CC2_M7_ACC28;                   /* CC2_M7.3: Allocation Bit for CAPCOM Register CCy (y = 28-31) */
_sfrbit CC2_M7_ACC29;                   /* CC2_M7.7: Allocation Bit for CAPCOM Register CCy (y = 28-31) */
_sfrbit CC2_M7_ACC30;                   /* CC2_M7.11: Allocation Bit for CAPCOM Register CCy (y = 28-31) */
_sfrbit CC2_M7_ACC31;                   /* CC2_M7.15: Allocation Bit for CAPCOM Register CCy (y = 28-31) */

_sfr CC2_OUT;                           /* CAPCOM2 Compare Output Register */
_sfrbit CC2_OUT_CC16IO;                 /* CC2_OUT.0: Compare Output for Channel y */
_sfrbit CC2_OUT_CC17IO;                 /* CC2_OUT.1: Compare Output for Channel y */
_sfrbit CC2_OUT_CC18IO;                 /* CC2_OUT.2: Compare Output for Channel y */
_sfrbit CC2_OUT_CC19IO;                 /* CC2_OUT.3: Compare Output for Channel y */
_sfrbit CC2_OUT_CC20IO;                 /* CC2_OUT.4: Compare Output for Channel y */
_sfrbit CC2_OUT_CC21IO;                 /* CC2_OUT.5: Compare Output for Channel y */
_sfrbit CC2_OUT_CC22IO;                 /* CC2_OUT.6: Compare Output for Channel y */
_sfrbit CC2_OUT_CC23IO;                 /* CC2_OUT.7: Compare Output for Channel y */
_sfrbit CC2_OUT_CC24IO;                 /* CC2_OUT.8: Compare Output for Channel y */
_sfrbit CC2_OUT_CC25IO;                 /* CC2_OUT.9: Compare Output for Channel y */
_sfrbit CC2_OUT_CC26IO;                 /* CC2_OUT.10: Compare Output for Channel y */
_sfrbit CC2_OUT_CC27IO;                 /* CC2_OUT.11: Compare Output for Channel y */
_sfrbit CC2_OUT_CC28IO;                 /* CC2_OUT.12: Compare Output for Channel y */
_sfrbit CC2_OUT_CC29IO;                 /* CC2_OUT.13: Compare Output for Channel y */
_sfrbit CC2_OUT_CC30IO;                 /* CC2_OUT.14: Compare Output for Channel y */
_sfrbit CC2_OUT_CC31IO;                 /* CC2_OUT.15: Compare Output for Channel y */

_sfr CC2_DRM;                           /* CAPCOM2 Double-Register Compare Mode Register */

_esfr CC2_IOC;                          /* CAPCOM2 I/O Control Register */

_sfr CC2_SEM;                           /* CAPCOM2 Single Event Mode Control Register */

_sfr CC2_SEE;                           /* CAPCOM2 Single Event Enable Register */

_sfr CC2_KSCCFG;                        /* CAPCOM2 Kernel State Configuration Register */

#endif /* REGXC2361E_NOCAPCOM2 */

/********************************************************************************
 * CCU6
********************************************************************************/
#ifndef REGXC2361E_NOCCU6

_xsfr CCU60_T12;                        /* Timer T12 Counter Register */

_xsfr CCU60_T12PR;                      /* Timer 12 Period Register */

_xsfr CCU60_CC60R;                      /* Capture/Compare Register for Channel CC60 */

_xsfr CCU60_CC61R;                      /* Capture/Compare Register for Channel CC61 */

_xsfr CCU60_CC62R;                      /* Capture/Compare Register for Channel CC62 */

_xsfr CCU60_CC60SR;                     /* Capture/Compare Shadow Reg. for Channel CC60 */

_xsfr CCU60_CC61SR;                     /* Capture/Compare Shadow Reg. for Channel CC61 */

_xsfr CCU60_CC62SR;                     /* Capture/Compare Shadow Reg. for Channel CC62 */

_xsfr CCU60_T12DTC;                     /* Dead-Time Control Register for Timer12 */

_xsfr CCU60_CMPSTAT;                    /* Compare State Register */

_xsfr CCU60_CMPMODIF;                   /* Compare State Modification Register */

_xsfr CCU60_T12MSEL;                    /* T12 Mode Select Register */

_xsfr CCU60_TCTR0;                      /* Timer Control Register 0 */

_xsfr CCU60_TCTR2;                      /* Timer Control Register 2 */

_xsfr CCU60_TCTR4;                      /* Timer Control Register 4 */

_xsfr CCU60_T13;                        /* Timer T13 Counter Register */

_xsfr CCU60_T13PR;                      /* Timer 13 Period Register */

_xsfr CCU60_CC63R;                      /* Compare Register for T13 */

_xsfr CCU60_CC63SR;                     /* Compare Shadow Register for T13 */

_xsfr CCU60_MODCTR;                     /* Modulation Control Register */

_xsfr CCU60_TRPCTR;                     /* Trap Control Register */

_xsfr CCU60_PSLR;                       /* Passive State Level Register */

_xsfr CCU60_MCMCTR;                     /* Multi-Channel Mode Control Register */

_xsfr CCU60_MCMOUTS;                    /* Multi-Channel Mode Output Shadow Register */

_xsfr CCU60_MCMOUT;                     /* Multi-Channel Mode Output Register */

_xsfr CCU60_IS;                         /* Interrupt Status Register */

_xsfr CCU60_ISS;                        /* Interrupt Status Set Register */

_xsfr CCU60_ISR;                        /* Interrupt Status Reset Register */

_xsfr CCU60_IEN;                        /* Interrupt Enable Register */

_xsfr CCU60_INP;                        /* Interrupt Node Pointer Register */

_xsfr CCU60_ID;                         /* Module Identification Register */

_xsfr CCU60_PISELL;                     /* Port Input Select Register Low */

_xsfr CCU60_PISELH;                     /* Port Input Select Register High */

_xsfr CCU60_KSCFG;                      /* Kernel State Configuration Register */

_xsfr CCU60_KSCSR;                      /* Kernel State Control Sensitivity Register */

_xsfr CCU61_T12;                        /* Timer T12 Counter Register */

_xsfr CCU61_T12PR;                      /* Timer 12 Period Register */

_xsfr CCU61_CC60R;                      /* Capture/Compare Register for Channel CC60 */

_xsfr CCU61_CC61R;                      /* Capture/Compare Register for Channel CC61 */

_xsfr CCU61_CC62R;                      /* Capture/Compare Register for Channel CC62 */

_xsfr CCU61_CC60SR;                     /* Capture/Compare Shadow Reg. for Channel CC60 */

_xsfr CCU61_CC61SR;                     /* Capture/Compare Shadow Reg. for Channel CC61 */

_xsfr CCU61_CC62SR;                     /* Capture/Compare Shadow Reg. for Channel CC62 */

_xsfr CCU61_T12DTC;                     /* Dead-Time Control Register for Timer12 */

_xsfr CCU61_CMPSTAT;                    /* Compare State Register */

_xsfr CCU61_CMPMODIF;                   /* Compare State Modification Register */

_xsfr CCU61_T12MSEL;                    /* T12 Mode Select Register */

_xsfr CCU61_TCTR0;                      /* Timer Control Register 0 */

_xsfr CCU61_TCTR2;                      /* Timer Control Register 2 */

_xsfr CCU61_TCTR4;                      /* Timer Control Register 4 */

_xsfr CCU61_T13;                        /* Timer T13 Counter Register */

_xsfr CCU61_T13PR;                      /* Timer 13 Period Register */

_xsfr CCU61_CC63R;                      /* Compare Register for T13 */

_xsfr CCU61_CC63SR;                     /* Compare Shadow Register for T13 */

_xsfr CCU61_MODCTR;                     /* Modulation Control Register */

_xsfr CCU61_TRPCTR;                     /* Trap Control Register */

_xsfr CCU61_PSLR;                       /* Passive State Level Register */

_xsfr CCU61_MCMCTR;                     /* Multi-Channel Mode Control Register */

_xsfr CCU61_MCMOUTS;                    /* Multi-Channel Mode Output Shadow Register */

_xsfr CCU61_MCMOUT;                     /* Multi-Channel Mode Output Register */

_xsfr CCU61_IS;                         /* Interrupt Status Register */

_xsfr CCU61_ISS;                        /* Interrupt Status Set Register */

_xsfr CCU61_ISR;                        /* Interrupt Status Reset Register */

_xsfr CCU61_IEN;                        /* Interrupt Enable Register */

_xsfr CCU61_INP;                        /* Interrupt Node Pointer Register */

_xsfr CCU61_ID;                         /* Module Identification Register */

_xsfr CCU61_PISELL;                     /* Port Input Select Register Low */

_xsfr CCU61_PISELH;                     /* Port Input Select Register High */

_xsfr CCU61_KSCFG;                      /* Kernel State Configuration Register */

_xsfr CCU61_KSCSR;                      /* Kernel State Control Sensitivity Register */

_xsfr CCU62_T12;                        /* Timer T12 Counter Register */

_xsfr CCU62_T12PR;                      /* Timer 12 Period Register */

_xsfr CCU62_CC60R;                      /* Capture/Compare Register for Channel CC60 */

_xsfr CCU62_CC61R;                      /* Capture/Compare Register for Channel CC61 */

_xsfr CCU62_CC62R;                      /* Capture/Compare Register for Channel CC62 */

_xsfr CCU62_CC60SR;                     /* Capture/Compare Shadow Reg. for Channel CC60 */

_xsfr CCU62_CC61SR;                     /* Capture/Compare Shadow Reg. for Channel CC61 */

_xsfr CCU62_CC62SR;                     /* Capture/Compare Shadow Reg. for Channel CC62 */

_xsfr CCU62_T12DTC;                     /* Dead-Time Control Register for Timer12 */

_xsfr CCU62_CMPSTAT;                    /* Compare State Register */

_xsfr CCU62_CMPMODIF;                   /* Compare State Modification Register */

_xsfr CCU62_T12MSEL;                    /* T12 Mode Select Register */

_xsfr CCU62_TCTR0;                      /* Timer Control Register 0 */

_xsfr CCU62_TCTR2;                      /* Timer Control Register 2 */

_xsfr CCU62_TCTR4;                      /* Timer Control Register 4 */

_xsfr CCU62_T13;                        /* Timer T13 Counter Register */

_xsfr CCU62_T13PR;                      /* Timer 13 Period Register */

_xsfr CCU62_CC63R;                      /* Compare Register for T13 */

_xsfr CCU62_CC63SR;                     /* Compare Shadow Register for T13 */

_xsfr CCU62_MODCTR;                     /* Modulation Control Register */

_xsfr CCU62_TRPCTR;                     /* Trap Control Register */

_xsfr CCU62_PSLR;                       /* Passive State Level Register */

_xsfr CCU62_MCMCTR;                     /* Multi-Channel Mode Control Register */

_xsfr CCU62_MCMOUTS;                    /* Multi-Channel Mode Output Shadow Register */

_xsfr CCU62_MCMOUT;                     /* Multi-Channel Mode Output Register */

_xsfr CCU62_IS;                         /* Interrupt Status Register */

_xsfr CCU62_ISS;                        /* Interrupt Status Set Register */

_xsfr CCU62_ISR;                        /* Interrupt Status Reset Register */

_xsfr CCU62_IEN;                        /* Interrupt Enable Register */

_xsfr CCU62_INP;                        /* Interrupt Node Pointer Register */

_xsfr CCU62_ID;                         /* Module Identification Register */

_xsfr CCU62_PISELL;                     /* Port Input Select Register Low */

_xsfr CCU62_PISELH;                     /* Port Input Select Register High */

_xsfr CCU62_KSCFG;                      /* Kernel State Configuration Register */

_xsfr CCU62_KSCSR;                      /* Kernel State Control Sensitivity Register */

_xsfr CCU63_T12;                        /* Timer T12 Counter Register */

_xsfr CCU63_T12PR;                      /* Timer 12 Period Register */

_xsfr CCU63_CC60R;                      /* Capture/Compare Register for Channel CC60 */

_xsfr CCU63_CC61R;                      /* Capture/Compare Register for Channel CC61 */

_xsfr CCU63_CC62R;                      /* Capture/Compare Register for Channel CC62 */

_xsfr CCU63_CC60SR;                     /* Capture/Compare Shadow Reg. for Channel CC60 */

_xsfr CCU63_CC61SR;                     /* Capture/Compare Shadow Reg. for Channel CC61 */

_xsfr CCU63_CC62SR;                     /* Capture/Compare Shadow Reg. for Channel CC62 */

_xsfr CCU63_T12DTC;                     /* Dead-Time Control Register for Timer12 */

_xsfr CCU63_CMPSTAT;                    /* Compare State Register */

_xsfr CCU63_CMPMODIF;                   /* Compare State Modification Register */

_xsfr CCU63_T12MSEL;                    /* T12 Mode Select Register */

_xsfr CCU63_TCTR0;                      /* Timer Control Register 0 */

_xsfr CCU63_TCTR2;                      /* Timer Control Register 2 */

_xsfr CCU63_TCTR4;                      /* Timer Control Register 4 */

_xsfr CCU63_T13;                        /* Timer T13 Counter Register */

_xsfr CCU63_T13PR;                      /* Timer 13 Period Register */

_xsfr CCU63_CC63R;                      /* Compare Register for T13 */

_xsfr CCU63_CC63SR;                     /* Compare Shadow Register for T13 */

_xsfr CCU63_MODCTR;                     /* Modulation Control Register */

_xsfr CCU63_TRPCTR;                     /* Trap Control Register */

_xsfr CCU63_PSLR;                       /* Passive State Level Register */

_xsfr CCU63_MCMCTR;                     /* Multi-Channel Mode Control Register */

_xsfr CCU63_MCMOUTS;                    /* Multi-Channel Mode Output Shadow Register */

_xsfr CCU63_MCMOUT;                     /* Multi-Channel Mode Output Register */

_xsfr CCU63_IS;                         /* Interrupt Status Register */

_xsfr CCU63_ISS;                        /* Interrupt Status Set Register */

_xsfr CCU63_ISR;                        /* Interrupt Status Reset Register */

_xsfr CCU63_IEN;                        /* Interrupt Enable Register */

_xsfr CCU63_INP;                        /* Interrupt Node Pointer Register */

_xsfr CCU63_ID;                         /* Module Identification Register */

_xsfr CCU63_PISELL;                     /* Port Input Select Register Low */

_xsfr CCU63_PISELH;                     /* Port Input Select Register High */

_xsfr CCU63_KSCFG;                      /* Kernel State Configuration Register */

_xsfr CCU63_KSCSR;                      /* Kernel State Control Sensitivity Register */

#endif /* REGXC2361E_NOCCU6 */

/********************************************************************************
 * USIC0
********************************************************************************/
#ifndef REGXC2361E_NOUSIC0


#define U0C0_CCR        (*(_PAGE_081_MEM_TYPE(0x204010))) /* Channel Control Register */


#define U0C0_CCFG       (*(_PAGE_081_MEM_TYPE(0x204018))) /* Channel Configuration Register */


#define U0C0_KSCFG      (*(_PAGE_081_MEM_TYPE(0x20400C))) /* Kernel State Configuration Register */


#define U0C0_INPRL      (*(_PAGE_081_MEM_TYPE(0x204014))) /* Interrupt Node Pointer Register L */


#define U0C0_INPRH      (*(_PAGE_081_MEM_TYPE(0x204016))) /* Interrupt Node Pointer Register H */


#define U0C0_PCRL       (*(_PAGE_081_MEM_TYPE(0x204040))) /* Protocol Control Register L */


#define U0C0_PCRH       (*(_PAGE_081_MEM_TYPE(0x204042))) /* Protocol Control Register H */


#define U0C0_PSR        (*(_PAGE_081_MEM_TYPE(0x204044))) /* Protocol Status Register */


#define U0C0_PSCR       (*(_PAGE_081_MEM_TYPE(0x204048))) /* Protocol Status Clear Register */


#define U0C0_DX0CR      (*(_PAGE_081_MEM_TYPE(0x204020))) /* Input Control Register 0 */


#define U0C0_DX1CR      (*(_PAGE_081_MEM_TYPE(0x204024))) /* Input Control Register 1 */


#define U0C0_DX2CR      (*(_PAGE_081_MEM_TYPE(0x204028))) /* Input Control Register 2 */


#define U0C0_FDRL       (*(_PAGE_081_MEM_TYPE(0x204004))) /* Fractional Divider Register L */


#define U0C0_FDRH       (*(_PAGE_081_MEM_TYPE(0x204006))) /* Fractional Divider Register H */


#define U0C0_BRGL       (*(_PAGE_081_MEM_TYPE(0x20401C))) /* Baud Rate Generator Register L */


#define U0C0_BRGH       (*(_PAGE_081_MEM_TYPE(0x20401E))) /* Baud Rate Generator Register H */


#define U0C0_SCTRL      (*(_PAGE_081_MEM_TYPE(0x204030))) /* Shift Control Register L */


#define U0C0_SCTRH      (*(_PAGE_081_MEM_TYPE(0x204032))) /* Shift Control Register H */


#define U0C0_TCSRL      (*(_PAGE_081_MEM_TYPE(0x20403C))) /* Transmit Control/Status Register L */


#define U0C0_TCSRH      (*(_PAGE_081_MEM_TYPE(0x20403E))) /* Transmit Control/Status Register H */


#define U0C0_FMRL       (*(_PAGE_081_MEM_TYPE(0x204038))) /* Flag Modification Register L */


#define U0C0_FMRH       (*(_PAGE_081_MEM_TYPE(0x20403A))) /* Flag Modification Register H */


#define U0C0_TBUF00     (*(_PAGE_081_MEM_TYPE(0x204080))) /* Transmit Buffer Input Location 00 */


#define U0C0_TBUF01     (*(_PAGE_081_MEM_TYPE(0x204084))) /* Transmit Buffer Input Location 01 */


#define U0C0_TBUF02     (*(_PAGE_081_MEM_TYPE(0x204088))) /* Transmit Buffer Input Location 02 */


#define U0C0_TBUF03     (*(_PAGE_081_MEM_TYPE(0x20408C))) /* Transmit Buffer Input Location 03 */


#define U0C0_TBUF04     (*(_PAGE_081_MEM_TYPE(0x204090))) /* Transmit Buffer Input Location 04 */


#define U0C0_TBUF05     (*(_PAGE_081_MEM_TYPE(0x204094))) /* Transmit Buffer Input Location 05 */


#define U0C0_TBUF06     (*(_PAGE_081_MEM_TYPE(0x204098))) /* Transmit Buffer Input Location 06 */


#define U0C0_TBUF07     (*(_PAGE_081_MEM_TYPE(0x20409C))) /* Transmit Buffer Input Location 07 */


#define U0C0_TBUF08     (*(_PAGE_081_MEM_TYPE(0x2040A0))) /* Transmit Buffer Input Location 08 */


#define U0C0_TBUF09     (*(_PAGE_081_MEM_TYPE(0x2040A4))) /* Transmit Buffer Input Location 09 */


#define U0C0_TBUF10     (*(_PAGE_081_MEM_TYPE(0x2040A8))) /* Transmit Buffer Input Location 10 */


#define U0C0_TBUF11     (*(_PAGE_081_MEM_TYPE(0x2040AC))) /* Transmit Buffer Input Location 11 */


#define U0C0_TBUF12     (*(_PAGE_081_MEM_TYPE(0x2040B0))) /* Transmit Buffer Input Location 12 */


#define U0C0_TBUF13     (*(_PAGE_081_MEM_TYPE(0x2040B4))) /* Transmit Buffer Input Location 13 */


#define U0C0_TBUF14     (*(_PAGE_081_MEM_TYPE(0x2040B8))) /* Transmit Buffer Input Location 14 */


#define U0C0_TBUF15     (*(_PAGE_081_MEM_TYPE(0x2040BC))) /* Transmit Buffer Input Location 15 */


#define U0C0_TBUF16     (*(_PAGE_081_MEM_TYPE(0x2040C0))) /* Transmit Buffer Input Location 16 */


#define U0C0_TBUF17     (*(_PAGE_081_MEM_TYPE(0x2040C4))) /* Transmit Buffer Input Location 17 */


#define U0C0_TBUF18     (*(_PAGE_081_MEM_TYPE(0x2040C8))) /* Transmit Buffer Input Location 18 */


#define U0C0_TBUF19     (*(_PAGE_081_MEM_TYPE(0x2040CC))) /* Transmit Buffer Input Location 19 */


#define U0C0_TBUF20     (*(_PAGE_081_MEM_TYPE(0x2040D0))) /* Transmit Buffer Input Location 20 */


#define U0C0_TBUF21     (*(_PAGE_081_MEM_TYPE(0x2040D4))) /* Transmit Buffer Input Location 21 */


#define U0C0_TBUF22     (*(_PAGE_081_MEM_TYPE(0x2040D8))) /* Transmit Buffer Input Location 22 */


#define U0C0_TBUF23     (*(_PAGE_081_MEM_TYPE(0x2040DC))) /* Transmit Buffer Input Location 23 */


#define U0C0_TBUF24     (*(_PAGE_081_MEM_TYPE(0x2040E0))) /* Transmit Buffer Input Location 24 */


#define U0C0_TBUF25     (*(_PAGE_081_MEM_TYPE(0x2040E4))) /* Transmit Buffer Input Location 25 */


#define U0C0_TBUF26     (*(_PAGE_081_MEM_TYPE(0x2040E8))) /* Transmit Buffer Input Location 26 */


#define U0C0_TBUF27     (*(_PAGE_081_MEM_TYPE(0x2040EC))) /* Transmit Buffer Input Location 27 */


#define U0C0_TBUF28     (*(_PAGE_081_MEM_TYPE(0x2040F0))) /* Transmit Buffer Input Location 28 */


#define U0C0_TBUF29     (*(_PAGE_081_MEM_TYPE(0x2040F4))) /* Transmit Buffer Input Location 29 */


#define U0C0_TBUF30     (*(_PAGE_081_MEM_TYPE(0x2040F8))) /* Transmit Buffer Input Location 30 */


#define U0C0_TBUF31     (*(_PAGE_081_MEM_TYPE(0x2040FC))) /* Transmit Buffer Input Location 31 */


#define U0C0_RBUF0      (*(_PAGE_081_MEM_TYPE(0x204050))) /* Receiver Buffer Register 0 */


#define U0C0_RBUF01SRL  (*(_PAGE_081_MEM_TYPE(0x204060))) /* Receiver Buffer 01 Status Register L */


#define U0C0_RBUF1      (*(_PAGE_081_MEM_TYPE(0x204054))) /* Receiver Buffer Register 1 */


#define U0C0_RBUF01SRH  (*(_PAGE_081_MEM_TYPE(0x204062))) /* Receiver Buffer 01 Status Register H */


#define U0C0_RBUF       (*(_PAGE_081_MEM_TYPE(0x20405C))) /* Receiver Buffer Register */


#define U0C0_RBUFD      (*(_PAGE_081_MEM_TYPE(0x20404C))) /* Receiver Buffer Register for Debugger */


#define U0C0_RBUFSR     (*(_PAGE_081_MEM_TYPE(0x204058))) /* Receiver Buffer Status Register */


#define U0C0_BYP        (*(_PAGE_081_MEM_TYPE(0x204100))) /* Bypass Data Register */


#define U0C0_BYPCRL     (*(_PAGE_081_MEM_TYPE(0x204104))) /* Bypass Control Register L */


#define U0C0_BYPCRH     (*(_PAGE_081_MEM_TYPE(0x204106))) /* Bypass Control Register H */


#define U0C0_TRBSRL     (*(_PAGE_081_MEM_TYPE(0x204118))) /* Transmit/Receive Buffer Status Register L */


#define U0C0_TRBSRH     (*(_PAGE_081_MEM_TYPE(0x20411A))) /* Transmit/Receive Buffer Status Register H */


#define U0C0_TRBSCR     (*(_PAGE_081_MEM_TYPE(0x20411C))) /* Transmit/Receive Buffer Status Clear Register */


#define U0C0_TBCTRL     (*(_PAGE_081_MEM_TYPE(0x204110))) /* Transmitter Buffer Control Register L */


#define U0C0_TBCTRH     (*(_PAGE_081_MEM_TYPE(0x204112))) /* Transmitter Buffer Control Register H */


#define U0C0_RBCTRL     (*(_PAGE_081_MEM_TYPE(0x204114))) /* Receiver Buffer Control Register L */


#define U0C0_RBCTRH     (*(_PAGE_081_MEM_TYPE(0x204116))) /* Receiver Buffer Control Register H */


#define U0C0_IN00       (*(_PAGE_081_MEM_TYPE(0x204180))) /* Transmit FIFO Buffer Input Location 00 */


#define U0C0_IN01       (*(_PAGE_081_MEM_TYPE(0x204184))) /* Transmit FIFO Buffer Input Location 01 */


#define U0C0_IN02       (*(_PAGE_081_MEM_TYPE(0x204188))) /* Transmit FIFO Buffer Input Location 02 */


#define U0C0_IN03       (*(_PAGE_081_MEM_TYPE(0x20418C))) /* Transmit FIFO Buffer Input Location 03 */


#define U0C0_IN04       (*(_PAGE_081_MEM_TYPE(0x204190))) /* Transmit FIFO Buffer Input Location 04 */


#define U0C0_IN05       (*(_PAGE_081_MEM_TYPE(0x204194))) /* Transmit FIFO Buffer Input Location 05 */


#define U0C0_IN06       (*(_PAGE_081_MEM_TYPE(0x204198))) /* Transmit FIFO Buffer Input Location 06 */


#define U0C0_IN07       (*(_PAGE_081_MEM_TYPE(0x20419C))) /* Transmit FIFO Buffer Input Location 07 */


#define U0C0_IN08       (*(_PAGE_081_MEM_TYPE(0x2041A0))) /* Transmit FIFO Buffer Input Location 08 */


#define U0C0_IN09       (*(_PAGE_081_MEM_TYPE(0x2041A4))) /* Transmit FIFO Buffer Input Location 09 */


#define U0C0_IN10       (*(_PAGE_081_MEM_TYPE(0x2041A8))) /* Transmit FIFO Buffer Input Location 10 */


#define U0C0_IN11       (*(_PAGE_081_MEM_TYPE(0x2041AC))) /* Transmit FIFO Buffer Input Location 11 */


#define U0C0_IN12       (*(_PAGE_081_MEM_TYPE(0x2041B0))) /* Transmit FIFO Buffer Input Location 12 */


#define U0C0_IN13       (*(_PAGE_081_MEM_TYPE(0x2041B4))) /* Transmit FIFO Buffer Input Location 13 */


#define U0C0_IN14       (*(_PAGE_081_MEM_TYPE(0x2041B8))) /* Transmit FIFO Buffer Input Location 14 */


#define U0C0_IN15       (*(_PAGE_081_MEM_TYPE(0x2041BC))) /* Transmit FIFO Buffer Input Location 15 */


#define U0C0_IN16       (*(_PAGE_081_MEM_TYPE(0x2041C0))) /* Transmit FIFO Buffer Input Location 16 */


#define U0C0_IN17       (*(_PAGE_081_MEM_TYPE(0x2041C4))) /* Transmit FIFO Buffer Input Location 17 */


#define U0C0_IN18       (*(_PAGE_081_MEM_TYPE(0x2041C8))) /* Transmit FIFO Buffer Input Location 18 */


#define U0C0_IN19       (*(_PAGE_081_MEM_TYPE(0x2041CC))) /* Transmit FIFO Buffer Input Location 19 */


#define U0C0_IN20       (*(_PAGE_081_MEM_TYPE(0x2041D0))) /* Transmit FIFO Buffer Input Location 20 */


#define U0C0_IN21       (*(_PAGE_081_MEM_TYPE(0x2041D4))) /* Transmit FIFO Buffer Input Location 21 */


#define U0C0_IN22       (*(_PAGE_081_MEM_TYPE(0x2041D8))) /* Transmit FIFO Buffer Input Location 22 */


#define U0C0_IN23       (*(_PAGE_081_MEM_TYPE(0x2041DC))) /* Transmit FIFO Buffer Input Location 23 */


#define U0C0_IN24       (*(_PAGE_081_MEM_TYPE(0x2041E0))) /* Transmit FIFO Buffer Input Location 24 */


#define U0C0_IN25       (*(_PAGE_081_MEM_TYPE(0x2041E4))) /* Transmit FIFO Buffer Input Location 25 */


#define U0C0_IN26       (*(_PAGE_081_MEM_TYPE(0x2041E8))) /* Transmit FIFO Buffer Input Location 26 */


#define U0C0_IN27       (*(_PAGE_081_MEM_TYPE(0x2041EC))) /* Transmit FIFO Buffer Input Location 27 */


#define U0C0_IN28       (*(_PAGE_081_MEM_TYPE(0x2041F0))) /* Transmit FIFO Buffer Input Location 28 */


#define U0C0_IN29       (*(_PAGE_081_MEM_TYPE(0x2041F4))) /* Transmit FIFO Buffer Input Location 29 */


#define U0C0_IN30       (*(_PAGE_081_MEM_TYPE(0x2041F8))) /* Transmit FIFO Buffer Input Location 30 */


#define U0C0_IN31       (*(_PAGE_081_MEM_TYPE(0x2041FC))) /* Transmit FIFO Buffer Input Location 31 */


#define U0C0_OUTRL      (*(_PAGE_081_MEM_TYPE(0x204120))) /* Receiver Buffer Output Register L */


#define U0C0_OUTRH      (*(_PAGE_081_MEM_TYPE(0x204122))) /* Receiver Buffer Output Register H */


#define U0C0_OUTDRL     (*(_PAGE_081_MEM_TYPE(0x204124))) /* Receiver Buffer Output Register L for Debugger */


#define U0C0_OUTDRH     (*(_PAGE_081_MEM_TYPE(0x204126))) /* Receiver Buffer Output Register H for Debugger */


#define U0C0_TRBPTRL    (*(_PAGE_081_MEM_TYPE(0x204108))) /* Transmit/Receive Buffer Pointer Register L */


#define U0C0_TRBPTRH    (*(_PAGE_081_MEM_TYPE(0x20410A))) /* Transmit/Receive Buffer Pointer Register H */


#define U0C1_CCR        (*(_PAGE_081_MEM_TYPE(0x204210))) /* Channel Control Register */


#define U0C1_CCFG       (*(_PAGE_081_MEM_TYPE(0x204218))) /* Channel Configuration Register */


#define U0C1_KSCFG      (*(_PAGE_081_MEM_TYPE(0x20420C))) /* Kernel State Configuration Register */


#define U0C1_INPRL      (*(_PAGE_081_MEM_TYPE(0x204214))) /* Interrupt Node Pointer Register L */


#define U0C1_INPRH      (*(_PAGE_081_MEM_TYPE(0x204216))) /* Interrupt Node Pointer Register H */


#define U0C1_PCRL       (*(_PAGE_081_MEM_TYPE(0x204240))) /* Protocol Control Register L */


#define U0C1_PCRH       (*(_PAGE_081_MEM_TYPE(0x204242))) /* Protocol Control Register H */


#define U0C1_PSR        (*(_PAGE_081_MEM_TYPE(0x204244))) /* Protocol Status Register */


#define U0C1_PSCR       (*(_PAGE_081_MEM_TYPE(0x204248))) /* Protocol Status Clear Register */


#define U0C1_DX0CR      (*(_PAGE_081_MEM_TYPE(0x204220))) /* Input Control Register 0 */


#define U0C1_DX1CR      (*(_PAGE_081_MEM_TYPE(0x204224))) /* Input Control Register 1 */


#define U0C1_DX2CR      (*(_PAGE_081_MEM_TYPE(0x204228))) /* Input Control Register 2 */


#define U0C1_FDRL       (*(_PAGE_081_MEM_TYPE(0x204204))) /* Fractional Divider Register L */


#define U0C1_FDRH       (*(_PAGE_081_MEM_TYPE(0x204206))) /* Fractional Divider Register H */


#define U0C1_BRGL       (*(_PAGE_081_MEM_TYPE(0x20421C))) /* Baud Rate Generator Register L */


#define U0C1_BRGH       (*(_PAGE_081_MEM_TYPE(0x20421E))) /* Baud Rate Generator Register H */


#define U0C1_SCTRL      (*(_PAGE_081_MEM_TYPE(0x204230))) /* Shift Control Register L */


#define U0C1_SCTRH      (*(_PAGE_081_MEM_TYPE(0x204232))) /* Shift Control Register H */


#define U0C1_TCSRL      (*(_PAGE_081_MEM_TYPE(0x20423C))) /* Transmit Control/Status Register L */


#define U0C1_TCSRH      (*(_PAGE_081_MEM_TYPE(0x20423E))) /* Transmit Control/Status Register H */


#define U0C1_FMRL       (*(_PAGE_081_MEM_TYPE(0x204238))) /* Flag Modification Register L */


#define U0C1_FMRH       (*(_PAGE_081_MEM_TYPE(0x20423A))) /* Flag Modification Register H */


#define U0C1_TBUF00     (*(_PAGE_081_MEM_TYPE(0x204280))) /* Transmit Buffer Input Location 00 */


#define U0C1_TBUF01     (*(_PAGE_081_MEM_TYPE(0x204284))) /* Transmit Buffer Input Location 01 */


#define U0C1_TBUF02     (*(_PAGE_081_MEM_TYPE(0x204288))) /* Transmit Buffer Input Location 02 */


#define U0C1_TBUF03     (*(_PAGE_081_MEM_TYPE(0x20428C))) /* Transmit Buffer Input Location 03 */


#define U0C1_TBUF04     (*(_PAGE_081_MEM_TYPE(0x204290))) /* Transmit Buffer Input Location 04 */


#define U0C1_TBUF05     (*(_PAGE_081_MEM_TYPE(0x204294))) /* Transmit Buffer Input Location 05 */


#define U0C1_TBUF06     (*(_PAGE_081_MEM_TYPE(0x204298))) /* Transmit Buffer Input Location 06 */


#define U0C1_TBUF07     (*(_PAGE_081_MEM_TYPE(0x20429C))) /* Transmit Buffer Input Location 07 */


#define U0C1_TBUF08     (*(_PAGE_081_MEM_TYPE(0x2042A0))) /* Transmit Buffer Input Location 08 */


#define U0C1_TBUF09     (*(_PAGE_081_MEM_TYPE(0x2042A4))) /* Transmit Buffer Input Location 09 */


#define U0C1_TBUF10     (*(_PAGE_081_MEM_TYPE(0x2042A8))) /* Transmit Buffer Input Location 10 */


#define U0C1_TBUF11     (*(_PAGE_081_MEM_TYPE(0x2042AC))) /* Transmit Buffer Input Location 11 */


#define U0C1_TBUF12     (*(_PAGE_081_MEM_TYPE(0x2042B0))) /* Transmit Buffer Input Location 12 */


#define U0C1_TBUF13     (*(_PAGE_081_MEM_TYPE(0x2042B4))) /* Transmit Buffer Input Location 13 */


#define U0C1_TBUF14     (*(_PAGE_081_MEM_TYPE(0x2042B8))) /* Transmit Buffer Input Location 14 */


#define U0C1_TBUF15     (*(_PAGE_081_MEM_TYPE(0x2042BC))) /* Transmit Buffer Input Location 15 */


#define U0C1_TBUF16     (*(_PAGE_081_MEM_TYPE(0x2042C0))) /* Transmit Buffer Input Location 16 */


#define U0C1_TBUF17     (*(_PAGE_081_MEM_TYPE(0x2042C4))) /* Transmit Buffer Input Location 17 */


#define U0C1_TBUF18     (*(_PAGE_081_MEM_TYPE(0x2042C8))) /* Transmit Buffer Input Location 18 */


#define U0C1_TBUF19     (*(_PAGE_081_MEM_TYPE(0x2042CC))) /* Transmit Buffer Input Location 19 */


#define U0C1_TBUF20     (*(_PAGE_081_MEM_TYPE(0x2042D0))) /* Transmit Buffer Input Location 20 */


#define U0C1_TBUF21     (*(_PAGE_081_MEM_TYPE(0x2042D4))) /* Transmit Buffer Input Location 21 */


#define U0C1_TBUF22     (*(_PAGE_081_MEM_TYPE(0x2042D8))) /* Transmit Buffer Input Location 22 */


#define U0C1_TBUF23     (*(_PAGE_081_MEM_TYPE(0x2042DC))) /* Transmit Buffer Input Location 23 */


#define U0C1_TBUF24     (*(_PAGE_081_MEM_TYPE(0x2042E0))) /* Transmit Buffer Input Location 24 */


#define U0C1_TBUF25     (*(_PAGE_081_MEM_TYPE(0x2042E4))) /* Transmit Buffer Input Location 25 */


#define U0C1_TBUF26     (*(_PAGE_081_MEM_TYPE(0x2042E8))) /* Transmit Buffer Input Location 26 */


#define U0C1_TBUF27     (*(_PAGE_081_MEM_TYPE(0x2042EC))) /* Transmit Buffer Input Location 27 */


#define U0C1_TBUF28     (*(_PAGE_081_MEM_TYPE(0x2042F0))) /* Transmit Buffer Input Location 28 */


#define U0C1_TBUF29     (*(_PAGE_081_MEM_TYPE(0x2042F4))) /* Transmit Buffer Input Location 29 */


#define U0C1_TBUF30     (*(_PAGE_081_MEM_TYPE(0x2042F8))) /* Transmit Buffer Input Location 30 */


#define U0C1_TBUF31     (*(_PAGE_081_MEM_TYPE(0x2042FC))) /* Transmit Buffer Input Location 31 */


#define U0C1_RBUF0      (*(_PAGE_081_MEM_TYPE(0x204250))) /* Receiver Buffer Register 0 */


#define U0C1_RBUF01SRL  (*(_PAGE_081_MEM_TYPE(0x204260))) /* Receiver Buffer 01 Status Register L */


#define U0C1_RBUF1      (*(_PAGE_081_MEM_TYPE(0x204254))) /* Receiver Buffer Register 1 */


#define U0C1_RBUF01SRH  (*(_PAGE_081_MEM_TYPE(0x204262))) /* Receiver Buffer 01 Status Register H */


#define U0C1_RBUF       (*(_PAGE_081_MEM_TYPE(0x20425C))) /* Receiver Buffer Register */


#define U0C1_RBUFD      (*(_PAGE_081_MEM_TYPE(0x20424C))) /* Receiver Buffer Register for Debugger */


#define U0C1_RBUFSR     (*(_PAGE_081_MEM_TYPE(0x204258))) /* Receiver Buffer Status Register */


#define U0C1_BYP        (*(_PAGE_081_MEM_TYPE(0x204300))) /* Bypass Data Register */


#define U0C1_BYPCRL     (*(_PAGE_081_MEM_TYPE(0x204304))) /* Bypass Control Register L */


#define U0C1_BYPCRH     (*(_PAGE_081_MEM_TYPE(0x204306))) /* Bypass Control Register H */


#define U0C1_TRBSRL     (*(_PAGE_081_MEM_TYPE(0x204318))) /* Transmit/Receive Buffer Status Register L */


#define U0C1_TRBSRH     (*(_PAGE_081_MEM_TYPE(0x20431A))) /* Transmit/Receive Buffer Status Register H */


#define U0C1_TRBSCR     (*(_PAGE_081_MEM_TYPE(0x20431C))) /* Transmit/Receive Buffer Status Clear Register */


#define U0C1_TBCTRL     (*(_PAGE_081_MEM_TYPE(0x204310))) /* Transmitter Buffer Control Register L */


#define U0C1_TBCTRH     (*(_PAGE_081_MEM_TYPE(0x204312))) /* Transmitter Buffer Control Register H */


#define U0C1_RBCTRL     (*(_PAGE_081_MEM_TYPE(0x204314))) /* Receiver Buffer Control Register L */


#define U0C1_RBCTRH     (*(_PAGE_081_MEM_TYPE(0x204316))) /* Receiver Buffer Control Register H */


#define U0C1_IN00       (*(_PAGE_081_MEM_TYPE(0x204380))) /* Transmit FIFO Buffer Input Location 00 */


#define U0C1_IN01       (*(_PAGE_081_MEM_TYPE(0x204384))) /* Transmit FIFO Buffer Input Location 01 */


#define U0C1_IN02       (*(_PAGE_081_MEM_TYPE(0x204388))) /* Transmit FIFO Buffer Input Location 02 */


#define U0C1_IN03       (*(_PAGE_081_MEM_TYPE(0x20438C))) /* Transmit FIFO Buffer Input Location 03 */


#define U0C1_IN04       (*(_PAGE_081_MEM_TYPE(0x204390))) /* Transmit FIFO Buffer Input Location 04 */


#define U0C1_IN05       (*(_PAGE_081_MEM_TYPE(0x204394))) /* Transmit FIFO Buffer Input Location 05 */


#define U0C1_IN06       (*(_PAGE_081_MEM_TYPE(0x204398))) /* Transmit FIFO Buffer Input Location 06 */


#define U0C1_IN07       (*(_PAGE_081_MEM_TYPE(0x20439C))) /* Transmit FIFO Buffer Input Location 07 */


#define U0C1_IN08       (*(_PAGE_081_MEM_TYPE(0x2043A0))) /* Transmit FIFO Buffer Input Location 08 */


#define U0C1_IN09       (*(_PAGE_081_MEM_TYPE(0x2043A4))) /* Transmit FIFO Buffer Input Location 09 */


#define U0C1_IN10       (*(_PAGE_081_MEM_TYPE(0x2043A8))) /* Transmit FIFO Buffer Input Location 10 */


#define U0C1_IN11       (*(_PAGE_081_MEM_TYPE(0x2043AC))) /* Transmit FIFO Buffer Input Location 11 */


#define U0C1_IN12       (*(_PAGE_081_MEM_TYPE(0x2043B0))) /* Transmit FIFO Buffer Input Location 12 */


#define U0C1_IN13       (*(_PAGE_081_MEM_TYPE(0x2043B4))) /* Transmit FIFO Buffer Input Location 13 */


#define U0C1_IN14       (*(_PAGE_081_MEM_TYPE(0x2043B8))) /* Transmit FIFO Buffer Input Location 14 */


#define U0C1_IN15       (*(_PAGE_081_MEM_TYPE(0x2043BC))) /* Transmit FIFO Buffer Input Location 15 */


#define U0C1_IN16       (*(_PAGE_081_MEM_TYPE(0x2043C0))) /* Transmit FIFO Buffer Input Location 16 */


#define U0C1_IN17       (*(_PAGE_081_MEM_TYPE(0x2043C4))) /* Transmit FIFO Buffer Input Location 17 */


#define U0C1_IN18       (*(_PAGE_081_MEM_TYPE(0x2043C8))) /* Transmit FIFO Buffer Input Location 18 */


#define U0C1_IN19       (*(_PAGE_081_MEM_TYPE(0x2043CC))) /* Transmit FIFO Buffer Input Location 19 */


#define U0C1_IN20       (*(_PAGE_081_MEM_TYPE(0x2043D0))) /* Transmit FIFO Buffer Input Location 20 */


#define U0C1_IN21       (*(_PAGE_081_MEM_TYPE(0x2043D4))) /* Transmit FIFO Buffer Input Location 21 */


#define U0C1_IN22       (*(_PAGE_081_MEM_TYPE(0x2043D8))) /* Transmit FIFO Buffer Input Location 22 */


#define U0C1_IN23       (*(_PAGE_081_MEM_TYPE(0x2043DC))) /* Transmit FIFO Buffer Input Location 23 */


#define U0C1_IN24       (*(_PAGE_081_MEM_TYPE(0x2043E0))) /* Transmit FIFO Buffer Input Location 24 */


#define U0C1_IN25       (*(_PAGE_081_MEM_TYPE(0x2043E4))) /* Transmit FIFO Buffer Input Location 25 */


#define U0C1_IN26       (*(_PAGE_081_MEM_TYPE(0x2043E8))) /* Transmit FIFO Buffer Input Location 26 */


#define U0C1_IN27       (*(_PAGE_081_MEM_TYPE(0x2043EC))) /* Transmit FIFO Buffer Input Location 27 */


#define U0C1_IN28       (*(_PAGE_081_MEM_TYPE(0x2043F0))) /* Transmit FIFO Buffer Input Location 28 */


#define U0C1_IN29       (*(_PAGE_081_MEM_TYPE(0x2043F4))) /* Transmit FIFO Buffer Input Location 29 */


#define U0C1_IN30       (*(_PAGE_081_MEM_TYPE(0x2043F8))) /* Transmit FIFO Buffer Input Location 30 */


#define U0C1_IN31       (*(_PAGE_081_MEM_TYPE(0x2043FC))) /* Transmit FIFO Buffer Input Location 31 */


#define U0C1_OUTRL      (*(_PAGE_081_MEM_TYPE(0x204320))) /* Receiver Buffer Output Register L */


#define U0C1_OUTRH      (*(_PAGE_081_MEM_TYPE(0x204322))) /* Receiver Buffer Output Register H */


#define U0C1_OUTDRL     (*(_PAGE_081_MEM_TYPE(0x204324))) /* Receiver Buffer Output Register L for Debugger */


#define U0C1_OUTDRH     (*(_PAGE_081_MEM_TYPE(0x204326))) /* Receiver Buffer Output Register H for Debugger */


#define U0C1_TRBPTRL    (*(_PAGE_081_MEM_TYPE(0x204308))) /* Transmit/Receive Buffer Pointer Register L */


#define U0C1_TRBPTRH    (*(_PAGE_081_MEM_TYPE(0x20430A))) /* Transmit/Receive Buffer Pointer Register H */

#endif /* REGXC2361E_NOUSIC0 */

/********************************************************************************
 * USIC1
********************************************************************************/
#ifndef REGXC2361E_NOUSIC1


#define U1C0_CCR        (*(_PAGE_081_MEM_TYPE(0x204810))) /* Channel Control Register */


#define U1C0_CCFG       (*(_PAGE_081_MEM_TYPE(0x204818))) /* Channel Configuration Register */


#define U1C0_KSCFG      (*(_PAGE_081_MEM_TYPE(0x20480C))) /* Kernel State Configuration Register */


#define U1C0_INPRL      (*(_PAGE_081_MEM_TYPE(0x204814))) /* Interrupt Node Pointer Register L */


#define U1C0_INPRH      (*(_PAGE_081_MEM_TYPE(0x204816))) /* Interrupt Node Pointer Register H */


#define U1C0_PCRL       (*(_PAGE_081_MEM_TYPE(0x204840))) /* Protocol Control Register L */


#define U1C0_PCRH       (*(_PAGE_081_MEM_TYPE(0x204842))) /* Protocol Control Register H */


#define U1C0_PSR        (*(_PAGE_081_MEM_TYPE(0x204844))) /* Protocol Status Register */


#define U1C0_PSCR       (*(_PAGE_081_MEM_TYPE(0x204848))) /* Protocol Status Clear Register */


#define U1C0_DX0CR      (*(_PAGE_081_MEM_TYPE(0x204820))) /* Input Control Register 0 */


#define U1C0_DX1CR      (*(_PAGE_081_MEM_TYPE(0x204824))) /* Input Control Register 1 */


#define U1C0_DX2CR      (*(_PAGE_081_MEM_TYPE(0x204828))) /* Input Control Register 2 */


#define U1C0_FDRL       (*(_PAGE_081_MEM_TYPE(0x204804))) /* Fractional Divider Register L */


#define U1C0_FDRH       (*(_PAGE_081_MEM_TYPE(0x204806))) /* Fractional Divider Register H */


#define U1C0_BRGL       (*(_PAGE_081_MEM_TYPE(0x20481C))) /* Baud Rate Generator Register L */


#define U1C0_BRGH       (*(_PAGE_081_MEM_TYPE(0x20481E))) /* Baud Rate Generator Register H */


#define U1C0_SCTRL      (*(_PAGE_081_MEM_TYPE(0x204830))) /* Shift Control Register L */


#define U1C0_SCTRH      (*(_PAGE_081_MEM_TYPE(0x204832))) /* Shift Control Register H */


#define U1C0_TCSRL      (*(_PAGE_081_MEM_TYPE(0x20483C))) /* Transmit Control/Status Register L */


#define U1C0_TCSRH      (*(_PAGE_081_MEM_TYPE(0x20483E))) /* Transmit Control/Status Register H */


#define U1C0_FMRL       (*(_PAGE_081_MEM_TYPE(0x204838))) /* Flag Modification Register L */


#define U1C0_FMRH       (*(_PAGE_081_MEM_TYPE(0x20483A))) /* Flag Modification Register H */


#define U1C0_TBUF00     (*(_PAGE_081_MEM_TYPE(0x204880))) /* Transmit Buffer Input Location 00 */


#define U1C0_TBUF01     (*(_PAGE_081_MEM_TYPE(0x204884))) /* Transmit Buffer Input Location 01 */


#define U1C0_TBUF02     (*(_PAGE_081_MEM_TYPE(0x204888))) /* Transmit Buffer Input Location 02 */


#define U1C0_TBUF03     (*(_PAGE_081_MEM_TYPE(0x20488C))) /* Transmit Buffer Input Location 03 */


#define U1C0_TBUF04     (*(_PAGE_081_MEM_TYPE(0x204890))) /* Transmit Buffer Input Location 04 */


#define U1C0_TBUF05     (*(_PAGE_081_MEM_TYPE(0x204894))) /* Transmit Buffer Input Location 05 */


#define U1C0_TBUF06     (*(_PAGE_081_MEM_TYPE(0x204898))) /* Transmit Buffer Input Location 06 */


#define U1C0_TBUF07     (*(_PAGE_081_MEM_TYPE(0x20489C))) /* Transmit Buffer Input Location 07 */


#define U1C0_TBUF08     (*(_PAGE_081_MEM_TYPE(0x2048A0))) /* Transmit Buffer Input Location 08 */


#define U1C0_TBUF09     (*(_PAGE_081_MEM_TYPE(0x2048A4))) /* Transmit Buffer Input Location 09 */


#define U1C0_TBUF10     (*(_PAGE_081_MEM_TYPE(0x2048A8))) /* Transmit Buffer Input Location 10 */


#define U1C0_TBUF11     (*(_PAGE_081_MEM_TYPE(0x2048AC))) /* Transmit Buffer Input Location 11 */


#define U1C0_TBUF12     (*(_PAGE_081_MEM_TYPE(0x2048B0))) /* Transmit Buffer Input Location 12 */


#define U1C0_TBUF13     (*(_PAGE_081_MEM_TYPE(0x2048B4))) /* Transmit Buffer Input Location 13 */


#define U1C0_TBUF14     (*(_PAGE_081_MEM_TYPE(0x2048B8))) /* Transmit Buffer Input Location 14 */


#define U1C0_TBUF15     (*(_PAGE_081_MEM_TYPE(0x2048BC))) /* Transmit Buffer Input Location 15 */


#define U1C0_TBUF16     (*(_PAGE_081_MEM_TYPE(0x2048C0))) /* Transmit Buffer Input Location 16 */


#define U1C0_TBUF17     (*(_PAGE_081_MEM_TYPE(0x2048C4))) /* Transmit Buffer Input Location 17 */


#define U1C0_TBUF18     (*(_PAGE_081_MEM_TYPE(0x2048C8))) /* Transmit Buffer Input Location 18 */


#define U1C0_TBUF19     (*(_PAGE_081_MEM_TYPE(0x2048CC))) /* Transmit Buffer Input Location 19 */


#define U1C0_TBUF20     (*(_PAGE_081_MEM_TYPE(0x2048D0))) /* Transmit Buffer Input Location 20 */


#define U1C0_TBUF21     (*(_PAGE_081_MEM_TYPE(0x2048D4))) /* Transmit Buffer Input Location 21 */


#define U1C0_TBUF22     (*(_PAGE_081_MEM_TYPE(0x2048D8))) /* Transmit Buffer Input Location 22 */


#define U1C0_TBUF23     (*(_PAGE_081_MEM_TYPE(0x2048DC))) /* Transmit Buffer Input Location 23 */


#define U1C0_TBUF24     (*(_PAGE_081_MEM_TYPE(0x2048E0))) /* Transmit Buffer Input Location 24 */


#define U1C0_TBUF25     (*(_PAGE_081_MEM_TYPE(0x2048E4))) /* Transmit Buffer Input Location 25 */


#define U1C0_TBUF26     (*(_PAGE_081_MEM_TYPE(0x2048E8))) /* Transmit Buffer Input Location 26 */


#define U1C0_TBUF27     (*(_PAGE_081_MEM_TYPE(0x2048EC))) /* Transmit Buffer Input Location 27 */


#define U1C0_TBUF28     (*(_PAGE_081_MEM_TYPE(0x2048F0))) /* Transmit Buffer Input Location 28 */


#define U1C0_TBUF29     (*(_PAGE_081_MEM_TYPE(0x2048F4))) /* Transmit Buffer Input Location 29 */


#define U1C0_TBUF30     (*(_PAGE_081_MEM_TYPE(0x2048F8))) /* Transmit Buffer Input Location 30 */


#define U1C0_TBUF31     (*(_PAGE_081_MEM_TYPE(0x2048FC))) /* Transmit Buffer Input Location 31 */


#define U1C0_RBUF0      (*(_PAGE_081_MEM_TYPE(0x204850))) /* Receiver Buffer Register 0 */


#define U1C0_RBUF01SRL  (*(_PAGE_081_MEM_TYPE(0x204860))) /* Receiver Buffer 01 Status Register L */


#define U1C0_RBUF1      (*(_PAGE_081_MEM_TYPE(0x204854))) /* Receiver Buffer Register 1 */


#define U1C0_RBUF01SRH  (*(_PAGE_081_MEM_TYPE(0x204862))) /* Receiver Buffer 01 Status Register H */


#define U1C0_RBUF       (*(_PAGE_081_MEM_TYPE(0x20485C))) /* Receiver Buffer Register */


#define U1C0_RBUFD      (*(_PAGE_081_MEM_TYPE(0x20484C))) /* Receiver Buffer Register for Debugger */


#define U1C0_RBUFSR     (*(_PAGE_081_MEM_TYPE(0x204858))) /* Receiver Buffer Status Register */


#define U1C0_BYP        (*(_PAGE_081_MEM_TYPE(0x204900))) /* Bypass Data Register */


#define U1C0_BYPCRL     (*(_PAGE_081_MEM_TYPE(0x204904))) /* Bypass Control Register L */


#define U1C0_BYPCRH     (*(_PAGE_081_MEM_TYPE(0x204906))) /* Bypass Control Register H */


#define U1C0_TRBSRL     (*(_PAGE_081_MEM_TYPE(0x204918))) /* Transmit/Receive Buffer Status Register L */


#define U1C0_TRBSRH     (*(_PAGE_081_MEM_TYPE(0x20491A))) /* Transmit/Receive Buffer Status Register H */


#define U1C0_TRBSCR     (*(_PAGE_081_MEM_TYPE(0x20491C))) /* Transmit/Receive Buffer Status Clear Register */


#define U1C0_TBCTRL     (*(_PAGE_081_MEM_TYPE(0x204910))) /* Transmitter Buffer Control Register L */


#define U1C0_TBCTRH     (*(_PAGE_081_MEM_TYPE(0x204912))) /* Transmitter Buffer Control Register H */


#define U1C0_RBCTRL     (*(_PAGE_081_MEM_TYPE(0x204914))) /* Receiver Buffer Control Register L */


#define U1C0_RBCTRH     (*(_PAGE_081_MEM_TYPE(0x204916))) /* Receiver Buffer Control Register H */


#define U1C0_IN00       (*(_PAGE_081_MEM_TYPE(0x204980))) /* Transmit FIFO Buffer Input Location 00 */


#define U1C0_IN01       (*(_PAGE_081_MEM_TYPE(0x204984))) /* Transmit FIFO Buffer Input Location 01 */


#define U1C0_IN02       (*(_PAGE_081_MEM_TYPE(0x204988))) /* Transmit FIFO Buffer Input Location 02 */


#define U1C0_IN03       (*(_PAGE_081_MEM_TYPE(0x20498C))) /* Transmit FIFO Buffer Input Location 03 */


#define U1C0_IN04       (*(_PAGE_081_MEM_TYPE(0x204990))) /* Transmit FIFO Buffer Input Location 04 */


#define U1C0_IN05       (*(_PAGE_081_MEM_TYPE(0x204994))) /* Transmit FIFO Buffer Input Location 05 */


#define U1C0_IN06       (*(_PAGE_081_MEM_TYPE(0x204998))) /* Transmit FIFO Buffer Input Location 06 */


#define U1C0_IN07       (*(_PAGE_081_MEM_TYPE(0x20499C))) /* Transmit FIFO Buffer Input Location 07 */


#define U1C0_IN08       (*(_PAGE_081_MEM_TYPE(0x2049A0))) /* Transmit FIFO Buffer Input Location 08 */


#define U1C0_IN09       (*(_PAGE_081_MEM_TYPE(0x2049A4))) /* Transmit FIFO Buffer Input Location 09 */


#define U1C0_IN10       (*(_PAGE_081_MEM_TYPE(0x2049A8))) /* Transmit FIFO Buffer Input Location 10 */


#define U1C0_IN11       (*(_PAGE_081_MEM_TYPE(0x2049AC))) /* Transmit FIFO Buffer Input Location 11 */


#define U1C0_IN12       (*(_PAGE_081_MEM_TYPE(0x2049B0))) /* Transmit FIFO Buffer Input Location 12 */


#define U1C0_IN13       (*(_PAGE_081_MEM_TYPE(0x2049B4))) /* Transmit FIFO Buffer Input Location 13 */


#define U1C0_IN14       (*(_PAGE_081_MEM_TYPE(0x2049B8))) /* Transmit FIFO Buffer Input Location 14 */


#define U1C0_IN15       (*(_PAGE_081_MEM_TYPE(0x2049BC))) /* Transmit FIFO Buffer Input Location 15 */


#define U1C0_IN16       (*(_PAGE_081_MEM_TYPE(0x2049C0))) /* Transmit FIFO Buffer Input Location 16 */


#define U1C0_IN17       (*(_PAGE_081_MEM_TYPE(0x2049C4))) /* Transmit FIFO Buffer Input Location 17 */


#define U1C0_IN18       (*(_PAGE_081_MEM_TYPE(0x2049C8))) /* Transmit FIFO Buffer Input Location 18 */


#define U1C0_IN19       (*(_PAGE_081_MEM_TYPE(0x2049CC))) /* Transmit FIFO Buffer Input Location 19 */


#define U1C0_IN20       (*(_PAGE_081_MEM_TYPE(0x2049D0))) /* Transmit FIFO Buffer Input Location 20 */


#define U1C0_IN21       (*(_PAGE_081_MEM_TYPE(0x2049D4))) /* Transmit FIFO Buffer Input Location 21 */


#define U1C0_IN22       (*(_PAGE_081_MEM_TYPE(0x2049D8))) /* Transmit FIFO Buffer Input Location 22 */


#define U1C0_IN23       (*(_PAGE_081_MEM_TYPE(0x2049DC))) /* Transmit FIFO Buffer Input Location 23 */


#define U1C0_IN24       (*(_PAGE_081_MEM_TYPE(0x2049E0))) /* Transmit FIFO Buffer Input Location 24 */


#define U1C0_IN25       (*(_PAGE_081_MEM_TYPE(0x2049E4))) /* Transmit FIFO Buffer Input Location 25 */


#define U1C0_IN26       (*(_PAGE_081_MEM_TYPE(0x2049E8))) /* Transmit FIFO Buffer Input Location 26 */


#define U1C0_IN27       (*(_PAGE_081_MEM_TYPE(0x2049EC))) /* Transmit FIFO Buffer Input Location 27 */


#define U1C0_IN28       (*(_PAGE_081_MEM_TYPE(0x2049F0))) /* Transmit FIFO Buffer Input Location 28 */


#define U1C0_IN29       (*(_PAGE_081_MEM_TYPE(0x2049F4))) /* Transmit FIFO Buffer Input Location 29 */


#define U1C0_IN30       (*(_PAGE_081_MEM_TYPE(0x2049F8))) /* Transmit FIFO Buffer Input Location 30 */


#define U1C0_IN31       (*(_PAGE_081_MEM_TYPE(0x2049FC))) /* Transmit FIFO Buffer Input Location 31 */


#define U1C0_OUTRL      (*(_PAGE_081_MEM_TYPE(0x204920))) /* Receiver Buffer Output Register L */


#define U1C0_OUTRH      (*(_PAGE_081_MEM_TYPE(0x204922))) /* Receiver Buffer Output Register H */


#define U1C0_OUTDRL     (*(_PAGE_081_MEM_TYPE(0x204924))) /* Receiver Buffer Output Register L for Debugger */


#define U1C0_OUTDRH     (*(_PAGE_081_MEM_TYPE(0x204926))) /* Receiver Buffer Output Register H for Debugger */


#define U1C0_TRBPTRL    (*(_PAGE_081_MEM_TYPE(0x204908))) /* Transmit/Receive Buffer Pointer Register L */


#define U1C0_TRBPTRH    (*(_PAGE_081_MEM_TYPE(0x20490A))) /* Transmit/Receive Buffer Pointer Register H */


#define U1C1_CCR        (*(_PAGE_081_MEM_TYPE(0x204A10))) /* Channel Control Register */


#define U1C1_CCFG       (*(_PAGE_081_MEM_TYPE(0x204A18))) /* Channel Configuration Register */


#define U1C1_KSCFG      (*(_PAGE_081_MEM_TYPE(0x204A0C))) /* Kernel State Configuration Register */


#define U1C1_INPRL      (*(_PAGE_081_MEM_TYPE(0x204A14))) /* Interrupt Node Pointer Register L */


#define U1C1_INPRH      (*(_PAGE_081_MEM_TYPE(0x204A16))) /* Interrupt Node Pointer Register H */


#define U1C1_PCRL       (*(_PAGE_081_MEM_TYPE(0x204A40))) /* Protocol Control Register L */


#define U1C1_PCRH       (*(_PAGE_081_MEM_TYPE(0x204A42))) /* Protocol Control Register H */


#define U1C1_PSR        (*(_PAGE_081_MEM_TYPE(0x204A44))) /* Protocol Status Register */


#define U1C1_PSCR       (*(_PAGE_081_MEM_TYPE(0x204A48))) /* Protocol Status Clear Register */


#define U1C1_DX0CR      (*(_PAGE_081_MEM_TYPE(0x204A20))) /* Input Control Register 0 */


#define U1C1_DX1CR      (*(_PAGE_081_MEM_TYPE(0x204A24))) /* Input Control Register 1 */


#define U1C1_DX2CR      (*(_PAGE_081_MEM_TYPE(0x204A28))) /* Input Control Register 2 */


#define U1C1_FDRL       (*(_PAGE_081_MEM_TYPE(0x204A04))) /* Fractional Divider Register L */


#define U1C1_FDRH       (*(_PAGE_081_MEM_TYPE(0x204A06))) /* Fractional Divider Register H */


#define U1C1_BRGL       (*(_PAGE_081_MEM_TYPE(0x204A1C))) /* Baud Rate Generator Register L */


#define U1C1_BRGH       (*(_PAGE_081_MEM_TYPE(0x204A1E))) /* Baud Rate Generator Register H */


#define U1C1_SCTRL      (*(_PAGE_081_MEM_TYPE(0x204A30))) /* Shift Control Register L */


#define U1C1_SCTRH      (*(_PAGE_081_MEM_TYPE(0x204A32))) /* Shift Control Register H */


#define U1C1_TCSRL      (*(_PAGE_081_MEM_TYPE(0x204A3C))) /* Transmit Control/Status Register L */


#define U1C1_TCSRH      (*(_PAGE_081_MEM_TYPE(0x204A3E))) /* Transmit Control/Status Register H */


#define U1C1_FMRL       (*(_PAGE_081_MEM_TYPE(0x204A38))) /* Flag Modification Register L */


#define U1C1_FMRH       (*(_PAGE_081_MEM_TYPE(0x204A3A))) /* Flag Modification Register H */


#define U1C1_TBUF00     (*(_PAGE_081_MEM_TYPE(0x204A80))) /* Transmit Buffer Input Location 00 */


#define U1C1_TBUF01     (*(_PAGE_081_MEM_TYPE(0x204A84))) /* Transmit Buffer Input Location 01 */


#define U1C1_TBUF02     (*(_PAGE_081_MEM_TYPE(0x204A88))) /* Transmit Buffer Input Location 02 */


#define U1C1_TBUF03     (*(_PAGE_081_MEM_TYPE(0x204A8C))) /* Transmit Buffer Input Location 03 */


#define U1C1_TBUF04     (*(_PAGE_081_MEM_TYPE(0x204A90))) /* Transmit Buffer Input Location 04 */


#define U1C1_TBUF05     (*(_PAGE_081_MEM_TYPE(0x204A94))) /* Transmit Buffer Input Location 05 */


#define U1C1_TBUF06     (*(_PAGE_081_MEM_TYPE(0x204A98))) /* Transmit Buffer Input Location 06 */


#define U1C1_TBUF07     (*(_PAGE_081_MEM_TYPE(0x204A9C))) /* Transmit Buffer Input Location 07 */


#define U1C1_TBUF08     (*(_PAGE_081_MEM_TYPE(0x204AA0))) /* Transmit Buffer Input Location 08 */


#define U1C1_TBUF09     (*(_PAGE_081_MEM_TYPE(0x204AA4))) /* Transmit Buffer Input Location 09 */


#define U1C1_TBUF10     (*(_PAGE_081_MEM_TYPE(0x204AA8))) /* Transmit Buffer Input Location 10 */


#define U1C1_TBUF11     (*(_PAGE_081_MEM_TYPE(0x204AAC))) /* Transmit Buffer Input Location 11 */


#define U1C1_TBUF12     (*(_PAGE_081_MEM_TYPE(0x204AB0))) /* Transmit Buffer Input Location 12 */


#define U1C1_TBUF13     (*(_PAGE_081_MEM_TYPE(0x204AB4))) /* Transmit Buffer Input Location 13 */


#define U1C1_TBUF14     (*(_PAGE_081_MEM_TYPE(0x204AB8))) /* Transmit Buffer Input Location 14 */


#define U1C1_TBUF15     (*(_PAGE_081_MEM_TYPE(0x204ABC))) /* Transmit Buffer Input Location 15 */


#define U1C1_TBUF16     (*(_PAGE_081_MEM_TYPE(0x204AC0))) /* Transmit Buffer Input Location 16 */


#define U1C1_TBUF17     (*(_PAGE_081_MEM_TYPE(0x204AC4))) /* Transmit Buffer Input Location 17 */


#define U1C1_TBUF18     (*(_PAGE_081_MEM_TYPE(0x204AC8))) /* Transmit Buffer Input Location 18 */


#define U1C1_TBUF19     (*(_PAGE_081_MEM_TYPE(0x204ACC))) /* Transmit Buffer Input Location 19 */


#define U1C1_TBUF20     (*(_PAGE_081_MEM_TYPE(0x204AD0))) /* Transmit Buffer Input Location 20 */


#define U1C1_TBUF21     (*(_PAGE_081_MEM_TYPE(0x204AD4))) /* Transmit Buffer Input Location 21 */


#define U1C1_TBUF22     (*(_PAGE_081_MEM_TYPE(0x204AD8))) /* Transmit Buffer Input Location 22 */


#define U1C1_TBUF23     (*(_PAGE_081_MEM_TYPE(0x204ADC))) /* Transmit Buffer Input Location 23 */


#define U1C1_TBUF24     (*(_PAGE_081_MEM_TYPE(0x204AE0))) /* Transmit Buffer Input Location 24 */


#define U1C1_TBUF25     (*(_PAGE_081_MEM_TYPE(0x204AE4))) /* Transmit Buffer Input Location 25 */


#define U1C1_TBUF26     (*(_PAGE_081_MEM_TYPE(0x204AE8))) /* Transmit Buffer Input Location 26 */


#define U1C1_TBUF27     (*(_PAGE_081_MEM_TYPE(0x204AEC))) /* Transmit Buffer Input Location 27 */


#define U1C1_TBUF28     (*(_PAGE_081_MEM_TYPE(0x204AF0))) /* Transmit Buffer Input Location 28 */


#define U1C1_TBUF29     (*(_PAGE_081_MEM_TYPE(0x204AF4))) /* Transmit Buffer Input Location 29 */


#define U1C1_TBUF30     (*(_PAGE_081_MEM_TYPE(0x204AF8))) /* Transmit Buffer Input Location 30 */


#define U1C1_TBUF31     (*(_PAGE_081_MEM_TYPE(0x204AFC))) /* Transmit Buffer Input Location 31 */


#define U1C1_RBUF0      (*(_PAGE_081_MEM_TYPE(0x204A50))) /* Receiver Buffer Register 0 */


#define U1C1_RBUF01SRL  (*(_PAGE_081_MEM_TYPE(0x204A60))) /* Receiver Buffer 01 Status Register L */


#define U1C1_RBUF1      (*(_PAGE_081_MEM_TYPE(0x204A54))) /* Receiver Buffer Register 1 */


#define U1C1_RBUF01SRH  (*(_PAGE_081_MEM_TYPE(0x204A62))) /* Receiver Buffer 01 Status Register H */


#define U1C1_RBUF       (*(_PAGE_081_MEM_TYPE(0x204A5C))) /* Receiver Buffer Register */


#define U1C1_RBUFD      (*(_PAGE_081_MEM_TYPE(0x204A4C))) /* Receiver Buffer Register for Debugger */


#define U1C1_RBUFSR     (*(_PAGE_081_MEM_TYPE(0x204A58))) /* Receiver Buffer Status Register */


#define U1C1_BYP        (*(_PAGE_081_MEM_TYPE(0x204B00))) /* Bypass Data Register */


#define U1C1_BYPCRL     (*(_PAGE_081_MEM_TYPE(0x204B04))) /* Bypass Control Register L */


#define U1C1_BYPCRH     (*(_PAGE_081_MEM_TYPE(0x204B06))) /* Bypass Control Register H */


#define U1C1_TRBSRL     (*(_PAGE_081_MEM_TYPE(0x204B18))) /* Transmit/Receive Buffer Status Register L */


#define U1C1_TRBSRH     (*(_PAGE_081_MEM_TYPE(0x204B1A))) /* Transmit/Receive Buffer Status Register H */


#define U1C1_TRBSCR     (*(_PAGE_081_MEM_TYPE(0x204B1C))) /* Transmit/Receive Buffer Status Clear Register */


#define U1C1_TBCTRL     (*(_PAGE_081_MEM_TYPE(0x204B10))) /* Transmitter Buffer Control Register L */


#define U1C1_TBCTRH     (*(_PAGE_081_MEM_TYPE(0x204B12))) /* Transmitter Buffer Control Register H */


#define U1C1_RBCTRL     (*(_PAGE_081_MEM_TYPE(0x204B14))) /* Receiver Buffer Control Register L */


#define U1C1_RBCTRH     (*(_PAGE_081_MEM_TYPE(0x204B16))) /* Receiver Buffer Control Register H */


#define U1C1_IN00       (*(_PAGE_081_MEM_TYPE(0x204B80))) /* Transmit FIFO Buffer Input Location 00 */


#define U1C1_IN01       (*(_PAGE_081_MEM_TYPE(0x204B84))) /* Transmit FIFO Buffer Input Location 01 */


#define U1C1_IN02       (*(_PAGE_081_MEM_TYPE(0x204B88))) /* Transmit FIFO Buffer Input Location 02 */


#define U1C1_IN03       (*(_PAGE_081_MEM_TYPE(0x204B8C))) /* Transmit FIFO Buffer Input Location 03 */


#define U1C1_IN04       (*(_PAGE_081_MEM_TYPE(0x204B90))) /* Transmit FIFO Buffer Input Location 04 */


#define U1C1_IN05       (*(_PAGE_081_MEM_TYPE(0x204B94))) /* Transmit FIFO Buffer Input Location 05 */


#define U1C1_IN06       (*(_PAGE_081_MEM_TYPE(0x204B98))) /* Transmit FIFO Buffer Input Location 06 */


#define U1C1_IN07       (*(_PAGE_081_MEM_TYPE(0x204B9C))) /* Transmit FIFO Buffer Input Location 07 */


#define U1C1_IN08       (*(_PAGE_081_MEM_TYPE(0x204BA0))) /* Transmit FIFO Buffer Input Location 08 */


#define U1C1_IN09       (*(_PAGE_081_MEM_TYPE(0x204BA4))) /* Transmit FIFO Buffer Input Location 09 */


#define U1C1_IN10       (*(_PAGE_081_MEM_TYPE(0x204BA8))) /* Transmit FIFO Buffer Input Location 10 */


#define U1C1_IN11       (*(_PAGE_081_MEM_TYPE(0x204BAC))) /* Transmit FIFO Buffer Input Location 11 */


#define U1C1_IN12       (*(_PAGE_081_MEM_TYPE(0x204BB0))) /* Transmit FIFO Buffer Input Location 12 */


#define U1C1_IN13       (*(_PAGE_081_MEM_TYPE(0x204BB4))) /* Transmit FIFO Buffer Input Location 13 */


#define U1C1_IN14       (*(_PAGE_081_MEM_TYPE(0x204BB8))) /* Transmit FIFO Buffer Input Location 14 */


#define U1C1_IN15       (*(_PAGE_081_MEM_TYPE(0x204BBC))) /* Transmit FIFO Buffer Input Location 15 */


#define U1C1_IN16       (*(_PAGE_081_MEM_TYPE(0x204BC0))) /* Transmit FIFO Buffer Input Location 16 */


#define U1C1_IN17       (*(_PAGE_081_MEM_TYPE(0x204BC4))) /* Transmit FIFO Buffer Input Location 17 */


#define U1C1_IN18       (*(_PAGE_081_MEM_TYPE(0x204BC8))) /* Transmit FIFO Buffer Input Location 18 */


#define U1C1_IN19       (*(_PAGE_081_MEM_TYPE(0x204BCC))) /* Transmit FIFO Buffer Input Location 19 */


#define U1C1_IN20       (*(_PAGE_081_MEM_TYPE(0x204BD0))) /* Transmit FIFO Buffer Input Location 20 */


#define U1C1_IN21       (*(_PAGE_081_MEM_TYPE(0x204BD4))) /* Transmit FIFO Buffer Input Location 21 */


#define U1C1_IN22       (*(_PAGE_081_MEM_TYPE(0x204BD8))) /* Transmit FIFO Buffer Input Location 22 */


#define U1C1_IN23       (*(_PAGE_081_MEM_TYPE(0x204BDC))) /* Transmit FIFO Buffer Input Location 23 */


#define U1C1_IN24       (*(_PAGE_081_MEM_TYPE(0x204BE0))) /* Transmit FIFO Buffer Input Location 24 */


#define U1C1_IN25       (*(_PAGE_081_MEM_TYPE(0x204BE4))) /* Transmit FIFO Buffer Input Location 25 */


#define U1C1_IN26       (*(_PAGE_081_MEM_TYPE(0x204BE8))) /* Transmit FIFO Buffer Input Location 26 */


#define U1C1_IN27       (*(_PAGE_081_MEM_TYPE(0x204BEC))) /* Transmit FIFO Buffer Input Location 27 */


#define U1C1_IN28       (*(_PAGE_081_MEM_TYPE(0x204BF0))) /* Transmit FIFO Buffer Input Location 28 */


#define U1C1_IN29       (*(_PAGE_081_MEM_TYPE(0x204BF4))) /* Transmit FIFO Buffer Input Location 29 */


#define U1C1_IN30       (*(_PAGE_081_MEM_TYPE(0x204BF8))) /* Transmit FIFO Buffer Input Location 30 */


#define U1C1_IN31       (*(_PAGE_081_MEM_TYPE(0x204BFC))) /* Transmit FIFO Buffer Input Location 31 */


#define U1C1_OUTRL      (*(_PAGE_081_MEM_TYPE(0x204B20))) /* Receiver Buffer Output Register L */


#define U1C1_OUTRH      (*(_PAGE_081_MEM_TYPE(0x204B22))) /* Receiver Buffer Output Register H */


#define U1C1_OUTDRL     (*(_PAGE_081_MEM_TYPE(0x204B24))) /* Receiver Buffer Output Register L for Debugger */


#define U1C1_OUTDRH     (*(_PAGE_081_MEM_TYPE(0x204B26))) /* Receiver Buffer Output Register H for Debugger */


#define U1C1_TRBPTRL    (*(_PAGE_081_MEM_TYPE(0x204B08))) /* Transmit/Receive Buffer Pointer Register L */


#define U1C1_TRBPTRH    (*(_PAGE_081_MEM_TYPE(0x204B0A))) /* Transmit/Receive Buffer Pointer Register H */

#endif /* REGXC2361E_NOUSIC1 */

/********************************************************************************
 * USIC2
********************************************************************************/
#ifndef REGXC2361E_NOUSIC2


#define U2C0_CCR        (*(_PAGE_081_MEM_TYPE(0x205010))) /* Channel Control Register */


#define U2C0_CCFG       (*(_PAGE_081_MEM_TYPE(0x205018))) /* Channel Configuration Register */


#define U2C0_KSCFG      (*(_PAGE_081_MEM_TYPE(0x20500C))) /* Kernel State Configuration Register */


#define U2C0_INPRL      (*(_PAGE_081_MEM_TYPE(0x205014))) /* Interrupt Node Pointer Register L */


#define U2C0_INPRH      (*(_PAGE_081_MEM_TYPE(0x205016))) /* Interrupt Node Pointer Register H */


#define U2C0_PCRL       (*(_PAGE_081_MEM_TYPE(0x205040))) /* Protocol Control Register L */


#define U2C0_PCRH       (*(_PAGE_081_MEM_TYPE(0x205042))) /* Protocol Control Register H */


#define U2C0_PSR        (*(_PAGE_081_MEM_TYPE(0x205044))) /* Protocol Status Register */


#define U2C0_PSCR       (*(_PAGE_081_MEM_TYPE(0x205048))) /* Protocol Status Clear Register */


#define U2C0_DX0CR      (*(_PAGE_081_MEM_TYPE(0x205020))) /* Input Control Register 0 */


#define U2C0_DX1CR      (*(_PAGE_081_MEM_TYPE(0x205024))) /* Input Control Register 1 */


#define U2C0_DX2CR      (*(_PAGE_081_MEM_TYPE(0x205028))) /* Input Control Register 2 */


#define U2C0_FDRL       (*(_PAGE_081_MEM_TYPE(0x205004))) /* Fractional Divider Register L */


#define U2C0_FDRH       (*(_PAGE_081_MEM_TYPE(0x205006))) /* Fractional Divider Register H */


#define U2C0_BRGL       (*(_PAGE_081_MEM_TYPE(0x20501C))) /* Baud Rate Generator Register L */


#define U2C0_BRGH       (*(_PAGE_081_MEM_TYPE(0x20501E))) /* Baud Rate Generator Register H */


#define U2C0_SCTRL      (*(_PAGE_081_MEM_TYPE(0x205030))) /* Shift Control Register L */


#define U2C0_SCTRH      (*(_PAGE_081_MEM_TYPE(0x205032))) /* Shift Control Register H */


#define U2C0_TCSRL      (*(_PAGE_081_MEM_TYPE(0x20503C))) /* Transmit Control/Status Register L */


#define U2C0_TCSRH      (*(_PAGE_081_MEM_TYPE(0x20503E))) /* Transmit Control/Status Register H */


#define U2C0_FMRL       (*(_PAGE_081_MEM_TYPE(0x205038))) /* Flag Modification Register L */


#define U2C0_FMRH       (*(_PAGE_081_MEM_TYPE(0x20503A))) /* Flag Modification Register H */


#define U2C0_TBUF00     (*(_PAGE_081_MEM_TYPE(0x205080))) /* Transmit Buffer Input Location 00 */


#define U2C0_TBUF01     (*(_PAGE_081_MEM_TYPE(0x205084))) /* Transmit Buffer Input Location 01 */


#define U2C0_TBUF02     (*(_PAGE_081_MEM_TYPE(0x205088))) /* Transmit Buffer Input Location 02 */


#define U2C0_TBUF03     (*(_PAGE_081_MEM_TYPE(0x20508C))) /* Transmit Buffer Input Location 03 */


#define U2C0_TBUF04     (*(_PAGE_081_MEM_TYPE(0x205090))) /* Transmit Buffer Input Location 04 */


#define U2C0_TBUF05     (*(_PAGE_081_MEM_TYPE(0x205094))) /* Transmit Buffer Input Location 05 */


#define U2C0_TBUF06     (*(_PAGE_081_MEM_TYPE(0x205098))) /* Transmit Buffer Input Location 06 */


#define U2C0_TBUF07     (*(_PAGE_081_MEM_TYPE(0x20509C))) /* Transmit Buffer Input Location 07 */


#define U2C0_TBUF08     (*(_PAGE_081_MEM_TYPE(0x2050A0))) /* Transmit Buffer Input Location 08 */


#define U2C0_TBUF09     (*(_PAGE_081_MEM_TYPE(0x2050A4))) /* Transmit Buffer Input Location 09 */


#define U2C0_TBUF10     (*(_PAGE_081_MEM_TYPE(0x2050A8))) /* Transmit Buffer Input Location 10 */


#define U2C0_TBUF11     (*(_PAGE_081_MEM_TYPE(0x2050AC))) /* Transmit Buffer Input Location 11 */


#define U2C0_TBUF12     (*(_PAGE_081_MEM_TYPE(0x2050B0))) /* Transmit Buffer Input Location 12 */


#define U2C0_TBUF13     (*(_PAGE_081_MEM_TYPE(0x2050B4))) /* Transmit Buffer Input Location 13 */


#define U2C0_TBUF14     (*(_PAGE_081_MEM_TYPE(0x2050B8))) /* Transmit Buffer Input Location 14 */


#define U2C0_TBUF15     (*(_PAGE_081_MEM_TYPE(0x2050BC))) /* Transmit Buffer Input Location 15 */


#define U2C0_TBUF16     (*(_PAGE_081_MEM_TYPE(0x2050C0))) /* Transmit Buffer Input Location 16 */


#define U2C0_TBUF17     (*(_PAGE_081_MEM_TYPE(0x2050C4))) /* Transmit Buffer Input Location 17 */


#define U2C0_TBUF18     (*(_PAGE_081_MEM_TYPE(0x2050C8))) /* Transmit Buffer Input Location 18 */


#define U2C0_TBUF19     (*(_PAGE_081_MEM_TYPE(0x2050CC))) /* Transmit Buffer Input Location 19 */


#define U2C0_TBUF20     (*(_PAGE_081_MEM_TYPE(0x2050D0))) /* Transmit Buffer Input Location 20 */


#define U2C0_TBUF21     (*(_PAGE_081_MEM_TYPE(0x2050D4))) /* Transmit Buffer Input Location 21 */


#define U2C0_TBUF22     (*(_PAGE_081_MEM_TYPE(0x2050D8))) /* Transmit Buffer Input Location 22 */


#define U2C0_TBUF23     (*(_PAGE_081_MEM_TYPE(0x2050DC))) /* Transmit Buffer Input Location 23 */


#define U2C0_TBUF24     (*(_PAGE_081_MEM_TYPE(0x2050E0))) /* Transmit Buffer Input Location 24 */


#define U2C0_TBUF25     (*(_PAGE_081_MEM_TYPE(0x2050E4))) /* Transmit Buffer Input Location 25 */


#define U2C0_TBUF26     (*(_PAGE_081_MEM_TYPE(0x2050E8))) /* Transmit Buffer Input Location 26 */


#define U2C0_TBUF27     (*(_PAGE_081_MEM_TYPE(0x2050EC))) /* Transmit Buffer Input Location 27 */


#define U2C0_TBUF28     (*(_PAGE_081_MEM_TYPE(0x2050F0))) /* Transmit Buffer Input Location 28 */


#define U2C0_TBUF29     (*(_PAGE_081_MEM_TYPE(0x2050F4))) /* Transmit Buffer Input Location 29 */


#define U2C0_TBUF30     (*(_PAGE_081_MEM_TYPE(0x2050F8))) /* Transmit Buffer Input Location 30 */


#define U2C0_TBUF31     (*(_PAGE_081_MEM_TYPE(0x2050FC))) /* Transmit Buffer Input Location 31 */


#define U2C0_RBUF0      (*(_PAGE_081_MEM_TYPE(0x205050))) /* Receiver Buffer Register 0 */


#define U2C0_RBUF01SRL  (*(_PAGE_081_MEM_TYPE(0x205060))) /* Receiver Buffer 01 Status Register L */


#define U2C0_RBUF1      (*(_PAGE_081_MEM_TYPE(0x205054))) /* Receiver Buffer Register 1 */


#define U2C0_RBUF01SRH  (*(_PAGE_081_MEM_TYPE(0x205062))) /* Receiver Buffer 01 Status Register H */


#define U2C0_RBUF       (*(_PAGE_081_MEM_TYPE(0x20505C))) /* Receiver Buffer Register */


#define U2C0_RBUFD      (*(_PAGE_081_MEM_TYPE(0x20504C))) /* Receiver Buffer Register for Debugger */


#define U2C0_RBUFSR     (*(_PAGE_081_MEM_TYPE(0x205058))) /* Receiver Buffer Status Register */


#define U2C0_BYP        (*(_PAGE_081_MEM_TYPE(0x205100))) /* Bypass Data Register */


#define U2C0_BYPCRL     (*(_PAGE_081_MEM_TYPE(0x205104))) /* Bypass Control Register L */


#define U2C0_BYPCRH     (*(_PAGE_081_MEM_TYPE(0x205106))) /* Bypass Control Register H */


#define U2C0_TRBSRL     (*(_PAGE_081_MEM_TYPE(0x205118))) /* Transmit/Receive Buffer Status Register L */


#define U2C0_TRBSRH     (*(_PAGE_081_MEM_TYPE(0x20511A))) /* Transmit/Receive Buffer Status Register H */


#define U2C0_TRBSCR     (*(_PAGE_081_MEM_TYPE(0x20511C))) /* Transmit/Receive Buffer Status Clear Register */


#define U2C0_TBCTRL     (*(_PAGE_081_MEM_TYPE(0x205110))) /* Transmitter Buffer Control Register L */


#define U2C0_TBCTRH     (*(_PAGE_081_MEM_TYPE(0x205112))) /* Transmitter Buffer Control Register H */


#define U2C0_RBCTRL     (*(_PAGE_081_MEM_TYPE(0x205114))) /* Receiver Buffer Control Register L */


#define U2C0_RBCTRH     (*(_PAGE_081_MEM_TYPE(0x205116))) /* Receiver Buffer Control Register H */


#define U2C0_IN00       (*(_PAGE_081_MEM_TYPE(0x205180))) /* Transmit FIFO Buffer Input Location 00 */


#define U2C0_IN01       (*(_PAGE_081_MEM_TYPE(0x205184))) /* Transmit FIFO Buffer Input Location 01 */


#define U2C0_IN02       (*(_PAGE_081_MEM_TYPE(0x205188))) /* Transmit FIFO Buffer Input Location 02 */


#define U2C0_IN03       (*(_PAGE_081_MEM_TYPE(0x20518C))) /* Transmit FIFO Buffer Input Location 03 */


#define U2C0_IN04       (*(_PAGE_081_MEM_TYPE(0x205190))) /* Transmit FIFO Buffer Input Location 04 */


#define U2C0_IN05       (*(_PAGE_081_MEM_TYPE(0x205194))) /* Transmit FIFO Buffer Input Location 05 */


#define U2C0_IN06       (*(_PAGE_081_MEM_TYPE(0x205198))) /* Transmit FIFO Buffer Input Location 06 */


#define U2C0_IN07       (*(_PAGE_081_MEM_TYPE(0x20519C))) /* Transmit FIFO Buffer Input Location 07 */


#define U2C0_IN08       (*(_PAGE_081_MEM_TYPE(0x2051A0))) /* Transmit FIFO Buffer Input Location 08 */


#define U2C0_IN09       (*(_PAGE_081_MEM_TYPE(0x2051A4))) /* Transmit FIFO Buffer Input Location 09 */


#define U2C0_IN10       (*(_PAGE_081_MEM_TYPE(0x2051A8))) /* Transmit FIFO Buffer Input Location 10 */


#define U2C0_IN11       (*(_PAGE_081_MEM_TYPE(0x2051AC))) /* Transmit FIFO Buffer Input Location 11 */


#define U2C0_IN12       (*(_PAGE_081_MEM_TYPE(0x2051B0))) /* Transmit FIFO Buffer Input Location 12 */


#define U2C0_IN13       (*(_PAGE_081_MEM_TYPE(0x2051B4))) /* Transmit FIFO Buffer Input Location 13 */


#define U2C0_IN14       (*(_PAGE_081_MEM_TYPE(0x2051B8))) /* Transmit FIFO Buffer Input Location 14 */


#define U2C0_IN15       (*(_PAGE_081_MEM_TYPE(0x2051BC))) /* Transmit FIFO Buffer Input Location 15 */


#define U2C0_IN16       (*(_PAGE_081_MEM_TYPE(0x2051C0))) /* Transmit FIFO Buffer Input Location 16 */


#define U2C0_IN17       (*(_PAGE_081_MEM_TYPE(0x2051C4))) /* Transmit FIFO Buffer Input Location 17 */


#define U2C0_IN18       (*(_PAGE_081_MEM_TYPE(0x2051C8))) /* Transmit FIFO Buffer Input Location 18 */


#define U2C0_IN19       (*(_PAGE_081_MEM_TYPE(0x2051CC))) /* Transmit FIFO Buffer Input Location 19 */


#define U2C0_IN20       (*(_PAGE_081_MEM_TYPE(0x2051D0))) /* Transmit FIFO Buffer Input Location 20 */


#define U2C0_IN21       (*(_PAGE_081_MEM_TYPE(0x2051D4))) /* Transmit FIFO Buffer Input Location 21 */


#define U2C0_IN22       (*(_PAGE_081_MEM_TYPE(0x2051D8))) /* Transmit FIFO Buffer Input Location 22 */


#define U2C0_IN23       (*(_PAGE_081_MEM_TYPE(0x2051DC))) /* Transmit FIFO Buffer Input Location 23 */


#define U2C0_IN24       (*(_PAGE_081_MEM_TYPE(0x2051E0))) /* Transmit FIFO Buffer Input Location 24 */


#define U2C0_IN25       (*(_PAGE_081_MEM_TYPE(0x2051E4))) /* Transmit FIFO Buffer Input Location 25 */


#define U2C0_IN26       (*(_PAGE_081_MEM_TYPE(0x2051E8))) /* Transmit FIFO Buffer Input Location 26 */


#define U2C0_IN27       (*(_PAGE_081_MEM_TYPE(0x2051EC))) /* Transmit FIFO Buffer Input Location 27 */


#define U2C0_IN28       (*(_PAGE_081_MEM_TYPE(0x2051F0))) /* Transmit FIFO Buffer Input Location 28 */


#define U2C0_IN29       (*(_PAGE_081_MEM_TYPE(0x2051F4))) /* Transmit FIFO Buffer Input Location 29 */


#define U2C0_IN30       (*(_PAGE_081_MEM_TYPE(0x2051F8))) /* Transmit FIFO Buffer Input Location 30 */


#define U2C0_IN31       (*(_PAGE_081_MEM_TYPE(0x2051FC))) /* Transmit FIFO Buffer Input Location 31 */


#define U2C0_OUTRL      (*(_PAGE_081_MEM_TYPE(0x205120))) /* Receiver Buffer Output Register L */


#define U2C0_OUTRH      (*(_PAGE_081_MEM_TYPE(0x205122))) /* Receiver Buffer Output Register H */


#define U2C0_OUTDRL     (*(_PAGE_081_MEM_TYPE(0x205124))) /* Receiver Buffer Output Register L for Debugger */


#define U2C0_OUTDRH     (*(_PAGE_081_MEM_TYPE(0x205126))) /* Receiver Buffer Output Register H for Debugger */


#define U2C0_TRBPTRL    (*(_PAGE_081_MEM_TYPE(0x205108))) /* Transmit/Receive Buffer Pointer Register L */


#define U2C0_TRBPTRH    (*(_PAGE_081_MEM_TYPE(0x20510A))) /* Transmit/Receive Buffer Pointer Register H */


#define U2C1_CCR        (*(_PAGE_081_MEM_TYPE(0x205210))) /* Channel Control Register */


#define U2C1_CCFG       (*(_PAGE_081_MEM_TYPE(0x205218))) /* Channel Configuration Register */


#define U2C1_KSCFG      (*(_PAGE_081_MEM_TYPE(0x20520C))) /* Kernel State Configuration Register */


#define U2C1_INPRL      (*(_PAGE_081_MEM_TYPE(0x205214))) /* Interrupt Node Pointer Register L */


#define U2C1_INPRH      (*(_PAGE_081_MEM_TYPE(0x205216))) /* Interrupt Node Pointer Register H */


#define U2C1_PCRL       (*(_PAGE_081_MEM_TYPE(0x205240))) /* Protocol Control Register L */


#define U2C1_PCRH       (*(_PAGE_081_MEM_TYPE(0x205242))) /* Protocol Control Register H */


#define U2C1_PSR        (*(_PAGE_081_MEM_TYPE(0x205244))) /* Protocol Status Register */


#define U2C1_PSCR       (*(_PAGE_081_MEM_TYPE(0x205248))) /* Protocol Status Clear Register */


#define U2C1_DX0CR      (*(_PAGE_081_MEM_TYPE(0x205220))) /* Input Control Register 0 */


#define U2C1_DX1CR      (*(_PAGE_081_MEM_TYPE(0x205224))) /* Input Control Register 1 */


#define U2C1_DX2CR      (*(_PAGE_081_MEM_TYPE(0x205228))) /* Input Control Register 2 */


#define U2C1_FDRL       (*(_PAGE_081_MEM_TYPE(0x205204))) /* Fractional Divider Register L */


#define U2C1_FDRH       (*(_PAGE_081_MEM_TYPE(0x205206))) /* Fractional Divider Register H */


#define U2C1_BRGL       (*(_PAGE_081_MEM_TYPE(0x20521C))) /* Baud Rate Generator Register L */


#define U2C1_BRGH       (*(_PAGE_081_MEM_TYPE(0x20521E))) /* Baud Rate Generator Register H */


#define U2C1_SCTRL      (*(_PAGE_081_MEM_TYPE(0x205230))) /* Shift Control Register L */


#define U2C1_SCTRH      (*(_PAGE_081_MEM_TYPE(0x205232))) /* Shift Control Register H */


#define U2C1_TCSRL      (*(_PAGE_081_MEM_TYPE(0x20523C))) /* Transmit Control/Status Register L */


#define U2C1_TCSRH      (*(_PAGE_081_MEM_TYPE(0x20523E))) /* Transmit Control/Status Register H */


#define U2C1_FMRL       (*(_PAGE_081_MEM_TYPE(0x205238))) /* Flag Modification Register L */


#define U2C1_FMRH       (*(_PAGE_081_MEM_TYPE(0x20523A))) /* Flag Modification Register H */


#define U2C1_TBUF00     (*(_PAGE_081_MEM_TYPE(0x205280))) /* Transmit Buffer Input Location 00 */


#define U2C1_TBUF01     (*(_PAGE_081_MEM_TYPE(0x205284))) /* Transmit Buffer Input Location 01 */


#define U2C1_TBUF02     (*(_PAGE_081_MEM_TYPE(0x205288))) /* Transmit Buffer Input Location 02 */


#define U2C1_TBUF03     (*(_PAGE_081_MEM_TYPE(0x20528C))) /* Transmit Buffer Input Location 03 */


#define U2C1_TBUF04     (*(_PAGE_081_MEM_TYPE(0x205290))) /* Transmit Buffer Input Location 04 */


#define U2C1_TBUF05     (*(_PAGE_081_MEM_TYPE(0x205294))) /* Transmit Buffer Input Location 05 */


#define U2C1_TBUF06     (*(_PAGE_081_MEM_TYPE(0x205298))) /* Transmit Buffer Input Location 06 */


#define U2C1_TBUF07     (*(_PAGE_081_MEM_TYPE(0x20529C))) /* Transmit Buffer Input Location 07 */


#define U2C1_TBUF08     (*(_PAGE_081_MEM_TYPE(0x2052A0))) /* Transmit Buffer Input Location 08 */


#define U2C1_TBUF09     (*(_PAGE_081_MEM_TYPE(0x2052A4))) /* Transmit Buffer Input Location 09 */


#define U2C1_TBUF10     (*(_PAGE_081_MEM_TYPE(0x2052A8))) /* Transmit Buffer Input Location 10 */


#define U2C1_TBUF11     (*(_PAGE_081_MEM_TYPE(0x2052AC))) /* Transmit Buffer Input Location 11 */


#define U2C1_TBUF12     (*(_PAGE_081_MEM_TYPE(0x2052B0))) /* Transmit Buffer Input Location 12 */


#define U2C1_TBUF13     (*(_PAGE_081_MEM_TYPE(0x2052B4))) /* Transmit Buffer Input Location 13 */


#define U2C1_TBUF14     (*(_PAGE_081_MEM_TYPE(0x2052B8))) /* Transmit Buffer Input Location 14 */


#define U2C1_TBUF15     (*(_PAGE_081_MEM_TYPE(0x2052BC))) /* Transmit Buffer Input Location 15 */


#define U2C1_TBUF16     (*(_PAGE_081_MEM_TYPE(0x2052C0))) /* Transmit Buffer Input Location 16 */


#define U2C1_TBUF17     (*(_PAGE_081_MEM_TYPE(0x2052C4))) /* Transmit Buffer Input Location 17 */


#define U2C1_TBUF18     (*(_PAGE_081_MEM_TYPE(0x2052C8))) /* Transmit Buffer Input Location 18 */


#define U2C1_TBUF19     (*(_PAGE_081_MEM_TYPE(0x2052CC))) /* Transmit Buffer Input Location 19 */


#define U2C1_TBUF20     (*(_PAGE_081_MEM_TYPE(0x2052D0))) /* Transmit Buffer Input Location 20 */


#define U2C1_TBUF21     (*(_PAGE_081_MEM_TYPE(0x2052D4))) /* Transmit Buffer Input Location 21 */


#define U2C1_TBUF22     (*(_PAGE_081_MEM_TYPE(0x2052D8))) /* Transmit Buffer Input Location 22 */


#define U2C1_TBUF23     (*(_PAGE_081_MEM_TYPE(0x2052DC))) /* Transmit Buffer Input Location 23 */


#define U2C1_TBUF24     (*(_PAGE_081_MEM_TYPE(0x2052E0))) /* Transmit Buffer Input Location 24 */


#define U2C1_TBUF25     (*(_PAGE_081_MEM_TYPE(0x2052E4))) /* Transmit Buffer Input Location 25 */


#define U2C1_TBUF26     (*(_PAGE_081_MEM_TYPE(0x2052E8))) /* Transmit Buffer Input Location 26 */


#define U2C1_TBUF27     (*(_PAGE_081_MEM_TYPE(0x2052EC))) /* Transmit Buffer Input Location 27 */


#define U2C1_TBUF28     (*(_PAGE_081_MEM_TYPE(0x2052F0))) /* Transmit Buffer Input Location 28 */


#define U2C1_TBUF29     (*(_PAGE_081_MEM_TYPE(0x2052F4))) /* Transmit Buffer Input Location 29 */


#define U2C1_TBUF30     (*(_PAGE_081_MEM_TYPE(0x2052F8))) /* Transmit Buffer Input Location 30 */


#define U2C1_TBUF31     (*(_PAGE_081_MEM_TYPE(0x2052FC))) /* Transmit Buffer Input Location 31 */


#define U2C1_RBUF0      (*(_PAGE_081_MEM_TYPE(0x205250))) /* Receiver Buffer Register 0 */


#define U2C1_RBUF01SRL  (*(_PAGE_081_MEM_TYPE(0x205260))) /* Receiver Buffer 01 Status Register L */


#define U2C1_RBUF1      (*(_PAGE_081_MEM_TYPE(0x205254))) /* Receiver Buffer Register 1 */


#define U2C1_RBUF01SRH  (*(_PAGE_081_MEM_TYPE(0x205262))) /* Receiver Buffer 01 Status Register H */


#define U2C1_RBUF       (*(_PAGE_081_MEM_TYPE(0x20525C))) /* Receiver Buffer Register */


#define U2C1_RBUFD      (*(_PAGE_081_MEM_TYPE(0x20524C))) /* Receiver Buffer Register for Debugger */


#define U2C1_RBUFSR     (*(_PAGE_081_MEM_TYPE(0x205258))) /* Receiver Buffer Status Register */


#define U2C1_BYP        (*(_PAGE_081_MEM_TYPE(0x205300))) /* Bypass Data Register */


#define U2C1_BYPCRL     (*(_PAGE_081_MEM_TYPE(0x205304))) /* Bypass Control Register L */


#define U2C1_BYPCRH     (*(_PAGE_081_MEM_TYPE(0x205306))) /* Bypass Control Register H */


#define U2C1_TRBSRL     (*(_PAGE_081_MEM_TYPE(0x205318))) /* Transmit/Receive Buffer Status Register L */


#define U2C1_TRBSRH     (*(_PAGE_081_MEM_TYPE(0x20531A))) /* Transmit/Receive Buffer Status Register H */


#define U2C1_TRBSCR     (*(_PAGE_081_MEM_TYPE(0x20531C))) /* Transmit/Receive Buffer Status Clear Register */


#define U2C1_TBCTRL     (*(_PAGE_081_MEM_TYPE(0x205310))) /* Transmitter Buffer Control Register L */


#define U2C1_TBCTRH     (*(_PAGE_081_MEM_TYPE(0x205312))) /* Transmitter Buffer Control Register H */


#define U2C1_RBCTRL     (*(_PAGE_081_MEM_TYPE(0x205314))) /* Receiver Buffer Control Register L */


#define U2C1_RBCTRH     (*(_PAGE_081_MEM_TYPE(0x205316))) /* Receiver Buffer Control Register H */


#define U2C1_IN00       (*(_PAGE_081_MEM_TYPE(0x205380))) /* Transmit FIFO Buffer Input Location 00 */


#define U2C1_IN01       (*(_PAGE_081_MEM_TYPE(0x205384))) /* Transmit FIFO Buffer Input Location 01 */


#define U2C1_IN02       (*(_PAGE_081_MEM_TYPE(0x205388))) /* Transmit FIFO Buffer Input Location 02 */


#define U2C1_IN03       (*(_PAGE_081_MEM_TYPE(0x20538C))) /* Transmit FIFO Buffer Input Location 03 */


#define U2C1_IN04       (*(_PAGE_081_MEM_TYPE(0x205390))) /* Transmit FIFO Buffer Input Location 04 */


#define U2C1_IN05       (*(_PAGE_081_MEM_TYPE(0x205394))) /* Transmit FIFO Buffer Input Location 05 */


#define U2C1_IN06       (*(_PAGE_081_MEM_TYPE(0x205398))) /* Transmit FIFO Buffer Input Location 06 */


#define U2C1_IN07       (*(_PAGE_081_MEM_TYPE(0x20539C))) /* Transmit FIFO Buffer Input Location 07 */


#define U2C1_IN08       (*(_PAGE_081_MEM_TYPE(0x2053A0))) /* Transmit FIFO Buffer Input Location 08 */


#define U2C1_IN09       (*(_PAGE_081_MEM_TYPE(0x2053A4))) /* Transmit FIFO Buffer Input Location 09 */


#define U2C1_IN10       (*(_PAGE_081_MEM_TYPE(0x2053A8))) /* Transmit FIFO Buffer Input Location 10 */


#define U2C1_IN11       (*(_PAGE_081_MEM_TYPE(0x2053AC))) /* Transmit FIFO Buffer Input Location 11 */


#define U2C1_IN12       (*(_PAGE_081_MEM_TYPE(0x2053B0))) /* Transmit FIFO Buffer Input Location 12 */


#define U2C1_IN13       (*(_PAGE_081_MEM_TYPE(0x2053B4))) /* Transmit FIFO Buffer Input Location 13 */


#define U2C1_IN14       (*(_PAGE_081_MEM_TYPE(0x2053B8))) /* Transmit FIFO Buffer Input Location 14 */


#define U2C1_IN15       (*(_PAGE_081_MEM_TYPE(0x2053BC))) /* Transmit FIFO Buffer Input Location 15 */


#define U2C1_IN16       (*(_PAGE_081_MEM_TYPE(0x2053C0))) /* Transmit FIFO Buffer Input Location 16 */


#define U2C1_IN17       (*(_PAGE_081_MEM_TYPE(0x2053C4))) /* Transmit FIFO Buffer Input Location 17 */


#define U2C1_IN18       (*(_PAGE_081_MEM_TYPE(0x2053C8))) /* Transmit FIFO Buffer Input Location 18 */


#define U2C1_IN19       (*(_PAGE_081_MEM_TYPE(0x2053CC))) /* Transmit FIFO Buffer Input Location 19 */


#define U2C1_IN20       (*(_PAGE_081_MEM_TYPE(0x2053D0))) /* Transmit FIFO Buffer Input Location 20 */


#define U2C1_IN21       (*(_PAGE_081_MEM_TYPE(0x2053D4))) /* Transmit FIFO Buffer Input Location 21 */


#define U2C1_IN22       (*(_PAGE_081_MEM_TYPE(0x2053D8))) /* Transmit FIFO Buffer Input Location 22 */


#define U2C1_IN23       (*(_PAGE_081_MEM_TYPE(0x2053DC))) /* Transmit FIFO Buffer Input Location 23 */


#define U2C1_IN24       (*(_PAGE_081_MEM_TYPE(0x2053E0))) /* Transmit FIFO Buffer Input Location 24 */


#define U2C1_IN25       (*(_PAGE_081_MEM_TYPE(0x2053E4))) /* Transmit FIFO Buffer Input Location 25 */


#define U2C1_IN26       (*(_PAGE_081_MEM_TYPE(0x2053E8))) /* Transmit FIFO Buffer Input Location 26 */


#define U2C1_IN27       (*(_PAGE_081_MEM_TYPE(0x2053EC))) /* Transmit FIFO Buffer Input Location 27 */


#define U2C1_IN28       (*(_PAGE_081_MEM_TYPE(0x2053F0))) /* Transmit FIFO Buffer Input Location 28 */


#define U2C1_IN29       (*(_PAGE_081_MEM_TYPE(0x2053F4))) /* Transmit FIFO Buffer Input Location 29 */


#define U2C1_IN30       (*(_PAGE_081_MEM_TYPE(0x2053F8))) /* Transmit FIFO Buffer Input Location 30 */


#define U2C1_IN31       (*(_PAGE_081_MEM_TYPE(0x2053FC))) /* Transmit FIFO Buffer Input Location 31 */


#define U2C1_OUTRL      (*(_PAGE_081_MEM_TYPE(0x205320))) /* Receiver Buffer Output Register L */


#define U2C1_OUTRH      (*(_PAGE_081_MEM_TYPE(0x205322))) /* Receiver Buffer Output Register H */


#define U2C1_OUTDRL     (*(_PAGE_081_MEM_TYPE(0x205324))) /* Receiver Buffer Output Register L for Debugger */


#define U2C1_OUTDRH     (*(_PAGE_081_MEM_TYPE(0x205326))) /* Receiver Buffer Output Register H for Debugger */


#define U2C1_TRBPTRL    (*(_PAGE_081_MEM_TYPE(0x205308))) /* Transmit/Receive Buffer Pointer Register L */


#define U2C1_TRBPTRH    (*(_PAGE_081_MEM_TYPE(0x20530A))) /* Transmit/Receive Buffer Pointer Register H */

#endif /* REGXC2361E_NOUSIC2 */

/********************************************************************************
 * USIC3
********************************************************************************/
#ifndef REGXC2361E_NOUSIC3


#define U3C0_CCR        (*(_PAGE_081_MEM_TYPE(0x205810))) /* Channel Control Register */


#define U3C0_CCFG       (*(_PAGE_081_MEM_TYPE(0x205818))) /* Channel Configuration Register */


#define U3C0_KSCFG      (*(_PAGE_081_MEM_TYPE(0x20580C))) /* Kernel State Configuration Register */


#define U3C0_INPRL      (*(_PAGE_081_MEM_TYPE(0x205814))) /* Interrupt Node Pointer Register L */


#define U3C0_INPRH      (*(_PAGE_081_MEM_TYPE(0x205816))) /* Interrupt Node Pointer Register H */


#define U3C0_PCRL       (*(_PAGE_081_MEM_TYPE(0x205840))) /* Protocol Control Register L */


#define U3C0_PCRH       (*(_PAGE_081_MEM_TYPE(0x205842))) /* Protocol Control Register H */


#define U3C0_PSR        (*(_PAGE_081_MEM_TYPE(0x205844))) /* Protocol Status Register */


#define U3C0_PSCR       (*(_PAGE_081_MEM_TYPE(0x205848))) /* Protocol Status Clear Register */


#define U3C0_DX0CR      (*(_PAGE_081_MEM_TYPE(0x205820))) /* Input Control Register 0 */


#define U3C0_DX1CR      (*(_PAGE_081_MEM_TYPE(0x205824))) /* Input Control Register 1 */


#define U3C0_DX2CR      (*(_PAGE_081_MEM_TYPE(0x205828))) /* Input Control Register 2 */


#define U3C0_FDRL       (*(_PAGE_081_MEM_TYPE(0x205804))) /* Fractional Divider Register L */


#define U3C0_FDRH       (*(_PAGE_081_MEM_TYPE(0x205806))) /* Fractional Divider Register H */


#define U3C0_BRGL       (*(_PAGE_081_MEM_TYPE(0x20581C))) /* Baud Rate Generator Register L */


#define U3C0_BRGH       (*(_PAGE_081_MEM_TYPE(0x20581E))) /* Baud Rate Generator Register H */


#define U3C0_SCTRL      (*(_PAGE_081_MEM_TYPE(0x205830))) /* Shift Control Register L */


#define U3C0_SCTRH      (*(_PAGE_081_MEM_TYPE(0x205832))) /* Shift Control Register H */


#define U3C0_TCSRL      (*(_PAGE_081_MEM_TYPE(0x20583C))) /* Transmit Control/Status Register L */


#define U3C0_TCSRH      (*(_PAGE_081_MEM_TYPE(0x20583E))) /* Transmit Control/Status Register H */


#define U3C0_FMRL       (*(_PAGE_081_MEM_TYPE(0x205838))) /* Flag Modification Register L */


#define U3C0_FMRH       (*(_PAGE_081_MEM_TYPE(0x20583A))) /* Flag Modification Register H */


#define U3C0_TBUF00     (*(_PAGE_081_MEM_TYPE(0x205880))) /* Transmit Buffer Input Location 00 */


#define U3C0_TBUF01     (*(_PAGE_081_MEM_TYPE(0x205884))) /* Transmit Buffer Input Location 01 */


#define U3C0_TBUF02     (*(_PAGE_081_MEM_TYPE(0x205888))) /* Transmit Buffer Input Location 02 */


#define U3C0_TBUF03     (*(_PAGE_081_MEM_TYPE(0x20588C))) /* Transmit Buffer Input Location 03 */


#define U3C0_TBUF04     (*(_PAGE_081_MEM_TYPE(0x205890))) /* Transmit Buffer Input Location 04 */


#define U3C0_TBUF05     (*(_PAGE_081_MEM_TYPE(0x205894))) /* Transmit Buffer Input Location 05 */


#define U3C0_TBUF06     (*(_PAGE_081_MEM_TYPE(0x205898))) /* Transmit Buffer Input Location 06 */


#define U3C0_TBUF07     (*(_PAGE_081_MEM_TYPE(0x20589C))) /* Transmit Buffer Input Location 07 */


#define U3C0_TBUF08     (*(_PAGE_081_MEM_TYPE(0x2058A0))) /* Transmit Buffer Input Location 08 */


#define U3C0_TBUF09     (*(_PAGE_081_MEM_TYPE(0x2058A4))) /* Transmit Buffer Input Location 09 */


#define U3C0_TBUF10     (*(_PAGE_081_MEM_TYPE(0x2058A8))) /* Transmit Buffer Input Location 10 */


#define U3C0_TBUF11     (*(_PAGE_081_MEM_TYPE(0x2058AC))) /* Transmit Buffer Input Location 11 */


#define U3C0_TBUF12     (*(_PAGE_081_MEM_TYPE(0x2058B0))) /* Transmit Buffer Input Location 12 */


#define U3C0_TBUF13     (*(_PAGE_081_MEM_TYPE(0x2058B4))) /* Transmit Buffer Input Location 13 */


#define U3C0_TBUF14     (*(_PAGE_081_MEM_TYPE(0x2058B8))) /* Transmit Buffer Input Location 14 */


#define U3C0_TBUF15     (*(_PAGE_081_MEM_TYPE(0x2058BC))) /* Transmit Buffer Input Location 15 */


#define U3C0_TBUF16     (*(_PAGE_081_MEM_TYPE(0x2058C0))) /* Transmit Buffer Input Location 16 */


#define U3C0_TBUF17     (*(_PAGE_081_MEM_TYPE(0x2058C4))) /* Transmit Buffer Input Location 17 */


#define U3C0_TBUF18     (*(_PAGE_081_MEM_TYPE(0x2058C8))) /* Transmit Buffer Input Location 18 */


#define U3C0_TBUF19     (*(_PAGE_081_MEM_TYPE(0x2058CC))) /* Transmit Buffer Input Location 19 */


#define U3C0_TBUF20     (*(_PAGE_081_MEM_TYPE(0x2058D0))) /* Transmit Buffer Input Location 20 */


#define U3C0_TBUF21     (*(_PAGE_081_MEM_TYPE(0x2058D4))) /* Transmit Buffer Input Location 21 */


#define U3C0_TBUF22     (*(_PAGE_081_MEM_TYPE(0x2058D8))) /* Transmit Buffer Input Location 22 */


#define U3C0_TBUF23     (*(_PAGE_081_MEM_TYPE(0x2058DC))) /* Transmit Buffer Input Location 23 */


#define U3C0_TBUF24     (*(_PAGE_081_MEM_TYPE(0x2058E0))) /* Transmit Buffer Input Location 24 */


#define U3C0_TBUF25     (*(_PAGE_081_MEM_TYPE(0x2058E4))) /* Transmit Buffer Input Location 25 */


#define U3C0_TBUF26     (*(_PAGE_081_MEM_TYPE(0x2058E8))) /* Transmit Buffer Input Location 26 */


#define U3C0_TBUF27     (*(_PAGE_081_MEM_TYPE(0x2058EC))) /* Transmit Buffer Input Location 27 */


#define U3C0_TBUF28     (*(_PAGE_081_MEM_TYPE(0x2058F0))) /* Transmit Buffer Input Location 28 */


#define U3C0_TBUF29     (*(_PAGE_081_MEM_TYPE(0x2058F4))) /* Transmit Buffer Input Location 29 */


#define U3C0_TBUF30     (*(_PAGE_081_MEM_TYPE(0x2058F8))) /* Transmit Buffer Input Location 30 */


#define U3C0_TBUF31     (*(_PAGE_081_MEM_TYPE(0x2058FC))) /* Transmit Buffer Input Location 31 */


#define U3C0_RBUF0      (*(_PAGE_081_MEM_TYPE(0x205850))) /* Receiver Buffer Register 0 */


#define U3C0_RBUF01SRL  (*(_PAGE_081_MEM_TYPE(0x205860))) /* Receiver Buffer 01 Status Register L */


#define U3C0_RBUF1      (*(_PAGE_081_MEM_TYPE(0x205854))) /* Receiver Buffer Register 1 */


#define U3C0_RBUF01SRH  (*(_PAGE_081_MEM_TYPE(0x205862))) /* Receiver Buffer 01 Status Register H */


#define U3C0_RBUF       (*(_PAGE_081_MEM_TYPE(0x20585C))) /* Receiver Buffer Register */


#define U3C0_RBUFD      (*(_PAGE_081_MEM_TYPE(0x20584C))) /* Receiver Buffer Register for Debugger */


#define U3C0_RBUFSR     (*(_PAGE_081_MEM_TYPE(0x205858))) /* Receiver Buffer Status Register */


#define U3C0_BYP        (*(_PAGE_081_MEM_TYPE(0x205900))) /* Bypass Data Register */


#define U3C0_BYPCRL     (*(_PAGE_081_MEM_TYPE(0x205904))) /* Bypass Control Register L */


#define U3C0_BYPCRH     (*(_PAGE_081_MEM_TYPE(0x205906))) /* Bypass Control Register H */


#define U3C0_TRBSRL     (*(_PAGE_081_MEM_TYPE(0x205918))) /* Transmit/Receive Buffer Status Register L */


#define U3C0_TRBSRH     (*(_PAGE_081_MEM_TYPE(0x20591A))) /* Transmit/Receive Buffer Status Register H */


#define U3C0_TRBSCR     (*(_PAGE_081_MEM_TYPE(0x20591C))) /* Transmit/Receive Buffer Status Clear Register */


#define U3C0_TBCTRL     (*(_PAGE_081_MEM_TYPE(0x205910))) /* Transmitter Buffer Control Register L */


#define U3C0_TBCTRH     (*(_PAGE_081_MEM_TYPE(0x205912))) /* Transmitter Buffer Control Register H */


#define U3C0_RBCTRL     (*(_PAGE_081_MEM_TYPE(0x205914))) /* Receiver Buffer Control Register L */


#define U3C0_RBCTRH     (*(_PAGE_081_MEM_TYPE(0x205916))) /* Receiver Buffer Control Register H */


#define U3C0_IN00       (*(_PAGE_081_MEM_TYPE(0x205980))) /* Transmit FIFO Buffer Input Location 00 */


#define U3C0_IN01       (*(_PAGE_081_MEM_TYPE(0x205984))) /* Transmit FIFO Buffer Input Location 01 */


#define U3C0_IN02       (*(_PAGE_081_MEM_TYPE(0x205988))) /* Transmit FIFO Buffer Input Location 02 */


#define U3C0_IN03       (*(_PAGE_081_MEM_TYPE(0x20598C))) /* Transmit FIFO Buffer Input Location 03 */


#define U3C0_IN04       (*(_PAGE_081_MEM_TYPE(0x205990))) /* Transmit FIFO Buffer Input Location 04 */


#define U3C0_IN05       (*(_PAGE_081_MEM_TYPE(0x205994))) /* Transmit FIFO Buffer Input Location 05 */


#define U3C0_IN06       (*(_PAGE_081_MEM_TYPE(0x205998))) /* Transmit FIFO Buffer Input Location 06 */


#define U3C0_IN07       (*(_PAGE_081_MEM_TYPE(0x20599C))) /* Transmit FIFO Buffer Input Location 07 */


#define U3C0_IN08       (*(_PAGE_081_MEM_TYPE(0x2059A0))) /* Transmit FIFO Buffer Input Location 08 */


#define U3C0_IN09       (*(_PAGE_081_MEM_TYPE(0x2059A4))) /* Transmit FIFO Buffer Input Location 09 */


#define U3C0_IN10       (*(_PAGE_081_MEM_TYPE(0x2059A8))) /* Transmit FIFO Buffer Input Location 10 */


#define U3C0_IN11       (*(_PAGE_081_MEM_TYPE(0x2059AC))) /* Transmit FIFO Buffer Input Location 11 */


#define U3C0_IN12       (*(_PAGE_081_MEM_TYPE(0x2059B0))) /* Transmit FIFO Buffer Input Location 12 */


#define U3C0_IN13       (*(_PAGE_081_MEM_TYPE(0x2059B4))) /* Transmit FIFO Buffer Input Location 13 */


#define U3C0_IN14       (*(_PAGE_081_MEM_TYPE(0x2059B8))) /* Transmit FIFO Buffer Input Location 14 */


#define U3C0_IN15       (*(_PAGE_081_MEM_TYPE(0x2059BC))) /* Transmit FIFO Buffer Input Location 15 */


#define U3C0_IN16       (*(_PAGE_081_MEM_TYPE(0x2059C0))) /* Transmit FIFO Buffer Input Location 16 */


#define U3C0_IN17       (*(_PAGE_081_MEM_TYPE(0x2059C4))) /* Transmit FIFO Buffer Input Location 17 */


#define U3C0_IN18       (*(_PAGE_081_MEM_TYPE(0x2059C8))) /* Transmit FIFO Buffer Input Location 18 */


#define U3C0_IN19       (*(_PAGE_081_MEM_TYPE(0x2059CC))) /* Transmit FIFO Buffer Input Location 19 */


#define U3C0_IN20       (*(_PAGE_081_MEM_TYPE(0x2059D0))) /* Transmit FIFO Buffer Input Location 20 */


#define U3C0_IN21       (*(_PAGE_081_MEM_TYPE(0x2059D4))) /* Transmit FIFO Buffer Input Location 21 */


#define U3C0_IN22       (*(_PAGE_081_MEM_TYPE(0x2059D8))) /* Transmit FIFO Buffer Input Location 22 */


#define U3C0_IN23       (*(_PAGE_081_MEM_TYPE(0x2059DC))) /* Transmit FIFO Buffer Input Location 23 */


#define U3C0_IN24       (*(_PAGE_081_MEM_TYPE(0x2059E0))) /* Transmit FIFO Buffer Input Location 24 */


#define U3C0_IN25       (*(_PAGE_081_MEM_TYPE(0x2059E4))) /* Transmit FIFO Buffer Input Location 25 */


#define U3C0_IN26       (*(_PAGE_081_MEM_TYPE(0x2059E8))) /* Transmit FIFO Buffer Input Location 26 */


#define U3C0_IN27       (*(_PAGE_081_MEM_TYPE(0x2059EC))) /* Transmit FIFO Buffer Input Location 27 */


#define U3C0_IN28       (*(_PAGE_081_MEM_TYPE(0x2059F0))) /* Transmit FIFO Buffer Input Location 28 */


#define U3C0_IN29       (*(_PAGE_081_MEM_TYPE(0x2059F4))) /* Transmit FIFO Buffer Input Location 29 */


#define U3C0_IN30       (*(_PAGE_081_MEM_TYPE(0x2059F8))) /* Transmit FIFO Buffer Input Location 30 */


#define U3C0_IN31       (*(_PAGE_081_MEM_TYPE(0x2059FC))) /* Transmit FIFO Buffer Input Location 31 */


#define U3C0_OUTRL      (*(_PAGE_081_MEM_TYPE(0x205920))) /* Receiver Buffer Output Register L */


#define U3C0_OUTRH      (*(_PAGE_081_MEM_TYPE(0x205922))) /* Receiver Buffer Output Register H */


#define U3C0_OUTDRL     (*(_PAGE_081_MEM_TYPE(0x205924))) /* Receiver Buffer Output Register L for Debugger */


#define U3C0_OUTDRH     (*(_PAGE_081_MEM_TYPE(0x205926))) /* Receiver Buffer Output Register H for Debugger */


#define U3C0_TRBPTRL    (*(_PAGE_081_MEM_TYPE(0x205908))) /* Transmit/Receive Buffer Pointer Register L */


#define U3C0_TRBPTRH    (*(_PAGE_081_MEM_TYPE(0x20590A))) /* Transmit/Receive Buffer Pointer Register H */


#define U3C1_CCR        (*(_PAGE_081_MEM_TYPE(0x205A10))) /* Channel Control Register */


#define U3C1_CCFG       (*(_PAGE_081_MEM_TYPE(0x205A18))) /* Channel Configuration Register */


#define U3C1_KSCFG      (*(_PAGE_081_MEM_TYPE(0x205A0C))) /* Kernel State Configuration Register */


#define U3C1_INPRL      (*(_PAGE_081_MEM_TYPE(0x205A14))) /* Interrupt Node Pointer Register L */


#define U3C1_INPRH      (*(_PAGE_081_MEM_TYPE(0x205A16))) /* Interrupt Node Pointer Register H */


#define U3C1_PCRL       (*(_PAGE_081_MEM_TYPE(0x205A40))) /* Protocol Control Register L */


#define U3C1_PCRH       (*(_PAGE_081_MEM_TYPE(0x205A42))) /* Protocol Control Register H */


#define U3C1_PSR        (*(_PAGE_081_MEM_TYPE(0x205A44))) /* Protocol Status Register */


#define U3C1_PSCR       (*(_PAGE_081_MEM_TYPE(0x205A48))) /* Protocol Status Clear Register */


#define U3C1_DX0CR      (*(_PAGE_081_MEM_TYPE(0x205A20))) /* Input Control Register 0 */


#define U3C1_DX1CR      (*(_PAGE_081_MEM_TYPE(0x205A24))) /* Input Control Register 1 */


#define U3C1_DX2CR      (*(_PAGE_081_MEM_TYPE(0x205A28))) /* Input Control Register 2 */


#define U3C1_FDRL       (*(_PAGE_081_MEM_TYPE(0x205A04))) /* Fractional Divider Register L */


#define U3C1_FDRH       (*(_PAGE_081_MEM_TYPE(0x205A06))) /* Fractional Divider Register H */


#define U3C1_BRGL       (*(_PAGE_081_MEM_TYPE(0x205A1C))) /* Baud Rate Generator Register L */


#define U3C1_BRGH       (*(_PAGE_081_MEM_TYPE(0x205A1E))) /* Baud Rate Generator Register H */


#define U3C1_SCTRL      (*(_PAGE_081_MEM_TYPE(0x205A30))) /* Shift Control Register L */


#define U3C1_SCTRH      (*(_PAGE_081_MEM_TYPE(0x205A32))) /* Shift Control Register H */


#define U3C1_TCSRL      (*(_PAGE_081_MEM_TYPE(0x205A3C))) /* Transmit Control/Status Register L */


#define U3C1_TCSRH      (*(_PAGE_081_MEM_TYPE(0x205A3E))) /* Transmit Control/Status Register H */


#define U3C1_FMRL       (*(_PAGE_081_MEM_TYPE(0x205A38))) /* Flag Modification Register L */


#define U3C1_FMRH       (*(_PAGE_081_MEM_TYPE(0x205A3A))) /* Flag Modification Register H */


#define U3C1_TBUF00     (*(_PAGE_081_MEM_TYPE(0x205A80))) /* Transmit Buffer Input Location 00 */


#define U3C1_TBUF01     (*(_PAGE_081_MEM_TYPE(0x205A84))) /* Transmit Buffer Input Location 01 */


#define U3C1_TBUF02     (*(_PAGE_081_MEM_TYPE(0x205A88))) /* Transmit Buffer Input Location 02 */


#define U3C1_TBUF03     (*(_PAGE_081_MEM_TYPE(0x205A8C))) /* Transmit Buffer Input Location 03 */


#define U3C1_TBUF04     (*(_PAGE_081_MEM_TYPE(0x205A90))) /* Transmit Buffer Input Location 04 */


#define U3C1_TBUF05     (*(_PAGE_081_MEM_TYPE(0x205A94))) /* Transmit Buffer Input Location 05 */


#define U3C1_TBUF06     (*(_PAGE_081_MEM_TYPE(0x205A98))) /* Transmit Buffer Input Location 06 */


#define U3C1_TBUF07     (*(_PAGE_081_MEM_TYPE(0x205A9C))) /* Transmit Buffer Input Location 07 */


#define U3C1_TBUF08     (*(_PAGE_081_MEM_TYPE(0x205AA0))) /* Transmit Buffer Input Location 08 */


#define U3C1_TBUF09     (*(_PAGE_081_MEM_TYPE(0x205AA4))) /* Transmit Buffer Input Location 09 */


#define U3C1_TBUF10     (*(_PAGE_081_MEM_TYPE(0x205AA8))) /* Transmit Buffer Input Location 10 */


#define U3C1_TBUF11     (*(_PAGE_081_MEM_TYPE(0x205AAC))) /* Transmit Buffer Input Location 11 */


#define U3C1_TBUF12     (*(_PAGE_081_MEM_TYPE(0x205AB0))) /* Transmit Buffer Input Location 12 */


#define U3C1_TBUF13     (*(_PAGE_081_MEM_TYPE(0x205AB4))) /* Transmit Buffer Input Location 13 */


#define U3C1_TBUF14     (*(_PAGE_081_MEM_TYPE(0x205AB8))) /* Transmit Buffer Input Location 14 */


#define U3C1_TBUF15     (*(_PAGE_081_MEM_TYPE(0x205ABC))) /* Transmit Buffer Input Location 15 */


#define U3C1_TBUF16     (*(_PAGE_081_MEM_TYPE(0x205AC0))) /* Transmit Buffer Input Location 16 */


#define U3C1_TBUF17     (*(_PAGE_081_MEM_TYPE(0x205AC4))) /* Transmit Buffer Input Location 17 */


#define U3C1_TBUF18     (*(_PAGE_081_MEM_TYPE(0x205AC8))) /* Transmit Buffer Input Location 18 */


#define U3C1_TBUF19     (*(_PAGE_081_MEM_TYPE(0x205ACC))) /* Transmit Buffer Input Location 19 */


#define U3C1_TBUF20     (*(_PAGE_081_MEM_TYPE(0x205AD0))) /* Transmit Buffer Input Location 20 */


#define U3C1_TBUF21     (*(_PAGE_081_MEM_TYPE(0x205AD4))) /* Transmit Buffer Input Location 21 */


#define U3C1_TBUF22     (*(_PAGE_081_MEM_TYPE(0x205AD8))) /* Transmit Buffer Input Location 22 */


#define U3C1_TBUF23     (*(_PAGE_081_MEM_TYPE(0x205ADC))) /* Transmit Buffer Input Location 23 */


#define U3C1_TBUF24     (*(_PAGE_081_MEM_TYPE(0x205AE0))) /* Transmit Buffer Input Location 24 */


#define U3C1_TBUF25     (*(_PAGE_081_MEM_TYPE(0x205AE4))) /* Transmit Buffer Input Location 25 */


#define U3C1_TBUF26     (*(_PAGE_081_MEM_TYPE(0x205AE8))) /* Transmit Buffer Input Location 26 */


#define U3C1_TBUF27     (*(_PAGE_081_MEM_TYPE(0x205AEC))) /* Transmit Buffer Input Location 27 */


#define U3C1_TBUF28     (*(_PAGE_081_MEM_TYPE(0x205AF0))) /* Transmit Buffer Input Location 28 */


#define U3C1_TBUF29     (*(_PAGE_081_MEM_TYPE(0x205AF4))) /* Transmit Buffer Input Location 29 */


#define U3C1_TBUF30     (*(_PAGE_081_MEM_TYPE(0x205AF8))) /* Transmit Buffer Input Location 30 */


#define U3C1_TBUF31     (*(_PAGE_081_MEM_TYPE(0x205AFC))) /* Transmit Buffer Input Location 31 */


#define U3C1_RBUF0      (*(_PAGE_081_MEM_TYPE(0x205A50))) /* Receiver Buffer Register 0 */


#define U3C1_RBUF01SRL  (*(_PAGE_081_MEM_TYPE(0x205A60))) /* Receiver Buffer 01 Status Register L */


#define U3C1_RBUF1      (*(_PAGE_081_MEM_TYPE(0x205A54))) /* Receiver Buffer Register 1 */


#define U3C1_RBUF01SRH  (*(_PAGE_081_MEM_TYPE(0x205A62))) /* Receiver Buffer 01 Status Register H */


#define U3C1_RBUF       (*(_PAGE_081_MEM_TYPE(0x205A5C))) /* Receiver Buffer Register */


#define U3C1_RBUFD      (*(_PAGE_081_MEM_TYPE(0x205A4C))) /* Receiver Buffer Register for Debugger */


#define U3C1_RBUFSR     (*(_PAGE_081_MEM_TYPE(0x205A58))) /* Receiver Buffer Status Register */


#define U3C1_BYP        (*(_PAGE_081_MEM_TYPE(0x205B00))) /* Bypass Data Register */


#define U3C1_BYPCRL     (*(_PAGE_081_MEM_TYPE(0x205B04))) /* Bypass Control Register L */


#define U3C1_BYPCRH     (*(_PAGE_081_MEM_TYPE(0x205B06))) /* Bypass Control Register H */


#define U3C1_TRBSRL     (*(_PAGE_081_MEM_TYPE(0x205B18))) /* Transmit/Receive Buffer Status Register L */


#define U3C1_TRBSRH     (*(_PAGE_081_MEM_TYPE(0x205B1A))) /* Transmit/Receive Buffer Status Register H */


#define U3C1_TRBSCR     (*(_PAGE_081_MEM_TYPE(0x205B1C))) /* Transmit/Receive Buffer Status Clear Register */


#define U3C1_TBCTRL     (*(_PAGE_081_MEM_TYPE(0x205B10))) /* Transmitter Buffer Control Register L */


#define U3C1_TBCTRH     (*(_PAGE_081_MEM_TYPE(0x205B12))) /* Transmitter Buffer Control Register H */


#define U3C1_RBCTRL     (*(_PAGE_081_MEM_TYPE(0x205B14))) /* Receiver Buffer Control Register L */


#define U3C1_RBCTRH     (*(_PAGE_081_MEM_TYPE(0x205B16))) /* Receiver Buffer Control Register H */


#define U3C1_IN00       (*(_PAGE_081_MEM_TYPE(0x205B80))) /* Transmit FIFO Buffer Input Location 00 */


#define U3C1_IN01       (*(_PAGE_081_MEM_TYPE(0x205B84))) /* Transmit FIFO Buffer Input Location 01 */


#define U3C1_IN02       (*(_PAGE_081_MEM_TYPE(0x205B88))) /* Transmit FIFO Buffer Input Location 02 */


#define U3C1_IN03       (*(_PAGE_081_MEM_TYPE(0x205B8C))) /* Transmit FIFO Buffer Input Location 03 */


#define U3C1_IN04       (*(_PAGE_081_MEM_TYPE(0x205B90))) /* Transmit FIFO Buffer Input Location 04 */


#define U3C1_IN05       (*(_PAGE_081_MEM_TYPE(0x205B94))) /* Transmit FIFO Buffer Input Location 05 */


#define U3C1_IN06       (*(_PAGE_081_MEM_TYPE(0x205B98))) /* Transmit FIFO Buffer Input Location 06 */


#define U3C1_IN07       (*(_PAGE_081_MEM_TYPE(0x205B9C))) /* Transmit FIFO Buffer Input Location 07 */


#define U3C1_IN08       (*(_PAGE_081_MEM_TYPE(0x205BA0))) /* Transmit FIFO Buffer Input Location 08 */


#define U3C1_IN09       (*(_PAGE_081_MEM_TYPE(0x205BA4))) /* Transmit FIFO Buffer Input Location 09 */


#define U3C1_IN10       (*(_PAGE_081_MEM_TYPE(0x205BA8))) /* Transmit FIFO Buffer Input Location 10 */


#define U3C1_IN11       (*(_PAGE_081_MEM_TYPE(0x205BAC))) /* Transmit FIFO Buffer Input Location 11 */


#define U3C1_IN12       (*(_PAGE_081_MEM_TYPE(0x205BB0))) /* Transmit FIFO Buffer Input Location 12 */


#define U3C1_IN13       (*(_PAGE_081_MEM_TYPE(0x205BB4))) /* Transmit FIFO Buffer Input Location 13 */


#define U3C1_IN14       (*(_PAGE_081_MEM_TYPE(0x205BB8))) /* Transmit FIFO Buffer Input Location 14 */


#define U3C1_IN15       (*(_PAGE_081_MEM_TYPE(0x205BBC))) /* Transmit FIFO Buffer Input Location 15 */


#define U3C1_IN16       (*(_PAGE_081_MEM_TYPE(0x205BC0))) /* Transmit FIFO Buffer Input Location 16 */


#define U3C1_IN17       (*(_PAGE_081_MEM_TYPE(0x205BC4))) /* Transmit FIFO Buffer Input Location 17 */


#define U3C1_IN18       (*(_PAGE_081_MEM_TYPE(0x205BC8))) /* Transmit FIFO Buffer Input Location 18 */


#define U3C1_IN19       (*(_PAGE_081_MEM_TYPE(0x205BCC))) /* Transmit FIFO Buffer Input Location 19 */


#define U3C1_IN20       (*(_PAGE_081_MEM_TYPE(0x205BD0))) /* Transmit FIFO Buffer Input Location 20 */


#define U3C1_IN21       (*(_PAGE_081_MEM_TYPE(0x205BD4))) /* Transmit FIFO Buffer Input Location 21 */


#define U3C1_IN22       (*(_PAGE_081_MEM_TYPE(0x205BD8))) /* Transmit FIFO Buffer Input Location 22 */


#define U3C1_IN23       (*(_PAGE_081_MEM_TYPE(0x205BDC))) /* Transmit FIFO Buffer Input Location 23 */


#define U3C1_IN24       (*(_PAGE_081_MEM_TYPE(0x205BE0))) /* Transmit FIFO Buffer Input Location 24 */


#define U3C1_IN25       (*(_PAGE_081_MEM_TYPE(0x205BE4))) /* Transmit FIFO Buffer Input Location 25 */


#define U3C1_IN26       (*(_PAGE_081_MEM_TYPE(0x205BE8))) /* Transmit FIFO Buffer Input Location 26 */


#define U3C1_IN27       (*(_PAGE_081_MEM_TYPE(0x205BEC))) /* Transmit FIFO Buffer Input Location 27 */


#define U3C1_IN28       (*(_PAGE_081_MEM_TYPE(0x205BF0))) /* Transmit FIFO Buffer Input Location 28 */


#define U3C1_IN29       (*(_PAGE_081_MEM_TYPE(0x205BF4))) /* Transmit FIFO Buffer Input Location 29 */


#define U3C1_IN30       (*(_PAGE_081_MEM_TYPE(0x205BF8))) /* Transmit FIFO Buffer Input Location 30 */


#define U3C1_IN31       (*(_PAGE_081_MEM_TYPE(0x205BFC))) /* Transmit FIFO Buffer Input Location 31 */


#define U3C1_OUTRL      (*(_PAGE_081_MEM_TYPE(0x205B20))) /* Receiver Buffer Output Register L */


#define U3C1_OUTRH      (*(_PAGE_081_MEM_TYPE(0x205B22))) /* Receiver Buffer Output Register H */


#define U3C1_OUTDRL     (*(_PAGE_081_MEM_TYPE(0x205B24))) /* Receiver Buffer Output Register L for Debugger */


#define U3C1_OUTDRH     (*(_PAGE_081_MEM_TYPE(0x205B26))) /* Receiver Buffer Output Register H for Debugger */


#define U3C1_TRBPTRL    (*(_PAGE_081_MEM_TYPE(0x205B08))) /* Transmit/Receive Buffer Pointer Register L */


#define U3C1_TRBPTRH    (*(_PAGE_081_MEM_TYPE(0x205B0A))) /* Transmit/Receive Buffer Pointer Register H */

#endif /* REGXC2361E_NOUSIC3 */

/********************************************************************************
 * USIC
********************************************************************************/
#ifndef REGXC2361E_NOUSIC


#define U4C0_CCR        (*(_PAGE_081_MEM_TYPE(0x206010))) /* Channel Control Register */


#define U4C0_CCFG       (*(_PAGE_081_MEM_TYPE(0x206018))) /* Channel Configuration Register */


#define U4C0_KSCFG      (*(_PAGE_081_MEM_TYPE(0x20600C))) /* Kernel State Configuration Register */


#define U4C0_INPRL      (*(_PAGE_081_MEM_TYPE(0x206014))) /* Interrupt Node Pointer Register L */


#define U4C0_INPRH      (*(_PAGE_081_MEM_TYPE(0x206016))) /* Interrupt Node Pointer Register H */


#define U4C0_PCRL       (*(_PAGE_081_MEM_TYPE(0x206040))) /* Protocol Control Register L */


#define U4C0_PCRH       (*(_PAGE_081_MEM_TYPE(0x206042))) /* Protocol Control Register H */


#define U4C0_PSR        (*(_PAGE_081_MEM_TYPE(0x206044))) /* Protocol Status Register */


#define U4C0_PSCR       (*(_PAGE_081_MEM_TYPE(0x206048))) /* Protocol Status Clear Register */


#define U4C0_DX0CR      (*(_PAGE_081_MEM_TYPE(0x206020))) /* Input Control Register 0 */


#define U4C0_DX1CR      (*(_PAGE_081_MEM_TYPE(0x206024))) /* Input Control Register 1 */


#define U4C0_DX2CR      (*(_PAGE_081_MEM_TYPE(0x206028))) /* Input Control Register 2 */


#define U4C0_FDRL       (*(_PAGE_081_MEM_TYPE(0x206004))) /* Fractional Divider Register L */


#define U4C0_FDRH       (*(_PAGE_081_MEM_TYPE(0x206006))) /* Fractional Divider Register H */


#define U4C0_BRGL       (*(_PAGE_081_MEM_TYPE(0x20601C))) /* Baud Rate Generator Register L */


#define U4C0_BRGH       (*(_PAGE_081_MEM_TYPE(0x20601E))) /* Baud Rate Generator Register H */


#define U4C0_SCTRL      (*(_PAGE_081_MEM_TYPE(0x206030))) /* Shift Control Register L */


#define U4C0_SCTRH      (*(_PAGE_081_MEM_TYPE(0x206032))) /* Shift Control Register H */


#define U4C0_TCSRL      (*(_PAGE_081_MEM_TYPE(0x20603C))) /* Transmit Control/Status Register L */


#define U4C0_TCSRH      (*(_PAGE_081_MEM_TYPE(0x20603E))) /* Transmit Control/Status Register H */


#define U4C0_FMRL       (*(_PAGE_081_MEM_TYPE(0x206038))) /* Flag Modification Register L */


#define U4C0_FMRH       (*(_PAGE_081_MEM_TYPE(0x20603A))) /* Flag Modification Register H */


#define U4C0_TBUF00     (*(_PAGE_081_MEM_TYPE(0x206080))) /* Transmit Buffer Input Location 00 */


#define U4C0_TBUF01     (*(_PAGE_081_MEM_TYPE(0x206084))) /* Transmit Buffer Input Location 01 */


#define U4C0_TBUF02     (*(_PAGE_081_MEM_TYPE(0x206088))) /* Transmit Buffer Input Location 02 */


#define U4C0_TBUF03     (*(_PAGE_081_MEM_TYPE(0x20608C))) /* Transmit Buffer Input Location 03 */


#define U4C0_TBUF04     (*(_PAGE_081_MEM_TYPE(0x206090))) /* Transmit Buffer Input Location 04 */


#define U4C0_TBUF05     (*(_PAGE_081_MEM_TYPE(0x206094))) /* Transmit Buffer Input Location 05 */


#define U4C0_TBUF06     (*(_PAGE_081_MEM_TYPE(0x206098))) /* Transmit Buffer Input Location 06 */


#define U4C0_TBUF07     (*(_PAGE_081_MEM_TYPE(0x20609C))) /* Transmit Buffer Input Location 07 */


#define U4C0_TBUF08     (*(_PAGE_081_MEM_TYPE(0x2060A0))) /* Transmit Buffer Input Location 08 */


#define U4C0_TBUF09     (*(_PAGE_081_MEM_TYPE(0x2060A4))) /* Transmit Buffer Input Location 09 */


#define U4C0_TBUF10     (*(_PAGE_081_MEM_TYPE(0x2060A8))) /* Transmit Buffer Input Location 10 */


#define U4C0_TBUF11     (*(_PAGE_081_MEM_TYPE(0x2060AC))) /* Transmit Buffer Input Location 11 */


#define U4C0_TBUF12     (*(_PAGE_081_MEM_TYPE(0x2060B0))) /* Transmit Buffer Input Location 12 */


#define U4C0_TBUF13     (*(_PAGE_081_MEM_TYPE(0x2060B4))) /* Transmit Buffer Input Location 13 */


#define U4C0_TBUF14     (*(_PAGE_081_MEM_TYPE(0x2060B8))) /* Transmit Buffer Input Location 14 */


#define U4C0_TBUF15     (*(_PAGE_081_MEM_TYPE(0x2060BC))) /* Transmit Buffer Input Location 15 */


#define U4C0_TBUF16     (*(_PAGE_081_MEM_TYPE(0x2060C0))) /* Transmit Buffer Input Location 16 */


#define U4C0_TBUF17     (*(_PAGE_081_MEM_TYPE(0x2060C4))) /* Transmit Buffer Input Location 17 */


#define U4C0_TBUF18     (*(_PAGE_081_MEM_TYPE(0x2060C8))) /* Transmit Buffer Input Location 18 */


#define U4C0_TBUF19     (*(_PAGE_081_MEM_TYPE(0x2060CC))) /* Transmit Buffer Input Location 19 */


#define U4C0_TBUF20     (*(_PAGE_081_MEM_TYPE(0x2060D0))) /* Transmit Buffer Input Location 20 */


#define U4C0_TBUF21     (*(_PAGE_081_MEM_TYPE(0x2060D4))) /* Transmit Buffer Input Location 21 */


#define U4C0_TBUF22     (*(_PAGE_081_MEM_TYPE(0x2060D8))) /* Transmit Buffer Input Location 22 */


#define U4C0_TBUF23     (*(_PAGE_081_MEM_TYPE(0x2060DC))) /* Transmit Buffer Input Location 23 */


#define U4C0_TBUF24     (*(_PAGE_081_MEM_TYPE(0x2060E0))) /* Transmit Buffer Input Location 24 */


#define U4C0_TBUF25     (*(_PAGE_081_MEM_TYPE(0x2060E4))) /* Transmit Buffer Input Location 25 */


#define U4C0_TBUF26     (*(_PAGE_081_MEM_TYPE(0x2060E8))) /* Transmit Buffer Input Location 26 */


#define U4C0_TBUF27     (*(_PAGE_081_MEM_TYPE(0x2060EC))) /* Transmit Buffer Input Location 27 */


#define U4C0_TBUF28     (*(_PAGE_081_MEM_TYPE(0x2060F0))) /* Transmit Buffer Input Location 28 */


#define U4C0_TBUF29     (*(_PAGE_081_MEM_TYPE(0x2060F4))) /* Transmit Buffer Input Location 29 */


#define U4C0_TBUF30     (*(_PAGE_081_MEM_TYPE(0x2060F8))) /* Transmit Buffer Input Location 30 */


#define U4C0_TBUF31     (*(_PAGE_081_MEM_TYPE(0x2060FC))) /* Transmit Buffer Input Location 31 */


#define U4C0_RBUF0      (*(_PAGE_081_MEM_TYPE(0x206050))) /* Receiver Buffer Register 0 */


#define U4C0_RBUF01SRL  (*(_PAGE_081_MEM_TYPE(0x206060))) /* Receiver Buffer 01 Status Register L */


#define U4C0_RBUF1      (*(_PAGE_081_MEM_TYPE(0x206054))) /* Receiver Buffer Register 1 */


#define U4C0_RBUF01SRH  (*(_PAGE_081_MEM_TYPE(0x206062))) /* Receiver Buffer 01 Status Register H */


#define U4C0_RBUF       (*(_PAGE_081_MEM_TYPE(0x20605C))) /* Receiver Buffer Register */


#define U4C0_RBUFD      (*(_PAGE_081_MEM_TYPE(0x20604C))) /* Receiver Buffer Register for Debugger */


#define U4C0_RBUFSR     (*(_PAGE_081_MEM_TYPE(0x206058))) /* Receiver Buffer Status Register */


#define U4C0_BYP        (*(_PAGE_081_MEM_TYPE(0x206100))) /* Bypass Data Register */


#define U4C0_BYPCRL     (*(_PAGE_081_MEM_TYPE(0x206104))) /* Bypass Control Register L */


#define U4C0_BYPCRH     (*(_PAGE_081_MEM_TYPE(0x206106))) /* Bypass Control Register H */


#define U4C0_TRBSRL     (*(_PAGE_081_MEM_TYPE(0x206118))) /* Transmit/Receive Buffer Status Register L */


#define U4C0_TRBSRH     (*(_PAGE_081_MEM_TYPE(0x20611A))) /* Transmit/Receive Buffer Status Register H */


#define U4C0_TRBSCR     (*(_PAGE_081_MEM_TYPE(0x20611C))) /* Transmit/Receive Buffer Status Clear Register */


#define U4C0_TBCTRL     (*(_PAGE_081_MEM_TYPE(0x206110))) /* Transmitter Buffer Control Register L */


#define U4C0_TBCTRH     (*(_PAGE_081_MEM_TYPE(0x206112))) /* Transmitter Buffer Control Register H */


#define U4C0_RBCTRL     (*(_PAGE_081_MEM_TYPE(0x206114))) /* Receiver Buffer Control Register L */


#define U4C0_RBCTRH     (*(_PAGE_081_MEM_TYPE(0x206116))) /* Receiver Buffer Control Register H */


#define U4C0_IN00       (*(_PAGE_081_MEM_TYPE(0x206180))) /* Transmit FIFO Buffer Input Location 00 */


#define U4C0_IN01       (*(_PAGE_081_MEM_TYPE(0x206184))) /* Transmit FIFO Buffer Input Location 01 */


#define U4C0_IN02       (*(_PAGE_081_MEM_TYPE(0x206188))) /* Transmit FIFO Buffer Input Location 02 */


#define U4C0_IN03       (*(_PAGE_081_MEM_TYPE(0x20618C))) /* Transmit FIFO Buffer Input Location 03 */


#define U4C0_IN04       (*(_PAGE_081_MEM_TYPE(0x206190))) /* Transmit FIFO Buffer Input Location 04 */


#define U4C0_IN05       (*(_PAGE_081_MEM_TYPE(0x206194))) /* Transmit FIFO Buffer Input Location 05 */


#define U4C0_IN06       (*(_PAGE_081_MEM_TYPE(0x206198))) /* Transmit FIFO Buffer Input Location 06 */


#define U4C0_IN07       (*(_PAGE_081_MEM_TYPE(0x20619C))) /* Transmit FIFO Buffer Input Location 07 */


#define U4C0_IN08       (*(_PAGE_081_MEM_TYPE(0x2061A0))) /* Transmit FIFO Buffer Input Location 08 */


#define U4C0_IN09       (*(_PAGE_081_MEM_TYPE(0x2061A4))) /* Transmit FIFO Buffer Input Location 09 */


#define U4C0_IN10       (*(_PAGE_081_MEM_TYPE(0x2061A8))) /* Transmit FIFO Buffer Input Location 10 */


#define U4C0_IN11       (*(_PAGE_081_MEM_TYPE(0x2061AC))) /* Transmit FIFO Buffer Input Location 11 */


#define U4C0_IN12       (*(_PAGE_081_MEM_TYPE(0x2061B0))) /* Transmit FIFO Buffer Input Location 12 */


#define U4C0_IN13       (*(_PAGE_081_MEM_TYPE(0x2061B4))) /* Transmit FIFO Buffer Input Location 13 */


#define U4C0_IN14       (*(_PAGE_081_MEM_TYPE(0x2061B8))) /* Transmit FIFO Buffer Input Location 14 */


#define U4C0_IN15       (*(_PAGE_081_MEM_TYPE(0x2061BC))) /* Transmit FIFO Buffer Input Location 15 */


#define U4C0_IN16       (*(_PAGE_081_MEM_TYPE(0x2061C0))) /* Transmit FIFO Buffer Input Location 16 */


#define U4C0_IN17       (*(_PAGE_081_MEM_TYPE(0x2061C4))) /* Transmit FIFO Buffer Input Location 17 */


#define U4C0_IN18       (*(_PAGE_081_MEM_TYPE(0x2061C8))) /* Transmit FIFO Buffer Input Location 18 */


#define U4C0_IN19       (*(_PAGE_081_MEM_TYPE(0x2061CC))) /* Transmit FIFO Buffer Input Location 19 */


#define U4C0_IN20       (*(_PAGE_081_MEM_TYPE(0x2061D0))) /* Transmit FIFO Buffer Input Location 20 */


#define U4C0_IN21       (*(_PAGE_081_MEM_TYPE(0x2061D4))) /* Transmit FIFO Buffer Input Location 21 */


#define U4C0_IN22       (*(_PAGE_081_MEM_TYPE(0x2061D8))) /* Transmit FIFO Buffer Input Location 22 */


#define U4C0_IN23       (*(_PAGE_081_MEM_TYPE(0x2061DC))) /* Transmit FIFO Buffer Input Location 23 */


#define U4C0_IN24       (*(_PAGE_081_MEM_TYPE(0x2061E0))) /* Transmit FIFO Buffer Input Location 24 */


#define U4C0_IN25       (*(_PAGE_081_MEM_TYPE(0x2061E4))) /* Transmit FIFO Buffer Input Location 25 */


#define U4C0_IN26       (*(_PAGE_081_MEM_TYPE(0x2061E8))) /* Transmit FIFO Buffer Input Location 26 */


#define U4C0_IN27       (*(_PAGE_081_MEM_TYPE(0x2061EC))) /* Transmit FIFO Buffer Input Location 27 */


#define U4C0_IN28       (*(_PAGE_081_MEM_TYPE(0x2061F0))) /* Transmit FIFO Buffer Input Location 28 */


#define U4C0_IN29       (*(_PAGE_081_MEM_TYPE(0x2061F4))) /* Transmit FIFO Buffer Input Location 29 */


#define U4C0_IN30       (*(_PAGE_081_MEM_TYPE(0x2061F8))) /* Transmit FIFO Buffer Input Location 30 */


#define U4C0_IN31       (*(_PAGE_081_MEM_TYPE(0x2061FC))) /* Transmit FIFO Buffer Input Location 31 */


#define U4C0_OUTRL      (*(_PAGE_081_MEM_TYPE(0x206120))) /* Receiver Buffer Output Register L */


#define U4C0_OUTRH      (*(_PAGE_081_MEM_TYPE(0x206122))) /* Receiver Buffer Output Register H */


#define U4C0_OUTDRL     (*(_PAGE_081_MEM_TYPE(0x206124))) /* Receiver Buffer Output Register L for Debugger */


#define U4C0_OUTDRH     (*(_PAGE_081_MEM_TYPE(0x206126))) /* Receiver Buffer Output Register H for Debugger */


#define U4C0_TRBPTRL    (*(_PAGE_081_MEM_TYPE(0x206108))) /* Transmit/Receive Buffer Pointer Register L */


#define U4C0_TRBPTRH    (*(_PAGE_081_MEM_TYPE(0x20610A))) /* Transmit/Receive Buffer Pointer Register H */


#define U4C1_CCR        (*(_PAGE_081_MEM_TYPE(0x206210))) /* Channel Control Register */


#define U4C1_CCFG       (*(_PAGE_081_MEM_TYPE(0x206218))) /* Channel Configuration Register */


#define U4C1_KSCFG      (*(_PAGE_081_MEM_TYPE(0x20620C))) /* Kernel State Configuration Register */


#define U4C1_INPRL      (*(_PAGE_081_MEM_TYPE(0x206214))) /* Interrupt Node Pointer Register L */


#define U4C1_INPRH      (*(_PAGE_081_MEM_TYPE(0x206216))) /* Interrupt Node Pointer Register H */


#define U4C1_PCRL       (*(_PAGE_081_MEM_TYPE(0x206240))) /* Protocol Control Register L */


#define U4C1_PCRH       (*(_PAGE_081_MEM_TYPE(0x206242))) /* Protocol Control Register H */


#define U4C1_PSR        (*(_PAGE_081_MEM_TYPE(0x206244))) /* Protocol Status Register */


#define U4C1_PSCR       (*(_PAGE_081_MEM_TYPE(0x206248))) /* Protocol Status Clear Register */


#define U4C1_DX0CR      (*(_PAGE_081_MEM_TYPE(0x206220))) /* Input Control Register 0 */


#define U4C1_DX1CR      (*(_PAGE_081_MEM_TYPE(0x206224))) /* Input Control Register 1 */


#define U4C1_DX2CR      (*(_PAGE_081_MEM_TYPE(0x206228))) /* Input Control Register 2 */


#define U4C1_FDRL       (*(_PAGE_081_MEM_TYPE(0x206204))) /* Fractional Divider Register L */


#define U4C1_FDRH       (*(_PAGE_081_MEM_TYPE(0x206206))) /* Fractional Divider Register H */


#define U4C1_BRGL       (*(_PAGE_081_MEM_TYPE(0x20621C))) /* Baud Rate Generator Register L */


#define U4C1_BRGH       (*(_PAGE_081_MEM_TYPE(0x20621E))) /* Baud Rate Generator Register H */


#define U4C1_SCTRL      (*(_PAGE_081_MEM_TYPE(0x206230))) /* Shift Control Register L */


#define U4C1_SCTRH      (*(_PAGE_081_MEM_TYPE(0x206232))) /* Shift Control Register H */


#define U4C1_TCSRL      (*(_PAGE_081_MEM_TYPE(0x20623C))) /* Transmit Control/Status Register L */


#define U4C1_TCSRH      (*(_PAGE_081_MEM_TYPE(0x20623E))) /* Transmit Control/Status Register H */


#define U4C1_FMRL       (*(_PAGE_081_MEM_TYPE(0x206238))) /* Flag Modification Register L */


#define U4C1_FMRH       (*(_PAGE_081_MEM_TYPE(0x20623A))) /* Flag Modification Register H */


#define U4C1_TBUF00     (*(_PAGE_081_MEM_TYPE(0x206280))) /* Transmit Buffer Input Location 00 */


#define U4C1_TBUF01     (*(_PAGE_081_MEM_TYPE(0x206284))) /* Transmit Buffer Input Location 01 */


#define U4C1_TBUF02     (*(_PAGE_081_MEM_TYPE(0x206288))) /* Transmit Buffer Input Location 02 */


#define U4C1_TBUF03     (*(_PAGE_081_MEM_TYPE(0x20628C))) /* Transmit Buffer Input Location 03 */


#define U4C1_TBUF04     (*(_PAGE_081_MEM_TYPE(0x206290))) /* Transmit Buffer Input Location 04 */


#define U4C1_TBUF05     (*(_PAGE_081_MEM_TYPE(0x206294))) /* Transmit Buffer Input Location 05 */


#define U4C1_TBUF06     (*(_PAGE_081_MEM_TYPE(0x206298))) /* Transmit Buffer Input Location 06 */


#define U4C1_TBUF07     (*(_PAGE_081_MEM_TYPE(0x20629C))) /* Transmit Buffer Input Location 07 */


#define U4C1_TBUF08     (*(_PAGE_081_MEM_TYPE(0x2062A0))) /* Transmit Buffer Input Location 08 */


#define U4C1_TBUF09     (*(_PAGE_081_MEM_TYPE(0x2062A4))) /* Transmit Buffer Input Location 09 */


#define U4C1_TBUF10     (*(_PAGE_081_MEM_TYPE(0x2062A8))) /* Transmit Buffer Input Location 10 */


#define U4C1_TBUF11     (*(_PAGE_081_MEM_TYPE(0x2062AC))) /* Transmit Buffer Input Location 11 */


#define U4C1_TBUF12     (*(_PAGE_081_MEM_TYPE(0x2062B0))) /* Transmit Buffer Input Location 12 */


#define U4C1_TBUF13     (*(_PAGE_081_MEM_TYPE(0x2062B4))) /* Transmit Buffer Input Location 13 */


#define U4C1_TBUF14     (*(_PAGE_081_MEM_TYPE(0x2062B8))) /* Transmit Buffer Input Location 14 */


#define U4C1_TBUF15     (*(_PAGE_081_MEM_TYPE(0x2062BC))) /* Transmit Buffer Input Location 15 */


#define U4C1_TBUF16     (*(_PAGE_081_MEM_TYPE(0x2062C0))) /* Transmit Buffer Input Location 16 */


#define U4C1_TBUF17     (*(_PAGE_081_MEM_TYPE(0x2062C4))) /* Transmit Buffer Input Location 17 */


#define U4C1_TBUF18     (*(_PAGE_081_MEM_TYPE(0x2062C8))) /* Transmit Buffer Input Location 18 */


#define U4C1_TBUF19     (*(_PAGE_081_MEM_TYPE(0x2062CC))) /* Transmit Buffer Input Location 19 */


#define U4C1_TBUF20     (*(_PAGE_081_MEM_TYPE(0x2062D0))) /* Transmit Buffer Input Location 20 */


#define U4C1_TBUF21     (*(_PAGE_081_MEM_TYPE(0x2062D4))) /* Transmit Buffer Input Location 21 */


#define U4C1_TBUF22     (*(_PAGE_081_MEM_TYPE(0x2062D8))) /* Transmit Buffer Input Location 22 */


#define U4C1_TBUF23     (*(_PAGE_081_MEM_TYPE(0x2062DC))) /* Transmit Buffer Input Location 23 */


#define U4C1_TBUF24     (*(_PAGE_081_MEM_TYPE(0x2062E0))) /* Transmit Buffer Input Location 24 */


#define U4C1_TBUF25     (*(_PAGE_081_MEM_TYPE(0x2062E4))) /* Transmit Buffer Input Location 25 */


#define U4C1_TBUF26     (*(_PAGE_081_MEM_TYPE(0x2062E8))) /* Transmit Buffer Input Location 26 */


#define U4C1_TBUF27     (*(_PAGE_081_MEM_TYPE(0x2062EC))) /* Transmit Buffer Input Location 27 */


#define U4C1_TBUF28     (*(_PAGE_081_MEM_TYPE(0x2062F0))) /* Transmit Buffer Input Location 28 */


#define U4C1_TBUF29     (*(_PAGE_081_MEM_TYPE(0x2062F4))) /* Transmit Buffer Input Location 29 */


#define U4C1_TBUF30     (*(_PAGE_081_MEM_TYPE(0x2062F8))) /* Transmit Buffer Input Location 30 */


#define U4C1_TBUF31     (*(_PAGE_081_MEM_TYPE(0x2062FC))) /* Transmit Buffer Input Location 31 */


#define U4C1_RBUF0      (*(_PAGE_081_MEM_TYPE(0x206250))) /* Receiver Buffer Register 0 */


#define U4C1_RBUF01SRL  (*(_PAGE_081_MEM_TYPE(0x206260))) /* Receiver Buffer 01 Status Register L */


#define U4C1_RBUF1      (*(_PAGE_081_MEM_TYPE(0x206254))) /* Receiver Buffer Register 1 */


#define U4C1_RBUF01SRH  (*(_PAGE_081_MEM_TYPE(0x206262))) /* Receiver Buffer 01 Status Register H */


#define U4C1_RBUF       (*(_PAGE_081_MEM_TYPE(0x20625C))) /* Receiver Buffer Register */


#define U4C1_RBUFD      (*(_PAGE_081_MEM_TYPE(0x20624C))) /* Receiver Buffer Register for Debugger */


#define U4C1_RBUFSR     (*(_PAGE_081_MEM_TYPE(0x206258))) /* Receiver Buffer Status Register */


#define U4C1_BYP        (*(_PAGE_081_MEM_TYPE(0x206300))) /* Bypass Data Register */


#define U4C1_BYPCRL     (*(_PAGE_081_MEM_TYPE(0x206304))) /* Bypass Control Register L */


#define U4C1_BYPCRH     (*(_PAGE_081_MEM_TYPE(0x206306))) /* Bypass Control Register H */


#define U4C1_TRBSRL     (*(_PAGE_081_MEM_TYPE(0x206318))) /* Transmit/Receive Buffer Status Register L */


#define U4C1_TRBSRH     (*(_PAGE_081_MEM_TYPE(0x20631A))) /* Transmit/Receive Buffer Status Register H */


#define U4C1_TRBSCR     (*(_PAGE_081_MEM_TYPE(0x20631C))) /* Transmit/Receive Buffer Status Clear Register */


#define U4C1_TBCTRL     (*(_PAGE_081_MEM_TYPE(0x206310))) /* Transmitter Buffer Control Register L */


#define U4C1_TBCTRH     (*(_PAGE_081_MEM_TYPE(0x206312))) /* Transmitter Buffer Control Register H */


#define U4C1_RBCTRL     (*(_PAGE_081_MEM_TYPE(0x206314))) /* Receiver Buffer Control Register L */


#define U4C1_RBCTRH     (*(_PAGE_081_MEM_TYPE(0x206316))) /* Receiver Buffer Control Register H */


#define U4C1_IN00       (*(_PAGE_081_MEM_TYPE(0x206380))) /* Transmit FIFO Buffer Input Location 00 */


#define U4C1_IN01       (*(_PAGE_081_MEM_TYPE(0x206384))) /* Transmit FIFO Buffer Input Location 01 */


#define U4C1_IN02       (*(_PAGE_081_MEM_TYPE(0x206388))) /* Transmit FIFO Buffer Input Location 02 */


#define U4C1_IN03       (*(_PAGE_081_MEM_TYPE(0x20638C))) /* Transmit FIFO Buffer Input Location 03 */


#define U4C1_IN04       (*(_PAGE_081_MEM_TYPE(0x206390))) /* Transmit FIFO Buffer Input Location 04 */


#define U4C1_IN05       (*(_PAGE_081_MEM_TYPE(0x206394))) /* Transmit FIFO Buffer Input Location 05 */


#define U4C1_IN06       (*(_PAGE_081_MEM_TYPE(0x206398))) /* Transmit FIFO Buffer Input Location 06 */


#define U4C1_IN07       (*(_PAGE_081_MEM_TYPE(0x20639C))) /* Transmit FIFO Buffer Input Location 07 */


#define U4C1_IN08       (*(_PAGE_081_MEM_TYPE(0x2063A0))) /* Transmit FIFO Buffer Input Location 08 */


#define U4C1_IN09       (*(_PAGE_081_MEM_TYPE(0x2063A4))) /* Transmit FIFO Buffer Input Location 09 */


#define U4C1_IN10       (*(_PAGE_081_MEM_TYPE(0x2063A8))) /* Transmit FIFO Buffer Input Location 10 */


#define U4C1_IN11       (*(_PAGE_081_MEM_TYPE(0x2063AC))) /* Transmit FIFO Buffer Input Location 11 */


#define U4C1_IN12       (*(_PAGE_081_MEM_TYPE(0x2063B0))) /* Transmit FIFO Buffer Input Location 12 */


#define U4C1_IN13       (*(_PAGE_081_MEM_TYPE(0x2063B4))) /* Transmit FIFO Buffer Input Location 13 */


#define U4C1_IN14       (*(_PAGE_081_MEM_TYPE(0x2063B8))) /* Transmit FIFO Buffer Input Location 14 */


#define U4C1_IN15       (*(_PAGE_081_MEM_TYPE(0x2063BC))) /* Transmit FIFO Buffer Input Location 15 */


#define U4C1_IN16       (*(_PAGE_081_MEM_TYPE(0x2063C0))) /* Transmit FIFO Buffer Input Location 16 */


#define U4C1_IN17       (*(_PAGE_081_MEM_TYPE(0x2063C4))) /* Transmit FIFO Buffer Input Location 17 */


#define U4C1_IN18       (*(_PAGE_081_MEM_TYPE(0x2063C8))) /* Transmit FIFO Buffer Input Location 18 */


#define U4C1_IN19       (*(_PAGE_081_MEM_TYPE(0x2063CC))) /* Transmit FIFO Buffer Input Location 19 */


#define U4C1_IN20       (*(_PAGE_081_MEM_TYPE(0x2063D0))) /* Transmit FIFO Buffer Input Location 20 */


#define U4C1_IN21       (*(_PAGE_081_MEM_TYPE(0x2063D4))) /* Transmit FIFO Buffer Input Location 21 */


#define U4C1_IN22       (*(_PAGE_081_MEM_TYPE(0x2063D8))) /* Transmit FIFO Buffer Input Location 22 */


#define U4C1_IN23       (*(_PAGE_081_MEM_TYPE(0x2063DC))) /* Transmit FIFO Buffer Input Location 23 */


#define U4C1_IN24       (*(_PAGE_081_MEM_TYPE(0x2063E0))) /* Transmit FIFO Buffer Input Location 24 */


#define U4C1_IN25       (*(_PAGE_081_MEM_TYPE(0x2063E4))) /* Transmit FIFO Buffer Input Location 25 */


#define U4C1_IN26       (*(_PAGE_081_MEM_TYPE(0x2063E8))) /* Transmit FIFO Buffer Input Location 26 */


#define U4C1_IN27       (*(_PAGE_081_MEM_TYPE(0x2063EC))) /* Transmit FIFO Buffer Input Location 27 */


#define U4C1_IN28       (*(_PAGE_081_MEM_TYPE(0x2063F0))) /* Transmit FIFO Buffer Input Location 28 */


#define U4C1_IN29       (*(_PAGE_081_MEM_TYPE(0x2063F4))) /* Transmit FIFO Buffer Input Location 29 */


#define U4C1_IN30       (*(_PAGE_081_MEM_TYPE(0x2063F8))) /* Transmit FIFO Buffer Input Location 30 */


#define U4C1_IN31       (*(_PAGE_081_MEM_TYPE(0x2063FC))) /* Transmit FIFO Buffer Input Location 31 */


#define U4C1_OUTRL      (*(_PAGE_081_MEM_TYPE(0x206320))) /* Receiver Buffer Output Register L */


#define U4C1_OUTRH      (*(_PAGE_081_MEM_TYPE(0x206322))) /* Receiver Buffer Output Register H */


#define U4C1_OUTDRL     (*(_PAGE_081_MEM_TYPE(0x206324))) /* Receiver Buffer Output Register L for Debugger */


#define U4C1_OUTDRH     (*(_PAGE_081_MEM_TYPE(0x206326))) /* Receiver Buffer Output Register H for Debugger */


#define U4C1_TRBPTRL    (*(_PAGE_081_MEM_TYPE(0x206308))) /* Transmit/Receive Buffer Pointer Register L */


#define U4C1_TRBPTRH    (*(_PAGE_081_MEM_TYPE(0x20630A))) /* Transmit/Receive Buffer Pointer Register H */


#define USIC0_IDL       (*(_PAGE_081_MEM_TYPE(0x204008))) /* Module Identification Register L */


#define USIC1_IDL       (*(_PAGE_081_MEM_TYPE(0x204808))) /* Module Identification Register L */


#define USIC2_IDL       (*(_PAGE_081_MEM_TYPE(0x205008))) /* Module Identification Register L */


#define USIC3_IDL       (*(_PAGE_081_MEM_TYPE(0x205808))) /* Module Identification Register L */


#define USIC4_IDL       (*(_PAGE_081_MEM_TYPE(0x206008))) /* Module Identification Register L */


#define USIC0_IDH       (*(_PAGE_081_MEM_TYPE(0x20400A))) /* Module Identification Register H */


#define USIC1_IDH       (*(_PAGE_081_MEM_TYPE(0x20480A))) /* Module Identification Register H */


#define USIC2_IDH       (*(_PAGE_081_MEM_TYPE(0x20500A))) /* Module Identification Register H */


#define USIC3_IDH       (*(_PAGE_081_MEM_TYPE(0x20580A))) /* Module Identification Register H */


#define USIC4_IDH       (*(_PAGE_081_MEM_TYPE(0x20600A))) /* Module Identification Register H */

#endif /* REGXC2361E_NOUSIC */

/********************************************************************************
 * MULTICAN
********************************************************************************/
#ifndef REGXC2361E_NOMULTICAN


#define CAN_ID          (*(_PAGE_080_MEM_TYPE(0x200008))) /* Module Identification Register */


#define CAN_PANCTRH     (*(_PAGE_080_MEM_TYPE(0x2001C6))) /* Panel Control Register */


#define CAN_PANCTRL     (*(_PAGE_080_MEM_TYPE(0x2001C4))) /* Panel Control Register */


#define CAN_MCR         (*(_PAGE_080_MEM_TYPE(0x2001C8))) /* Module Control Register */


#define CAN_MITR        (*(_PAGE_080_MEM_TYPE(0x2001CC))) /* Module Interrupt Trigger Register */


#define CAN_LIST0H      (*(_PAGE_080_MEM_TYPE(0x200102))) /* List Register 0 High */


#define CAN_LIST1H      (*(_PAGE_080_MEM_TYPE(0x200106))) /* List Register 1 High */


#define CAN_LIST2H      (*(_PAGE_080_MEM_TYPE(0x20010A))) /* List Register 2 High */


#define CAN_LIST3H      (*(_PAGE_080_MEM_TYPE(0x20010E))) /* List Register 3 High */


#define CAN_LIST4H      (*(_PAGE_080_MEM_TYPE(0x200112))) /* List Register 4 High */


#define CAN_LIST5H      (*(_PAGE_080_MEM_TYPE(0x200116))) /* List Register 5 High */


#define CAN_LIST6H      (*(_PAGE_080_MEM_TYPE(0x20011A))) /* List Register 6 High */


#define CAN_LIST7H      (*(_PAGE_080_MEM_TYPE(0x20011E))) /* List Register 7 High */


#define CAN_LIST0L      (*(_PAGE_080_MEM_TYPE(0x200100))) /* List Register 0 Low */


#define CAN_LIST1L      (*(_PAGE_080_MEM_TYPE(0x200104))) /* List Register 1 Low */


#define CAN_LIST2L      (*(_PAGE_080_MEM_TYPE(0x200108))) /* List Register 2 Low */


#define CAN_LIST3L      (*(_PAGE_080_MEM_TYPE(0x20010C))) /* List Register 3 Low */


#define CAN_LIST4L      (*(_PAGE_080_MEM_TYPE(0x200110))) /* List Register 4 Low */


#define CAN_LIST5L      (*(_PAGE_080_MEM_TYPE(0x200114))) /* List Register 5 Low */


#define CAN_LIST6L      (*(_PAGE_080_MEM_TYPE(0x200118))) /* List Register 6 Low */


#define CAN_LIST7L      (*(_PAGE_080_MEM_TYPE(0x20011C))) /* List Register 7 Low */


#define CAN_MSPND0H     (*(_PAGE_080_MEM_TYPE(0x200142))) /* Message Pending Register 0 High */


#define CAN_MSPND1H     (*(_PAGE_080_MEM_TYPE(0x200146))) /* Message Pending Register 1 High */


#define CAN_MSPND2H     (*(_PAGE_080_MEM_TYPE(0x20014A))) /* Message Pending Register 2 High */


#define CAN_MSPND3H     (*(_PAGE_080_MEM_TYPE(0x20014E))) /* Message Pending Register 3 High */


#define CAN_MSPND4H     (*(_PAGE_080_MEM_TYPE(0x200152))) /* Message Pending Register 4 High */


#define CAN_MSPND5H     (*(_PAGE_080_MEM_TYPE(0x200156))) /* Message Pending Register 5 High */


#define CAN_MSPND6H     (*(_PAGE_080_MEM_TYPE(0x20015A))) /* Message Pending Register 6 High */


#define CAN_MSPND7H     (*(_PAGE_080_MEM_TYPE(0x20015E))) /* Message Pending Register 7 High */


#define CAN_MSPND0L     (*(_PAGE_080_MEM_TYPE(0x200140))) /* Message Pending Register 0 Low */


#define CAN_MSPND1L     (*(_PAGE_080_MEM_TYPE(0x200144))) /* Message Pending Register 1 Low */


#define CAN_MSPND2L     (*(_PAGE_080_MEM_TYPE(0x200148))) /* Message Pending Register 2 Low */


#define CAN_MSPND3L     (*(_PAGE_080_MEM_TYPE(0x20014C))) /* Message Pending Register 3 Low */


#define CAN_MSPND4L     (*(_PAGE_080_MEM_TYPE(0x200150))) /* Message Pending Register 4 Low */


#define CAN_MSPND5L     (*(_PAGE_080_MEM_TYPE(0x200154))) /* Message Pending Register 5 Low */


#define CAN_MSPND6L     (*(_PAGE_080_MEM_TYPE(0x200158))) /* Message Pending Register 6 Low */


#define CAN_MSPND7L     (*(_PAGE_080_MEM_TYPE(0x20015C))) /* Message Pending Register 7 Low */


#define CAN_MSID0       (*(_PAGE_080_MEM_TYPE(0x200180))) /* Message Index Register 0 */


#define CAN_MSID1       (*(_PAGE_080_MEM_TYPE(0x200184))) /* Message Index Register 1 */


#define CAN_MSID2       (*(_PAGE_080_MEM_TYPE(0x200188))) /* Message Index Register 2 */


#define CAN_MSID3       (*(_PAGE_080_MEM_TYPE(0x20018C))) /* Message Index Register 3 */


#define CAN_MSID4       (*(_PAGE_080_MEM_TYPE(0x200190))) /* Message Index Register 4 */


#define CAN_MSID5       (*(_PAGE_080_MEM_TYPE(0x200194))) /* Message Index Register 5 */


#define CAN_MSID6       (*(_PAGE_080_MEM_TYPE(0x200198))) /* Message Index Register 6 */


#define CAN_MSID7       (*(_PAGE_080_MEM_TYPE(0x20019C))) /* Message Index Register 7 */


#define CAN_MSIMASKH    (*(_PAGE_080_MEM_TYPE(0x2001C2))) /* Message Index Mask Register High */


#define CAN_MSIMASKL    (*(_PAGE_080_MEM_TYPE(0x2001C0))) /* Message Index Mask Register Low */


#define CAN_NCR0        (*(_PAGE_080_MEM_TYPE(0x200200))) /* Node 0 Control Register */


#define CAN_NCR1        (*(_PAGE_080_MEM_TYPE(0x200300))) /* Node 1 Control Register */


#define CAN_NCR2        (*(_PAGE_080_MEM_TYPE(0x200400))) /* Node 2 Control Register */


#define CAN_NCR3        (*(_PAGE_080_MEM_TYPE(0x200500))) /* Node 3 Control Register */


#define CAN_NCR4        (*(_PAGE_080_MEM_TYPE(0x200600))) /* Node 4 Control Register */


#define CAN_NCR5        (*(_PAGE_080_MEM_TYPE(0x200700))) /* Node 5 Control Register */


#define CAN_NSR0        (*(_PAGE_080_MEM_TYPE(0x200204))) /* Node 0 Status Register */


#define CAN_NSR1        (*(_PAGE_080_MEM_TYPE(0x200304))) /* Node 1 Status Register */


#define CAN_NSR2        (*(_PAGE_080_MEM_TYPE(0x200404))) /* Node 2 Status Register */


#define CAN_NSR3        (*(_PAGE_080_MEM_TYPE(0x200504))) /* Node 3 Status Register */


#define CAN_NSR4        (*(_PAGE_080_MEM_TYPE(0x200604))) /* Node 4 Status Register */


#define CAN_NSR5        (*(_PAGE_080_MEM_TYPE(0x200704))) /* Node 5 Status Register */


#define CAN_NIPR0       (*(_PAGE_080_MEM_TYPE(0x200208))) /* Node 0 Interrupt Pointer Register */


#define CAN_NIPR1       (*(_PAGE_080_MEM_TYPE(0x200308))) /* Node 1 Interrupt Pointer Register */


#define CAN_NIPR2       (*(_PAGE_080_MEM_TYPE(0x200408))) /* Node 2 Interrupt Pointer Register */


#define CAN_NIPR3       (*(_PAGE_080_MEM_TYPE(0x200508))) /* Node 3 Interrupt Pointer Register */


#define CAN_NIPR4       (*(_PAGE_080_MEM_TYPE(0x200608))) /* Node 4 Interrupt Pointer Register */


#define CAN_NIPR5       (*(_PAGE_080_MEM_TYPE(0x200708))) /* Node 5 Interrupt Pointer Register */


#define CAN_NPCR0       (*(_PAGE_080_MEM_TYPE(0x20020C))) /* Node 0 Port Control Register */


#define CAN_NPCR1       (*(_PAGE_080_MEM_TYPE(0x20030C))) /* Node 1 Port Control Register */


#define CAN_NPCR2       (*(_PAGE_080_MEM_TYPE(0x20040C))) /* Node 2 Port Control Register */


#define CAN_NPCR3       (*(_PAGE_080_MEM_TYPE(0x20050C))) /* Node 3 Port Control Register */


#define CAN_NPCR4       (*(_PAGE_080_MEM_TYPE(0x20060C))) /* Node 4 Port Control Register */


#define CAN_NPCR5       (*(_PAGE_080_MEM_TYPE(0x20070C))) /* Node 5 Port Control Register */


#define CAN_NBTR0H      (*(_PAGE_080_MEM_TYPE(0x200212))) /* Node 0 Bit Timing Register High */


#define CAN_NBTR1H      (*(_PAGE_080_MEM_TYPE(0x200312))) /* Node 1 Bit Timing Register High */


#define CAN_NBTR2H      (*(_PAGE_080_MEM_TYPE(0x200412))) /* Node 2 Bit Timing Register High */


#define CAN_NBTR3H      (*(_PAGE_080_MEM_TYPE(0x200512))) /* Node 3 Bit Timing Register High */


#define CAN_NBTR4H      (*(_PAGE_080_MEM_TYPE(0x200612))) /* Node 4 Bit Timing Register High */


#define CAN_NBTR5H      (*(_PAGE_080_MEM_TYPE(0x200712))) /* Node 5 Bit Timing Register High */


#define CAN_NBTR0L      (*(_PAGE_080_MEM_TYPE(0x200210))) /* Node 0 Bit Timing Register Low */


#define CAN_NBTR1L      (*(_PAGE_080_MEM_TYPE(0x200310))) /* Node 1 Bit Timing Register Low */


#define CAN_NBTR2L      (*(_PAGE_080_MEM_TYPE(0x200410))) /* Node 2 Bit Timing Register Low */


#define CAN_NBTR3L      (*(_PAGE_080_MEM_TYPE(0x200510))) /* Node 3 Bit Timing Register Low */


#define CAN_NBTR4L      (*(_PAGE_080_MEM_TYPE(0x200610))) /* Node 4 Bit Timing Register Low */


#define CAN_NBTR5L      (*(_PAGE_080_MEM_TYPE(0x200710))) /* Node 5 Bit Timing Register Low */


#define CAN_NECNT0H     (*(_PAGE_080_MEM_TYPE(0x200216))) /* Node 0 Error Counter Register High */


#define CAN_NECNT1H     (*(_PAGE_080_MEM_TYPE(0x200316))) /* Node 1 Error Counter Register High */


#define CAN_NECNT2H     (*(_PAGE_080_MEM_TYPE(0x200416))) /* Node 2 Error Counter Register High */


#define CAN_NECNT3H     (*(_PAGE_080_MEM_TYPE(0x200516))) /* Node 3 Error Counter Register High */


#define CAN_NECNT4H     (*(_PAGE_080_MEM_TYPE(0x200616))) /* Node 4 Error Counter Register High */


#define CAN_NECNT5H     (*(_PAGE_080_MEM_TYPE(0x200716))) /* Node 5 Error Counter Register High */


#define CAN_NECNT0L     (*(_PAGE_080_MEM_TYPE(0x200214))) /* Node 0 Error Counter Register Low */


#define CAN_NECNT1L     (*(_PAGE_080_MEM_TYPE(0x200314))) /* Node 1 Error Counter Register Low */


#define CAN_NECNT2L     (*(_PAGE_080_MEM_TYPE(0x200414))) /* Node 2 Error Counter Register Low */


#define CAN_NECNT3L     (*(_PAGE_080_MEM_TYPE(0x200514))) /* Node 3 Error Counter Register Low */


#define CAN_NECNT4L     (*(_PAGE_080_MEM_TYPE(0x200614))) /* Node 4 Error Counter Register Low */


#define CAN_NECNT5L     (*(_PAGE_080_MEM_TYPE(0x200714))) /* Node 5 Error Counter Register Low */


#define CAN_NFCR0H      (*(_PAGE_080_MEM_TYPE(0x20021A))) /* Node 0 Frame Counter Register High */


#define CAN_NFCR1H      (*(_PAGE_080_MEM_TYPE(0x20031A))) /* Node 1 Frame Counter Register High */


#define CAN_NFCR2H      (*(_PAGE_080_MEM_TYPE(0x20041A))) /* Node 2 Frame Counter Register High */


#define CAN_NFCR3H      (*(_PAGE_080_MEM_TYPE(0x20051A))) /* Node 3 Frame Counter Register High */


#define CAN_NFCR4H      (*(_PAGE_080_MEM_TYPE(0x20061A))) /* Node 4 Frame Counter Register High */


#define CAN_NFCR5H      (*(_PAGE_080_MEM_TYPE(0x20071A))) /* Node 5 Frame Counter Register High */


#define CAN_NFCR0L      (*(_PAGE_080_MEM_TYPE(0x200218))) /* Node 0 Frame Counter Register Low */


#define CAN_NFCR1L      (*(_PAGE_080_MEM_TYPE(0x200318))) /* Node 1 Frame Counter Register Low */


#define CAN_NFCR2L      (*(_PAGE_080_MEM_TYPE(0x200418))) /* Node 2 Frame Counter Register Low */


#define CAN_NFCR3L      (*(_PAGE_080_MEM_TYPE(0x200518))) /* Node 3 Frame Counter Register Low */


#define CAN_NFCR4L      (*(_PAGE_080_MEM_TYPE(0x200618))) /* Node 4 Frame Counter Register Low */


#define CAN_NFCR5L      (*(_PAGE_080_MEM_TYPE(0x200718))) /* Node 5 Frame Counter Register Low */


#define CAN_MOCTR0H     (*(_PAGE_080_MEM_TYPE(0x20101E))) /* Message Object 0 Control Register High */


#define CAN_MOCTR255H   (*(_PAGE_080_MEM_TYPE(0x202FFE))) /* Message Object 255 Control Register High */


#define CAN_MOCTR1H     (*(_PAGE_080_MEM_TYPE(0x20103E))) /* Message Object 1 Control Register High */


#define CAN_MOCTR2H     (*(_PAGE_080_MEM_TYPE(0x20105E))) /* Message Object 2 Control Register High */


#define CAN_MOCTR3H     (*(_PAGE_080_MEM_TYPE(0x20107E))) /* Message Object 3 Control Register High */


#define CAN_MOCTR4H     (*(_PAGE_080_MEM_TYPE(0x20109E))) /* Message Object 4 Control Register High */


#define CAN_MOCTR5H     (*(_PAGE_080_MEM_TYPE(0x2010BE))) /* Message Object 5 Control Register High */


#define CAN_MOCTR6H     (*(_PAGE_080_MEM_TYPE(0x2010DE))) /* Message Object 6 Control Register High */


#define CAN_MOCTR7H     (*(_PAGE_080_MEM_TYPE(0x2010FE))) /* Message Object 7 Control Register High */


#define CAN_MOCTR8H     (*(_PAGE_080_MEM_TYPE(0x20111E))) /* Message Object 8 Control Register High */


#define CAN_MOCTR9H     (*(_PAGE_080_MEM_TYPE(0x20113E))) /* Message Object 9 Control Register High */


#define CAN_MOCTR10H    (*(_PAGE_080_MEM_TYPE(0x20115E))) /* Message Object 10 Control Register High */


#define CAN_MOCTR11H    (*(_PAGE_080_MEM_TYPE(0x20117E))) /* Message Object 11 Control Register High */


#define CAN_MOCTR12H    (*(_PAGE_080_MEM_TYPE(0x20119E))) /* Message Object 12 Control Register High */


#define CAN_MOCTR13H    (*(_PAGE_080_MEM_TYPE(0x2011BE))) /* Message Object 13 Control Register High */


#define CAN_MOCTR14H    (*(_PAGE_080_MEM_TYPE(0x2011DE))) /* Message Object 14 Control Register High */


#define CAN_MOCTR15H    (*(_PAGE_080_MEM_TYPE(0x2011FE))) /* Message Object 15 Control Register High */


#define CAN_MOCTR16H    (*(_PAGE_080_MEM_TYPE(0x20121E))) /* Message Object 16 Control Register High */


#define CAN_MOCTR17H    (*(_PAGE_080_MEM_TYPE(0x20123E))) /* Message Object 17 Control Register High */


#define CAN_MOCTR18H    (*(_PAGE_080_MEM_TYPE(0x20125E))) /* Message Object 18 Control Register High */


#define CAN_MOCTR19H    (*(_PAGE_080_MEM_TYPE(0x20127E))) /* Message Object 19 Control Register High */


#define CAN_MOCTR20H    (*(_PAGE_080_MEM_TYPE(0x20129E))) /* Message Object 20 Control Register High */


#define CAN_MOCTR21H    (*(_PAGE_080_MEM_TYPE(0x2012BE))) /* Message Object 21 Control Register High */


#define CAN_MOCTR22H    (*(_PAGE_080_MEM_TYPE(0x2012DE))) /* Message Object 22 Control Register High */


#define CAN_MOCTR23H    (*(_PAGE_080_MEM_TYPE(0x2012FE))) /* Message Object 23 Control Register High */


#define CAN_MOCTR24H    (*(_PAGE_080_MEM_TYPE(0x20131E))) /* Message Object 24 Control Register High */


#define CAN_MOCTR25H    (*(_PAGE_080_MEM_TYPE(0x20133E))) /* Message Object 25 Control Register High */


#define CAN_MOCTR26H    (*(_PAGE_080_MEM_TYPE(0x20135E))) /* Message Object 26 Control Register High */


#define CAN_MOCTR27H    (*(_PAGE_080_MEM_TYPE(0x20137E))) /* Message Object 27 Control Register High */


#define CAN_MOCTR28H    (*(_PAGE_080_MEM_TYPE(0x20139E))) /* Message Object 28 Control Register High */


#define CAN_MOCTR29H    (*(_PAGE_080_MEM_TYPE(0x2013BE))) /* Message Object 29 Control Register High */


#define CAN_MOCTR30H    (*(_PAGE_080_MEM_TYPE(0x2013DE))) /* Message Object 30 Control Register High */


#define CAN_MOCTR31H    (*(_PAGE_080_MEM_TYPE(0x2013FE))) /* Message Object 31 Control Register High */


#define CAN_MOCTR32H    (*(_PAGE_080_MEM_TYPE(0x20141E))) /* Message Object 32 Control Register High */


#define CAN_MOCTR33H    (*(_PAGE_080_MEM_TYPE(0x20143E))) /* Message Object 33 Control Register High */


#define CAN_MOCTR34H    (*(_PAGE_080_MEM_TYPE(0x20145E))) /* Message Object 34 Control Register High */


#define CAN_MOCTR35H    (*(_PAGE_080_MEM_TYPE(0x20147E))) /* Message Object 35 Control Register High */


#define CAN_MOCTR36H    (*(_PAGE_080_MEM_TYPE(0x20149E))) /* Message Object 36 Control Register High */


#define CAN_MOCTR37H    (*(_PAGE_080_MEM_TYPE(0x2014BE))) /* Message Object 37 Control Register High */


#define CAN_MOCTR38H    (*(_PAGE_080_MEM_TYPE(0x2014DE))) /* Message Object 38 Control Register High */


#define CAN_MOCTR39H    (*(_PAGE_080_MEM_TYPE(0x2014FE))) /* Message Object 39 Control Register High */


#define CAN_MOCTR40H    (*(_PAGE_080_MEM_TYPE(0x20151E))) /* Message Object 40 Control Register High */


#define CAN_MOCTR41H    (*(_PAGE_080_MEM_TYPE(0x20153E))) /* Message Object 41 Control Register High */


#define CAN_MOCTR42H    (*(_PAGE_080_MEM_TYPE(0x20155E))) /* Message Object 42 Control Register High */


#define CAN_MOCTR43H    (*(_PAGE_080_MEM_TYPE(0x20157E))) /* Message Object 43 Control Register High */


#define CAN_MOCTR44H    (*(_PAGE_080_MEM_TYPE(0x20159E))) /* Message Object 44 Control Register High */


#define CAN_MOCTR45H    (*(_PAGE_080_MEM_TYPE(0x2015BE))) /* Message Object 45 Control Register High */


#define CAN_MOCTR46H    (*(_PAGE_080_MEM_TYPE(0x2015DE))) /* Message Object 46 Control Register High */


#define CAN_MOCTR47H    (*(_PAGE_080_MEM_TYPE(0x2015FE))) /* Message Object 47 Control Register High */


#define CAN_MOCTR48H    (*(_PAGE_080_MEM_TYPE(0x20161E))) /* Message Object 48 Control Register High */


#define CAN_MOCTR49H    (*(_PAGE_080_MEM_TYPE(0x20163E))) /* Message Object 49 Control Register High */


#define CAN_MOCTR50H    (*(_PAGE_080_MEM_TYPE(0x20165E))) /* Message Object 50 Control Register High */


#define CAN_MOCTR51H    (*(_PAGE_080_MEM_TYPE(0x20167E))) /* Message Object 51 Control Register High */


#define CAN_MOCTR52H    (*(_PAGE_080_MEM_TYPE(0x20169E))) /* Message Object 52 Control Register High */


#define CAN_MOCTR53H    (*(_PAGE_080_MEM_TYPE(0x2016BE))) /* Message Object 53 Control Register High */


#define CAN_MOCTR54H    (*(_PAGE_080_MEM_TYPE(0x2016DE))) /* Message Object 54 Control Register High */


#define CAN_MOCTR55H    (*(_PAGE_080_MEM_TYPE(0x2016FE))) /* Message Object 55 Control Register High */


#define CAN_MOCTR56H    (*(_PAGE_080_MEM_TYPE(0x20171E))) /* Message Object 56 Control Register High */


#define CAN_MOCTR57H    (*(_PAGE_080_MEM_TYPE(0x20173E))) /* Message Object 57 Control Register High */


#define CAN_MOCTR58H    (*(_PAGE_080_MEM_TYPE(0x20175E))) /* Message Object 58 Control Register High */


#define CAN_MOCTR59H    (*(_PAGE_080_MEM_TYPE(0x20177E))) /* Message Object 59 Control Register High */


#define CAN_MOCTR60H    (*(_PAGE_080_MEM_TYPE(0x20179E))) /* Message Object 60 Control Register High */


#define CAN_MOCTR61H    (*(_PAGE_080_MEM_TYPE(0x2017BE))) /* Message Object 61 Control Register High */


#define CAN_MOCTR62H    (*(_PAGE_080_MEM_TYPE(0x2017DE))) /* Message Object 62 Control Register High */


#define CAN_MOCTR63H    (*(_PAGE_080_MEM_TYPE(0x2017FE))) /* Message Object 63 Control Register High */


#define CAN_MOCTR64H    (*(_PAGE_080_MEM_TYPE(0x20181E))) /* Message Object 64 Control Register High */


#define CAN_MOCTR65H    (*(_PAGE_080_MEM_TYPE(0x20183E))) /* Message Object 65 Control Register High */


#define CAN_MOCTR66H    (*(_PAGE_080_MEM_TYPE(0x20185E))) /* Message Object 66 Control Register High */


#define CAN_MOCTR67H    (*(_PAGE_080_MEM_TYPE(0x20187E))) /* Message Object 67 Control Register High */


#define CAN_MOCTR68H    (*(_PAGE_080_MEM_TYPE(0x20189E))) /* Message Object 68 Control Register High */


#define CAN_MOCTR69H    (*(_PAGE_080_MEM_TYPE(0x2018BE))) /* Message Object 69 Control Register High */


#define CAN_MOCTR70H    (*(_PAGE_080_MEM_TYPE(0x2018DE))) /* Message Object 70 Control Register High */


#define CAN_MOCTR71H    (*(_PAGE_080_MEM_TYPE(0x2018FE))) /* Message Object 71 Control Register High */


#define CAN_MOCTR72H    (*(_PAGE_080_MEM_TYPE(0x20191E))) /* Message Object 72 Control Register High */


#define CAN_MOCTR73H    (*(_PAGE_080_MEM_TYPE(0x20193E))) /* Message Object 73 Control Register High */


#define CAN_MOCTR74H    (*(_PAGE_080_MEM_TYPE(0x20195E))) /* Message Object 74 Control Register High */


#define CAN_MOCTR75H    (*(_PAGE_080_MEM_TYPE(0x20197E))) /* Message Object 75 Control Register High */


#define CAN_MOCTR76H    (*(_PAGE_080_MEM_TYPE(0x20199E))) /* Message Object 76 Control Register High */


#define CAN_MOCTR77H    (*(_PAGE_080_MEM_TYPE(0x2019BE))) /* Message Object 77 Control Register High */


#define CAN_MOCTR78H    (*(_PAGE_080_MEM_TYPE(0x2019DE))) /* Message Object 78 Control Register High */


#define CAN_MOCTR79H    (*(_PAGE_080_MEM_TYPE(0x2019FE))) /* Message Object 79 Control Register High */


#define CAN_MOCTR80H    (*(_PAGE_080_MEM_TYPE(0x201A1E))) /* Message Object 80 Control Register High */


#define CAN_MOCTR81H    (*(_PAGE_080_MEM_TYPE(0x201A3E))) /* Message Object 81 Control Register High */


#define CAN_MOCTR82H    (*(_PAGE_080_MEM_TYPE(0x201A5E))) /* Message Object 82 Control Register High */


#define CAN_MOCTR83H    (*(_PAGE_080_MEM_TYPE(0x201A7E))) /* Message Object 83 Control Register High */


#define CAN_MOCTR84H    (*(_PAGE_080_MEM_TYPE(0x201A9E))) /* Message Object 84 Control Register High */


#define CAN_MOCTR85H    (*(_PAGE_080_MEM_TYPE(0x201ABE))) /* Message Object 85 Control Register High */


#define CAN_MOCTR86H    (*(_PAGE_080_MEM_TYPE(0x201ADE))) /* Message Object 86 Control Register High */


#define CAN_MOCTR87H    (*(_PAGE_080_MEM_TYPE(0x201AFE))) /* Message Object 87 Control Register High */


#define CAN_MOCTR88H    (*(_PAGE_080_MEM_TYPE(0x201B1E))) /* Message Object 88 Control Register High */


#define CAN_MOCTR89H    (*(_PAGE_080_MEM_TYPE(0x201B3E))) /* Message Object 89 Control Register High */


#define CAN_MOCTR90H    (*(_PAGE_080_MEM_TYPE(0x201B5E))) /* Message Object 90 Control Register High */


#define CAN_MOCTR91H    (*(_PAGE_080_MEM_TYPE(0x201B7E))) /* Message Object 91 Control Register High */


#define CAN_MOCTR92H    (*(_PAGE_080_MEM_TYPE(0x201B9E))) /* Message Object 92 Control Register High */


#define CAN_MOCTR93H    (*(_PAGE_080_MEM_TYPE(0x201BBE))) /* Message Object 93 Control Register High */


#define CAN_MOCTR94H    (*(_PAGE_080_MEM_TYPE(0x201BDE))) /* Message Object 94 Control Register High */


#define CAN_MOCTR95H    (*(_PAGE_080_MEM_TYPE(0x201BFE))) /* Message Object 95 Control Register High */


#define CAN_MOCTR96H    (*(_PAGE_080_MEM_TYPE(0x201C1E))) /* Message Object 96 Control Register High */


#define CAN_MOCTR97H    (*(_PAGE_080_MEM_TYPE(0x201C3E))) /* Message Object 97 Control Register High */


#define CAN_MOCTR98H    (*(_PAGE_080_MEM_TYPE(0x201C5E))) /* Message Object 98 Control Register High */


#define CAN_MOCTR99H    (*(_PAGE_080_MEM_TYPE(0x201C7E))) /* Message Object 99 Control Register High */


#define CAN_MOCTR100H   (*(_PAGE_080_MEM_TYPE(0x201C9E))) /* Message Object 100 Control Register High */


#define CAN_MOCTR101H   (*(_PAGE_080_MEM_TYPE(0x201CBE))) /* Message Object 101 Control Register High */


#define CAN_MOCTR102H   (*(_PAGE_080_MEM_TYPE(0x201CDE))) /* Message Object 102 Control Register High */


#define CAN_MOCTR103H   (*(_PAGE_080_MEM_TYPE(0x201CFE))) /* Message Object 103 Control Register High */


#define CAN_MOCTR104H   (*(_PAGE_080_MEM_TYPE(0x201D1E))) /* Message Object 104 Control Register High */


#define CAN_MOCTR105H   (*(_PAGE_080_MEM_TYPE(0x201D3E))) /* Message Object 105 Control Register High */


#define CAN_MOCTR106H   (*(_PAGE_080_MEM_TYPE(0x201D5E))) /* Message Object 106 Control Register High */


#define CAN_MOCTR107H   (*(_PAGE_080_MEM_TYPE(0x201D7E))) /* Message Object 107 Control Register High */


#define CAN_MOCTR108H   (*(_PAGE_080_MEM_TYPE(0x201D9E))) /* Message Object 108 Control Register High */


#define CAN_MOCTR109H   (*(_PAGE_080_MEM_TYPE(0x201DBE))) /* Message Object 109 Control Register High */


#define CAN_MOCTR110H   (*(_PAGE_080_MEM_TYPE(0x201DDE))) /* Message Object 110 Control Register High */


#define CAN_MOCTR111H   (*(_PAGE_080_MEM_TYPE(0x201DFE))) /* Message Object 111 Control Register High */


#define CAN_MOCTR112H   (*(_PAGE_080_MEM_TYPE(0x201E1E))) /* Message Object 112 Control Register High */


#define CAN_MOCTR113H   (*(_PAGE_080_MEM_TYPE(0x201E3E))) /* Message Object 113 Control Register High */


#define CAN_MOCTR114H   (*(_PAGE_080_MEM_TYPE(0x201E5E))) /* Message Object 114 Control Register High */


#define CAN_MOCTR115H   (*(_PAGE_080_MEM_TYPE(0x201E7E))) /* Message Object 115 Control Register High */


#define CAN_MOCTR116H   (*(_PAGE_080_MEM_TYPE(0x201E9E))) /* Message Object 116 Control Register High */


#define CAN_MOCTR117H   (*(_PAGE_080_MEM_TYPE(0x201EBE))) /* Message Object 117 Control Register High */


#define CAN_MOCTR118H   (*(_PAGE_080_MEM_TYPE(0x201EDE))) /* Message Object 118 Control Register High */


#define CAN_MOCTR119H   (*(_PAGE_080_MEM_TYPE(0x201EFE))) /* Message Object 119 Control Register High */


#define CAN_MOCTR120H   (*(_PAGE_080_MEM_TYPE(0x201F1E))) /* Message Object 120 Control Register High */


#define CAN_MOCTR121H   (*(_PAGE_080_MEM_TYPE(0x201F3E))) /* Message Object 121 Control Register High */


#define CAN_MOCTR122H   (*(_PAGE_080_MEM_TYPE(0x201F5E))) /* Message Object 122 Control Register High */


#define CAN_MOCTR123H   (*(_PAGE_080_MEM_TYPE(0x201F7E))) /* Message Object 123 Control Register High */


#define CAN_MOCTR124H   (*(_PAGE_080_MEM_TYPE(0x201F9E))) /* Message Object 124 Control Register High */


#define CAN_MOCTR125H   (*(_PAGE_080_MEM_TYPE(0x201FBE))) /* Message Object 125 Control Register High */


#define CAN_MOCTR126H   (*(_PAGE_080_MEM_TYPE(0x201FDE))) /* Message Object 126 Control Register High */


#define CAN_MOCTR127H   (*(_PAGE_080_MEM_TYPE(0x201FFE))) /* Message Object 127 Control Register High */


#define CAN_MOCTR128H   (*(_PAGE_080_MEM_TYPE(0x20201E))) /* Message Object 128 Control Register High */


#define CAN_MOCTR129H   (*(_PAGE_080_MEM_TYPE(0x20203E))) /* Message Object 129 Control Register High */


#define CAN_MOCTR130H   (*(_PAGE_080_MEM_TYPE(0x20205E))) /* Message Object 130 Control Register High */


#define CAN_MOCTR131H   (*(_PAGE_080_MEM_TYPE(0x20207E))) /* Message Object 131 Control Register High */


#define CAN_MOCTR132H   (*(_PAGE_080_MEM_TYPE(0x20209E))) /* Message Object 132 Control Register High */


#define CAN_MOCTR133H   (*(_PAGE_080_MEM_TYPE(0x2020BE))) /* Message Object 133 Control Register High */


#define CAN_MOCTR134H   (*(_PAGE_080_MEM_TYPE(0x2020DE))) /* Message Object 134 Control Register High */


#define CAN_MOCTR135H   (*(_PAGE_080_MEM_TYPE(0x2020FE))) /* Message Object 135 Control Register High */


#define CAN_MOCTR136H   (*(_PAGE_080_MEM_TYPE(0x20211E))) /* Message Object 136 Control Register High */


#define CAN_MOCTR137H   (*(_PAGE_080_MEM_TYPE(0x20213E))) /* Message Object 137 Control Register High */


#define CAN_MOCTR138H   (*(_PAGE_080_MEM_TYPE(0x20215E))) /* Message Object 138 Control Register High */


#define CAN_MOCTR139H   (*(_PAGE_080_MEM_TYPE(0x20217E))) /* Message Object 139 Control Register High */


#define CAN_MOCTR140H   (*(_PAGE_080_MEM_TYPE(0x20219E))) /* Message Object 140 Control Register High */


#define CAN_MOCTR141H   (*(_PAGE_080_MEM_TYPE(0x2021BE))) /* Message Object 141 Control Register High */


#define CAN_MOCTR142H   (*(_PAGE_080_MEM_TYPE(0x2021DE))) /* Message Object 142 Control Register High */


#define CAN_MOCTR143H   (*(_PAGE_080_MEM_TYPE(0x2021FE))) /* Message Object 143 Control Register High */


#define CAN_MOCTR144H   (*(_PAGE_080_MEM_TYPE(0x20221E))) /* Message Object 144 Control Register High */


#define CAN_MOCTR145H   (*(_PAGE_080_MEM_TYPE(0x20223E))) /* Message Object 145 Control Register High */


#define CAN_MOCTR146H   (*(_PAGE_080_MEM_TYPE(0x20225E))) /* Message Object 146 Control Register High */


#define CAN_MOCTR147H   (*(_PAGE_080_MEM_TYPE(0x20227E))) /* Message Object 147 Control Register High */


#define CAN_MOCTR148H   (*(_PAGE_080_MEM_TYPE(0x20229E))) /* Message Object 148 Control Register High */


#define CAN_MOCTR149H   (*(_PAGE_080_MEM_TYPE(0x2022BE))) /* Message Object 149 Control Register High */


#define CAN_MOCTR150H   (*(_PAGE_080_MEM_TYPE(0x2022DE))) /* Message Object 150 Control Register High */


#define CAN_MOCTR151H   (*(_PAGE_080_MEM_TYPE(0x2022FE))) /* Message Object 151 Control Register High */


#define CAN_MOCTR152H   (*(_PAGE_080_MEM_TYPE(0x20231E))) /* Message Object 152 Control Register High */


#define CAN_MOCTR153H   (*(_PAGE_080_MEM_TYPE(0x20233E))) /* Message Object 153 Control Register High */


#define CAN_MOCTR154H   (*(_PAGE_080_MEM_TYPE(0x20235E))) /* Message Object 154 Control Register High */


#define CAN_MOCTR155H   (*(_PAGE_080_MEM_TYPE(0x20237E))) /* Message Object 155 Control Register High */


#define CAN_MOCTR156H   (*(_PAGE_080_MEM_TYPE(0x20239E))) /* Message Object 156 Control Register High */


#define CAN_MOCTR157H   (*(_PAGE_080_MEM_TYPE(0x2023BE))) /* Message Object 157 Control Register High */


#define CAN_MOCTR158H   (*(_PAGE_080_MEM_TYPE(0x2023DE))) /* Message Object 158 Control Register High */


#define CAN_MOCTR159H   (*(_PAGE_080_MEM_TYPE(0x2023FE))) /* Message Object 159 Control Register High */


#define CAN_MOCTR160H   (*(_PAGE_080_MEM_TYPE(0x20241E))) /* Message Object 160 Control Register High */


#define CAN_MOCTR161H   (*(_PAGE_080_MEM_TYPE(0x20243E))) /* Message Object 161 Control Register High */


#define CAN_MOCTR162H   (*(_PAGE_080_MEM_TYPE(0x20245E))) /* Message Object 162 Control Register High */


#define CAN_MOCTR163H   (*(_PAGE_080_MEM_TYPE(0x20247E))) /* Message Object 163 Control Register High */


#define CAN_MOCTR164H   (*(_PAGE_080_MEM_TYPE(0x20249E))) /* Message Object 164 Control Register High */


#define CAN_MOCTR165H   (*(_PAGE_080_MEM_TYPE(0x2024BE))) /* Message Object 165 Control Register High */


#define CAN_MOCTR166H   (*(_PAGE_080_MEM_TYPE(0x2024DE))) /* Message Object 166 Control Register High */


#define CAN_MOCTR167H   (*(_PAGE_080_MEM_TYPE(0x2024FE))) /* Message Object 167 Control Register High */


#define CAN_MOCTR168H   (*(_PAGE_080_MEM_TYPE(0x20251E))) /* Message Object 168 Control Register High */


#define CAN_MOCTR169H   (*(_PAGE_080_MEM_TYPE(0x20253E))) /* Message Object 169 Control Register High */


#define CAN_MOCTR170H   (*(_PAGE_080_MEM_TYPE(0x20255E))) /* Message Object 170 Control Register High */


#define CAN_MOCTR171H   (*(_PAGE_080_MEM_TYPE(0x20257E))) /* Message Object 171 Control Register High */


#define CAN_MOCTR172H   (*(_PAGE_080_MEM_TYPE(0x20259E))) /* Message Object 172 Control Register High */


#define CAN_MOCTR173H   (*(_PAGE_080_MEM_TYPE(0x2025BE))) /* Message Object 173 Control Register High */


#define CAN_MOCTR174H   (*(_PAGE_080_MEM_TYPE(0x2025DE))) /* Message Object 174 Control Register High */


#define CAN_MOCTR175H   (*(_PAGE_080_MEM_TYPE(0x2025FE))) /* Message Object 175 Control Register High */


#define CAN_MOCTR176H   (*(_PAGE_080_MEM_TYPE(0x20261E))) /* Message Object 176 Control Register High */


#define CAN_MOCTR177H   (*(_PAGE_080_MEM_TYPE(0x20263E))) /* Message Object 177 Control Register High */


#define CAN_MOCTR178H   (*(_PAGE_080_MEM_TYPE(0x20265E))) /* Message Object 178 Control Register High */


#define CAN_MOCTR179H   (*(_PAGE_080_MEM_TYPE(0x20267E))) /* Message Object 179 Control Register High */


#define CAN_MOCTR180H   (*(_PAGE_080_MEM_TYPE(0x20269E))) /* Message Object 180 Control Register High */


#define CAN_MOCTR181H   (*(_PAGE_080_MEM_TYPE(0x2026BE))) /* Message Object 181 Control Register High */


#define CAN_MOCTR182H   (*(_PAGE_080_MEM_TYPE(0x2026DE))) /* Message Object 182 Control Register High */


#define CAN_MOCTR183H   (*(_PAGE_080_MEM_TYPE(0x2026FE))) /* Message Object 183 Control Register High */


#define CAN_MOCTR184H   (*(_PAGE_080_MEM_TYPE(0x20271E))) /* Message Object 184 Control Register High */


#define CAN_MOCTR185H   (*(_PAGE_080_MEM_TYPE(0x20273E))) /* Message Object 185 Control Register High */


#define CAN_MOCTR186H   (*(_PAGE_080_MEM_TYPE(0x20275E))) /* Message Object 186 Control Register High */


#define CAN_MOCTR187H   (*(_PAGE_080_MEM_TYPE(0x20277E))) /* Message Object 187 Control Register High */


#define CAN_MOCTR188H   (*(_PAGE_080_MEM_TYPE(0x20279E))) /* Message Object 188 Control Register High */


#define CAN_MOCTR189H   (*(_PAGE_080_MEM_TYPE(0x2027BE))) /* Message Object 189 Control Register High */


#define CAN_MOCTR190H   (*(_PAGE_080_MEM_TYPE(0x2027DE))) /* Message Object 190 Control Register High */


#define CAN_MOCTR191H   (*(_PAGE_080_MEM_TYPE(0x2027FE))) /* Message Object 191 Control Register High */


#define CAN_MOCTR192H   (*(_PAGE_080_MEM_TYPE(0x20281E))) /* Message Object 192 Control Register High */


#define CAN_MOCTR193H   (*(_PAGE_080_MEM_TYPE(0x20283E))) /* Message Object 193 Control Register High */


#define CAN_MOCTR194H   (*(_PAGE_080_MEM_TYPE(0x20285E))) /* Message Object 194 Control Register High */


#define CAN_MOCTR195H   (*(_PAGE_080_MEM_TYPE(0x20287E))) /* Message Object 195 Control Register High */


#define CAN_MOCTR196H   (*(_PAGE_080_MEM_TYPE(0x20289E))) /* Message Object 196 Control Register High */


#define CAN_MOCTR197H   (*(_PAGE_080_MEM_TYPE(0x2028BE))) /* Message Object 197 Control Register High */


#define CAN_MOCTR198H   (*(_PAGE_080_MEM_TYPE(0x2028DE))) /* Message Object 198 Control Register High */


#define CAN_MOCTR199H   (*(_PAGE_080_MEM_TYPE(0x2028FE))) /* Message Object 199 Control Register High */


#define CAN_MOCTR200H   (*(_PAGE_080_MEM_TYPE(0x20291E))) /* Message Object 200 Control Register High */


#define CAN_MOCTR201H   (*(_PAGE_080_MEM_TYPE(0x20293E))) /* Message Object 201 Control Register High */


#define CAN_MOCTR202H   (*(_PAGE_080_MEM_TYPE(0x20295E))) /* Message Object 202 Control Register High */


#define CAN_MOCTR203H   (*(_PAGE_080_MEM_TYPE(0x20297E))) /* Message Object 203 Control Register High */


#define CAN_MOCTR204H   (*(_PAGE_080_MEM_TYPE(0x20299E))) /* Message Object 204 Control Register High */


#define CAN_MOCTR205H   (*(_PAGE_080_MEM_TYPE(0x2029BE))) /* Message Object 205 Control Register High */


#define CAN_MOCTR206H   (*(_PAGE_080_MEM_TYPE(0x2029DE))) /* Message Object 206 Control Register High */


#define CAN_MOCTR207H   (*(_PAGE_080_MEM_TYPE(0x2029FE))) /* Message Object 207 Control Register High */


#define CAN_MOCTR208H   (*(_PAGE_080_MEM_TYPE(0x202A1E))) /* Message Object 208 Control Register High */


#define CAN_MOCTR209H   (*(_PAGE_080_MEM_TYPE(0x202A3E))) /* Message Object 209 Control Register High */


#define CAN_MOCTR210H   (*(_PAGE_080_MEM_TYPE(0x202A5E))) /* Message Object 210 Control Register High */


#define CAN_MOCTR211H   (*(_PAGE_080_MEM_TYPE(0x202A7E))) /* Message Object 211 Control Register High */


#define CAN_MOCTR212H   (*(_PAGE_080_MEM_TYPE(0x202A9E))) /* Message Object 212 Control Register High */


#define CAN_MOCTR213H   (*(_PAGE_080_MEM_TYPE(0x202ABE))) /* Message Object 213 Control Register High */


#define CAN_MOCTR214H   (*(_PAGE_080_MEM_TYPE(0x202ADE))) /* Message Object 214 Control Register High */


#define CAN_MOCTR215H   (*(_PAGE_080_MEM_TYPE(0x202AFE))) /* Message Object 215 Control Register High */


#define CAN_MOCTR216H   (*(_PAGE_080_MEM_TYPE(0x202B1E))) /* Message Object 216 Control Register High */


#define CAN_MOCTR217H   (*(_PAGE_080_MEM_TYPE(0x202B3E))) /* Message Object 217 Control Register High */


#define CAN_MOCTR218H   (*(_PAGE_080_MEM_TYPE(0x202B5E))) /* Message Object 218 Control Register High */


#define CAN_MOCTR219H   (*(_PAGE_080_MEM_TYPE(0x202B7E))) /* Message Object 219 Control Register High */


#define CAN_MOCTR220H   (*(_PAGE_080_MEM_TYPE(0x202B9E))) /* Message Object 220 Control Register High */


#define CAN_MOCTR221H   (*(_PAGE_080_MEM_TYPE(0x202BBE))) /* Message Object 221 Control Register High */


#define CAN_MOCTR222H   (*(_PAGE_080_MEM_TYPE(0x202BDE))) /* Message Object 222 Control Register High */


#define CAN_MOCTR223H   (*(_PAGE_080_MEM_TYPE(0x202BFE))) /* Message Object 223 Control Register High */


#define CAN_MOCTR224H   (*(_PAGE_080_MEM_TYPE(0x202C1E))) /* Message Object 224 Control Register High */


#define CAN_MOCTR225H   (*(_PAGE_080_MEM_TYPE(0x202C3E))) /* Message Object 225 Control Register High */


#define CAN_MOCTR226H   (*(_PAGE_080_MEM_TYPE(0x202C5E))) /* Message Object 226 Control Register High */


#define CAN_MOCTR227H   (*(_PAGE_080_MEM_TYPE(0x202C7E))) /* Message Object 227 Control Register High */


#define CAN_MOCTR228H   (*(_PAGE_080_MEM_TYPE(0x202C9E))) /* Message Object 228 Control Register High */


#define CAN_MOCTR229H   (*(_PAGE_080_MEM_TYPE(0x202CBE))) /* Message Object 229 Control Register High */


#define CAN_MOCTR230H   (*(_PAGE_080_MEM_TYPE(0x202CDE))) /* Message Object 230 Control Register High */


#define CAN_MOCTR231H   (*(_PAGE_080_MEM_TYPE(0x202CFE))) /* Message Object 231 Control Register High */


#define CAN_MOCTR232H   (*(_PAGE_080_MEM_TYPE(0x202D1E))) /* Message Object 232 Control Register High */


#define CAN_MOCTR233H   (*(_PAGE_080_MEM_TYPE(0x202D3E))) /* Message Object 233 Control Register High */


#define CAN_MOCTR234H   (*(_PAGE_080_MEM_TYPE(0x202D5E))) /* Message Object 234 Control Register High */


#define CAN_MOCTR235H   (*(_PAGE_080_MEM_TYPE(0x202D7E))) /* Message Object 235 Control Register High */


#define CAN_MOCTR236H   (*(_PAGE_080_MEM_TYPE(0x202D9E))) /* Message Object 236 Control Register High */


#define CAN_MOCTR237H   (*(_PAGE_080_MEM_TYPE(0x202DBE))) /* Message Object 237 Control Register High */


#define CAN_MOCTR238H   (*(_PAGE_080_MEM_TYPE(0x202DDE))) /* Message Object 238 Control Register High */


#define CAN_MOCTR239H   (*(_PAGE_080_MEM_TYPE(0x202DFE))) /* Message Object 239 Control Register High */


#define CAN_MOCTR240H   (*(_PAGE_080_MEM_TYPE(0x202E1E))) /* Message Object 240 Control Register High */


#define CAN_MOCTR241H   (*(_PAGE_080_MEM_TYPE(0x202E3E))) /* Message Object 241 Control Register High */


#define CAN_MOCTR242H   (*(_PAGE_080_MEM_TYPE(0x202E5E))) /* Message Object 242 Control Register High */


#define CAN_MOCTR243H   (*(_PAGE_080_MEM_TYPE(0x202E7E))) /* Message Object 243 Control Register High */


#define CAN_MOCTR244H   (*(_PAGE_080_MEM_TYPE(0x202E9E))) /* Message Object 244 Control Register High */


#define CAN_MOCTR245H   (*(_PAGE_080_MEM_TYPE(0x202EBE))) /* Message Object 245 Control Register High */


#define CAN_MOCTR246H   (*(_PAGE_080_MEM_TYPE(0x202EDE))) /* Message Object 246 Control Register High */


#define CAN_MOCTR247H   (*(_PAGE_080_MEM_TYPE(0x202EFE))) /* Message Object 247 Control Register High */


#define CAN_MOCTR248H   (*(_PAGE_080_MEM_TYPE(0x202F1E))) /* Message Object 248 Control Register High */


#define CAN_MOCTR249H   (*(_PAGE_080_MEM_TYPE(0x202F3E))) /* Message Object 249 Control Register High */


#define CAN_MOCTR250H   (*(_PAGE_080_MEM_TYPE(0x202F5E))) /* Message Object 250 Control Register High */


#define CAN_MOCTR251H   (*(_PAGE_080_MEM_TYPE(0x202F7E))) /* Message Object 251 Control Register High */


#define CAN_MOCTR252H   (*(_PAGE_080_MEM_TYPE(0x202F9E))) /* Message Object 252 Control Register High */


#define CAN_MOCTR253H   (*(_PAGE_080_MEM_TYPE(0x202FBE))) /* Message Object 253 Control Register High */


#define CAN_MOCTR254H   (*(_PAGE_080_MEM_TYPE(0x202FDE))) /* Message Object 254 Control Register High */


#define CAN_MOCTR0L     (*(_PAGE_080_MEM_TYPE(0x20101C))) /* Message Object 0 Control Register Low */


#define CAN_MOCTR1L     (*(_PAGE_080_MEM_TYPE(0x20103C))) /* Message Object 1 Control Register Low */


#define CAN_MOCTR2L     (*(_PAGE_080_MEM_TYPE(0x20105C))) /* Message Object 2 Control Register Low */


#define CAN_MOCTR3L     (*(_PAGE_080_MEM_TYPE(0x20107C))) /* Message Object 3 Control Register Low */


#define CAN_MOCTR4L     (*(_PAGE_080_MEM_TYPE(0x20109C))) /* Message Object 4 Control Register Low */


#define CAN_MOCTR5L     (*(_PAGE_080_MEM_TYPE(0x2010BC))) /* Message Object 5 Control Register Low */


#define CAN_MOCTR6L     (*(_PAGE_080_MEM_TYPE(0x2010DC))) /* Message Object 6 Control Register Low */


#define CAN_MOCTR7L     (*(_PAGE_080_MEM_TYPE(0x2010FC))) /* Message Object 7 Control Register Low */


#define CAN_MOCTR8L     (*(_PAGE_080_MEM_TYPE(0x20111C))) /* Message Object 8 Control Register Low */


#define CAN_MOCTR9L     (*(_PAGE_080_MEM_TYPE(0x20113C))) /* Message Object 9 Control Register Low */


#define CAN_MOCTR10L    (*(_PAGE_080_MEM_TYPE(0x20115C))) /* Message Object 10 Control Register Low */


#define CAN_MOCTR11L    (*(_PAGE_080_MEM_TYPE(0x20117C))) /* Message Object 11 Control Register Low */


#define CAN_MOCTR12L    (*(_PAGE_080_MEM_TYPE(0x20119C))) /* Message Object 12 Control Register Low */


#define CAN_MOCTR13L    (*(_PAGE_080_MEM_TYPE(0x2011BC))) /* Message Object 13 Control Register Low */


#define CAN_MOCTR14L    (*(_PAGE_080_MEM_TYPE(0x2011DC))) /* Message Object 14 Control Register Low */


#define CAN_MOCTR15L    (*(_PAGE_080_MEM_TYPE(0x2011FC))) /* Message Object 15 Control Register Low */


#define CAN_MOCTR16L    (*(_PAGE_080_MEM_TYPE(0x20121C))) /* Message Object 16 Control Register Low */


#define CAN_MOCTR17L    (*(_PAGE_080_MEM_TYPE(0x20123C))) /* Message Object 17 Control Register Low */


#define CAN_MOCTR18L    (*(_PAGE_080_MEM_TYPE(0x20125C))) /* Message Object 18 Control Register Low */


#define CAN_MOCTR19L    (*(_PAGE_080_MEM_TYPE(0x20127C))) /* Message Object 19 Control Register Low */


#define CAN_MOCTR20L    (*(_PAGE_080_MEM_TYPE(0x20129C))) /* Message Object 20 Control Register Low */


#define CAN_MOCTR21L    (*(_PAGE_080_MEM_TYPE(0x2012BC))) /* Message Object 21 Control Register Low */


#define CAN_MOCTR22L    (*(_PAGE_080_MEM_TYPE(0x2012DC))) /* Message Object 22 Control Register Low */


#define CAN_MOCTR23L    (*(_PAGE_080_MEM_TYPE(0x2012FC))) /* Message Object 23 Control Register Low */


#define CAN_MOCTR24L    (*(_PAGE_080_MEM_TYPE(0x20131C))) /* Message Object 24 Control Register Low */


#define CAN_MOCTR25L    (*(_PAGE_080_MEM_TYPE(0x20133C))) /* Message Object 25 Control Register Low */


#define CAN_MOCTR26L    (*(_PAGE_080_MEM_TYPE(0x20135C))) /* Message Object 26 Control Register Low */


#define CAN_MOCTR27L    (*(_PAGE_080_MEM_TYPE(0x20137C))) /* Message Object 27 Control Register Low */


#define CAN_MOCTR28L    (*(_PAGE_080_MEM_TYPE(0x20139C))) /* Message Object 28 Control Register Low */


#define CAN_MOCTR29L    (*(_PAGE_080_MEM_TYPE(0x2013BC))) /* Message Object 29 Control Register Low */


#define CAN_MOCTR30L    (*(_PAGE_080_MEM_TYPE(0x2013DC))) /* Message Object 30 Control Register Low */


#define CAN_MOCTR31L    (*(_PAGE_080_MEM_TYPE(0x2013FC))) /* Message Object 31 Control Register Low */


#define CAN_MOCTR32L    (*(_PAGE_080_MEM_TYPE(0x20141C))) /* Message Object 32 Control Register Low */


#define CAN_MOCTR33L    (*(_PAGE_080_MEM_TYPE(0x20143C))) /* Message Object 33 Control Register Low */


#define CAN_MOCTR34L    (*(_PAGE_080_MEM_TYPE(0x20145C))) /* Message Object 34 Control Register Low */


#define CAN_MOCTR35L    (*(_PAGE_080_MEM_TYPE(0x20147C))) /* Message Object 35 Control Register Low */


#define CAN_MOCTR36L    (*(_PAGE_080_MEM_TYPE(0x20149C))) /* Message Object 36 Control Register Low */


#define CAN_MOCTR37L    (*(_PAGE_080_MEM_TYPE(0x2014BC))) /* Message Object 37 Control Register Low */


#define CAN_MOCTR38L    (*(_PAGE_080_MEM_TYPE(0x2014DC))) /* Message Object 38 Control Register Low */


#define CAN_MOCTR39L    (*(_PAGE_080_MEM_TYPE(0x2014FC))) /* Message Object 39 Control Register Low */


#define CAN_MOCTR40L    (*(_PAGE_080_MEM_TYPE(0x20151C))) /* Message Object 40 Control Register Low */


#define CAN_MOCTR41L    (*(_PAGE_080_MEM_TYPE(0x20153C))) /* Message Object 41 Control Register Low */


#define CAN_MOCTR42L    (*(_PAGE_080_MEM_TYPE(0x20155C))) /* Message Object 42 Control Register Low */


#define CAN_MOCTR43L    (*(_PAGE_080_MEM_TYPE(0x20157C))) /* Message Object 43 Control Register Low */


#define CAN_MOCTR44L    (*(_PAGE_080_MEM_TYPE(0x20159C))) /* Message Object 44 Control Register Low */


#define CAN_MOCTR45L    (*(_PAGE_080_MEM_TYPE(0x2015BC))) /* Message Object 45 Control Register Low */


#define CAN_MOCTR46L    (*(_PAGE_080_MEM_TYPE(0x2015DC))) /* Message Object 46 Control Register Low */


#define CAN_MOCTR47L    (*(_PAGE_080_MEM_TYPE(0x2015FC))) /* Message Object 47 Control Register Low */


#define CAN_MOCTR48L    (*(_PAGE_080_MEM_TYPE(0x20161C))) /* Message Object 48 Control Register Low */


#define CAN_MOCTR49L    (*(_PAGE_080_MEM_TYPE(0x20163C))) /* Message Object 49 Control Register Low */


#define CAN_MOCTR50L    (*(_PAGE_080_MEM_TYPE(0x20165C))) /* Message Object 50 Control Register Low */


#define CAN_MOCTR51L    (*(_PAGE_080_MEM_TYPE(0x20167C))) /* Message Object 51 Control Register Low */


#define CAN_MOCTR52L    (*(_PAGE_080_MEM_TYPE(0x20169C))) /* Message Object 52 Control Register Low */


#define CAN_MOCTR53L    (*(_PAGE_080_MEM_TYPE(0x2016BC))) /* Message Object 53 Control Register Low */


#define CAN_MOCTR54L    (*(_PAGE_080_MEM_TYPE(0x2016DC))) /* Message Object 54 Control Register Low */


#define CAN_MOCTR55L    (*(_PAGE_080_MEM_TYPE(0x2016FC))) /* Message Object 55 Control Register Low */


#define CAN_MOCTR56L    (*(_PAGE_080_MEM_TYPE(0x20171C))) /* Message Object 56 Control Register Low */


#define CAN_MOCTR57L    (*(_PAGE_080_MEM_TYPE(0x20173C))) /* Message Object 57 Control Register Low */


#define CAN_MOCTR58L    (*(_PAGE_080_MEM_TYPE(0x20175C))) /* Message Object 58 Control Register Low */


#define CAN_MOCTR59L    (*(_PAGE_080_MEM_TYPE(0x20177C))) /* Message Object 59 Control Register Low */


#define CAN_MOCTR60L    (*(_PAGE_080_MEM_TYPE(0x20179C))) /* Message Object 60 Control Register Low */


#define CAN_MOCTR61L    (*(_PAGE_080_MEM_TYPE(0x2017BC))) /* Message Object 61 Control Register Low */


#define CAN_MOCTR62L    (*(_PAGE_080_MEM_TYPE(0x2017DC))) /* Message Object 62 Control Register Low */


#define CAN_MOCTR63L    (*(_PAGE_080_MEM_TYPE(0x2017FC))) /* Message Object 63 Control Register Low */


#define CAN_MOCTR64L    (*(_PAGE_080_MEM_TYPE(0x20181C))) /* Message Object 64 Control Register Low */


#define CAN_MOCTR65L    (*(_PAGE_080_MEM_TYPE(0x20183C))) /* Message Object 65 Control Register Low */


#define CAN_MOCTR66L    (*(_PAGE_080_MEM_TYPE(0x20185C))) /* Message Object 66 Control Register Low */


#define CAN_MOCTR67L    (*(_PAGE_080_MEM_TYPE(0x20187C))) /* Message Object 67 Control Register Low */


#define CAN_MOCTR68L    (*(_PAGE_080_MEM_TYPE(0x20189C))) /* Message Object 68 Control Register Low */


#define CAN_MOCTR69L    (*(_PAGE_080_MEM_TYPE(0x2018BC))) /* Message Object 69 Control Register Low */


#define CAN_MOCTR70L    (*(_PAGE_080_MEM_TYPE(0x2018DC))) /* Message Object 70 Control Register Low */


#define CAN_MOCTR71L    (*(_PAGE_080_MEM_TYPE(0x2018FC))) /* Message Object 71 Control Register Low */


#define CAN_MOCTR72L    (*(_PAGE_080_MEM_TYPE(0x20191C))) /* Message Object 72 Control Register Low */


#define CAN_MOCTR73L    (*(_PAGE_080_MEM_TYPE(0x20193C))) /* Message Object 73 Control Register Low */


#define CAN_MOCTR74L    (*(_PAGE_080_MEM_TYPE(0x20195C))) /* Message Object 74 Control Register Low */


#define CAN_MOCTR75L    (*(_PAGE_080_MEM_TYPE(0x20197C))) /* Message Object 75 Control Register Low */


#define CAN_MOCTR76L    (*(_PAGE_080_MEM_TYPE(0x20199C))) /* Message Object 76 Control Register Low */


#define CAN_MOCTR77L    (*(_PAGE_080_MEM_TYPE(0x2019BC))) /* Message Object 77 Control Register Low */


#define CAN_MOCTR78L    (*(_PAGE_080_MEM_TYPE(0x2019DC))) /* Message Object 78 Control Register Low */


#define CAN_MOCTR79L    (*(_PAGE_080_MEM_TYPE(0x2019FC))) /* Message Object 79 Control Register Low */


#define CAN_MOCTR80L    (*(_PAGE_080_MEM_TYPE(0x201A1C))) /* Message Object 80 Control Register Low */


#define CAN_MOCTR81L    (*(_PAGE_080_MEM_TYPE(0x201A3C))) /* Message Object 81 Control Register Low */


#define CAN_MOCTR82L    (*(_PAGE_080_MEM_TYPE(0x201A5C))) /* Message Object 82 Control Register Low */


#define CAN_MOCTR83L    (*(_PAGE_080_MEM_TYPE(0x201A7C))) /* Message Object 83 Control Register Low */


#define CAN_MOCTR84L    (*(_PAGE_080_MEM_TYPE(0x201A9C))) /* Message Object 84 Control Register Low */


#define CAN_MOCTR85L    (*(_PAGE_080_MEM_TYPE(0x201ABC))) /* Message Object 85 Control Register Low */


#define CAN_MOCTR86L    (*(_PAGE_080_MEM_TYPE(0x201ADC))) /* Message Object 86 Control Register Low */


#define CAN_MOCTR87L    (*(_PAGE_080_MEM_TYPE(0x201AFC))) /* Message Object 87 Control Register Low */


#define CAN_MOCTR88L    (*(_PAGE_080_MEM_TYPE(0x201B1C))) /* Message Object 88 Control Register Low */


#define CAN_MOCTR89L    (*(_PAGE_080_MEM_TYPE(0x201B3C))) /* Message Object 89 Control Register Low */


#define CAN_MOCTR90L    (*(_PAGE_080_MEM_TYPE(0x201B5C))) /* Message Object 90 Control Register Low */


#define CAN_MOCTR91L    (*(_PAGE_080_MEM_TYPE(0x201B7C))) /* Message Object 91 Control Register Low */


#define CAN_MOCTR92L    (*(_PAGE_080_MEM_TYPE(0x201B9C))) /* Message Object 92 Control Register Low */


#define CAN_MOCTR93L    (*(_PAGE_080_MEM_TYPE(0x201BBC))) /* Message Object 93 Control Register Low */


#define CAN_MOCTR94L    (*(_PAGE_080_MEM_TYPE(0x201BDC))) /* Message Object 94 Control Register Low */


#define CAN_MOCTR95L    (*(_PAGE_080_MEM_TYPE(0x201BFC))) /* Message Object 95 Control Register Low */


#define CAN_MOCTR96L    (*(_PAGE_080_MEM_TYPE(0x201C1C))) /* Message Object 96 Control Register Low */


#define CAN_MOCTR97L    (*(_PAGE_080_MEM_TYPE(0x201C3C))) /* Message Object 97 Control Register Low */


#define CAN_MOCTR98L    (*(_PAGE_080_MEM_TYPE(0x201C5C))) /* Message Object 98 Control Register Low */


#define CAN_MOCTR99L    (*(_PAGE_080_MEM_TYPE(0x201C7C))) /* Message Object 99 Control Register Low */


#define CAN_MOCTR100L   (*(_PAGE_080_MEM_TYPE(0x201C9C))) /* Message Object 100 Control Register Low */


#define CAN_MOCTR101L   (*(_PAGE_080_MEM_TYPE(0x201CBC))) /* Message Object 101 Control Register Low */


#define CAN_MOCTR102L   (*(_PAGE_080_MEM_TYPE(0x201CDC))) /* Message Object 102 Control Register Low */


#define CAN_MOCTR103L   (*(_PAGE_080_MEM_TYPE(0x201CFC))) /* Message Object 103 Control Register Low */


#define CAN_MOCTR104L   (*(_PAGE_080_MEM_TYPE(0x201D1C))) /* Message Object 104 Control Register Low */


#define CAN_MOCTR105L   (*(_PAGE_080_MEM_TYPE(0x201D3C))) /* Message Object 105 Control Register Low */


#define CAN_MOCTR106L   (*(_PAGE_080_MEM_TYPE(0x201D5C))) /* Message Object 106 Control Register Low */


#define CAN_MOCTR107L   (*(_PAGE_080_MEM_TYPE(0x201D7C))) /* Message Object 107 Control Register Low */


#define CAN_MOCTR108L   (*(_PAGE_080_MEM_TYPE(0x201D9C))) /* Message Object 108 Control Register Low */


#define CAN_MOCTR109L   (*(_PAGE_080_MEM_TYPE(0x201DBC))) /* Message Object 109 Control Register Low */


#define CAN_MOCTR110L   (*(_PAGE_080_MEM_TYPE(0x201DDC))) /* Message Object 110 Control Register Low */


#define CAN_MOCTR111L   (*(_PAGE_080_MEM_TYPE(0x201DFC))) /* Message Object 111 Control Register Low */


#define CAN_MOCTR112L   (*(_PAGE_080_MEM_TYPE(0x201E1C))) /* Message Object 112 Control Register Low */


#define CAN_MOCTR113L   (*(_PAGE_080_MEM_TYPE(0x201E3C))) /* Message Object 113 Control Register Low */


#define CAN_MOCTR114L   (*(_PAGE_080_MEM_TYPE(0x201E5C))) /* Message Object 114 Control Register Low */


#define CAN_MOCTR115L   (*(_PAGE_080_MEM_TYPE(0x201E7C))) /* Message Object 115 Control Register Low */


#define CAN_MOCTR116L   (*(_PAGE_080_MEM_TYPE(0x201E9C))) /* Message Object 116 Control Register Low */


#define CAN_MOCTR117L   (*(_PAGE_080_MEM_TYPE(0x201EBC))) /* Message Object 117 Control Register Low */


#define CAN_MOCTR118L   (*(_PAGE_080_MEM_TYPE(0x201EDC))) /* Message Object 118 Control Register Low */


#define CAN_MOCTR119L   (*(_PAGE_080_MEM_TYPE(0x201EFC))) /* Message Object 119 Control Register Low */


#define CAN_MOCTR120L   (*(_PAGE_080_MEM_TYPE(0x201F1C))) /* Message Object 120 Control Register Low */


#define CAN_MOCTR121L   (*(_PAGE_080_MEM_TYPE(0x201F3C))) /* Message Object 121 Control Register Low */


#define CAN_MOCTR122L   (*(_PAGE_080_MEM_TYPE(0x201F5C))) /* Message Object 122 Control Register Low */


#define CAN_MOCTR123L   (*(_PAGE_080_MEM_TYPE(0x201F7C))) /* Message Object 123 Control Register Low */


#define CAN_MOCTR124L   (*(_PAGE_080_MEM_TYPE(0x201F9C))) /* Message Object 124 Control Register Low */


#define CAN_MOCTR125L   (*(_PAGE_080_MEM_TYPE(0x201FBC))) /* Message Object 125 Control Register Low */


#define CAN_MOCTR126L   (*(_PAGE_080_MEM_TYPE(0x201FDC))) /* Message Object 126 Control Register Low */


#define CAN_MOCTR127L   (*(_PAGE_080_MEM_TYPE(0x201FFC))) /* Message Object 127 Control Register Low */


#define CAN_MOCTR128L   (*(_PAGE_080_MEM_TYPE(0x20201C))) /* Message Object 128 Control Register Low */


#define CAN_MOCTR129L   (*(_PAGE_080_MEM_TYPE(0x20203C))) /* Message Object 129 Control Register Low */


#define CAN_MOCTR130L   (*(_PAGE_080_MEM_TYPE(0x20205C))) /* Message Object 130 Control Register Low */


#define CAN_MOCTR131L   (*(_PAGE_080_MEM_TYPE(0x20207C))) /* Message Object 131 Control Register Low */


#define CAN_MOCTR132L   (*(_PAGE_080_MEM_TYPE(0x20209C))) /* Message Object 132 Control Register Low */


#define CAN_MOCTR133L   (*(_PAGE_080_MEM_TYPE(0x2020BC))) /* Message Object 133 Control Register Low */


#define CAN_MOCTR134L   (*(_PAGE_080_MEM_TYPE(0x2020DC))) /* Message Object 134 Control Register Low */


#define CAN_MOCTR135L   (*(_PAGE_080_MEM_TYPE(0x2020FC))) /* Message Object 135 Control Register Low */


#define CAN_MOCTR136L   (*(_PAGE_080_MEM_TYPE(0x20211C))) /* Message Object 136 Control Register Low */


#define CAN_MOCTR137L   (*(_PAGE_080_MEM_TYPE(0x20213C))) /* Message Object 137 Control Register Low */


#define CAN_MOCTR138L   (*(_PAGE_080_MEM_TYPE(0x20215C))) /* Message Object 138 Control Register Low */


#define CAN_MOCTR139L   (*(_PAGE_080_MEM_TYPE(0x20217C))) /* Message Object 139 Control Register Low */


#define CAN_MOCTR140L   (*(_PAGE_080_MEM_TYPE(0x20219C))) /* Message Object 140 Control Register Low */


#define CAN_MOCTR141L   (*(_PAGE_080_MEM_TYPE(0x2021BC))) /* Message Object 141 Control Register Low */


#define CAN_MOCTR142L   (*(_PAGE_080_MEM_TYPE(0x2021DC))) /* Message Object 142 Control Register Low */


#define CAN_MOCTR143L   (*(_PAGE_080_MEM_TYPE(0x2021FC))) /* Message Object 143 Control Register Low */


#define CAN_MOCTR144L   (*(_PAGE_080_MEM_TYPE(0x20221C))) /* Message Object 144 Control Register Low */


#define CAN_MOCTR145L   (*(_PAGE_080_MEM_TYPE(0x20223C))) /* Message Object 145 Control Register Low */


#define CAN_MOCTR146L   (*(_PAGE_080_MEM_TYPE(0x20225C))) /* Message Object 146 Control Register Low */


#define CAN_MOCTR147L   (*(_PAGE_080_MEM_TYPE(0x20227C))) /* Message Object 147 Control Register Low */


#define CAN_MOCTR148L   (*(_PAGE_080_MEM_TYPE(0x20229C))) /* Message Object 148 Control Register Low */


#define CAN_MOCTR149L   (*(_PAGE_080_MEM_TYPE(0x2022BC))) /* Message Object 149 Control Register Low */


#define CAN_MOCTR150L   (*(_PAGE_080_MEM_TYPE(0x2022DC))) /* Message Object 150 Control Register Low */


#define CAN_MOCTR151L   (*(_PAGE_080_MEM_TYPE(0x2022FC))) /* Message Object 151 Control Register Low */


#define CAN_MOCTR152L   (*(_PAGE_080_MEM_TYPE(0x20231C))) /* Message Object 152 Control Register Low */


#define CAN_MOCTR153L   (*(_PAGE_080_MEM_TYPE(0x20233C))) /* Message Object 153 Control Register Low */


#define CAN_MOCTR154L   (*(_PAGE_080_MEM_TYPE(0x20235C))) /* Message Object 154 Control Register Low */


#define CAN_MOCTR155L   (*(_PAGE_080_MEM_TYPE(0x20237C))) /* Message Object 155 Control Register Low */


#define CAN_MOCTR156L   (*(_PAGE_080_MEM_TYPE(0x20239C))) /* Message Object 156 Control Register Low */


#define CAN_MOCTR157L   (*(_PAGE_080_MEM_TYPE(0x2023BC))) /* Message Object 157 Control Register Low */


#define CAN_MOCTR158L   (*(_PAGE_080_MEM_TYPE(0x2023DC))) /* Message Object 158 Control Register Low */


#define CAN_MOCTR159L   (*(_PAGE_080_MEM_TYPE(0x2023FC))) /* Message Object 159 Control Register Low */


#define CAN_MOCTR160L   (*(_PAGE_080_MEM_TYPE(0x20241C))) /* Message Object 160 Control Register Low */


#define CAN_MOCTR161L   (*(_PAGE_080_MEM_TYPE(0x20243C))) /* Message Object 161 Control Register Low */


#define CAN_MOCTR162L   (*(_PAGE_080_MEM_TYPE(0x20245C))) /* Message Object 162 Control Register Low */


#define CAN_MOCTR163L   (*(_PAGE_080_MEM_TYPE(0x20247C))) /* Message Object 163 Control Register Low */


#define CAN_MOCTR164L   (*(_PAGE_080_MEM_TYPE(0x20249C))) /* Message Object 164 Control Register Low */


#define CAN_MOCTR165L   (*(_PAGE_080_MEM_TYPE(0x2024BC))) /* Message Object 165 Control Register Low */


#define CAN_MOCTR166L   (*(_PAGE_080_MEM_TYPE(0x2024DC))) /* Message Object 166 Control Register Low */


#define CAN_MOCTR167L   (*(_PAGE_080_MEM_TYPE(0x2024FC))) /* Message Object 167 Control Register Low */


#define CAN_MOCTR168L   (*(_PAGE_080_MEM_TYPE(0x20251C))) /* Message Object 168 Control Register Low */


#define CAN_MOCTR169L   (*(_PAGE_080_MEM_TYPE(0x20253C))) /* Message Object 169 Control Register Low */


#define CAN_MOCTR170L   (*(_PAGE_080_MEM_TYPE(0x20255C))) /* Message Object 170 Control Register Low */


#define CAN_MOCTR171L   (*(_PAGE_080_MEM_TYPE(0x20257C))) /* Message Object 171 Control Register Low */


#define CAN_MOCTR172L   (*(_PAGE_080_MEM_TYPE(0x20259C))) /* Message Object 172 Control Register Low */


#define CAN_MOCTR173L   (*(_PAGE_080_MEM_TYPE(0x2025BC))) /* Message Object 173 Control Register Low */


#define CAN_MOCTR174L   (*(_PAGE_080_MEM_TYPE(0x2025DC))) /* Message Object 174 Control Register Low */


#define CAN_MOCTR175L   (*(_PAGE_080_MEM_TYPE(0x2025FC))) /* Message Object 175 Control Register Low */


#define CAN_MOCTR176L   (*(_PAGE_080_MEM_TYPE(0x20261C))) /* Message Object 176 Control Register Low */


#define CAN_MOCTR177L   (*(_PAGE_080_MEM_TYPE(0x20263C))) /* Message Object 177 Control Register Low */


#define CAN_MOCTR178L   (*(_PAGE_080_MEM_TYPE(0x20265C))) /* Message Object 178 Control Register Low */


#define CAN_MOCTR179L   (*(_PAGE_080_MEM_TYPE(0x20267C))) /* Message Object 179 Control Register Low */


#define CAN_MOCTR180L   (*(_PAGE_080_MEM_TYPE(0x20269C))) /* Message Object 180 Control Register Low */


#define CAN_MOCTR181L   (*(_PAGE_080_MEM_TYPE(0x2026BC))) /* Message Object 181 Control Register Low */


#define CAN_MOCTR182L   (*(_PAGE_080_MEM_TYPE(0x2026DC))) /* Message Object 182 Control Register Low */


#define CAN_MOCTR183L   (*(_PAGE_080_MEM_TYPE(0x2026FC))) /* Message Object 183 Control Register Low */


#define CAN_MOCTR184L   (*(_PAGE_080_MEM_TYPE(0x20271C))) /* Message Object 184 Control Register Low */


#define CAN_MOCTR185L   (*(_PAGE_080_MEM_TYPE(0x20273C))) /* Message Object 185 Control Register Low */


#define CAN_MOCTR186L   (*(_PAGE_080_MEM_TYPE(0x20275C))) /* Message Object 186 Control Register Low */


#define CAN_MOCTR187L   (*(_PAGE_080_MEM_TYPE(0x20277C))) /* Message Object 187 Control Register Low */


#define CAN_MOCTR188L   (*(_PAGE_080_MEM_TYPE(0x20279C))) /* Message Object 188 Control Register Low */


#define CAN_MOCTR189L   (*(_PAGE_080_MEM_TYPE(0x2027BC))) /* Message Object 189 Control Register Low */


#define CAN_MOCTR190L   (*(_PAGE_080_MEM_TYPE(0x2027DC))) /* Message Object 190 Control Register Low */


#define CAN_MOCTR191L   (*(_PAGE_080_MEM_TYPE(0x2027FC))) /* Message Object 191 Control Register Low */


#define CAN_MOCTR192L   (*(_PAGE_080_MEM_TYPE(0x20281C))) /* Message Object 192 Control Register Low */


#define CAN_MOCTR193L   (*(_PAGE_080_MEM_TYPE(0x20283C))) /* Message Object 193 Control Register Low */


#define CAN_MOCTR194L   (*(_PAGE_080_MEM_TYPE(0x20285C))) /* Message Object 194 Control Register Low */


#define CAN_MOCTR195L   (*(_PAGE_080_MEM_TYPE(0x20287C))) /* Message Object 195 Control Register Low */


#define CAN_MOCTR196L   (*(_PAGE_080_MEM_TYPE(0x20289C))) /* Message Object 196 Control Register Low */


#define CAN_MOCTR197L   (*(_PAGE_080_MEM_TYPE(0x2028BC))) /* Message Object 197 Control Register Low */


#define CAN_MOCTR198L   (*(_PAGE_080_MEM_TYPE(0x2028DC))) /* Message Object 198 Control Register Low */


#define CAN_MOCTR199L   (*(_PAGE_080_MEM_TYPE(0x2028FC))) /* Message Object 199 Control Register Low */


#define CAN_MOCTR200L   (*(_PAGE_080_MEM_TYPE(0x20291C))) /* Message Object 200 Control Register Low */


#define CAN_MOCTR201L   (*(_PAGE_080_MEM_TYPE(0x20293C))) /* Message Object 201 Control Register Low */


#define CAN_MOCTR202L   (*(_PAGE_080_MEM_TYPE(0x20295C))) /* Message Object 202 Control Register Low */


#define CAN_MOCTR203L   (*(_PAGE_080_MEM_TYPE(0x20297C))) /* Message Object 203 Control Register Low */


#define CAN_MOCTR204L   (*(_PAGE_080_MEM_TYPE(0x20299C))) /* Message Object 204 Control Register Low */


#define CAN_MOCTR205L   (*(_PAGE_080_MEM_TYPE(0x2029BC))) /* Message Object 205 Control Register Low */


#define CAN_MOCTR206L   (*(_PAGE_080_MEM_TYPE(0x2029DC))) /* Message Object 206 Control Register Low */


#define CAN_MOCTR207L   (*(_PAGE_080_MEM_TYPE(0x2029FC))) /* Message Object 207 Control Register Low */


#define CAN_MOCTR208L   (*(_PAGE_080_MEM_TYPE(0x202A1C))) /* Message Object 208 Control Register Low */


#define CAN_MOCTR209L   (*(_PAGE_080_MEM_TYPE(0x202A3C))) /* Message Object 209 Control Register Low */


#define CAN_MOCTR210L   (*(_PAGE_080_MEM_TYPE(0x202A5C))) /* Message Object 210 Control Register Low */


#define CAN_MOCTR211L   (*(_PAGE_080_MEM_TYPE(0x202A7C))) /* Message Object 211 Control Register Low */


#define CAN_MOCTR212L   (*(_PAGE_080_MEM_TYPE(0x202A9C))) /* Message Object 212 Control Register Low */


#define CAN_MOCTR213L   (*(_PAGE_080_MEM_TYPE(0x202ABC))) /* Message Object 213 Control Register Low */


#define CAN_MOCTR214L   (*(_PAGE_080_MEM_TYPE(0x202ADC))) /* Message Object 214 Control Register Low */


#define CAN_MOCTR215L   (*(_PAGE_080_MEM_TYPE(0x202AFC))) /* Message Object 215 Control Register Low */


#define CAN_MOCTR216L   (*(_PAGE_080_MEM_TYPE(0x202B1C))) /* Message Object 216 Control Register Low */


#define CAN_MOCTR217L   (*(_PAGE_080_MEM_TYPE(0x202B3C))) /* Message Object 217 Control Register Low */


#define CAN_MOCTR218L   (*(_PAGE_080_MEM_TYPE(0x202B5C))) /* Message Object 218 Control Register Low */


#define CAN_MOCTR219L   (*(_PAGE_080_MEM_TYPE(0x202B7C))) /* Message Object 219 Control Register Low */


#define CAN_MOCTR220L   (*(_PAGE_080_MEM_TYPE(0x202B9C))) /* Message Object 220 Control Register Low */


#define CAN_MOCTR221L   (*(_PAGE_080_MEM_TYPE(0x202BBC))) /* Message Object 221 Control Register Low */


#define CAN_MOCTR222L   (*(_PAGE_080_MEM_TYPE(0x202BDC))) /* Message Object 222 Control Register Low */


#define CAN_MOCTR223L   (*(_PAGE_080_MEM_TYPE(0x202BFC))) /* Message Object 223 Control Register Low */


#define CAN_MOCTR224L   (*(_PAGE_080_MEM_TYPE(0x202C1C))) /* Message Object 224 Control Register Low */


#define CAN_MOCTR225L   (*(_PAGE_080_MEM_TYPE(0x202C3C))) /* Message Object 225 Control Register Low */


#define CAN_MOCTR226L   (*(_PAGE_080_MEM_TYPE(0x202C5C))) /* Message Object 226 Control Register Low */


#define CAN_MOCTR227L   (*(_PAGE_080_MEM_TYPE(0x202C7C))) /* Message Object 227 Control Register Low */


#define CAN_MOCTR228L   (*(_PAGE_080_MEM_TYPE(0x202C9C))) /* Message Object 228 Control Register Low */


#define CAN_MOCTR229L   (*(_PAGE_080_MEM_TYPE(0x202CBC))) /* Message Object 229 Control Register Low */


#define CAN_MOCTR230L   (*(_PAGE_080_MEM_TYPE(0x202CDC))) /* Message Object 230 Control Register Low */


#define CAN_MOCTR231L   (*(_PAGE_080_MEM_TYPE(0x202CFC))) /* Message Object 231 Control Register Low */


#define CAN_MOCTR232L   (*(_PAGE_080_MEM_TYPE(0x202D1C))) /* Message Object 232 Control Register Low */


#define CAN_MOCTR233L   (*(_PAGE_080_MEM_TYPE(0x202D3C))) /* Message Object 233 Control Register Low */


#define CAN_MOCTR234L   (*(_PAGE_080_MEM_TYPE(0x202D5C))) /* Message Object 234 Control Register Low */


#define CAN_MOCTR235L   (*(_PAGE_080_MEM_TYPE(0x202D7C))) /* Message Object 235 Control Register Low */


#define CAN_MOCTR236L   (*(_PAGE_080_MEM_TYPE(0x202D9C))) /* Message Object 236 Control Register Low */


#define CAN_MOCTR237L   (*(_PAGE_080_MEM_TYPE(0x202DBC))) /* Message Object 237 Control Register Low */


#define CAN_MOCTR238L   (*(_PAGE_080_MEM_TYPE(0x202DDC))) /* Message Object 238 Control Register Low */


#define CAN_MOCTR239L   (*(_PAGE_080_MEM_TYPE(0x202DFC))) /* Message Object 239 Control Register Low */


#define CAN_MOCTR240L   (*(_PAGE_080_MEM_TYPE(0x202E1C))) /* Message Object 240 Control Register Low */


#define CAN_MOCTR241L   (*(_PAGE_080_MEM_TYPE(0x202E3C))) /* Message Object 241 Control Register Low */


#define CAN_MOCTR242L   (*(_PAGE_080_MEM_TYPE(0x202E5C))) /* Message Object 242 Control Register Low */


#define CAN_MOCTR243L   (*(_PAGE_080_MEM_TYPE(0x202E7C))) /* Message Object 243 Control Register Low */


#define CAN_MOCTR244L   (*(_PAGE_080_MEM_TYPE(0x202E9C))) /* Message Object 244 Control Register Low */


#define CAN_MOCTR245L   (*(_PAGE_080_MEM_TYPE(0x202EBC))) /* Message Object 245 Control Register Low */


#define CAN_MOCTR246L   (*(_PAGE_080_MEM_TYPE(0x202EDC))) /* Message Object 246 Control Register Low */


#define CAN_MOCTR247L   (*(_PAGE_080_MEM_TYPE(0x202EFC))) /* Message Object 247 Control Register Low */


#define CAN_MOCTR248L   (*(_PAGE_080_MEM_TYPE(0x202F1C))) /* Message Object 248 Control Register Low */


#define CAN_MOCTR249L   (*(_PAGE_080_MEM_TYPE(0x202F3C))) /* Message Object 249 Control Register Low */


#define CAN_MOCTR250L   (*(_PAGE_080_MEM_TYPE(0x202F5C))) /* Message Object 250 Control Register Low */


#define CAN_MOCTR251L   (*(_PAGE_080_MEM_TYPE(0x202F7C))) /* Message Object 251 Control Register Low */


#define CAN_MOCTR252L   (*(_PAGE_080_MEM_TYPE(0x202F9C))) /* Message Object 252 Control Register Low */


#define CAN_MOCTR253L   (*(_PAGE_080_MEM_TYPE(0x202FBC))) /* Message Object 253 Control Register Low */


#define CAN_MOCTR254L   (*(_PAGE_080_MEM_TYPE(0x202FDC))) /* Message Object 254 Control Register Low */


#define CAN_MOCTR255L   (*(_PAGE_080_MEM_TYPE(0x202FFC))) /* Message Object 255 Control Register Low */


#define CAN_MOIPR0H     (*(_PAGE_080_MEM_TYPE(0x20100A))) /* Message Object 0 Interrupt Pointer Register High */


#define CAN_MOIPR1H     (*(_PAGE_080_MEM_TYPE(0x20102A))) /* Message Object 1 Interrupt Pointer Register High */


#define CAN_MOIPR2H     (*(_PAGE_080_MEM_TYPE(0x20104A))) /* Message Object 2 Interrupt Pointer Register High */


#define CAN_MOIPR3H     (*(_PAGE_080_MEM_TYPE(0x20106A))) /* Message Object 3 Interrupt Pointer Register High */


#define CAN_MOIPR4H     (*(_PAGE_080_MEM_TYPE(0x20108A))) /* Message Object 4 Interrupt Pointer Register High */


#define CAN_MOIPR5H     (*(_PAGE_080_MEM_TYPE(0x2010AA))) /* Message Object 5 Interrupt Pointer Register High */


#define CAN_MOIPR6H     (*(_PAGE_080_MEM_TYPE(0x2010CA))) /* Message Object 6 Interrupt Pointer Register High */


#define CAN_MOIPR7H     (*(_PAGE_080_MEM_TYPE(0x2010EA))) /* Message Object 7 Interrupt Pointer Register High */


#define CAN_MOIPR8H     (*(_PAGE_080_MEM_TYPE(0x20110A))) /* Message Object 8 Interrupt Pointer Register High */


#define CAN_MOIPR9H     (*(_PAGE_080_MEM_TYPE(0x20112A))) /* Message Object 9 Interrupt Pointer Register High */


#define CAN_MOIPR10H    (*(_PAGE_080_MEM_TYPE(0x20114A))) /* Message Object 10 Interrupt Pointer Register High */


#define CAN_MOIPR11H    (*(_PAGE_080_MEM_TYPE(0x20116A))) /* Message Object 11 Interrupt Pointer Register High */


#define CAN_MOIPR12H    (*(_PAGE_080_MEM_TYPE(0x20118A))) /* Message Object 12 Interrupt Pointer Register High */


#define CAN_MOIPR13H    (*(_PAGE_080_MEM_TYPE(0x2011AA))) /* Message Object 13 Interrupt Pointer Register High */


#define CAN_MOIPR14H    (*(_PAGE_080_MEM_TYPE(0x2011CA))) /* Message Object 14 Interrupt Pointer Register High */


#define CAN_MOIPR15H    (*(_PAGE_080_MEM_TYPE(0x2011EA))) /* Message Object 15 Interrupt Pointer Register High */


#define CAN_MOIPR16H    (*(_PAGE_080_MEM_TYPE(0x20120A))) /* Message Object 16 Interrupt Pointer Register High */


#define CAN_MOIPR17H    (*(_PAGE_080_MEM_TYPE(0x20122A))) /* Message Object 17 Interrupt Pointer Register High */


#define CAN_MOIPR18H    (*(_PAGE_080_MEM_TYPE(0x20124A))) /* Message Object 18 Interrupt Pointer Register High */


#define CAN_MOIPR19H    (*(_PAGE_080_MEM_TYPE(0x20126A))) /* Message Object 19 Interrupt Pointer Register High */


#define CAN_MOIPR20H    (*(_PAGE_080_MEM_TYPE(0x20128A))) /* Message Object 20 Interrupt Pointer Register High */


#define CAN_MOIPR21H    (*(_PAGE_080_MEM_TYPE(0x2012AA))) /* Message Object 21 Interrupt Pointer Register High */


#define CAN_MOIPR22H    (*(_PAGE_080_MEM_TYPE(0x2012CA))) /* Message Object 22 Interrupt Pointer Register High */


#define CAN_MOIPR23H    (*(_PAGE_080_MEM_TYPE(0x2012EA))) /* Message Object 23 Interrupt Pointer Register High */


#define CAN_MOIPR24H    (*(_PAGE_080_MEM_TYPE(0x20130A))) /* Message Object 24 Interrupt Pointer Register High */


#define CAN_MOIPR25H    (*(_PAGE_080_MEM_TYPE(0x20132A))) /* Message Object 25 Interrupt Pointer Register High */


#define CAN_MOIPR26H    (*(_PAGE_080_MEM_TYPE(0x20134A))) /* Message Object 26 Interrupt Pointer Register High */


#define CAN_MOIPR27H    (*(_PAGE_080_MEM_TYPE(0x20136A))) /* Message Object 27 Interrupt Pointer Register High */


#define CAN_MOIPR28H    (*(_PAGE_080_MEM_TYPE(0x20138A))) /* Message Object 28 Interrupt Pointer Register High */


#define CAN_MOIPR29H    (*(_PAGE_080_MEM_TYPE(0x2013AA))) /* Message Object 29 Interrupt Pointer Register High */


#define CAN_MOIPR30H    (*(_PAGE_080_MEM_TYPE(0x2013CA))) /* Message Object 30 Interrupt Pointer Register High */


#define CAN_MOIPR31H    (*(_PAGE_080_MEM_TYPE(0x2013EA))) /* Message Object 31 Interrupt Pointer Register High */


#define CAN_MOIPR32H    (*(_PAGE_080_MEM_TYPE(0x20140A))) /* Message Object 32 Interrupt Pointer Register High */


#define CAN_MOIPR33H    (*(_PAGE_080_MEM_TYPE(0x20142A))) /* Message Object 33 Interrupt Pointer Register High */


#define CAN_MOIPR34H    (*(_PAGE_080_MEM_TYPE(0x20144A))) /* Message Object 34 Interrupt Pointer Register High */


#define CAN_MOIPR35H    (*(_PAGE_080_MEM_TYPE(0x20146A))) /* Message Object 35 Interrupt Pointer Register High */


#define CAN_MOIPR36H    (*(_PAGE_080_MEM_TYPE(0x20148A))) /* Message Object 36 Interrupt Pointer Register High */


#define CAN_MOIPR37H    (*(_PAGE_080_MEM_TYPE(0x2014AA))) /* Message Object 37 Interrupt Pointer Register High */


#define CAN_MOIPR38H    (*(_PAGE_080_MEM_TYPE(0x2014CA))) /* Message Object 38 Interrupt Pointer Register High */


#define CAN_MOIPR39H    (*(_PAGE_080_MEM_TYPE(0x2014EA))) /* Message Object 39 Interrupt Pointer Register High */


#define CAN_MOIPR40H    (*(_PAGE_080_MEM_TYPE(0x20150A))) /* Message Object 40 Interrupt Pointer Register High */


#define CAN_MOIPR41H    (*(_PAGE_080_MEM_TYPE(0x20152A))) /* Message Object 41 Interrupt Pointer Register High */


#define CAN_MOIPR42H    (*(_PAGE_080_MEM_TYPE(0x20154A))) /* Message Object 42 Interrupt Pointer Register High */


#define CAN_MOIPR43H    (*(_PAGE_080_MEM_TYPE(0x20156A))) /* Message Object 43 Interrupt Pointer Register High */


#define CAN_MOIPR44H    (*(_PAGE_080_MEM_TYPE(0x20158A))) /* Message Object 44 Interrupt Pointer Register High */


#define CAN_MOIPR45H    (*(_PAGE_080_MEM_TYPE(0x2015AA))) /* Message Object 45 Interrupt Pointer Register High */


#define CAN_MOIPR46H    (*(_PAGE_080_MEM_TYPE(0x2015CA))) /* Message Object 46 Interrupt Pointer Register High */


#define CAN_MOIPR47H    (*(_PAGE_080_MEM_TYPE(0x2015EA))) /* Message Object 47 Interrupt Pointer Register High */


#define CAN_MOIPR48H    (*(_PAGE_080_MEM_TYPE(0x20160A))) /* Message Object 48 Interrupt Pointer Register High */


#define CAN_MOIPR49H    (*(_PAGE_080_MEM_TYPE(0x20162A))) /* Message Object 49 Interrupt Pointer Register High */


#define CAN_MOIPR50H    (*(_PAGE_080_MEM_TYPE(0x20164A))) /* Message Object 50 Interrupt Pointer Register High */


#define CAN_MOIPR51H    (*(_PAGE_080_MEM_TYPE(0x20166A))) /* Message Object 51 Interrupt Pointer Register High */


#define CAN_MOIPR52H    (*(_PAGE_080_MEM_TYPE(0x20168A))) /* Message Object 52 Interrupt Pointer Register High */


#define CAN_MOIPR53H    (*(_PAGE_080_MEM_TYPE(0x2016AA))) /* Message Object 53 Interrupt Pointer Register High */


#define CAN_MOIPR54H    (*(_PAGE_080_MEM_TYPE(0x2016CA))) /* Message Object 54 Interrupt Pointer Register High */


#define CAN_MOIPR55H    (*(_PAGE_080_MEM_TYPE(0x2016EA))) /* Message Object 55 Interrupt Pointer Register High */


#define CAN_MOIPR56H    (*(_PAGE_080_MEM_TYPE(0x20170A))) /* Message Object 56 Interrupt Pointer Register High */


#define CAN_MOIPR57H    (*(_PAGE_080_MEM_TYPE(0x20172A))) /* Message Object 57 Interrupt Pointer Register High */


#define CAN_MOIPR58H    (*(_PAGE_080_MEM_TYPE(0x20174A))) /* Message Object 58 Interrupt Pointer Register High */


#define CAN_MOIPR59H    (*(_PAGE_080_MEM_TYPE(0x20176A))) /* Message Object 59 Interrupt Pointer Register High */


#define CAN_MOIPR60H    (*(_PAGE_080_MEM_TYPE(0x20178A))) /* Message Object 60 Interrupt Pointer Register High */


#define CAN_MOIPR61H    (*(_PAGE_080_MEM_TYPE(0x2017AA))) /* Message Object 61 Interrupt Pointer Register High */


#define CAN_MOIPR62H    (*(_PAGE_080_MEM_TYPE(0x2017CA))) /* Message Object 62 Interrupt Pointer Register High */


#define CAN_MOIPR63H    (*(_PAGE_080_MEM_TYPE(0x2017EA))) /* Message Object 63 Interrupt Pointer Register High */


#define CAN_MOIPR64H    (*(_PAGE_080_MEM_TYPE(0x20180A))) /* Message Object 64 Interrupt Pointer Register High */


#define CAN_MOIPR65H    (*(_PAGE_080_MEM_TYPE(0x20182A))) /* Message Object 65 Interrupt Pointer Register High */


#define CAN_MOIPR66H    (*(_PAGE_080_MEM_TYPE(0x20184A))) /* Message Object 66 Interrupt Pointer Register High */


#define CAN_MOIPR67H    (*(_PAGE_080_MEM_TYPE(0x20186A))) /* Message Object 67 Interrupt Pointer Register High */


#define CAN_MOIPR68H    (*(_PAGE_080_MEM_TYPE(0x20188A))) /* Message Object 68 Interrupt Pointer Register High */


#define CAN_MOIPR69H    (*(_PAGE_080_MEM_TYPE(0x2018AA))) /* Message Object 69 Interrupt Pointer Register High */


#define CAN_MOIPR70H    (*(_PAGE_080_MEM_TYPE(0x2018CA))) /* Message Object 70 Interrupt Pointer Register High */


#define CAN_MOIPR71H    (*(_PAGE_080_MEM_TYPE(0x2018EA))) /* Message Object 71 Interrupt Pointer Register High */


#define CAN_MOIPR72H    (*(_PAGE_080_MEM_TYPE(0x20190A))) /* Message Object 72 Interrupt Pointer Register High */


#define CAN_MOIPR73H    (*(_PAGE_080_MEM_TYPE(0x20192A))) /* Message Object 73 Interrupt Pointer Register High */


#define CAN_MOIPR74H    (*(_PAGE_080_MEM_TYPE(0x20194A))) /* Message Object 74 Interrupt Pointer Register High */


#define CAN_MOIPR75H    (*(_PAGE_080_MEM_TYPE(0x20196A))) /* Message Object 75 Interrupt Pointer Register High */


#define CAN_MOIPR76H    (*(_PAGE_080_MEM_TYPE(0x20198A))) /* Message Object 76 Interrupt Pointer Register High */


#define CAN_MOIPR77H    (*(_PAGE_080_MEM_TYPE(0x2019AA))) /* Message Object 77 Interrupt Pointer Register High */


#define CAN_MOIPR78H    (*(_PAGE_080_MEM_TYPE(0x2019CA))) /* Message Object 78 Interrupt Pointer Register High */


#define CAN_MOIPR79H    (*(_PAGE_080_MEM_TYPE(0x2019EA))) /* Message Object 79 Interrupt Pointer Register High */


#define CAN_MOIPR80H    (*(_PAGE_080_MEM_TYPE(0x201A0A))) /* Message Object 80 Interrupt Pointer Register High */


#define CAN_MOIPR81H    (*(_PAGE_080_MEM_TYPE(0x201A2A))) /* Message Object 81 Interrupt Pointer Register High */


#define CAN_MOIPR82H    (*(_PAGE_080_MEM_TYPE(0x201A4A))) /* Message Object 82 Interrupt Pointer Register High */


#define CAN_MOIPR83H    (*(_PAGE_080_MEM_TYPE(0x201A6A))) /* Message Object 83 Interrupt Pointer Register High */


#define CAN_MOIPR84H    (*(_PAGE_080_MEM_TYPE(0x201A8A))) /* Message Object 84 Interrupt Pointer Register High */


#define CAN_MOIPR85H    (*(_PAGE_080_MEM_TYPE(0x201AAA))) /* Message Object 85 Interrupt Pointer Register High */


#define CAN_MOIPR86H    (*(_PAGE_080_MEM_TYPE(0x201ACA))) /* Message Object 86 Interrupt Pointer Register High */


#define CAN_MOIPR87H    (*(_PAGE_080_MEM_TYPE(0x201AEA))) /* Message Object 87 Interrupt Pointer Register High */


#define CAN_MOIPR88H    (*(_PAGE_080_MEM_TYPE(0x201B0A))) /* Message Object 88 Interrupt Pointer Register High */


#define CAN_MOIPR89H    (*(_PAGE_080_MEM_TYPE(0x201B2A))) /* Message Object 89 Interrupt Pointer Register High */


#define CAN_MOIPR90H    (*(_PAGE_080_MEM_TYPE(0x201B4A))) /* Message Object 90 Interrupt Pointer Register High */


#define CAN_MOIPR91H    (*(_PAGE_080_MEM_TYPE(0x201B6A))) /* Message Object 91 Interrupt Pointer Register High */


#define CAN_MOIPR92H    (*(_PAGE_080_MEM_TYPE(0x201B8A))) /* Message Object 92 Interrupt Pointer Register High */


#define CAN_MOIPR93H    (*(_PAGE_080_MEM_TYPE(0x201BAA))) /* Message Object 93 Interrupt Pointer Register High */


#define CAN_MOIPR94H    (*(_PAGE_080_MEM_TYPE(0x201BCA))) /* Message Object 94 Interrupt Pointer Register High */


#define CAN_MOIPR95H    (*(_PAGE_080_MEM_TYPE(0x201BEA))) /* Message Object 95 Interrupt Pointer Register High */


#define CAN_MOIPR96H    (*(_PAGE_080_MEM_TYPE(0x201C0A))) /* Message Object 96 Interrupt Pointer Register High */


#define CAN_MOIPR97H    (*(_PAGE_080_MEM_TYPE(0x201C2A))) /* Message Object 97 Interrupt Pointer Register High */


#define CAN_MOIPR98H    (*(_PAGE_080_MEM_TYPE(0x201C4A))) /* Message Object 98 Interrupt Pointer Register High */


#define CAN_MOIPR99H    (*(_PAGE_080_MEM_TYPE(0x201C6A))) /* Message Object 99 Interrupt Pointer Register High */


#define CAN_MOIPR100H   (*(_PAGE_080_MEM_TYPE(0x201C8A))) /* Message Object 100 Interrupt Pointer Register High */


#define CAN_MOIPR101H   (*(_PAGE_080_MEM_TYPE(0x201CAA))) /* Message Object 101 Interrupt Pointer Register High */


#define CAN_MOIPR102H   (*(_PAGE_080_MEM_TYPE(0x201CCA))) /* Message Object 102 Interrupt Pointer Register High */


#define CAN_MOIPR103H   (*(_PAGE_080_MEM_TYPE(0x201CEA))) /* Message Object 103 Interrupt Pointer Register High */


#define CAN_MOIPR104H   (*(_PAGE_080_MEM_TYPE(0x201D0A))) /* Message Object 104 Interrupt Pointer Register High */


#define CAN_MOIPR105H   (*(_PAGE_080_MEM_TYPE(0x201D2A))) /* Message Object 105 Interrupt Pointer Register High */


#define CAN_MOIPR106H   (*(_PAGE_080_MEM_TYPE(0x201D4A))) /* Message Object 106 Interrupt Pointer Register High */


#define CAN_MOIPR107H   (*(_PAGE_080_MEM_TYPE(0x201D6A))) /* Message Object 107 Interrupt Pointer Register High */


#define CAN_MOIPR108H   (*(_PAGE_080_MEM_TYPE(0x201D8A))) /* Message Object 108 Interrupt Pointer Register High */


#define CAN_MOIPR109H   (*(_PAGE_080_MEM_TYPE(0x201DAA))) /* Message Object 109 Interrupt Pointer Register High */


#define CAN_MOIPR110H   (*(_PAGE_080_MEM_TYPE(0x201DCA))) /* Message Object 110 Interrupt Pointer Register High */


#define CAN_MOIPR111H   (*(_PAGE_080_MEM_TYPE(0x201DEA))) /* Message Object 111 Interrupt Pointer Register High */


#define CAN_MOIPR112H   (*(_PAGE_080_MEM_TYPE(0x201E0A))) /* Message Object 112 Interrupt Pointer Register High */


#define CAN_MOIPR113H   (*(_PAGE_080_MEM_TYPE(0x201E2A))) /* Message Object 113 Interrupt Pointer Register High */


#define CAN_MOIPR114H   (*(_PAGE_080_MEM_TYPE(0x201E4A))) /* Message Object 114 Interrupt Pointer Register High */


#define CAN_MOIPR115H   (*(_PAGE_080_MEM_TYPE(0x201E6A))) /* Message Object 115 Interrupt Pointer Register High */


#define CAN_MOIPR116H   (*(_PAGE_080_MEM_TYPE(0x201E8A))) /* Message Object 116 Interrupt Pointer Register High */


#define CAN_MOIPR117H   (*(_PAGE_080_MEM_TYPE(0x201EAA))) /* Message Object 117 Interrupt Pointer Register High */


#define CAN_MOIPR118H   (*(_PAGE_080_MEM_TYPE(0x201ECA))) /* Message Object 118 Interrupt Pointer Register High */


#define CAN_MOIPR119H   (*(_PAGE_080_MEM_TYPE(0x201EEA))) /* Message Object 119 Interrupt Pointer Register High */


#define CAN_MOIPR120H   (*(_PAGE_080_MEM_TYPE(0x201F0A))) /* Message Object 120 Interrupt Pointer Register High */


#define CAN_MOIPR121H   (*(_PAGE_080_MEM_TYPE(0x201F2A))) /* Message Object 121 Interrupt Pointer Register High */


#define CAN_MOIPR122H   (*(_PAGE_080_MEM_TYPE(0x201F4A))) /* Message Object 122 Interrupt Pointer Register High */


#define CAN_MOIPR123H   (*(_PAGE_080_MEM_TYPE(0x201F6A))) /* Message Object 123 Interrupt Pointer Register High */


#define CAN_MOIPR124H   (*(_PAGE_080_MEM_TYPE(0x201F8A))) /* Message Object 124 Interrupt Pointer Register High */


#define CAN_MOIPR125H   (*(_PAGE_080_MEM_TYPE(0x201FAA))) /* Message Object 125 Interrupt Pointer Register High */


#define CAN_MOIPR126H   (*(_PAGE_080_MEM_TYPE(0x201FCA))) /* Message Object 126 Interrupt Pointer Register High */


#define CAN_MOIPR127H   (*(_PAGE_080_MEM_TYPE(0x201FEA))) /* Message Object 127 Interrupt Pointer Register High */


#define CAN_MOIPR128H   (*(_PAGE_080_MEM_TYPE(0x20200A))) /* Message Object 128 Interrupt Pointer Register High */


#define CAN_MOIPR129H   (*(_PAGE_080_MEM_TYPE(0x20202A))) /* Message Object 129 Interrupt Pointer Register High */


#define CAN_MOIPR130H   (*(_PAGE_080_MEM_TYPE(0x20204A))) /* Message Object 130 Interrupt Pointer Register High */


#define CAN_MOIPR131H   (*(_PAGE_080_MEM_TYPE(0x20206A))) /* Message Object 131 Interrupt Pointer Register High */


#define CAN_MOIPR132H   (*(_PAGE_080_MEM_TYPE(0x20208A))) /* Message Object 132 Interrupt Pointer Register High */


#define CAN_MOIPR133H   (*(_PAGE_080_MEM_TYPE(0x2020AA))) /* Message Object 133 Interrupt Pointer Register High */


#define CAN_MOIPR134H   (*(_PAGE_080_MEM_TYPE(0x2020CA))) /* Message Object 134 Interrupt Pointer Register High */


#define CAN_MOIPR135H   (*(_PAGE_080_MEM_TYPE(0x2020EA))) /* Message Object 135 Interrupt Pointer Register High */


#define CAN_MOIPR136H   (*(_PAGE_080_MEM_TYPE(0x20210A))) /* Message Object 136 Interrupt Pointer Register High */


#define CAN_MOIPR137H   (*(_PAGE_080_MEM_TYPE(0x20212A))) /* Message Object 137 Interrupt Pointer Register High */


#define CAN_MOIPR138H   (*(_PAGE_080_MEM_TYPE(0x20214A))) /* Message Object 138 Interrupt Pointer Register High */


#define CAN_MOIPR139H   (*(_PAGE_080_MEM_TYPE(0x20216A))) /* Message Object 139 Interrupt Pointer Register High */


#define CAN_MOIPR140H   (*(_PAGE_080_MEM_TYPE(0x20218A))) /* Message Object 140 Interrupt Pointer Register High */


#define CAN_MOIPR141H   (*(_PAGE_080_MEM_TYPE(0x2021AA))) /* Message Object 141 Interrupt Pointer Register High */


#define CAN_MOIPR142H   (*(_PAGE_080_MEM_TYPE(0x2021CA))) /* Message Object 142 Interrupt Pointer Register High */


#define CAN_MOIPR143H   (*(_PAGE_080_MEM_TYPE(0x2021EA))) /* Message Object 143 Interrupt Pointer Register High */


#define CAN_MOIPR144H   (*(_PAGE_080_MEM_TYPE(0x20220A))) /* Message Object 144 Interrupt Pointer Register High */


#define CAN_MOIPR145H   (*(_PAGE_080_MEM_TYPE(0x20222A))) /* Message Object 145 Interrupt Pointer Register High */


#define CAN_MOIPR146H   (*(_PAGE_080_MEM_TYPE(0x20224A))) /* Message Object 146 Interrupt Pointer Register High */


#define CAN_MOIPR147H   (*(_PAGE_080_MEM_TYPE(0x20226A))) /* Message Object 147 Interrupt Pointer Register High */


#define CAN_MOIPR148H   (*(_PAGE_080_MEM_TYPE(0x20228A))) /* Message Object 148 Interrupt Pointer Register High */


#define CAN_MOIPR149H   (*(_PAGE_080_MEM_TYPE(0x2022AA))) /* Message Object 149 Interrupt Pointer Register High */


#define CAN_MOIPR150H   (*(_PAGE_080_MEM_TYPE(0x2022CA))) /* Message Object 150 Interrupt Pointer Register High */


#define CAN_MOIPR151H   (*(_PAGE_080_MEM_TYPE(0x2022EA))) /* Message Object 151 Interrupt Pointer Register High */


#define CAN_MOIPR152H   (*(_PAGE_080_MEM_TYPE(0x20230A))) /* Message Object 152 Interrupt Pointer Register High */


#define CAN_MOIPR153H   (*(_PAGE_080_MEM_TYPE(0x20232A))) /* Message Object 153 Interrupt Pointer Register High */


#define CAN_MOIPR154H   (*(_PAGE_080_MEM_TYPE(0x20234A))) /* Message Object 154 Interrupt Pointer Register High */


#define CAN_MOIPR155H   (*(_PAGE_080_MEM_TYPE(0x20236A))) /* Message Object 155 Interrupt Pointer Register High */


#define CAN_MOIPR156H   (*(_PAGE_080_MEM_TYPE(0x20238A))) /* Message Object 156 Interrupt Pointer Register High */


#define CAN_MOIPR157H   (*(_PAGE_080_MEM_TYPE(0x2023AA))) /* Message Object 157 Interrupt Pointer Register High */


#define CAN_MOIPR158H   (*(_PAGE_080_MEM_TYPE(0x2023CA))) /* Message Object 158 Interrupt Pointer Register High */


#define CAN_MOIPR159H   (*(_PAGE_080_MEM_TYPE(0x2023EA))) /* Message Object 159 Interrupt Pointer Register High */


#define CAN_MOIPR160H   (*(_PAGE_080_MEM_TYPE(0x20240A))) /* Message Object 160 Interrupt Pointer Register High */


#define CAN_MOIPR161H   (*(_PAGE_080_MEM_TYPE(0x20242A))) /* Message Object 161 Interrupt Pointer Register High */


#define CAN_MOIPR162H   (*(_PAGE_080_MEM_TYPE(0x20244A))) /* Message Object 162 Interrupt Pointer Register High */


#define CAN_MOIPR163H   (*(_PAGE_080_MEM_TYPE(0x20246A))) /* Message Object 163 Interrupt Pointer Register High */


#define CAN_MOIPR164H   (*(_PAGE_080_MEM_TYPE(0x20248A))) /* Message Object 164 Interrupt Pointer Register High */


#define CAN_MOIPR165H   (*(_PAGE_080_MEM_TYPE(0x2024AA))) /* Message Object 165 Interrupt Pointer Register High */


#define CAN_MOIPR166H   (*(_PAGE_080_MEM_TYPE(0x2024CA))) /* Message Object 166 Interrupt Pointer Register High */


#define CAN_MOIPR167H   (*(_PAGE_080_MEM_TYPE(0x2024EA))) /* Message Object 167 Interrupt Pointer Register High */


#define CAN_MOIPR168H   (*(_PAGE_080_MEM_TYPE(0x20250A))) /* Message Object 168 Interrupt Pointer Register High */


#define CAN_MOIPR169H   (*(_PAGE_080_MEM_TYPE(0x20252A))) /* Message Object 169 Interrupt Pointer Register High */


#define CAN_MOIPR170H   (*(_PAGE_080_MEM_TYPE(0x20254A))) /* Message Object 170 Interrupt Pointer Register High */


#define CAN_MOIPR171H   (*(_PAGE_080_MEM_TYPE(0x20256A))) /* Message Object 171 Interrupt Pointer Register High */


#define CAN_MOIPR172H   (*(_PAGE_080_MEM_TYPE(0x20258A))) /* Message Object 172 Interrupt Pointer Register High */


#define CAN_MOIPR173H   (*(_PAGE_080_MEM_TYPE(0x2025AA))) /* Message Object 173 Interrupt Pointer Register High */


#define CAN_MOIPR174H   (*(_PAGE_080_MEM_TYPE(0x2025CA))) /* Message Object 174 Interrupt Pointer Register High */


#define CAN_MOIPR175H   (*(_PAGE_080_MEM_TYPE(0x2025EA))) /* Message Object 175 Interrupt Pointer Register High */


#define CAN_MOIPR176H   (*(_PAGE_080_MEM_TYPE(0x20260A))) /* Message Object 176 Interrupt Pointer Register High */


#define CAN_MOIPR177H   (*(_PAGE_080_MEM_TYPE(0x20262A))) /* Message Object 177 Interrupt Pointer Register High */


#define CAN_MOIPR178H   (*(_PAGE_080_MEM_TYPE(0x20264A))) /* Message Object 178 Interrupt Pointer Register High */


#define CAN_MOIPR179H   (*(_PAGE_080_MEM_TYPE(0x20266A))) /* Message Object 179 Interrupt Pointer Register High */


#define CAN_MOIPR180H   (*(_PAGE_080_MEM_TYPE(0x20268A))) /* Message Object 180 Interrupt Pointer Register High */


#define CAN_MOIPR181H   (*(_PAGE_080_MEM_TYPE(0x2026AA))) /* Message Object 181 Interrupt Pointer Register High */


#define CAN_MOIPR182H   (*(_PAGE_080_MEM_TYPE(0x2026CA))) /* Message Object 182 Interrupt Pointer Register High */


#define CAN_MOIPR183H   (*(_PAGE_080_MEM_TYPE(0x2026EA))) /* Message Object 183 Interrupt Pointer Register High */


#define CAN_MOIPR184H   (*(_PAGE_080_MEM_TYPE(0x20270A))) /* Message Object 184 Interrupt Pointer Register High */


#define CAN_MOIPR185H   (*(_PAGE_080_MEM_TYPE(0x20272A))) /* Message Object 185 Interrupt Pointer Register High */


#define CAN_MOIPR186H   (*(_PAGE_080_MEM_TYPE(0x20274A))) /* Message Object 186 Interrupt Pointer Register High */


#define CAN_MOIPR187H   (*(_PAGE_080_MEM_TYPE(0x20276A))) /* Message Object 187 Interrupt Pointer Register High */


#define CAN_MOIPR188H   (*(_PAGE_080_MEM_TYPE(0x20278A))) /* Message Object 188 Interrupt Pointer Register High */


#define CAN_MOIPR189H   (*(_PAGE_080_MEM_TYPE(0x2027AA))) /* Message Object 189 Interrupt Pointer Register High */


#define CAN_MOIPR190H   (*(_PAGE_080_MEM_TYPE(0x2027CA))) /* Message Object 190 Interrupt Pointer Register High */


#define CAN_MOIPR191H   (*(_PAGE_080_MEM_TYPE(0x2027EA))) /* Message Object 191 Interrupt Pointer Register High */


#define CAN_MOIPR192H   (*(_PAGE_080_MEM_TYPE(0x20280A))) /* Message Object 192 Interrupt Pointer Register High */


#define CAN_MOIPR193H   (*(_PAGE_080_MEM_TYPE(0x20282A))) /* Message Object 193 Interrupt Pointer Register High */


#define CAN_MOIPR194H   (*(_PAGE_080_MEM_TYPE(0x20284A))) /* Message Object 194 Interrupt Pointer Register High */


#define CAN_MOIPR195H   (*(_PAGE_080_MEM_TYPE(0x20286A))) /* Message Object 195 Interrupt Pointer Register High */


#define CAN_MOIPR196H   (*(_PAGE_080_MEM_TYPE(0x20288A))) /* Message Object 196 Interrupt Pointer Register High */


#define CAN_MOIPR197H   (*(_PAGE_080_MEM_TYPE(0x2028AA))) /* Message Object 197 Interrupt Pointer Register High */


#define CAN_MOIPR198H   (*(_PAGE_080_MEM_TYPE(0x2028CA))) /* Message Object 198 Interrupt Pointer Register High */


#define CAN_MOIPR199H   (*(_PAGE_080_MEM_TYPE(0x2028EA))) /* Message Object 199 Interrupt Pointer Register High */


#define CAN_MOIPR200H   (*(_PAGE_080_MEM_TYPE(0x20290A))) /* Message Object 200 Interrupt Pointer Register High */


#define CAN_MOIPR201H   (*(_PAGE_080_MEM_TYPE(0x20292A))) /* Message Object 201 Interrupt Pointer Register High */


#define CAN_MOIPR202H   (*(_PAGE_080_MEM_TYPE(0x20294A))) /* Message Object 202 Interrupt Pointer Register High */


#define CAN_MOIPR203H   (*(_PAGE_080_MEM_TYPE(0x20296A))) /* Message Object 203 Interrupt Pointer Register High */


#define CAN_MOIPR204H   (*(_PAGE_080_MEM_TYPE(0x20298A))) /* Message Object 204 Interrupt Pointer Register High */


#define CAN_MOIPR205H   (*(_PAGE_080_MEM_TYPE(0x2029AA))) /* Message Object 205 Interrupt Pointer Register High */


#define CAN_MOIPR206H   (*(_PAGE_080_MEM_TYPE(0x2029CA))) /* Message Object 206 Interrupt Pointer Register High */


#define CAN_MOIPR207H   (*(_PAGE_080_MEM_TYPE(0x2029EA))) /* Message Object 207 Interrupt Pointer Register High */


#define CAN_MOIPR208H   (*(_PAGE_080_MEM_TYPE(0x202A0A))) /* Message Object 208 Interrupt Pointer Register High */


#define CAN_MOIPR209H   (*(_PAGE_080_MEM_TYPE(0x202A2A))) /* Message Object 209 Interrupt Pointer Register High */


#define CAN_MOIPR210H   (*(_PAGE_080_MEM_TYPE(0x202A4A))) /* Message Object 210 Interrupt Pointer Register High */


#define CAN_MOIPR211H   (*(_PAGE_080_MEM_TYPE(0x202A6A))) /* Message Object 211 Interrupt Pointer Register High */


#define CAN_MOIPR212H   (*(_PAGE_080_MEM_TYPE(0x202A8A))) /* Message Object 212 Interrupt Pointer Register High */


#define CAN_MOIPR213H   (*(_PAGE_080_MEM_TYPE(0x202AAA))) /* Message Object 213 Interrupt Pointer Register High */


#define CAN_MOIPR214H   (*(_PAGE_080_MEM_TYPE(0x202ACA))) /* Message Object 214 Interrupt Pointer Register High */


#define CAN_MOIPR215H   (*(_PAGE_080_MEM_TYPE(0x202AEA))) /* Message Object 215 Interrupt Pointer Register High */


#define CAN_MOIPR216H   (*(_PAGE_080_MEM_TYPE(0x202B0A))) /* Message Object 216 Interrupt Pointer Register High */


#define CAN_MOIPR217H   (*(_PAGE_080_MEM_TYPE(0x202B2A))) /* Message Object 217 Interrupt Pointer Register High */


#define CAN_MOIPR218H   (*(_PAGE_080_MEM_TYPE(0x202B4A))) /* Message Object 218 Interrupt Pointer Register High */


#define CAN_MOIPR219H   (*(_PAGE_080_MEM_TYPE(0x202B6A))) /* Message Object 219 Interrupt Pointer Register High */


#define CAN_MOIPR220H   (*(_PAGE_080_MEM_TYPE(0x202B8A))) /* Message Object 220 Interrupt Pointer Register High */


#define CAN_MOIPR221H   (*(_PAGE_080_MEM_TYPE(0x202BAA))) /* Message Object 221 Interrupt Pointer Register High */


#define CAN_MOIPR222H   (*(_PAGE_080_MEM_TYPE(0x202BCA))) /* Message Object 222 Interrupt Pointer Register High */


#define CAN_MOIPR223H   (*(_PAGE_080_MEM_TYPE(0x202BEA))) /* Message Object 223 Interrupt Pointer Register High */


#define CAN_MOIPR224H   (*(_PAGE_080_MEM_TYPE(0x202C0A))) /* Message Object 224 Interrupt Pointer Register High */


#define CAN_MOIPR225H   (*(_PAGE_080_MEM_TYPE(0x202C2A))) /* Message Object 225 Interrupt Pointer Register High */


#define CAN_MOIPR226H   (*(_PAGE_080_MEM_TYPE(0x202C4A))) /* Message Object 226 Interrupt Pointer Register High */


#define CAN_MOIPR227H   (*(_PAGE_080_MEM_TYPE(0x202C6A))) /* Message Object 227 Interrupt Pointer Register High */


#define CAN_MOIPR228H   (*(_PAGE_080_MEM_TYPE(0x202C8A))) /* Message Object 228 Interrupt Pointer Register High */


#define CAN_MOIPR229H   (*(_PAGE_080_MEM_TYPE(0x202CAA))) /* Message Object 229 Interrupt Pointer Register High */


#define CAN_MOIPR230H   (*(_PAGE_080_MEM_TYPE(0x202CCA))) /* Message Object 230 Interrupt Pointer Register High */


#define CAN_MOIPR231H   (*(_PAGE_080_MEM_TYPE(0x202CEA))) /* Message Object 231 Interrupt Pointer Register High */


#define CAN_MOIPR232H   (*(_PAGE_080_MEM_TYPE(0x202D0A))) /* Message Object 232 Interrupt Pointer Register High */


#define CAN_MOIPR233H   (*(_PAGE_080_MEM_TYPE(0x202D2A))) /* Message Object 233 Interrupt Pointer Register High */


#define CAN_MOIPR234H   (*(_PAGE_080_MEM_TYPE(0x202D4A))) /* Message Object 234 Interrupt Pointer Register High */


#define CAN_MOIPR235H   (*(_PAGE_080_MEM_TYPE(0x202D6A))) /* Message Object 235 Interrupt Pointer Register High */


#define CAN_MOIPR236H   (*(_PAGE_080_MEM_TYPE(0x202D8A))) /* Message Object 236 Interrupt Pointer Register High */


#define CAN_MOIPR237H   (*(_PAGE_080_MEM_TYPE(0x202DAA))) /* Message Object 237 Interrupt Pointer Register High */


#define CAN_MOIPR238H   (*(_PAGE_080_MEM_TYPE(0x202DCA))) /* Message Object 238 Interrupt Pointer Register High */


#define CAN_MOIPR239H   (*(_PAGE_080_MEM_TYPE(0x202DEA))) /* Message Object 239 Interrupt Pointer Register High */


#define CAN_MOIPR240H   (*(_PAGE_080_MEM_TYPE(0x202E0A))) /* Message Object 240 Interrupt Pointer Register High */


#define CAN_MOIPR241H   (*(_PAGE_080_MEM_TYPE(0x202E2A))) /* Message Object 241 Interrupt Pointer Register High */


#define CAN_MOIPR242H   (*(_PAGE_080_MEM_TYPE(0x202E4A))) /* Message Object 242 Interrupt Pointer Register High */


#define CAN_MOIPR243H   (*(_PAGE_080_MEM_TYPE(0x202E6A))) /* Message Object 243 Interrupt Pointer Register High */


#define CAN_MOIPR244H   (*(_PAGE_080_MEM_TYPE(0x202E8A))) /* Message Object 244 Interrupt Pointer Register High */


#define CAN_MOIPR245H   (*(_PAGE_080_MEM_TYPE(0x202EAA))) /* Message Object 245 Interrupt Pointer Register High */


#define CAN_MOIPR246H   (*(_PAGE_080_MEM_TYPE(0x202ECA))) /* Message Object 246 Interrupt Pointer Register High */


#define CAN_MOIPR247H   (*(_PAGE_080_MEM_TYPE(0x202EEA))) /* Message Object 247 Interrupt Pointer Register High */


#define CAN_MOIPR248H   (*(_PAGE_080_MEM_TYPE(0x202F0A))) /* Message Object 248 Interrupt Pointer Register High */


#define CAN_MOIPR249H   (*(_PAGE_080_MEM_TYPE(0x202F2A))) /* Message Object 249 Interrupt Pointer Register High */


#define CAN_MOIPR250H   (*(_PAGE_080_MEM_TYPE(0x202F4A))) /* Message Object 250 Interrupt Pointer Register High */


#define CAN_MOIPR251H   (*(_PAGE_080_MEM_TYPE(0x202F6A))) /* Message Object 251 Interrupt Pointer Register High */


#define CAN_MOIPR252H   (*(_PAGE_080_MEM_TYPE(0x202F8A))) /* Message Object 252 Interrupt Pointer Register High */


#define CAN_MOIPR253H   (*(_PAGE_080_MEM_TYPE(0x202FAA))) /* Message Object 253 Interrupt Pointer Register High */


#define CAN_MOIPR254H   (*(_PAGE_080_MEM_TYPE(0x202FCA))) /* Message Object 254 Interrupt Pointer Register High */


#define CAN_MOIPR255H   (*(_PAGE_080_MEM_TYPE(0x202FEA))) /* Message Object 255 Interrupt Pointer Register High */


#define CAN_MOIPR0L     (*(_PAGE_080_MEM_TYPE(0x201008))) /* Message Object 0 Interrupt Pointer Register Low */


#define CAN_MOIPR1L     (*(_PAGE_080_MEM_TYPE(0x201028))) /* Message Object 1 Interrupt Pointer Register Low */


#define CAN_MOIPR2L     (*(_PAGE_080_MEM_TYPE(0x201048))) /* Message Object 2 Interrupt Pointer Register Low */


#define CAN_MOIPR3L     (*(_PAGE_080_MEM_TYPE(0x201068))) /* Message Object 3 Interrupt Pointer Register Low */


#define CAN_MOIPR4L     (*(_PAGE_080_MEM_TYPE(0x201088))) /* Message Object 4 Interrupt Pointer Register Low */


#define CAN_MOIPR5L     (*(_PAGE_080_MEM_TYPE(0x2010A8))) /* Message Object 5 Interrupt Pointer Register Low */


#define CAN_MOIPR6L     (*(_PAGE_080_MEM_TYPE(0x2010C8))) /* Message Object 6 Interrupt Pointer Register Low */


#define CAN_MOIPR7L     (*(_PAGE_080_MEM_TYPE(0x2010E8))) /* Message Object 7 Interrupt Pointer Register Low */


#define CAN_MOIPR8L     (*(_PAGE_080_MEM_TYPE(0x201108))) /* Message Object 8 Interrupt Pointer Register Low */


#define CAN_MOIPR9L     (*(_PAGE_080_MEM_TYPE(0x201128))) /* Message Object 9 Interrupt Pointer Register Low */


#define CAN_MOIPR10L    (*(_PAGE_080_MEM_TYPE(0x201148))) /* Message Object 10 Interrupt Pointer Register Low */


#define CAN_MOIPR11L    (*(_PAGE_080_MEM_TYPE(0x201168))) /* Message Object 11 Interrupt Pointer Register Low */


#define CAN_MOIPR12L    (*(_PAGE_080_MEM_TYPE(0x201188))) /* Message Object 12 Interrupt Pointer Register Low */


#define CAN_MOIPR13L    (*(_PAGE_080_MEM_TYPE(0x2011A8))) /* Message Object 13 Interrupt Pointer Register Low */


#define CAN_MOIPR14L    (*(_PAGE_080_MEM_TYPE(0x2011C8))) /* Message Object 14 Interrupt Pointer Register Low */


#define CAN_MOIPR15L    (*(_PAGE_080_MEM_TYPE(0x2011E8))) /* Message Object 15 Interrupt Pointer Register Low */


#define CAN_MOIPR16L    (*(_PAGE_080_MEM_TYPE(0x201208))) /* Message Object 16 Interrupt Pointer Register Low */


#define CAN_MOIPR17L    (*(_PAGE_080_MEM_TYPE(0x201228))) /* Message Object 17 Interrupt Pointer Register Low */


#define CAN_MOIPR18L    (*(_PAGE_080_MEM_TYPE(0x201248))) /* Message Object 18 Interrupt Pointer Register Low */


#define CAN_MOIPR19L    (*(_PAGE_080_MEM_TYPE(0x201268))) /* Message Object 19 Interrupt Pointer Register Low */


#define CAN_MOIPR20L    (*(_PAGE_080_MEM_TYPE(0x201288))) /* Message Object 20 Interrupt Pointer Register Low */


#define CAN_MOIPR21L    (*(_PAGE_080_MEM_TYPE(0x2012A8))) /* Message Object 21 Interrupt Pointer Register Low */


#define CAN_MOIPR22L    (*(_PAGE_080_MEM_TYPE(0x2012C8))) /* Message Object 22 Interrupt Pointer Register Low */


#define CAN_MOIPR23L    (*(_PAGE_080_MEM_TYPE(0x2012E8))) /* Message Object 23 Interrupt Pointer Register Low */


#define CAN_MOIPR24L    (*(_PAGE_080_MEM_TYPE(0x201308))) /* Message Object 24 Interrupt Pointer Register Low */


#define CAN_MOIPR25L    (*(_PAGE_080_MEM_TYPE(0x201328))) /* Message Object 25 Interrupt Pointer Register Low */


#define CAN_MOIPR26L    (*(_PAGE_080_MEM_TYPE(0x201348))) /* Message Object 26 Interrupt Pointer Register Low */


#define CAN_MOIPR27L    (*(_PAGE_080_MEM_TYPE(0x201368))) /* Message Object 27 Interrupt Pointer Register Low */


#define CAN_MOIPR28L    (*(_PAGE_080_MEM_TYPE(0x201388))) /* Message Object 28 Interrupt Pointer Register Low */


#define CAN_MOIPR29L    (*(_PAGE_080_MEM_TYPE(0x2013A8))) /* Message Object 29 Interrupt Pointer Register Low */


#define CAN_MOIPR30L    (*(_PAGE_080_MEM_TYPE(0x2013C8))) /* Message Object 30 Interrupt Pointer Register Low */


#define CAN_MOIPR31L    (*(_PAGE_080_MEM_TYPE(0x2013E8))) /* Message Object 31 Interrupt Pointer Register Low */


#define CAN_MOIPR32L    (*(_PAGE_080_MEM_TYPE(0x201408))) /* Message Object 32 Interrupt Pointer Register Low */


#define CAN_MOIPR33L    (*(_PAGE_080_MEM_TYPE(0x201428))) /* Message Object 33 Interrupt Pointer Register Low */


#define CAN_MOIPR34L    (*(_PAGE_080_MEM_TYPE(0x201448))) /* Message Object 34 Interrupt Pointer Register Low */


#define CAN_MOIPR35L    (*(_PAGE_080_MEM_TYPE(0x201468))) /* Message Object 35 Interrupt Pointer Register Low */


#define CAN_MOIPR36L    (*(_PAGE_080_MEM_TYPE(0x201488))) /* Message Object 36 Interrupt Pointer Register Low */


#define CAN_MOIPR37L    (*(_PAGE_080_MEM_TYPE(0x2014A8))) /* Message Object 37 Interrupt Pointer Register Low */


#define CAN_MOIPR38L    (*(_PAGE_080_MEM_TYPE(0x2014C8))) /* Message Object 38 Interrupt Pointer Register Low */


#define CAN_MOIPR39L    (*(_PAGE_080_MEM_TYPE(0x2014E8))) /* Message Object 39 Interrupt Pointer Register Low */


#define CAN_MOIPR40L    (*(_PAGE_080_MEM_TYPE(0x201508))) /* Message Object 40 Interrupt Pointer Register Low */


#define CAN_MOIPR41L    (*(_PAGE_080_MEM_TYPE(0x201528))) /* Message Object 41 Interrupt Pointer Register Low */


#define CAN_MOIPR42L    (*(_PAGE_080_MEM_TYPE(0x201548))) /* Message Object 42 Interrupt Pointer Register Low */


#define CAN_MOIPR43L    (*(_PAGE_080_MEM_TYPE(0x201568))) /* Message Object 43 Interrupt Pointer Register Low */


#define CAN_MOIPR44L    (*(_PAGE_080_MEM_TYPE(0x201588))) /* Message Object 44 Interrupt Pointer Register Low */


#define CAN_MOIPR45L    (*(_PAGE_080_MEM_TYPE(0x2015A8))) /* Message Object 45 Interrupt Pointer Register Low */


#define CAN_MOIPR46L    (*(_PAGE_080_MEM_TYPE(0x2015C8))) /* Message Object 46 Interrupt Pointer Register Low */


#define CAN_MOIPR47L    (*(_PAGE_080_MEM_TYPE(0x2015E8))) /* Message Object 47 Interrupt Pointer Register Low */


#define CAN_MOIPR48L    (*(_PAGE_080_MEM_TYPE(0x201608))) /* Message Object 48 Interrupt Pointer Register Low */


#define CAN_MOIPR49L    (*(_PAGE_080_MEM_TYPE(0x201628))) /* Message Object 49 Interrupt Pointer Register Low */


#define CAN_MOIPR50L    (*(_PAGE_080_MEM_TYPE(0x201648))) /* Message Object 50 Interrupt Pointer Register Low */


#define CAN_MOIPR51L    (*(_PAGE_080_MEM_TYPE(0x201668))) /* Message Object 51 Interrupt Pointer Register Low */


#define CAN_MOIPR52L    (*(_PAGE_080_MEM_TYPE(0x201688))) /* Message Object 52 Interrupt Pointer Register Low */


#define CAN_MOIPR53L    (*(_PAGE_080_MEM_TYPE(0x2016A8))) /* Message Object 53 Interrupt Pointer Register Low */


#define CAN_MOIPR54L    (*(_PAGE_080_MEM_TYPE(0x2016C8))) /* Message Object 54 Interrupt Pointer Register Low */


#define CAN_MOIPR55L    (*(_PAGE_080_MEM_TYPE(0x2016E8))) /* Message Object 55 Interrupt Pointer Register Low */


#define CAN_MOIPR56L    (*(_PAGE_080_MEM_TYPE(0x201708))) /* Message Object 56 Interrupt Pointer Register Low */


#define CAN_MOIPR57L    (*(_PAGE_080_MEM_TYPE(0x201728))) /* Message Object 57 Interrupt Pointer Register Low */


#define CAN_MOIPR58L    (*(_PAGE_080_MEM_TYPE(0x201748))) /* Message Object 58 Interrupt Pointer Register Low */


#define CAN_MOIPR59L    (*(_PAGE_080_MEM_TYPE(0x201768))) /* Message Object 59 Interrupt Pointer Register Low */


#define CAN_MOIPR60L    (*(_PAGE_080_MEM_TYPE(0x201788))) /* Message Object 60 Interrupt Pointer Register Low */


#define CAN_MOIPR61L    (*(_PAGE_080_MEM_TYPE(0x2017A8))) /* Message Object 61 Interrupt Pointer Register Low */


#define CAN_MOIPR62L    (*(_PAGE_080_MEM_TYPE(0x2017C8))) /* Message Object 62 Interrupt Pointer Register Low */


#define CAN_MOIPR63L    (*(_PAGE_080_MEM_TYPE(0x2017E8))) /* Message Object 63 Interrupt Pointer Register Low */


#define CAN_MOIPR64L    (*(_PAGE_080_MEM_TYPE(0x201808))) /* Message Object 64 Interrupt Pointer Register Low */


#define CAN_MOIPR65L    (*(_PAGE_080_MEM_TYPE(0x201828))) /* Message Object 65 Interrupt Pointer Register Low */


#define CAN_MOIPR66L    (*(_PAGE_080_MEM_TYPE(0x201848))) /* Message Object 66 Interrupt Pointer Register Low */


#define CAN_MOIPR67L    (*(_PAGE_080_MEM_TYPE(0x201868))) /* Message Object 67 Interrupt Pointer Register Low */


#define CAN_MOIPR68L    (*(_PAGE_080_MEM_TYPE(0x201888))) /* Message Object 68 Interrupt Pointer Register Low */


#define CAN_MOIPR69L    (*(_PAGE_080_MEM_TYPE(0x2018A8))) /* Message Object 69 Interrupt Pointer Register Low */


#define CAN_MOIPR70L    (*(_PAGE_080_MEM_TYPE(0x2018C8))) /* Message Object 70 Interrupt Pointer Register Low */


#define CAN_MOIPR71L    (*(_PAGE_080_MEM_TYPE(0x2018E8))) /* Message Object 71 Interrupt Pointer Register Low */


#define CAN_MOIPR72L    (*(_PAGE_080_MEM_TYPE(0x201908))) /* Message Object 72 Interrupt Pointer Register Low */


#define CAN_MOIPR73L    (*(_PAGE_080_MEM_TYPE(0x201928))) /* Message Object 73 Interrupt Pointer Register Low */


#define CAN_MOIPR74L    (*(_PAGE_080_MEM_TYPE(0x201948))) /* Message Object 74 Interrupt Pointer Register Low */


#define CAN_MOIPR75L    (*(_PAGE_080_MEM_TYPE(0x201968))) /* Message Object 75 Interrupt Pointer Register Low */


#define CAN_MOIPR76L    (*(_PAGE_080_MEM_TYPE(0x201988))) /* Message Object 76 Interrupt Pointer Register Low */


#define CAN_MOIPR77L    (*(_PAGE_080_MEM_TYPE(0x2019A8))) /* Message Object 77 Interrupt Pointer Register Low */


#define CAN_MOIPR78L    (*(_PAGE_080_MEM_TYPE(0x2019C8))) /* Message Object 78 Interrupt Pointer Register Low */


#define CAN_MOIPR79L    (*(_PAGE_080_MEM_TYPE(0x2019E8))) /* Message Object 79 Interrupt Pointer Register Low */


#define CAN_MOIPR80L    (*(_PAGE_080_MEM_TYPE(0x201A08))) /* Message Object 80 Interrupt Pointer Register Low */


#define CAN_MOIPR81L    (*(_PAGE_080_MEM_TYPE(0x201A28))) /* Message Object 81 Interrupt Pointer Register Low */


#define CAN_MOIPR82L    (*(_PAGE_080_MEM_TYPE(0x201A48))) /* Message Object 82 Interrupt Pointer Register Low */


#define CAN_MOIPR83L    (*(_PAGE_080_MEM_TYPE(0x201A68))) /* Message Object 83 Interrupt Pointer Register Low */


#define CAN_MOIPR84L    (*(_PAGE_080_MEM_TYPE(0x201A88))) /* Message Object 84 Interrupt Pointer Register Low */


#define CAN_MOIPR85L    (*(_PAGE_080_MEM_TYPE(0x201AA8))) /* Message Object 85 Interrupt Pointer Register Low */


#define CAN_MOIPR86L    (*(_PAGE_080_MEM_TYPE(0x201AC8))) /* Message Object 86 Interrupt Pointer Register Low */


#define CAN_MOIPR87L    (*(_PAGE_080_MEM_TYPE(0x201AE8))) /* Message Object 87 Interrupt Pointer Register Low */


#define CAN_MOIPR88L    (*(_PAGE_080_MEM_TYPE(0x201B08))) /* Message Object 88 Interrupt Pointer Register Low */


#define CAN_MOIPR89L    (*(_PAGE_080_MEM_TYPE(0x201B28))) /* Message Object 89 Interrupt Pointer Register Low */


#define CAN_MOIPR90L    (*(_PAGE_080_MEM_TYPE(0x201B48))) /* Message Object 90 Interrupt Pointer Register Low */


#define CAN_MOIPR91L    (*(_PAGE_080_MEM_TYPE(0x201B68))) /* Message Object 91 Interrupt Pointer Register Low */


#define CAN_MOIPR92L    (*(_PAGE_080_MEM_TYPE(0x201B88))) /* Message Object 92 Interrupt Pointer Register Low */


#define CAN_MOIPR93L    (*(_PAGE_080_MEM_TYPE(0x201BA8))) /* Message Object 93 Interrupt Pointer Register Low */


#define CAN_MOIPR94L    (*(_PAGE_080_MEM_TYPE(0x201BC8))) /* Message Object 94 Interrupt Pointer Register Low */


#define CAN_MOIPR95L    (*(_PAGE_080_MEM_TYPE(0x201BE8))) /* Message Object 95 Interrupt Pointer Register Low */


#define CAN_MOIPR96L    (*(_PAGE_080_MEM_TYPE(0x201C08))) /* Message Object 96 Interrupt Pointer Register Low */


#define CAN_MOIPR97L    (*(_PAGE_080_MEM_TYPE(0x201C28))) /* Message Object 97 Interrupt Pointer Register Low */


#define CAN_MOIPR98L    (*(_PAGE_080_MEM_TYPE(0x201C48))) /* Message Object 98 Interrupt Pointer Register Low */


#define CAN_MOIPR99L    (*(_PAGE_080_MEM_TYPE(0x201C68))) /* Message Object 99 Interrupt Pointer Register Low */


#define CAN_MOIPR100L   (*(_PAGE_080_MEM_TYPE(0x201C88))) /* Message Object 100 Interrupt Pointer Register Low */


#define CAN_MOIPR101L   (*(_PAGE_080_MEM_TYPE(0x201CA8))) /* Message Object 101 Interrupt Pointer Register Low */


#define CAN_MOIPR102L   (*(_PAGE_080_MEM_TYPE(0x201CC8))) /* Message Object 102 Interrupt Pointer Register Low */


#define CAN_MOIPR103L   (*(_PAGE_080_MEM_TYPE(0x201CE8))) /* Message Object 103 Interrupt Pointer Register Low */


#define CAN_MOIPR104L   (*(_PAGE_080_MEM_TYPE(0x201D08))) /* Message Object 104 Interrupt Pointer Register Low */


#define CAN_MOIPR105L   (*(_PAGE_080_MEM_TYPE(0x201D28))) /* Message Object 105 Interrupt Pointer Register Low */


#define CAN_MOIPR106L   (*(_PAGE_080_MEM_TYPE(0x201D48))) /* Message Object 106 Interrupt Pointer Register Low */


#define CAN_MOIPR107L   (*(_PAGE_080_MEM_TYPE(0x201D68))) /* Message Object 107 Interrupt Pointer Register Low */


#define CAN_MOIPR108L   (*(_PAGE_080_MEM_TYPE(0x201D88))) /* Message Object 108 Interrupt Pointer Register Low */


#define CAN_MOIPR109L   (*(_PAGE_080_MEM_TYPE(0x201DA8))) /* Message Object 109 Interrupt Pointer Register Low */


#define CAN_MOIPR110L   (*(_PAGE_080_MEM_TYPE(0x201DC8))) /* Message Object 110 Interrupt Pointer Register Low */


#define CAN_MOIPR111L   (*(_PAGE_080_MEM_TYPE(0x201DE8))) /* Message Object 111 Interrupt Pointer Register Low */


#define CAN_MOIPR112L   (*(_PAGE_080_MEM_TYPE(0x201E08))) /* Message Object 112 Interrupt Pointer Register Low */


#define CAN_MOIPR113L   (*(_PAGE_080_MEM_TYPE(0x201E28))) /* Message Object 113 Interrupt Pointer Register Low */


#define CAN_MOIPR114L   (*(_PAGE_080_MEM_TYPE(0x201E48))) /* Message Object 114 Interrupt Pointer Register Low */


#define CAN_MOIPR115L   (*(_PAGE_080_MEM_TYPE(0x201E68))) /* Message Object 115 Interrupt Pointer Register Low */


#define CAN_MOIPR116L   (*(_PAGE_080_MEM_TYPE(0x201E88))) /* Message Object 116 Interrupt Pointer Register Low */


#define CAN_MOIPR117L   (*(_PAGE_080_MEM_TYPE(0x201EA8))) /* Message Object 117 Interrupt Pointer Register Low */


#define CAN_MOIPR118L   (*(_PAGE_080_MEM_TYPE(0x201EC8))) /* Message Object 118 Interrupt Pointer Register Low */


#define CAN_MOIPR119L   (*(_PAGE_080_MEM_TYPE(0x201EE8))) /* Message Object 119 Interrupt Pointer Register Low */


#define CAN_MOIPR120L   (*(_PAGE_080_MEM_TYPE(0x201F08))) /* Message Object 120 Interrupt Pointer Register Low */


#define CAN_MOIPR121L   (*(_PAGE_080_MEM_TYPE(0x201F28))) /* Message Object 121 Interrupt Pointer Register Low */


#define CAN_MOIPR122L   (*(_PAGE_080_MEM_TYPE(0x201F48))) /* Message Object 122 Interrupt Pointer Register Low */


#define CAN_MOIPR123L   (*(_PAGE_080_MEM_TYPE(0x201F68))) /* Message Object 123 Interrupt Pointer Register Low */


#define CAN_MOIPR124L   (*(_PAGE_080_MEM_TYPE(0x201F88))) /* Message Object 124 Interrupt Pointer Register Low */


#define CAN_MOIPR125L   (*(_PAGE_080_MEM_TYPE(0x201FA8))) /* Message Object 125 Interrupt Pointer Register Low */


#define CAN_MOIPR126L   (*(_PAGE_080_MEM_TYPE(0x201FC8))) /* Message Object 126 Interrupt Pointer Register Low */


#define CAN_MOIPR127L   (*(_PAGE_080_MEM_TYPE(0x201FE8))) /* Message Object 127 Interrupt Pointer Register Low */


#define CAN_MOIPR128L   (*(_PAGE_080_MEM_TYPE(0x202008))) /* Message Object 128 Interrupt Pointer Register Low */


#define CAN_MOIPR129L   (*(_PAGE_080_MEM_TYPE(0x202028))) /* Message Object 129 Interrupt Pointer Register Low */


#define CAN_MOIPR130L   (*(_PAGE_080_MEM_TYPE(0x202048))) /* Message Object 130 Interrupt Pointer Register Low */


#define CAN_MOIPR131L   (*(_PAGE_080_MEM_TYPE(0x202068))) /* Message Object 131 Interrupt Pointer Register Low */


#define CAN_MOIPR132L   (*(_PAGE_080_MEM_TYPE(0x202088))) /* Message Object 132 Interrupt Pointer Register Low */


#define CAN_MOIPR133L   (*(_PAGE_080_MEM_TYPE(0x2020A8))) /* Message Object 133 Interrupt Pointer Register Low */


#define CAN_MOIPR134L   (*(_PAGE_080_MEM_TYPE(0x2020C8))) /* Message Object 134 Interrupt Pointer Register Low */


#define CAN_MOIPR135L   (*(_PAGE_080_MEM_TYPE(0x2020E8))) /* Message Object 135 Interrupt Pointer Register Low */


#define CAN_MOIPR136L   (*(_PAGE_080_MEM_TYPE(0x202108))) /* Message Object 136 Interrupt Pointer Register Low */


#define CAN_MOIPR137L   (*(_PAGE_080_MEM_TYPE(0x202128))) /* Message Object 137 Interrupt Pointer Register Low */


#define CAN_MOIPR138L   (*(_PAGE_080_MEM_TYPE(0x202148))) /* Message Object 138 Interrupt Pointer Register Low */


#define CAN_MOIPR139L   (*(_PAGE_080_MEM_TYPE(0x202168))) /* Message Object 139 Interrupt Pointer Register Low */


#define CAN_MOIPR140L   (*(_PAGE_080_MEM_TYPE(0x202188))) /* Message Object 140 Interrupt Pointer Register Low */


#define CAN_MOIPR141L   (*(_PAGE_080_MEM_TYPE(0x2021A8))) /* Message Object 141 Interrupt Pointer Register Low */


#define CAN_MOIPR142L   (*(_PAGE_080_MEM_TYPE(0x2021C8))) /* Message Object 142 Interrupt Pointer Register Low */


#define CAN_MOIPR143L   (*(_PAGE_080_MEM_TYPE(0x2021E8))) /* Message Object 143 Interrupt Pointer Register Low */


#define CAN_MOIPR144L   (*(_PAGE_080_MEM_TYPE(0x202208))) /* Message Object 144 Interrupt Pointer Register Low */


#define CAN_MOIPR145L   (*(_PAGE_080_MEM_TYPE(0x202228))) /* Message Object 145 Interrupt Pointer Register Low */


#define CAN_MOIPR146L   (*(_PAGE_080_MEM_TYPE(0x202248))) /* Message Object 146 Interrupt Pointer Register Low */


#define CAN_MOIPR147L   (*(_PAGE_080_MEM_TYPE(0x202268))) /* Message Object 147 Interrupt Pointer Register Low */


#define CAN_MOIPR148L   (*(_PAGE_080_MEM_TYPE(0x202288))) /* Message Object 148 Interrupt Pointer Register Low */


#define CAN_MOIPR149L   (*(_PAGE_080_MEM_TYPE(0x2022A8))) /* Message Object 149 Interrupt Pointer Register Low */


#define CAN_MOIPR150L   (*(_PAGE_080_MEM_TYPE(0x2022C8))) /* Message Object 150 Interrupt Pointer Register Low */


#define CAN_MOIPR151L   (*(_PAGE_080_MEM_TYPE(0x2022E8))) /* Message Object 151 Interrupt Pointer Register Low */


#define CAN_MOIPR152L   (*(_PAGE_080_MEM_TYPE(0x202308))) /* Message Object 152 Interrupt Pointer Register Low */


#define CAN_MOIPR153L   (*(_PAGE_080_MEM_TYPE(0x202328))) /* Message Object 153 Interrupt Pointer Register Low */


#define CAN_MOIPR154L   (*(_PAGE_080_MEM_TYPE(0x202348))) /* Message Object 154 Interrupt Pointer Register Low */


#define CAN_MOIPR155L   (*(_PAGE_080_MEM_TYPE(0x202368))) /* Message Object 155 Interrupt Pointer Register Low */


#define CAN_MOIPR156L   (*(_PAGE_080_MEM_TYPE(0x202388))) /* Message Object 156 Interrupt Pointer Register Low */


#define CAN_MOIPR157L   (*(_PAGE_080_MEM_TYPE(0x2023A8))) /* Message Object 157 Interrupt Pointer Register Low */


#define CAN_MOIPR158L   (*(_PAGE_080_MEM_TYPE(0x2023C8))) /* Message Object 158 Interrupt Pointer Register Low */


#define CAN_MOIPR159L   (*(_PAGE_080_MEM_TYPE(0x2023E8))) /* Message Object 159 Interrupt Pointer Register Low */


#define CAN_MOIPR160L   (*(_PAGE_080_MEM_TYPE(0x202408))) /* Message Object 160 Interrupt Pointer Register Low */


#define CAN_MOIPR161L   (*(_PAGE_080_MEM_TYPE(0x202428))) /* Message Object 161 Interrupt Pointer Register Low */


#define CAN_MOIPR162L   (*(_PAGE_080_MEM_TYPE(0x202448))) /* Message Object 162 Interrupt Pointer Register Low */


#define CAN_MOIPR163L   (*(_PAGE_080_MEM_TYPE(0x202468))) /* Message Object 163 Interrupt Pointer Register Low */


#define CAN_MOIPR164L   (*(_PAGE_080_MEM_TYPE(0x202488))) /* Message Object 164 Interrupt Pointer Register Low */


#define CAN_MOIPR165L   (*(_PAGE_080_MEM_TYPE(0x2024A8))) /* Message Object 165 Interrupt Pointer Register Low */


#define CAN_MOIPR166L   (*(_PAGE_080_MEM_TYPE(0x2024C8))) /* Message Object 166 Interrupt Pointer Register Low */


#define CAN_MOIPR167L   (*(_PAGE_080_MEM_TYPE(0x2024E8))) /* Message Object 167 Interrupt Pointer Register Low */


#define CAN_MOIPR168L   (*(_PAGE_080_MEM_TYPE(0x202508))) /* Message Object 168 Interrupt Pointer Register Low */


#define CAN_MOIPR169L   (*(_PAGE_080_MEM_TYPE(0x202528))) /* Message Object 169 Interrupt Pointer Register Low */


#define CAN_MOIPR170L   (*(_PAGE_080_MEM_TYPE(0x202548))) /* Message Object 170 Interrupt Pointer Register Low */


#define CAN_MOIPR171L   (*(_PAGE_080_MEM_TYPE(0x202568))) /* Message Object 171 Interrupt Pointer Register Low */


#define CAN_MOIPR172L   (*(_PAGE_080_MEM_TYPE(0x202588))) /* Message Object 172 Interrupt Pointer Register Low */


#define CAN_MOIPR173L   (*(_PAGE_080_MEM_TYPE(0x2025A8))) /* Message Object 173 Interrupt Pointer Register Low */


#define CAN_MOIPR174L   (*(_PAGE_080_MEM_TYPE(0x2025C8))) /* Message Object 174 Interrupt Pointer Register Low */


#define CAN_MOIPR175L   (*(_PAGE_080_MEM_TYPE(0x2025E8))) /* Message Object 175 Interrupt Pointer Register Low */


#define CAN_MOIPR176L   (*(_PAGE_080_MEM_TYPE(0x202608))) /* Message Object 176 Interrupt Pointer Register Low */


#define CAN_MOIPR177L   (*(_PAGE_080_MEM_TYPE(0x202628))) /* Message Object 177 Interrupt Pointer Register Low */


#define CAN_MOIPR178L   (*(_PAGE_080_MEM_TYPE(0x202648))) /* Message Object 178 Interrupt Pointer Register Low */


#define CAN_MOIPR179L   (*(_PAGE_080_MEM_TYPE(0x202668))) /* Message Object 179 Interrupt Pointer Register Low */


#define CAN_MOIPR180L   (*(_PAGE_080_MEM_TYPE(0x202688))) /* Message Object 180 Interrupt Pointer Register Low */


#define CAN_MOIPR181L   (*(_PAGE_080_MEM_TYPE(0x2026A8))) /* Message Object 181 Interrupt Pointer Register Low */


#define CAN_MOIPR182L   (*(_PAGE_080_MEM_TYPE(0x2026C8))) /* Message Object 182 Interrupt Pointer Register Low */


#define CAN_MOIPR183L   (*(_PAGE_080_MEM_TYPE(0x2026E8))) /* Message Object 183 Interrupt Pointer Register Low */


#define CAN_MOIPR184L   (*(_PAGE_080_MEM_TYPE(0x202708))) /* Message Object 184 Interrupt Pointer Register Low */


#define CAN_MOIPR185L   (*(_PAGE_080_MEM_TYPE(0x202728))) /* Message Object 185 Interrupt Pointer Register Low */


#define CAN_MOIPR186L   (*(_PAGE_080_MEM_TYPE(0x202748))) /* Message Object 186 Interrupt Pointer Register Low */


#define CAN_MOIPR187L   (*(_PAGE_080_MEM_TYPE(0x202768))) /* Message Object 187 Interrupt Pointer Register Low */


#define CAN_MOIPR188L   (*(_PAGE_080_MEM_TYPE(0x202788))) /* Message Object 188 Interrupt Pointer Register Low */


#define CAN_MOIPR189L   (*(_PAGE_080_MEM_TYPE(0x2027A8))) /* Message Object 189 Interrupt Pointer Register Low */


#define CAN_MOIPR190L   (*(_PAGE_080_MEM_TYPE(0x2027C8))) /* Message Object 190 Interrupt Pointer Register Low */


#define CAN_MOIPR191L   (*(_PAGE_080_MEM_TYPE(0x2027E8))) /* Message Object 191 Interrupt Pointer Register Low */


#define CAN_MOIPR192L   (*(_PAGE_080_MEM_TYPE(0x202808))) /* Message Object 192 Interrupt Pointer Register Low */


#define CAN_MOIPR193L   (*(_PAGE_080_MEM_TYPE(0x202828))) /* Message Object 193 Interrupt Pointer Register Low */


#define CAN_MOIPR194L   (*(_PAGE_080_MEM_TYPE(0x202848))) /* Message Object 194 Interrupt Pointer Register Low */


#define CAN_MOIPR195L   (*(_PAGE_080_MEM_TYPE(0x202868))) /* Message Object 195 Interrupt Pointer Register Low */


#define CAN_MOIPR196L   (*(_PAGE_080_MEM_TYPE(0x202888))) /* Message Object 196 Interrupt Pointer Register Low */


#define CAN_MOIPR197L   (*(_PAGE_080_MEM_TYPE(0x2028A8))) /* Message Object 197 Interrupt Pointer Register Low */


#define CAN_MOIPR198L   (*(_PAGE_080_MEM_TYPE(0x2028C8))) /* Message Object 198 Interrupt Pointer Register Low */


#define CAN_MOIPR199L   (*(_PAGE_080_MEM_TYPE(0x2028E8))) /* Message Object 199 Interrupt Pointer Register Low */


#define CAN_MOIPR200L   (*(_PAGE_080_MEM_TYPE(0x202908))) /* Message Object 200 Interrupt Pointer Register Low */


#define CAN_MOIPR201L   (*(_PAGE_080_MEM_TYPE(0x202928))) /* Message Object 201 Interrupt Pointer Register Low */


#define CAN_MOIPR202L   (*(_PAGE_080_MEM_TYPE(0x202948))) /* Message Object 202 Interrupt Pointer Register Low */


#define CAN_MOIPR203L   (*(_PAGE_080_MEM_TYPE(0x202968))) /* Message Object 203 Interrupt Pointer Register Low */


#define CAN_MOIPR204L   (*(_PAGE_080_MEM_TYPE(0x202988))) /* Message Object 204 Interrupt Pointer Register Low */


#define CAN_MOIPR205L   (*(_PAGE_080_MEM_TYPE(0x2029A8))) /* Message Object 205 Interrupt Pointer Register Low */


#define CAN_MOIPR206L   (*(_PAGE_080_MEM_TYPE(0x2029C8))) /* Message Object 206 Interrupt Pointer Register Low */


#define CAN_MOIPR207L   (*(_PAGE_080_MEM_TYPE(0x2029E8))) /* Message Object 207 Interrupt Pointer Register Low */


#define CAN_MOIPR208L   (*(_PAGE_080_MEM_TYPE(0x202A08))) /* Message Object 208 Interrupt Pointer Register Low */


#define CAN_MOIPR209L   (*(_PAGE_080_MEM_TYPE(0x202A28))) /* Message Object 209 Interrupt Pointer Register Low */


#define CAN_MOIPR210L   (*(_PAGE_080_MEM_TYPE(0x202A48))) /* Message Object 210 Interrupt Pointer Register Low */


#define CAN_MOIPR211L   (*(_PAGE_080_MEM_TYPE(0x202A68))) /* Message Object 211 Interrupt Pointer Register Low */


#define CAN_MOIPR212L   (*(_PAGE_080_MEM_TYPE(0x202A88))) /* Message Object 212 Interrupt Pointer Register Low */


#define CAN_MOIPR213L   (*(_PAGE_080_MEM_TYPE(0x202AA8))) /* Message Object 213 Interrupt Pointer Register Low */


#define CAN_MOIPR214L   (*(_PAGE_080_MEM_TYPE(0x202AC8))) /* Message Object 214 Interrupt Pointer Register Low */


#define CAN_MOIPR215L   (*(_PAGE_080_MEM_TYPE(0x202AE8))) /* Message Object 215 Interrupt Pointer Register Low */


#define CAN_MOIPR216L   (*(_PAGE_080_MEM_TYPE(0x202B08))) /* Message Object 216 Interrupt Pointer Register Low */


#define CAN_MOIPR217L   (*(_PAGE_080_MEM_TYPE(0x202B28))) /* Message Object 217 Interrupt Pointer Register Low */


#define CAN_MOIPR218L   (*(_PAGE_080_MEM_TYPE(0x202B48))) /* Message Object 218 Interrupt Pointer Register Low */


#define CAN_MOIPR219L   (*(_PAGE_080_MEM_TYPE(0x202B68))) /* Message Object 219 Interrupt Pointer Register Low */


#define CAN_MOIPR220L   (*(_PAGE_080_MEM_TYPE(0x202B88))) /* Message Object 220 Interrupt Pointer Register Low */


#define CAN_MOIPR221L   (*(_PAGE_080_MEM_TYPE(0x202BA8))) /* Message Object 221 Interrupt Pointer Register Low */


#define CAN_MOIPR222L   (*(_PAGE_080_MEM_TYPE(0x202BC8))) /* Message Object 222 Interrupt Pointer Register Low */


#define CAN_MOIPR223L   (*(_PAGE_080_MEM_TYPE(0x202BE8))) /* Message Object 223 Interrupt Pointer Register Low */


#define CAN_MOIPR224L   (*(_PAGE_080_MEM_TYPE(0x202C08))) /* Message Object 224 Interrupt Pointer Register Low */


#define CAN_MOIPR225L   (*(_PAGE_080_MEM_TYPE(0x202C28))) /* Message Object 225 Interrupt Pointer Register Low */


#define CAN_MOIPR226L   (*(_PAGE_080_MEM_TYPE(0x202C48))) /* Message Object 226 Interrupt Pointer Register Low */


#define CAN_MOIPR227L   (*(_PAGE_080_MEM_TYPE(0x202C68))) /* Message Object 227 Interrupt Pointer Register Low */


#define CAN_MOIPR228L   (*(_PAGE_080_MEM_TYPE(0x202C88))) /* Message Object 228 Interrupt Pointer Register Low */


#define CAN_MOIPR229L   (*(_PAGE_080_MEM_TYPE(0x202CA8))) /* Message Object 229 Interrupt Pointer Register Low */


#define CAN_MOIPR230L   (*(_PAGE_080_MEM_TYPE(0x202CC8))) /* Message Object 230 Interrupt Pointer Register Low */


#define CAN_MOIPR231L   (*(_PAGE_080_MEM_TYPE(0x202CE8))) /* Message Object 231 Interrupt Pointer Register Low */


#define CAN_MOIPR232L   (*(_PAGE_080_MEM_TYPE(0x202D08))) /* Message Object 232 Interrupt Pointer Register Low */


#define CAN_MOIPR233L   (*(_PAGE_080_MEM_TYPE(0x202D28))) /* Message Object 233 Interrupt Pointer Register Low */


#define CAN_MOIPR234L   (*(_PAGE_080_MEM_TYPE(0x202D48))) /* Message Object 234 Interrupt Pointer Register Low */


#define CAN_MOIPR235L   (*(_PAGE_080_MEM_TYPE(0x202D68))) /* Message Object 235 Interrupt Pointer Register Low */


#define CAN_MOIPR236L   (*(_PAGE_080_MEM_TYPE(0x202D88))) /* Message Object 236 Interrupt Pointer Register Low */


#define CAN_MOIPR237L   (*(_PAGE_080_MEM_TYPE(0x202DA8))) /* Message Object 237 Interrupt Pointer Register Low */


#define CAN_MOIPR238L   (*(_PAGE_080_MEM_TYPE(0x202DC8))) /* Message Object 238 Interrupt Pointer Register Low */


#define CAN_MOIPR239L   (*(_PAGE_080_MEM_TYPE(0x202DE8))) /* Message Object 239 Interrupt Pointer Register Low */


#define CAN_MOIPR240L   (*(_PAGE_080_MEM_TYPE(0x202E08))) /* Message Object 240 Interrupt Pointer Register Low */


#define CAN_MOIPR241L   (*(_PAGE_080_MEM_TYPE(0x202E28))) /* Message Object 241 Interrupt Pointer Register Low */


#define CAN_MOIPR242L   (*(_PAGE_080_MEM_TYPE(0x202E48))) /* Message Object 242 Interrupt Pointer Register Low */


#define CAN_MOIPR243L   (*(_PAGE_080_MEM_TYPE(0x202E68))) /* Message Object 243 Interrupt Pointer Register Low */


#define CAN_MOIPR244L   (*(_PAGE_080_MEM_TYPE(0x202E88))) /* Message Object 244 Interrupt Pointer Register Low */


#define CAN_MOIPR245L   (*(_PAGE_080_MEM_TYPE(0x202EA8))) /* Message Object 245 Interrupt Pointer Register Low */


#define CAN_MOIPR246L   (*(_PAGE_080_MEM_TYPE(0x202EC8))) /* Message Object 246 Interrupt Pointer Register Low */


#define CAN_MOIPR247L   (*(_PAGE_080_MEM_TYPE(0x202EE8))) /* Message Object 247 Interrupt Pointer Register Low */


#define CAN_MOIPR248L   (*(_PAGE_080_MEM_TYPE(0x202F08))) /* Message Object 248 Interrupt Pointer Register Low */


#define CAN_MOIPR249L   (*(_PAGE_080_MEM_TYPE(0x202F28))) /* Message Object 249 Interrupt Pointer Register Low */


#define CAN_MOIPR250L   (*(_PAGE_080_MEM_TYPE(0x202F48))) /* Message Object 250 Interrupt Pointer Register Low */


#define CAN_MOIPR251L   (*(_PAGE_080_MEM_TYPE(0x202F68))) /* Message Object 251 Interrupt Pointer Register Low */


#define CAN_MOIPR252L   (*(_PAGE_080_MEM_TYPE(0x202F88))) /* Message Object 252 Interrupt Pointer Register Low */


#define CAN_MOIPR253L   (*(_PAGE_080_MEM_TYPE(0x202FA8))) /* Message Object 253 Interrupt Pointer Register Low */


#define CAN_MOIPR254L   (*(_PAGE_080_MEM_TYPE(0x202FC8))) /* Message Object 254 Interrupt Pointer Register Low */


#define CAN_MOIPR255L   (*(_PAGE_080_MEM_TYPE(0x202FE8))) /* Message Object 255 Interrupt Pointer Register Low */


#define CAN_MOFCR0H     (*(_PAGE_080_MEM_TYPE(0x201002))) /* Message Object 0 Function Control Register High */


#define CAN_MOFCR1H     (*(_PAGE_080_MEM_TYPE(0x201022))) /* Message Object 1 Function Control Register High */


#define CAN_MOFCR2H     (*(_PAGE_080_MEM_TYPE(0x201042))) /* Message Object 2 Function Control Register High */


#define CAN_MOFCR3H     (*(_PAGE_080_MEM_TYPE(0x201062))) /* Message Object 3 Function Control Register High */


#define CAN_MOFCR4H     (*(_PAGE_080_MEM_TYPE(0x201082))) /* Message Object 4 Function Control Register High */


#define CAN_MOFCR5H     (*(_PAGE_080_MEM_TYPE(0x2010A2))) /* Message Object 5 Function Control Register High */


#define CAN_MOFCR6H     (*(_PAGE_080_MEM_TYPE(0x2010C2))) /* Message Object 6 Function Control Register High */


#define CAN_MOFCR7H     (*(_PAGE_080_MEM_TYPE(0x2010E2))) /* Message Object 7 Function Control Register High */


#define CAN_MOFCR8H     (*(_PAGE_080_MEM_TYPE(0x201102))) /* Message Object 8 Function Control Register High */


#define CAN_MOFCR9H     (*(_PAGE_080_MEM_TYPE(0x201122))) /* Message Object 9 Function Control Register High */


#define CAN_MOFCR10H    (*(_PAGE_080_MEM_TYPE(0x201142))) /* Message Object 10 Function Control Register High */


#define CAN_MOFCR11H    (*(_PAGE_080_MEM_TYPE(0x201162))) /* Message Object 11 Function Control Register High */


#define CAN_MOFCR12H    (*(_PAGE_080_MEM_TYPE(0x201182))) /* Message Object 12 Function Control Register High */


#define CAN_MOFCR13H    (*(_PAGE_080_MEM_TYPE(0x2011A2))) /* Message Object 13 Function Control Register High */


#define CAN_MOFCR14H    (*(_PAGE_080_MEM_TYPE(0x2011C2))) /* Message Object 14 Function Control Register High */


#define CAN_MOFCR15H    (*(_PAGE_080_MEM_TYPE(0x2011E2))) /* Message Object 15 Function Control Register High */


#define CAN_MOFCR16H    (*(_PAGE_080_MEM_TYPE(0x201202))) /* Message Object 16 Function Control Register High */


#define CAN_MOFCR17H    (*(_PAGE_080_MEM_TYPE(0x201222))) /* Message Object 17 Function Control Register High */


#define CAN_MOFCR18H    (*(_PAGE_080_MEM_TYPE(0x201242))) /* Message Object 18 Function Control Register High */


#define CAN_MOFCR19H    (*(_PAGE_080_MEM_TYPE(0x201262))) /* Message Object 19 Function Control Register High */


#define CAN_MOFCR20H    (*(_PAGE_080_MEM_TYPE(0x201282))) /* Message Object 20 Function Control Register High */


#define CAN_MOFCR21H    (*(_PAGE_080_MEM_TYPE(0x2012A2))) /* Message Object 21 Function Control Register High */


#define CAN_MOFCR22H    (*(_PAGE_080_MEM_TYPE(0x2012C2))) /* Message Object 22 Function Control Register High */


#define CAN_MOFCR23H    (*(_PAGE_080_MEM_TYPE(0x2012E2))) /* Message Object 23 Function Control Register High */


#define CAN_MOFCR24H    (*(_PAGE_080_MEM_TYPE(0x201302))) /* Message Object 24 Function Control Register High */


#define CAN_MOFCR25H    (*(_PAGE_080_MEM_TYPE(0x201322))) /* Message Object 25 Function Control Register High */


#define CAN_MOFCR26H    (*(_PAGE_080_MEM_TYPE(0x201342))) /* Message Object 26 Function Control Register High */


#define CAN_MOFCR27H    (*(_PAGE_080_MEM_TYPE(0x201362))) /* Message Object 27 Function Control Register High */


#define CAN_MOFCR28H    (*(_PAGE_080_MEM_TYPE(0x201382))) /* Message Object 28 Function Control Register High */


#define CAN_MOFCR29H    (*(_PAGE_080_MEM_TYPE(0x2013A2))) /* Message Object 29 Function Control Register High */


#define CAN_MOFCR30H    (*(_PAGE_080_MEM_TYPE(0x2013C2))) /* Message Object 30 Function Control Register High */


#define CAN_MOFCR31H    (*(_PAGE_080_MEM_TYPE(0x2013E2))) /* Message Object 31 Function Control Register High */


#define CAN_MOFCR32H    (*(_PAGE_080_MEM_TYPE(0x201402))) /* Message Object 32 Function Control Register High */


#define CAN_MOFCR33H    (*(_PAGE_080_MEM_TYPE(0x201422))) /* Message Object 33 Function Control Register High */


#define CAN_MOFCR34H    (*(_PAGE_080_MEM_TYPE(0x201442))) /* Message Object 34 Function Control Register High */


#define CAN_MOFCR35H    (*(_PAGE_080_MEM_TYPE(0x201462))) /* Message Object 35 Function Control Register High */


#define CAN_MOFCR36H    (*(_PAGE_080_MEM_TYPE(0x201482))) /* Message Object 36 Function Control Register High */


#define CAN_MOFCR37H    (*(_PAGE_080_MEM_TYPE(0x2014A2))) /* Message Object 37 Function Control Register High */


#define CAN_MOFCR38H    (*(_PAGE_080_MEM_TYPE(0x2014C2))) /* Message Object 38 Function Control Register High */


#define CAN_MOFCR39H    (*(_PAGE_080_MEM_TYPE(0x2014E2))) /* Message Object 39 Function Control Register High */


#define CAN_MOFCR40H    (*(_PAGE_080_MEM_TYPE(0x201502))) /* Message Object 40 Function Control Register High */


#define CAN_MOFCR41H    (*(_PAGE_080_MEM_TYPE(0x201522))) /* Message Object 41 Function Control Register High */


#define CAN_MOFCR42H    (*(_PAGE_080_MEM_TYPE(0x201542))) /* Message Object 42 Function Control Register High */


#define CAN_MOFCR43H    (*(_PAGE_080_MEM_TYPE(0x201562))) /* Message Object 43 Function Control Register High */


#define CAN_MOFCR44H    (*(_PAGE_080_MEM_TYPE(0x201582))) /* Message Object 44 Function Control Register High */


#define CAN_MOFCR45H    (*(_PAGE_080_MEM_TYPE(0x2015A2))) /* Message Object 45 Function Control Register High */


#define CAN_MOFCR46H    (*(_PAGE_080_MEM_TYPE(0x2015C2))) /* Message Object 46 Function Control Register High */


#define CAN_MOFCR47H    (*(_PAGE_080_MEM_TYPE(0x2015E2))) /* Message Object 47 Function Control Register High */


#define CAN_MOFCR48H    (*(_PAGE_080_MEM_TYPE(0x201602))) /* Message Object 48 Function Control Register High */


#define CAN_MOFCR49H    (*(_PAGE_080_MEM_TYPE(0x201622))) /* Message Object 49 Function Control Register High */


#define CAN_MOFCR50H    (*(_PAGE_080_MEM_TYPE(0x201642))) /* Message Object 50 Function Control Register High */


#define CAN_MOFCR51H    (*(_PAGE_080_MEM_TYPE(0x201662))) /* Message Object 51 Function Control Register High */


#define CAN_MOFCR52H    (*(_PAGE_080_MEM_TYPE(0x201682))) /* Message Object 52 Function Control Register High */


#define CAN_MOFCR53H    (*(_PAGE_080_MEM_TYPE(0x2016A2))) /* Message Object 53 Function Control Register High */


#define CAN_MOFCR54H    (*(_PAGE_080_MEM_TYPE(0x2016C2))) /* Message Object 54 Function Control Register High */


#define CAN_MOFCR55H    (*(_PAGE_080_MEM_TYPE(0x2016E2))) /* Message Object 55 Function Control Register High */


#define CAN_MOFCR56H    (*(_PAGE_080_MEM_TYPE(0x201702))) /* Message Object 56 Function Control Register High */


#define CAN_MOFCR57H    (*(_PAGE_080_MEM_TYPE(0x201722))) /* Message Object 57 Function Control Register High */


#define CAN_MOFCR58H    (*(_PAGE_080_MEM_TYPE(0x201742))) /* Message Object 58 Function Control Register High */


#define CAN_MOFCR59H    (*(_PAGE_080_MEM_TYPE(0x201762))) /* Message Object 59 Function Control Register High */


#define CAN_MOFCR60H    (*(_PAGE_080_MEM_TYPE(0x201782))) /* Message Object 60 Function Control Register High */


#define CAN_MOFCR61H    (*(_PAGE_080_MEM_TYPE(0x2017A2))) /* Message Object 61 Function Control Register High */


#define CAN_MOFCR62H    (*(_PAGE_080_MEM_TYPE(0x2017C2))) /* Message Object 62 Function Control Register High */


#define CAN_MOFCR63H    (*(_PAGE_080_MEM_TYPE(0x2017E2))) /* Message Object 63 Function Control Register High */


#define CAN_MOFCR64H    (*(_PAGE_080_MEM_TYPE(0x201802))) /* Message Object 64 Function Control Register High */


#define CAN_MOFCR65H    (*(_PAGE_080_MEM_TYPE(0x201822))) /* Message Object 65 Function Control Register High */


#define CAN_MOFCR66H    (*(_PAGE_080_MEM_TYPE(0x201842))) /* Message Object 66 Function Control Register High */


#define CAN_MOFCR67H    (*(_PAGE_080_MEM_TYPE(0x201862))) /* Message Object 67 Function Control Register High */


#define CAN_MOFCR68H    (*(_PAGE_080_MEM_TYPE(0x201882))) /* Message Object 68 Function Control Register High */


#define CAN_MOFCR69H    (*(_PAGE_080_MEM_TYPE(0x2018A2))) /* Message Object 69 Function Control Register High */


#define CAN_MOFCR70H    (*(_PAGE_080_MEM_TYPE(0x2018C2))) /* Message Object 70 Function Control Register High */


#define CAN_MOFCR71H    (*(_PAGE_080_MEM_TYPE(0x2018E2))) /* Message Object 71 Function Control Register High */


#define CAN_MOFCR72H    (*(_PAGE_080_MEM_TYPE(0x201902))) /* Message Object 72 Function Control Register High */


#define CAN_MOFCR73H    (*(_PAGE_080_MEM_TYPE(0x201922))) /* Message Object 73 Function Control Register High */


#define CAN_MOFCR74H    (*(_PAGE_080_MEM_TYPE(0x201942))) /* Message Object 74 Function Control Register High */


#define CAN_MOFCR75H    (*(_PAGE_080_MEM_TYPE(0x201962))) /* Message Object 75 Function Control Register High */


#define CAN_MOFCR76H    (*(_PAGE_080_MEM_TYPE(0x201982))) /* Message Object 76 Function Control Register High */


#define CAN_MOFCR77H    (*(_PAGE_080_MEM_TYPE(0x2019A2))) /* Message Object 77 Function Control Register High */


#define CAN_MOFCR78H    (*(_PAGE_080_MEM_TYPE(0x2019C2))) /* Message Object 78 Function Control Register High */


#define CAN_MOFCR79H    (*(_PAGE_080_MEM_TYPE(0x2019E2))) /* Message Object 79 Function Control Register High */


#define CAN_MOFCR80H    (*(_PAGE_080_MEM_TYPE(0x201A02))) /* Message Object 80 Function Control Register High */


#define CAN_MOFCR81H    (*(_PAGE_080_MEM_TYPE(0x201A22))) /* Message Object 81 Function Control Register High */


#define CAN_MOFCR82H    (*(_PAGE_080_MEM_TYPE(0x201A42))) /* Message Object 82 Function Control Register High */


#define CAN_MOFCR83H    (*(_PAGE_080_MEM_TYPE(0x201A62))) /* Message Object 83 Function Control Register High */


#define CAN_MOFCR84H    (*(_PAGE_080_MEM_TYPE(0x201A82))) /* Message Object 84 Function Control Register High */


#define CAN_MOFCR85H    (*(_PAGE_080_MEM_TYPE(0x201AA2))) /* Message Object 85 Function Control Register High */


#define CAN_MOFCR86H    (*(_PAGE_080_MEM_TYPE(0x201AC2))) /* Message Object 86 Function Control Register High */


#define CAN_MOFCR87H    (*(_PAGE_080_MEM_TYPE(0x201AE2))) /* Message Object 87 Function Control Register High */


#define CAN_MOFCR88H    (*(_PAGE_080_MEM_TYPE(0x201B02))) /* Message Object 88 Function Control Register High */


#define CAN_MOFCR89H    (*(_PAGE_080_MEM_TYPE(0x201B22))) /* Message Object 89 Function Control Register High */


#define CAN_MOFCR90H    (*(_PAGE_080_MEM_TYPE(0x201B42))) /* Message Object 90 Function Control Register High */


#define CAN_MOFCR91H    (*(_PAGE_080_MEM_TYPE(0x201B62))) /* Message Object 91 Function Control Register High */


#define CAN_MOFCR92H    (*(_PAGE_080_MEM_TYPE(0x201B82))) /* Message Object 92 Function Control Register High */


#define CAN_MOFCR93H    (*(_PAGE_080_MEM_TYPE(0x201BA2))) /* Message Object 93 Function Control Register High */


#define CAN_MOFCR94H    (*(_PAGE_080_MEM_TYPE(0x201BC2))) /* Message Object 94 Function Control Register High */


#define CAN_MOFCR95H    (*(_PAGE_080_MEM_TYPE(0x201BE2))) /* Message Object 95 Function Control Register High */


#define CAN_MOFCR96H    (*(_PAGE_080_MEM_TYPE(0x201C02))) /* Message Object 96 Function Control Register High */


#define CAN_MOFCR97H    (*(_PAGE_080_MEM_TYPE(0x201C22))) /* Message Object 97 Function Control Register High */


#define CAN_MOFCR98H    (*(_PAGE_080_MEM_TYPE(0x201C42))) /* Message Object 98 Function Control Register High */


#define CAN_MOFCR99H    (*(_PAGE_080_MEM_TYPE(0x201C62))) /* Message Object 99 Function Control Register High */


#define CAN_MOFCR100H   (*(_PAGE_080_MEM_TYPE(0x201C82))) /* Message Object 100 Function Control Register High */


#define CAN_MOFCR101H   (*(_PAGE_080_MEM_TYPE(0x201CA2))) /* Message Object 101 Function Control Register High */


#define CAN_MOFCR102H   (*(_PAGE_080_MEM_TYPE(0x201CC2))) /* Message Object 102 Function Control Register High */


#define CAN_MOFCR103H   (*(_PAGE_080_MEM_TYPE(0x201CE2))) /* Message Object 103 Function Control Register High */


#define CAN_MOFCR104H   (*(_PAGE_080_MEM_TYPE(0x201D02))) /* Message Object 104 Function Control Register High */


#define CAN_MOFCR105H   (*(_PAGE_080_MEM_TYPE(0x201D22))) /* Message Object 105 Function Control Register High */


#define CAN_MOFCR106H   (*(_PAGE_080_MEM_TYPE(0x201D42))) /* Message Object 106 Function Control Register High */


#define CAN_MOFCR107H   (*(_PAGE_080_MEM_TYPE(0x201D62))) /* Message Object 107 Function Control Register High */


#define CAN_MOFCR108H   (*(_PAGE_080_MEM_TYPE(0x201D82))) /* Message Object 108 Function Control Register High */


#define CAN_MOFCR109H   (*(_PAGE_080_MEM_TYPE(0x201DA2))) /* Message Object 109 Function Control Register High */


#define CAN_MOFCR110H   (*(_PAGE_080_MEM_TYPE(0x201DC2))) /* Message Object 110 Function Control Register High */


#define CAN_MOFCR111H   (*(_PAGE_080_MEM_TYPE(0x201DE2))) /* Message Object 111 Function Control Register High */


#define CAN_MOFCR112H   (*(_PAGE_080_MEM_TYPE(0x201E02))) /* Message Object 112 Function Control Register High */


#define CAN_MOFCR113H   (*(_PAGE_080_MEM_TYPE(0x201E22))) /* Message Object 113 Function Control Register High */


#define CAN_MOFCR114H   (*(_PAGE_080_MEM_TYPE(0x201E42))) /* Message Object 114 Function Control Register High */


#define CAN_MOFCR115H   (*(_PAGE_080_MEM_TYPE(0x201E62))) /* Message Object 115 Function Control Register High */


#define CAN_MOFCR116H   (*(_PAGE_080_MEM_TYPE(0x201E82))) /* Message Object 116 Function Control Register High */


#define CAN_MOFCR117H   (*(_PAGE_080_MEM_TYPE(0x201EA2))) /* Message Object 117 Function Control Register High */


#define CAN_MOFCR118H   (*(_PAGE_080_MEM_TYPE(0x201EC2))) /* Message Object 118 Function Control Register High */


#define CAN_MOFCR119H   (*(_PAGE_080_MEM_TYPE(0x201EE2))) /* Message Object 119 Function Control Register High */


#define CAN_MOFCR120H   (*(_PAGE_080_MEM_TYPE(0x201F02))) /* Message Object 120 Function Control Register High */


#define CAN_MOFCR121H   (*(_PAGE_080_MEM_TYPE(0x201F22))) /* Message Object 121 Function Control Register High */


#define CAN_MOFCR122H   (*(_PAGE_080_MEM_TYPE(0x201F42))) /* Message Object 122 Function Control Register High */


#define CAN_MOFCR123H   (*(_PAGE_080_MEM_TYPE(0x201F62))) /* Message Object 123 Function Control Register High */


#define CAN_MOFCR124H   (*(_PAGE_080_MEM_TYPE(0x201F82))) /* Message Object 124 Function Control Register High */


#define CAN_MOFCR125H   (*(_PAGE_080_MEM_TYPE(0x201FA2))) /* Message Object 125 Function Control Register High */


#define CAN_MOFCR126H   (*(_PAGE_080_MEM_TYPE(0x201FC2))) /* Message Object 126 Function Control Register High */


#define CAN_MOFCR127H   (*(_PAGE_080_MEM_TYPE(0x201FE2))) /* Message Object 127 Function Control Register High */


#define CAN_MOFCR128H   (*(_PAGE_080_MEM_TYPE(0x202002))) /* Message Object 128 Function Control Register High */


#define CAN_MOFCR129H   (*(_PAGE_080_MEM_TYPE(0x202022))) /* Message Object 129 Function Control Register High */


#define CAN_MOFCR130H   (*(_PAGE_080_MEM_TYPE(0x202042))) /* Message Object 130 Function Control Register High */


#define CAN_MOFCR131H   (*(_PAGE_080_MEM_TYPE(0x202062))) /* Message Object 131 Function Control Register High */


#define CAN_MOFCR132H   (*(_PAGE_080_MEM_TYPE(0x202082))) /* Message Object 132 Function Control Register High */


#define CAN_MOFCR133H   (*(_PAGE_080_MEM_TYPE(0x2020A2))) /* Message Object 133 Function Control Register High */


#define CAN_MOFCR134H   (*(_PAGE_080_MEM_TYPE(0x2020C2))) /* Message Object 134 Function Control Register High */


#define CAN_MOFCR135H   (*(_PAGE_080_MEM_TYPE(0x2020E2))) /* Message Object 135 Function Control Register High */


#define CAN_MOFCR136H   (*(_PAGE_080_MEM_TYPE(0x202102))) /* Message Object 136 Function Control Register High */


#define CAN_MOFCR137H   (*(_PAGE_080_MEM_TYPE(0x202122))) /* Message Object 137 Function Control Register High */


#define CAN_MOFCR138H   (*(_PAGE_080_MEM_TYPE(0x202142))) /* Message Object 138 Function Control Register High */


#define CAN_MOFCR139H   (*(_PAGE_080_MEM_TYPE(0x202162))) /* Message Object 139 Function Control Register High */


#define CAN_MOFCR140H   (*(_PAGE_080_MEM_TYPE(0x202182))) /* Message Object 140 Function Control Register High */


#define CAN_MOFCR141H   (*(_PAGE_080_MEM_TYPE(0x2021A2))) /* Message Object 141 Function Control Register High */


#define CAN_MOFCR142H   (*(_PAGE_080_MEM_TYPE(0x2021C2))) /* Message Object 142 Function Control Register High */


#define CAN_MOFCR143H   (*(_PAGE_080_MEM_TYPE(0x2021E2))) /* Message Object 143 Function Control Register High */


#define CAN_MOFCR144H   (*(_PAGE_080_MEM_TYPE(0x202202))) /* Message Object 144 Function Control Register High */


#define CAN_MOFCR145H   (*(_PAGE_080_MEM_TYPE(0x202222))) /* Message Object 145 Function Control Register High */


#define CAN_MOFCR146H   (*(_PAGE_080_MEM_TYPE(0x202242))) /* Message Object 146 Function Control Register High */


#define CAN_MOFCR147H   (*(_PAGE_080_MEM_TYPE(0x202262))) /* Message Object 147 Function Control Register High */


#define CAN_MOFCR148H   (*(_PAGE_080_MEM_TYPE(0x202282))) /* Message Object 148 Function Control Register High */


#define CAN_MOFCR149H   (*(_PAGE_080_MEM_TYPE(0x2022A2))) /* Message Object 149 Function Control Register High */


#define CAN_MOFCR150H   (*(_PAGE_080_MEM_TYPE(0x2022C2))) /* Message Object 150 Function Control Register High */


#define CAN_MOFCR151H   (*(_PAGE_080_MEM_TYPE(0x2022E2))) /* Message Object 151 Function Control Register High */


#define CAN_MOFCR152H   (*(_PAGE_080_MEM_TYPE(0x202302))) /* Message Object 152 Function Control Register High */


#define CAN_MOFCR153H   (*(_PAGE_080_MEM_TYPE(0x202322))) /* Message Object 153 Function Control Register High */


#define CAN_MOFCR154H   (*(_PAGE_080_MEM_TYPE(0x202342))) /* Message Object 154 Function Control Register High */


#define CAN_MOFCR155H   (*(_PAGE_080_MEM_TYPE(0x202362))) /* Message Object 155 Function Control Register High */


#define CAN_MOFCR156H   (*(_PAGE_080_MEM_TYPE(0x202382))) /* Message Object 156 Function Control Register High */


#define CAN_MOFCR157H   (*(_PAGE_080_MEM_TYPE(0x2023A2))) /* Message Object 157 Function Control Register High */


#define CAN_MOFCR158H   (*(_PAGE_080_MEM_TYPE(0x2023C2))) /* Message Object 158 Function Control Register High */


#define CAN_MOFCR159H   (*(_PAGE_080_MEM_TYPE(0x2023E2))) /* Message Object 159 Function Control Register High */


#define CAN_MOFCR160H   (*(_PAGE_080_MEM_TYPE(0x202402))) /* Message Object 160 Function Control Register High */


#define CAN_MOFCR161H   (*(_PAGE_080_MEM_TYPE(0x202422))) /* Message Object 161 Function Control Register High */


#define CAN_MOFCR162H   (*(_PAGE_080_MEM_TYPE(0x202442))) /* Message Object 162 Function Control Register High */


#define CAN_MOFCR163H   (*(_PAGE_080_MEM_TYPE(0x202462))) /* Message Object 163 Function Control Register High */


#define CAN_MOFCR164H   (*(_PAGE_080_MEM_TYPE(0x202482))) /* Message Object 164 Function Control Register High */


#define CAN_MOFCR165H   (*(_PAGE_080_MEM_TYPE(0x2024A2))) /* Message Object 165 Function Control Register High */


#define CAN_MOFCR166H   (*(_PAGE_080_MEM_TYPE(0x2024C2))) /* Message Object 166 Function Control Register High */


#define CAN_MOFCR167H   (*(_PAGE_080_MEM_TYPE(0x2024E2))) /* Message Object 167 Function Control Register High */


#define CAN_MOFCR168H   (*(_PAGE_080_MEM_TYPE(0x202502))) /* Message Object 168 Function Control Register High */


#define CAN_MOFCR169H   (*(_PAGE_080_MEM_TYPE(0x202522))) /* Message Object 169 Function Control Register High */


#define CAN_MOFCR170H   (*(_PAGE_080_MEM_TYPE(0x202542))) /* Message Object 170 Function Control Register High */


#define CAN_MOFCR171H   (*(_PAGE_080_MEM_TYPE(0x202562))) /* Message Object 171 Function Control Register High */


#define CAN_MOFCR172H   (*(_PAGE_080_MEM_TYPE(0x202582))) /* Message Object 172 Function Control Register High */


#define CAN_MOFCR173H   (*(_PAGE_080_MEM_TYPE(0x2025A2))) /* Message Object 173 Function Control Register High */


#define CAN_MOFCR174H   (*(_PAGE_080_MEM_TYPE(0x2025C2))) /* Message Object 174 Function Control Register High */


#define CAN_MOFCR175H   (*(_PAGE_080_MEM_TYPE(0x2025E2))) /* Message Object 175 Function Control Register High */


#define CAN_MOFCR176H   (*(_PAGE_080_MEM_TYPE(0x202602))) /* Message Object 176 Function Control Register High */


#define CAN_MOFCR177H   (*(_PAGE_080_MEM_TYPE(0x202622))) /* Message Object 177 Function Control Register High */


#define CAN_MOFCR178H   (*(_PAGE_080_MEM_TYPE(0x202642))) /* Message Object 178 Function Control Register High */


#define CAN_MOFCR179H   (*(_PAGE_080_MEM_TYPE(0x202662))) /* Message Object 179 Function Control Register High */


#define CAN_MOFCR180H   (*(_PAGE_080_MEM_TYPE(0x202682))) /* Message Object 180 Function Control Register High */


#define CAN_MOFCR181H   (*(_PAGE_080_MEM_TYPE(0x2026A2))) /* Message Object 181 Function Control Register High */


#define CAN_MOFCR182H   (*(_PAGE_080_MEM_TYPE(0x2026C2))) /* Message Object 182 Function Control Register High */


#define CAN_MOFCR183H   (*(_PAGE_080_MEM_TYPE(0x2026E2))) /* Message Object 183 Function Control Register High */


#define CAN_MOFCR184H   (*(_PAGE_080_MEM_TYPE(0x202702))) /* Message Object 184 Function Control Register High */


#define CAN_MOFCR185H   (*(_PAGE_080_MEM_TYPE(0x202722))) /* Message Object 185 Function Control Register High */


#define CAN_MOFCR186H   (*(_PAGE_080_MEM_TYPE(0x202742))) /* Message Object 186 Function Control Register High */


#define CAN_MOFCR187H   (*(_PAGE_080_MEM_TYPE(0x202762))) /* Message Object 187 Function Control Register High */


#define CAN_MOFCR188H   (*(_PAGE_080_MEM_TYPE(0x202782))) /* Message Object 188 Function Control Register High */


#define CAN_MOFCR189H   (*(_PAGE_080_MEM_TYPE(0x2027A2))) /* Message Object 189 Function Control Register High */


#define CAN_MOFCR190H   (*(_PAGE_080_MEM_TYPE(0x2027C2))) /* Message Object 190 Function Control Register High */


#define CAN_MOFCR191H   (*(_PAGE_080_MEM_TYPE(0x2027E2))) /* Message Object 191 Function Control Register High */


#define CAN_MOFCR192H   (*(_PAGE_080_MEM_TYPE(0x202802))) /* Message Object 192 Function Control Register High */


#define CAN_MOFCR193H   (*(_PAGE_080_MEM_TYPE(0x202822))) /* Message Object 193 Function Control Register High */


#define CAN_MOFCR194H   (*(_PAGE_080_MEM_TYPE(0x202842))) /* Message Object 194 Function Control Register High */


#define CAN_MOFCR195H   (*(_PAGE_080_MEM_TYPE(0x202862))) /* Message Object 195 Function Control Register High */


#define CAN_MOFCR196H   (*(_PAGE_080_MEM_TYPE(0x202882))) /* Message Object 196 Function Control Register High */


#define CAN_MOFCR197H   (*(_PAGE_080_MEM_TYPE(0x2028A2))) /* Message Object 197 Function Control Register High */


#define CAN_MOFCR198H   (*(_PAGE_080_MEM_TYPE(0x2028C2))) /* Message Object 198 Function Control Register High */


#define CAN_MOFCR199H   (*(_PAGE_080_MEM_TYPE(0x2028E2))) /* Message Object 199 Function Control Register High */


#define CAN_MOFCR200H   (*(_PAGE_080_MEM_TYPE(0x202902))) /* Message Object 200 Function Control Register High */


#define CAN_MOFCR201H   (*(_PAGE_080_MEM_TYPE(0x202922))) /* Message Object 201 Function Control Register High */


#define CAN_MOFCR202H   (*(_PAGE_080_MEM_TYPE(0x202942))) /* Message Object 202 Function Control Register High */


#define CAN_MOFCR203H   (*(_PAGE_080_MEM_TYPE(0x202962))) /* Message Object 203 Function Control Register High */


#define CAN_MOFCR204H   (*(_PAGE_080_MEM_TYPE(0x202982))) /* Message Object 204 Function Control Register High */


#define CAN_MOFCR205H   (*(_PAGE_080_MEM_TYPE(0x2029A2))) /* Message Object 205 Function Control Register High */


#define CAN_MOFCR206H   (*(_PAGE_080_MEM_TYPE(0x2029C2))) /* Message Object 206 Function Control Register High */


#define CAN_MOFCR207H   (*(_PAGE_080_MEM_TYPE(0x2029E2))) /* Message Object 207 Function Control Register High */


#define CAN_MOFCR208H   (*(_PAGE_080_MEM_TYPE(0x202A02))) /* Message Object 208 Function Control Register High */


#define CAN_MOFCR209H   (*(_PAGE_080_MEM_TYPE(0x202A22))) /* Message Object 209 Function Control Register High */


#define CAN_MOFCR210H   (*(_PAGE_080_MEM_TYPE(0x202A42))) /* Message Object 210 Function Control Register High */


#define CAN_MOFCR211H   (*(_PAGE_080_MEM_TYPE(0x202A62))) /* Message Object 211 Function Control Register High */


#define CAN_MOFCR212H   (*(_PAGE_080_MEM_TYPE(0x202A82))) /* Message Object 212 Function Control Register High */


#define CAN_MOFCR213H   (*(_PAGE_080_MEM_TYPE(0x202AA2))) /* Message Object 213 Function Control Register High */


#define CAN_MOFCR214H   (*(_PAGE_080_MEM_TYPE(0x202AC2))) /* Message Object 214 Function Control Register High */


#define CAN_MOFCR215H   (*(_PAGE_080_MEM_TYPE(0x202AE2))) /* Message Object 215 Function Control Register High */


#define CAN_MOFCR216H   (*(_PAGE_080_MEM_TYPE(0x202B02))) /* Message Object 216 Function Control Register High */


#define CAN_MOFCR217H   (*(_PAGE_080_MEM_TYPE(0x202B22))) /* Message Object 217 Function Control Register High */


#define CAN_MOFCR218H   (*(_PAGE_080_MEM_TYPE(0x202B42))) /* Message Object 218 Function Control Register High */


#define CAN_MOFCR219H   (*(_PAGE_080_MEM_TYPE(0x202B62))) /* Message Object 219 Function Control Register High */


#define CAN_MOFCR220H   (*(_PAGE_080_MEM_TYPE(0x202B82))) /* Message Object 220 Function Control Register High */


#define CAN_MOFCR221H   (*(_PAGE_080_MEM_TYPE(0x202BA2))) /* Message Object 221 Function Control Register High */


#define CAN_MOFCR222H   (*(_PAGE_080_MEM_TYPE(0x202BC2))) /* Message Object 222 Function Control Register High */


#define CAN_MOFCR223H   (*(_PAGE_080_MEM_TYPE(0x202BE2))) /* Message Object 223 Function Control Register High */


#define CAN_MOFCR224H   (*(_PAGE_080_MEM_TYPE(0x202C02))) /* Message Object 224 Function Control Register High */


#define CAN_MOFCR225H   (*(_PAGE_080_MEM_TYPE(0x202C22))) /* Message Object 225 Function Control Register High */


#define CAN_MOFCR226H   (*(_PAGE_080_MEM_TYPE(0x202C42))) /* Message Object 226 Function Control Register High */


#define CAN_MOFCR227H   (*(_PAGE_080_MEM_TYPE(0x202C62))) /* Message Object 227 Function Control Register High */


#define CAN_MOFCR228H   (*(_PAGE_080_MEM_TYPE(0x202C82))) /* Message Object 228 Function Control Register High */


#define CAN_MOFCR229H   (*(_PAGE_080_MEM_TYPE(0x202CA2))) /* Message Object 229 Function Control Register High */


#define CAN_MOFCR230H   (*(_PAGE_080_MEM_TYPE(0x202CC2))) /* Message Object 230 Function Control Register High */


#define CAN_MOFCR231H   (*(_PAGE_080_MEM_TYPE(0x202CE2))) /* Message Object 231 Function Control Register High */


#define CAN_MOFCR232H   (*(_PAGE_080_MEM_TYPE(0x202D02))) /* Message Object 232 Function Control Register High */


#define CAN_MOFCR233H   (*(_PAGE_080_MEM_TYPE(0x202D22))) /* Message Object 233 Function Control Register High */


#define CAN_MOFCR234H   (*(_PAGE_080_MEM_TYPE(0x202D42))) /* Message Object 234 Function Control Register High */


#define CAN_MOFCR235H   (*(_PAGE_080_MEM_TYPE(0x202D62))) /* Message Object 235 Function Control Register High */


#define CAN_MOFCR236H   (*(_PAGE_080_MEM_TYPE(0x202D82))) /* Message Object 236 Function Control Register High */


#define CAN_MOFCR237H   (*(_PAGE_080_MEM_TYPE(0x202DA2))) /* Message Object 237 Function Control Register High */


#define CAN_MOFCR238H   (*(_PAGE_080_MEM_TYPE(0x202DC2))) /* Message Object 238 Function Control Register High */


#define CAN_MOFCR239H   (*(_PAGE_080_MEM_TYPE(0x202DE2))) /* Message Object 239 Function Control Register High */


#define CAN_MOFCR240H   (*(_PAGE_080_MEM_TYPE(0x202E02))) /* Message Object 240 Function Control Register High */


#define CAN_MOFCR241H   (*(_PAGE_080_MEM_TYPE(0x202E22))) /* Message Object 241 Function Control Register High */


#define CAN_MOFCR242H   (*(_PAGE_080_MEM_TYPE(0x202E42))) /* Message Object 242 Function Control Register High */


#define CAN_MOFCR243H   (*(_PAGE_080_MEM_TYPE(0x202E62))) /* Message Object 243 Function Control Register High */


#define CAN_MOFCR244H   (*(_PAGE_080_MEM_TYPE(0x202E82))) /* Message Object 244 Function Control Register High */


#define CAN_MOFCR245H   (*(_PAGE_080_MEM_TYPE(0x202EA2))) /* Message Object 245 Function Control Register High */


#define CAN_MOFCR246H   (*(_PAGE_080_MEM_TYPE(0x202EC2))) /* Message Object 246 Function Control Register High */


#define CAN_MOFCR247H   (*(_PAGE_080_MEM_TYPE(0x202EE2))) /* Message Object 247 Function Control Register High */


#define CAN_MOFCR248H   (*(_PAGE_080_MEM_TYPE(0x202F02))) /* Message Object 248 Function Control Register High */


#define CAN_MOFCR249H   (*(_PAGE_080_MEM_TYPE(0x202F22))) /* Message Object 249 Function Control Register High */


#define CAN_MOFCR250H   (*(_PAGE_080_MEM_TYPE(0x202F42))) /* Message Object 250 Function Control Register High */


#define CAN_MOFCR251H   (*(_PAGE_080_MEM_TYPE(0x202F62))) /* Message Object 251 Function Control Register High */


#define CAN_MOFCR252H   (*(_PAGE_080_MEM_TYPE(0x202F82))) /* Message Object 252 Function Control Register High */


#define CAN_MOFCR253H   (*(_PAGE_080_MEM_TYPE(0x202FA2))) /* Message Object 253 Function Control Register High */


#define CAN_MOFCR254H   (*(_PAGE_080_MEM_TYPE(0x202FC2))) /* Message Object 254 Function Control Register High */


#define CAN_MOFCR255H   (*(_PAGE_080_MEM_TYPE(0x202FE2))) /* Message Object 255 Function Control Register High */


#define CAN_MOFCR0L     (*(_PAGE_080_MEM_TYPE(0x201000))) /* Message Object 0 Function Control Register Low */


#define CAN_MOFCR1L     (*(_PAGE_080_MEM_TYPE(0x201020))) /* Message Object 1 Function Control Register Low */


#define CAN_MOFCR2L     (*(_PAGE_080_MEM_TYPE(0x201040))) /* Message Object 2 Function Control Register Low */


#define CAN_MOFCR3L     (*(_PAGE_080_MEM_TYPE(0x201060))) /* Message Object 3 Function Control Register Low */


#define CAN_MOFCR4L     (*(_PAGE_080_MEM_TYPE(0x201080))) /* Message Object 4 Function Control Register Low */


#define CAN_MOFCR5L     (*(_PAGE_080_MEM_TYPE(0x2010A0))) /* Message Object 5 Function Control Register Low */


#define CAN_MOFCR6L     (*(_PAGE_080_MEM_TYPE(0x2010C0))) /* Message Object 6 Function Control Register Low */


#define CAN_MOFCR7L     (*(_PAGE_080_MEM_TYPE(0x2010E0))) /* Message Object 7 Function Control Register Low */


#define CAN_MOFCR8L     (*(_PAGE_080_MEM_TYPE(0x201100))) /* Message Object 8 Function Control Register Low */


#define CAN_MOFCR9L     (*(_PAGE_080_MEM_TYPE(0x201120))) /* Message Object 9 Function Control Register Low */


#define CAN_MOFCR10L    (*(_PAGE_080_MEM_TYPE(0x201140))) /* Message Object 10 Function Control Register Low */


#define CAN_MOFCR11L    (*(_PAGE_080_MEM_TYPE(0x201160))) /* Message Object 11 Function Control Register Low */


#define CAN_MOFCR12L    (*(_PAGE_080_MEM_TYPE(0x201180))) /* Message Object 12 Function Control Register Low */


#define CAN_MOFCR13L    (*(_PAGE_080_MEM_TYPE(0x2011A0))) /* Message Object 13 Function Control Register Low */


#define CAN_MOFCR14L    (*(_PAGE_080_MEM_TYPE(0x2011C0))) /* Message Object 14 Function Control Register Low */


#define CAN_MOFCR15L    (*(_PAGE_080_MEM_TYPE(0x2011E0))) /* Message Object 15 Function Control Register Low */


#define CAN_MOFCR16L    (*(_PAGE_080_MEM_TYPE(0x201200))) /* Message Object 16 Function Control Register Low */


#define CAN_MOFCR17L    (*(_PAGE_080_MEM_TYPE(0x201220))) /* Message Object 17 Function Control Register Low */


#define CAN_MOFCR18L    (*(_PAGE_080_MEM_TYPE(0x201240))) /* Message Object 18 Function Control Register Low */


#define CAN_MOFCR19L    (*(_PAGE_080_MEM_TYPE(0x201260))) /* Message Object 19 Function Control Register Low */


#define CAN_MOFCR20L    (*(_PAGE_080_MEM_TYPE(0x201280))) /* Message Object 20 Function Control Register Low */


#define CAN_MOFCR21L    (*(_PAGE_080_MEM_TYPE(0x2012A0))) /* Message Object 21 Function Control Register Low */


#define CAN_MOFCR22L    (*(_PAGE_080_MEM_TYPE(0x2012C0))) /* Message Object 22 Function Control Register Low */


#define CAN_MOFCR23L    (*(_PAGE_080_MEM_TYPE(0x2012E0))) /* Message Object 23 Function Control Register Low */


#define CAN_MOFCR24L    (*(_PAGE_080_MEM_TYPE(0x201300))) /* Message Object 24 Function Control Register Low */


#define CAN_MOFCR25L    (*(_PAGE_080_MEM_TYPE(0x201320))) /* Message Object 25 Function Control Register Low */


#define CAN_MOFCR26L    (*(_PAGE_080_MEM_TYPE(0x201340))) /* Message Object 26 Function Control Register Low */


#define CAN_MOFCR27L    (*(_PAGE_080_MEM_TYPE(0x201360))) /* Message Object 27 Function Control Register Low */


#define CAN_MOFCR28L    (*(_PAGE_080_MEM_TYPE(0x201380))) /* Message Object 28 Function Control Register Low */


#define CAN_MOFCR29L    (*(_PAGE_080_MEM_TYPE(0x2013A0))) /* Message Object 29 Function Control Register Low */


#define CAN_MOFCR30L    (*(_PAGE_080_MEM_TYPE(0x2013C0))) /* Message Object 30 Function Control Register Low */


#define CAN_MOFCR31L    (*(_PAGE_080_MEM_TYPE(0x2013E0))) /* Message Object 31 Function Control Register Low */


#define CAN_MOFCR32L    (*(_PAGE_080_MEM_TYPE(0x201400))) /* Message Object 32 Function Control Register Low */


#define CAN_MOFCR33L    (*(_PAGE_080_MEM_TYPE(0x201420))) /* Message Object 33 Function Control Register Low */


#define CAN_MOFCR34L    (*(_PAGE_080_MEM_TYPE(0x201440))) /* Message Object 34 Function Control Register Low */


#define CAN_MOFCR35L    (*(_PAGE_080_MEM_TYPE(0x201460))) /* Message Object 35 Function Control Register Low */


#define CAN_MOFCR36L    (*(_PAGE_080_MEM_TYPE(0x201480))) /* Message Object 36 Function Control Register Low */


#define CAN_MOFCR37L    (*(_PAGE_080_MEM_TYPE(0x2014A0))) /* Message Object 37 Function Control Register Low */


#define CAN_MOFCR38L    (*(_PAGE_080_MEM_TYPE(0x2014C0))) /* Message Object 38 Function Control Register Low */


#define CAN_MOFCR39L    (*(_PAGE_080_MEM_TYPE(0x2014E0))) /* Message Object 39 Function Control Register Low */


#define CAN_MOFCR40L    (*(_PAGE_080_MEM_TYPE(0x201500))) /* Message Object 40 Function Control Register Low */


#define CAN_MOFCR41L    (*(_PAGE_080_MEM_TYPE(0x201520))) /* Message Object 41 Function Control Register Low */


#define CAN_MOFCR42L    (*(_PAGE_080_MEM_TYPE(0x201540))) /* Message Object 42 Function Control Register Low */


#define CAN_MOFCR43L    (*(_PAGE_080_MEM_TYPE(0x201560))) /* Message Object 43 Function Control Register Low */


#define CAN_MOFCR44L    (*(_PAGE_080_MEM_TYPE(0x201580))) /* Message Object 44 Function Control Register Low */


#define CAN_MOFCR45L    (*(_PAGE_080_MEM_TYPE(0x2015A0))) /* Message Object 45 Function Control Register Low */


#define CAN_MOFCR46L    (*(_PAGE_080_MEM_TYPE(0x2015C0))) /* Message Object 46 Function Control Register Low */


#define CAN_MOFCR47L    (*(_PAGE_080_MEM_TYPE(0x2015E0))) /* Message Object 47 Function Control Register Low */


#define CAN_MOFCR48L    (*(_PAGE_080_MEM_TYPE(0x201600))) /* Message Object 48 Function Control Register Low */


#define CAN_MOFCR49L    (*(_PAGE_080_MEM_TYPE(0x201620))) /* Message Object 49 Function Control Register Low */


#define CAN_MOFCR50L    (*(_PAGE_080_MEM_TYPE(0x201640))) /* Message Object 50 Function Control Register Low */


#define CAN_MOFCR51L    (*(_PAGE_080_MEM_TYPE(0x201660))) /* Message Object 51 Function Control Register Low */


#define CAN_MOFCR52L    (*(_PAGE_080_MEM_TYPE(0x201680))) /* Message Object 52 Function Control Register Low */


#define CAN_MOFCR53L    (*(_PAGE_080_MEM_TYPE(0x2016A0))) /* Message Object 53 Function Control Register Low */


#define CAN_MOFCR54L    (*(_PAGE_080_MEM_TYPE(0x2016C0))) /* Message Object 54 Function Control Register Low */


#define CAN_MOFCR55L    (*(_PAGE_080_MEM_TYPE(0x2016E0))) /* Message Object 55 Function Control Register Low */


#define CAN_MOFCR56L    (*(_PAGE_080_MEM_TYPE(0x201700))) /* Message Object 56 Function Control Register Low */


#define CAN_MOFCR57L    (*(_PAGE_080_MEM_TYPE(0x201720))) /* Message Object 57 Function Control Register Low */


#define CAN_MOFCR58L    (*(_PAGE_080_MEM_TYPE(0x201740))) /* Message Object 58 Function Control Register Low */


#define CAN_MOFCR59L    (*(_PAGE_080_MEM_TYPE(0x201760))) /* Message Object 59 Function Control Register Low */


#define CAN_MOFCR60L    (*(_PAGE_080_MEM_TYPE(0x201780))) /* Message Object 60 Function Control Register Low */


#define CAN_MOFCR61L    (*(_PAGE_080_MEM_TYPE(0x2017A0))) /* Message Object 61 Function Control Register Low */


#define CAN_MOFCR62L    (*(_PAGE_080_MEM_TYPE(0x2017C0))) /* Message Object 62 Function Control Register Low */


#define CAN_MOFCR63L    (*(_PAGE_080_MEM_TYPE(0x2017E0))) /* Message Object 63 Function Control Register Low */


#define CAN_MOFCR64L    (*(_PAGE_080_MEM_TYPE(0x201800))) /* Message Object 64 Function Control Register Low */


#define CAN_MOFCR65L    (*(_PAGE_080_MEM_TYPE(0x201820))) /* Message Object 65 Function Control Register Low */


#define CAN_MOFCR66L    (*(_PAGE_080_MEM_TYPE(0x201840))) /* Message Object 66 Function Control Register Low */


#define CAN_MOFCR67L    (*(_PAGE_080_MEM_TYPE(0x201860))) /* Message Object 67 Function Control Register Low */


#define CAN_MOFCR68L    (*(_PAGE_080_MEM_TYPE(0x201880))) /* Message Object 68 Function Control Register Low */


#define CAN_MOFCR69L    (*(_PAGE_080_MEM_TYPE(0x2018A0))) /* Message Object 69 Function Control Register Low */


#define CAN_MOFCR70L    (*(_PAGE_080_MEM_TYPE(0x2018C0))) /* Message Object 70 Function Control Register Low */


#define CAN_MOFCR71L    (*(_PAGE_080_MEM_TYPE(0x2018E0))) /* Message Object 71 Function Control Register Low */


#define CAN_MOFCR72L    (*(_PAGE_080_MEM_TYPE(0x201900))) /* Message Object 72 Function Control Register Low */


#define CAN_MOFCR73L    (*(_PAGE_080_MEM_TYPE(0x201920))) /* Message Object 73 Function Control Register Low */


#define CAN_MOFCR74L    (*(_PAGE_080_MEM_TYPE(0x201940))) /* Message Object 74 Function Control Register Low */


#define CAN_MOFCR75L    (*(_PAGE_080_MEM_TYPE(0x201960))) /* Message Object 75 Function Control Register Low */


#define CAN_MOFCR76L    (*(_PAGE_080_MEM_TYPE(0x201980))) /* Message Object 76 Function Control Register Low */


#define CAN_MOFCR77L    (*(_PAGE_080_MEM_TYPE(0x2019A0))) /* Message Object 77 Function Control Register Low */


#define CAN_MOFCR78L    (*(_PAGE_080_MEM_TYPE(0x2019C0))) /* Message Object 78 Function Control Register Low */


#define CAN_MOFCR79L    (*(_PAGE_080_MEM_TYPE(0x2019E0))) /* Message Object 79 Function Control Register Low */


#define CAN_MOFCR80L    (*(_PAGE_080_MEM_TYPE(0x201A00))) /* Message Object 80 Function Control Register Low */


#define CAN_MOFCR81L    (*(_PAGE_080_MEM_TYPE(0x201A20))) /* Message Object 81 Function Control Register Low */


#define CAN_MOFCR82L    (*(_PAGE_080_MEM_TYPE(0x201A40))) /* Message Object 82 Function Control Register Low */


#define CAN_MOFCR83L    (*(_PAGE_080_MEM_TYPE(0x201A60))) /* Message Object 83 Function Control Register Low */


#define CAN_MOFCR84L    (*(_PAGE_080_MEM_TYPE(0x201A80))) /* Message Object 84 Function Control Register Low */


#define CAN_MOFCR85L    (*(_PAGE_080_MEM_TYPE(0x201AA0))) /* Message Object 85 Function Control Register Low */


#define CAN_MOFCR86L    (*(_PAGE_080_MEM_TYPE(0x201AC0))) /* Message Object 86 Function Control Register Low */


#define CAN_MOFCR87L    (*(_PAGE_080_MEM_TYPE(0x201AE0))) /* Message Object 87 Function Control Register Low */


#define CAN_MOFCR88L    (*(_PAGE_080_MEM_TYPE(0x201B00))) /* Message Object 88 Function Control Register Low */


#define CAN_MOFCR89L    (*(_PAGE_080_MEM_TYPE(0x201B20))) /* Message Object 89 Function Control Register Low */


#define CAN_MOFCR90L    (*(_PAGE_080_MEM_TYPE(0x201B40))) /* Message Object 90 Function Control Register Low */


#define CAN_MOFCR91L    (*(_PAGE_080_MEM_TYPE(0x201B60))) /* Message Object 91 Function Control Register Low */


#define CAN_MOFCR92L    (*(_PAGE_080_MEM_TYPE(0x201B80))) /* Message Object 92 Function Control Register Low */


#define CAN_MOFCR93L    (*(_PAGE_080_MEM_TYPE(0x201BA0))) /* Message Object 93 Function Control Register Low */


#define CAN_MOFCR94L    (*(_PAGE_080_MEM_TYPE(0x201BC0))) /* Message Object 94 Function Control Register Low */


#define CAN_MOFCR95L    (*(_PAGE_080_MEM_TYPE(0x201BE0))) /* Message Object 95 Function Control Register Low */


#define CAN_MOFCR96L    (*(_PAGE_080_MEM_TYPE(0x201C00))) /* Message Object 96 Function Control Register Low */


#define CAN_MOFCR97L    (*(_PAGE_080_MEM_TYPE(0x201C20))) /* Message Object 97 Function Control Register Low */


#define CAN_MOFCR98L    (*(_PAGE_080_MEM_TYPE(0x201C40))) /* Message Object 98 Function Control Register Low */


#define CAN_MOFCR99L    (*(_PAGE_080_MEM_TYPE(0x201C60))) /* Message Object 99 Function Control Register Low */


#define CAN_MOFCR100L   (*(_PAGE_080_MEM_TYPE(0x201C80))) /* Message Object 100 Function Control Register Low */


#define CAN_MOFCR101L   (*(_PAGE_080_MEM_TYPE(0x201CA0))) /* Message Object 101 Function Control Register Low */


#define CAN_MOFCR102L   (*(_PAGE_080_MEM_TYPE(0x201CC0))) /* Message Object 102 Function Control Register Low */


#define CAN_MOFCR103L   (*(_PAGE_080_MEM_TYPE(0x201CE0))) /* Message Object 103 Function Control Register Low */


#define CAN_MOFCR104L   (*(_PAGE_080_MEM_TYPE(0x201D00))) /* Message Object 104 Function Control Register Low */


#define CAN_MOFCR105L   (*(_PAGE_080_MEM_TYPE(0x201D20))) /* Message Object 105 Function Control Register Low */


#define CAN_MOFCR106L   (*(_PAGE_080_MEM_TYPE(0x201D40))) /* Message Object 106 Function Control Register Low */


#define CAN_MOFCR107L   (*(_PAGE_080_MEM_TYPE(0x201D60))) /* Message Object 107 Function Control Register Low */


#define CAN_MOFCR108L   (*(_PAGE_080_MEM_TYPE(0x201D80))) /* Message Object 108 Function Control Register Low */


#define CAN_MOFCR109L   (*(_PAGE_080_MEM_TYPE(0x201DA0))) /* Message Object 109 Function Control Register Low */


#define CAN_MOFCR110L   (*(_PAGE_080_MEM_TYPE(0x201DC0))) /* Message Object 110 Function Control Register Low */


#define CAN_MOFCR111L   (*(_PAGE_080_MEM_TYPE(0x201DE0))) /* Message Object 111 Function Control Register Low */


#define CAN_MOFCR112L   (*(_PAGE_080_MEM_TYPE(0x201E00))) /* Message Object 112 Function Control Register Low */


#define CAN_MOFCR113L   (*(_PAGE_080_MEM_TYPE(0x201E20))) /* Message Object 113 Function Control Register Low */


#define CAN_MOFCR114L   (*(_PAGE_080_MEM_TYPE(0x201E40))) /* Message Object 114 Function Control Register Low */


#define CAN_MOFCR115L   (*(_PAGE_080_MEM_TYPE(0x201E60))) /* Message Object 115 Function Control Register Low */


#define CAN_MOFCR116L   (*(_PAGE_080_MEM_TYPE(0x201E80))) /* Message Object 116 Function Control Register Low */


#define CAN_MOFCR117L   (*(_PAGE_080_MEM_TYPE(0x201EA0))) /* Message Object 117 Function Control Register Low */


#define CAN_MOFCR118L   (*(_PAGE_080_MEM_TYPE(0x201EC0))) /* Message Object 118 Function Control Register Low */


#define CAN_MOFCR119L   (*(_PAGE_080_MEM_TYPE(0x201EE0))) /* Message Object 119 Function Control Register Low */


#define CAN_MOFCR120L   (*(_PAGE_080_MEM_TYPE(0x201F00))) /* Message Object 120 Function Control Register Low */


#define CAN_MOFCR121L   (*(_PAGE_080_MEM_TYPE(0x201F20))) /* Message Object 121 Function Control Register Low */


#define CAN_MOFCR122L   (*(_PAGE_080_MEM_TYPE(0x201F40))) /* Message Object 122 Function Control Register Low */


#define CAN_MOFCR123L   (*(_PAGE_080_MEM_TYPE(0x201F60))) /* Message Object 123 Function Control Register Low */


#define CAN_MOFCR124L   (*(_PAGE_080_MEM_TYPE(0x201F80))) /* Message Object 124 Function Control Register Low */


#define CAN_MOFCR125L   (*(_PAGE_080_MEM_TYPE(0x201FA0))) /* Message Object 125 Function Control Register Low */


#define CAN_MOFCR126L   (*(_PAGE_080_MEM_TYPE(0x201FC0))) /* Message Object 126 Function Control Register Low */


#define CAN_MOFCR127L   (*(_PAGE_080_MEM_TYPE(0x201FE0))) /* Message Object 127 Function Control Register Low */


#define CAN_MOFCR128L   (*(_PAGE_080_MEM_TYPE(0x202000))) /* Message Object 128 Function Control Register Low */


#define CAN_MOFCR129L   (*(_PAGE_080_MEM_TYPE(0x202020))) /* Message Object 129 Function Control Register Low */


#define CAN_MOFCR130L   (*(_PAGE_080_MEM_TYPE(0x202040))) /* Message Object 130 Function Control Register Low */


#define CAN_MOFCR131L   (*(_PAGE_080_MEM_TYPE(0x202060))) /* Message Object 131 Function Control Register Low */


#define CAN_MOFCR132L   (*(_PAGE_080_MEM_TYPE(0x202080))) /* Message Object 132 Function Control Register Low */


#define CAN_MOFCR133L   (*(_PAGE_080_MEM_TYPE(0x2020A0))) /* Message Object 133 Function Control Register Low */


#define CAN_MOFCR134L   (*(_PAGE_080_MEM_TYPE(0x2020C0))) /* Message Object 134 Function Control Register Low */


#define CAN_MOFCR135L   (*(_PAGE_080_MEM_TYPE(0x2020E0))) /* Message Object 135 Function Control Register Low */


#define CAN_MOFCR136L   (*(_PAGE_080_MEM_TYPE(0x202100))) /* Message Object 136 Function Control Register Low */


#define CAN_MOFCR137L   (*(_PAGE_080_MEM_TYPE(0x202120))) /* Message Object 137 Function Control Register Low */


#define CAN_MOFCR138L   (*(_PAGE_080_MEM_TYPE(0x202140))) /* Message Object 138 Function Control Register Low */


#define CAN_MOFCR139L   (*(_PAGE_080_MEM_TYPE(0x202160))) /* Message Object 139 Function Control Register Low */


#define CAN_MOFCR140L   (*(_PAGE_080_MEM_TYPE(0x202180))) /* Message Object 140 Function Control Register Low */


#define CAN_MOFCR141L   (*(_PAGE_080_MEM_TYPE(0x2021A0))) /* Message Object 141 Function Control Register Low */


#define CAN_MOFCR142L   (*(_PAGE_080_MEM_TYPE(0x2021C0))) /* Message Object 142 Function Control Register Low */


#define CAN_MOFCR143L   (*(_PAGE_080_MEM_TYPE(0x2021E0))) /* Message Object 143 Function Control Register Low */


#define CAN_MOFCR144L   (*(_PAGE_080_MEM_TYPE(0x202200))) /* Message Object 144 Function Control Register Low */


#define CAN_MOFCR145L   (*(_PAGE_080_MEM_TYPE(0x202220))) /* Message Object 145 Function Control Register Low */


#define CAN_MOFCR146L   (*(_PAGE_080_MEM_TYPE(0x202240))) /* Message Object 146 Function Control Register Low */


#define CAN_MOFCR147L   (*(_PAGE_080_MEM_TYPE(0x202260))) /* Message Object 147 Function Control Register Low */


#define CAN_MOFCR148L   (*(_PAGE_080_MEM_TYPE(0x202280))) /* Message Object 148 Function Control Register Low */


#define CAN_MOFCR149L   (*(_PAGE_080_MEM_TYPE(0x2022A0))) /* Message Object 149 Function Control Register Low */


#define CAN_MOFCR150L   (*(_PAGE_080_MEM_TYPE(0x2022C0))) /* Message Object 150 Function Control Register Low */


#define CAN_MOFCR151L   (*(_PAGE_080_MEM_TYPE(0x2022E0))) /* Message Object 151 Function Control Register Low */


#define CAN_MOFCR152L   (*(_PAGE_080_MEM_TYPE(0x202300))) /* Message Object 152 Function Control Register Low */


#define CAN_MOFCR153L   (*(_PAGE_080_MEM_TYPE(0x202320))) /* Message Object 153 Function Control Register Low */


#define CAN_MOFCR154L   (*(_PAGE_080_MEM_TYPE(0x202340))) /* Message Object 154 Function Control Register Low */


#define CAN_MOFCR155L   (*(_PAGE_080_MEM_TYPE(0x202360))) /* Message Object 155 Function Control Register Low */


#define CAN_MOFCR156L   (*(_PAGE_080_MEM_TYPE(0x202380))) /* Message Object 156 Function Control Register Low */


#define CAN_MOFCR157L   (*(_PAGE_080_MEM_TYPE(0x2023A0))) /* Message Object 157 Function Control Register Low */


#define CAN_MOFCR158L   (*(_PAGE_080_MEM_TYPE(0x2023C0))) /* Message Object 158 Function Control Register Low */


#define CAN_MOFCR159L   (*(_PAGE_080_MEM_TYPE(0x2023E0))) /* Message Object 159 Function Control Register Low */


#define CAN_MOFCR160L   (*(_PAGE_080_MEM_TYPE(0x202400))) /* Message Object 160 Function Control Register Low */


#define CAN_MOFCR161L   (*(_PAGE_080_MEM_TYPE(0x202420))) /* Message Object 161 Function Control Register Low */


#define CAN_MOFCR162L   (*(_PAGE_080_MEM_TYPE(0x202440))) /* Message Object 162 Function Control Register Low */


#define CAN_MOFCR163L   (*(_PAGE_080_MEM_TYPE(0x202460))) /* Message Object 163 Function Control Register Low */


#define CAN_MOFCR164L   (*(_PAGE_080_MEM_TYPE(0x202480))) /* Message Object 164 Function Control Register Low */


#define CAN_MOFCR165L   (*(_PAGE_080_MEM_TYPE(0x2024A0))) /* Message Object 165 Function Control Register Low */


#define CAN_MOFCR166L   (*(_PAGE_080_MEM_TYPE(0x2024C0))) /* Message Object 166 Function Control Register Low */


#define CAN_MOFCR167L   (*(_PAGE_080_MEM_TYPE(0x2024E0))) /* Message Object 167 Function Control Register Low */


#define CAN_MOFCR168L   (*(_PAGE_080_MEM_TYPE(0x202500))) /* Message Object 168 Function Control Register Low */


#define CAN_MOFCR169L   (*(_PAGE_080_MEM_TYPE(0x202520))) /* Message Object 169 Function Control Register Low */


#define CAN_MOFCR170L   (*(_PAGE_080_MEM_TYPE(0x202540))) /* Message Object 170 Function Control Register Low */


#define CAN_MOFCR171L   (*(_PAGE_080_MEM_TYPE(0x202560))) /* Message Object 171 Function Control Register Low */


#define CAN_MOFCR172L   (*(_PAGE_080_MEM_TYPE(0x202580))) /* Message Object 172 Function Control Register Low */


#define CAN_MOFCR173L   (*(_PAGE_080_MEM_TYPE(0x2025A0))) /* Message Object 173 Function Control Register Low */


#define CAN_MOFCR174L   (*(_PAGE_080_MEM_TYPE(0x2025C0))) /* Message Object 174 Function Control Register Low */


#define CAN_MOFCR175L   (*(_PAGE_080_MEM_TYPE(0x2025E0))) /* Message Object 175 Function Control Register Low */


#define CAN_MOFCR176L   (*(_PAGE_080_MEM_TYPE(0x202600))) /* Message Object 176 Function Control Register Low */


#define CAN_MOFCR177L   (*(_PAGE_080_MEM_TYPE(0x202620))) /* Message Object 177 Function Control Register Low */


#define CAN_MOFCR178L   (*(_PAGE_080_MEM_TYPE(0x202640))) /* Message Object 178 Function Control Register Low */


#define CAN_MOFCR179L   (*(_PAGE_080_MEM_TYPE(0x202660))) /* Message Object 179 Function Control Register Low */


#define CAN_MOFCR180L   (*(_PAGE_080_MEM_TYPE(0x202680))) /* Message Object 180 Function Control Register Low */


#define CAN_MOFCR181L   (*(_PAGE_080_MEM_TYPE(0x2026A0))) /* Message Object 181 Function Control Register Low */


#define CAN_MOFCR182L   (*(_PAGE_080_MEM_TYPE(0x2026C0))) /* Message Object 182 Function Control Register Low */


#define CAN_MOFCR183L   (*(_PAGE_080_MEM_TYPE(0x2026E0))) /* Message Object 183 Function Control Register Low */


#define CAN_MOFCR184L   (*(_PAGE_080_MEM_TYPE(0x202700))) /* Message Object 184 Function Control Register Low */


#define CAN_MOFCR185L   (*(_PAGE_080_MEM_TYPE(0x202720))) /* Message Object 185 Function Control Register Low */


#define CAN_MOFCR186L   (*(_PAGE_080_MEM_TYPE(0x202740))) /* Message Object 186 Function Control Register Low */


#define CAN_MOFCR187L   (*(_PAGE_080_MEM_TYPE(0x202760))) /* Message Object 187 Function Control Register Low */


#define CAN_MOFCR188L   (*(_PAGE_080_MEM_TYPE(0x202780))) /* Message Object 188 Function Control Register Low */


#define CAN_MOFCR189L   (*(_PAGE_080_MEM_TYPE(0x2027A0))) /* Message Object 189 Function Control Register Low */


#define CAN_MOFCR190L   (*(_PAGE_080_MEM_TYPE(0x2027C0))) /* Message Object 190 Function Control Register Low */


#define CAN_MOFCR191L   (*(_PAGE_080_MEM_TYPE(0x2027E0))) /* Message Object 191 Function Control Register Low */


#define CAN_MOFCR192L   (*(_PAGE_080_MEM_TYPE(0x202800))) /* Message Object 192 Function Control Register Low */


#define CAN_MOFCR193L   (*(_PAGE_080_MEM_TYPE(0x202820))) /* Message Object 193 Function Control Register Low */


#define CAN_MOFCR194L   (*(_PAGE_080_MEM_TYPE(0x202840))) /* Message Object 194 Function Control Register Low */


#define CAN_MOFCR195L   (*(_PAGE_080_MEM_TYPE(0x202860))) /* Message Object 195 Function Control Register Low */


#define CAN_MOFCR196L   (*(_PAGE_080_MEM_TYPE(0x202880))) /* Message Object 196 Function Control Register Low */


#define CAN_MOFCR197L   (*(_PAGE_080_MEM_TYPE(0x2028A0))) /* Message Object 197 Function Control Register Low */


#define CAN_MOFCR198L   (*(_PAGE_080_MEM_TYPE(0x2028C0))) /* Message Object 198 Function Control Register Low */


#define CAN_MOFCR199L   (*(_PAGE_080_MEM_TYPE(0x2028E0))) /* Message Object 199 Function Control Register Low */


#define CAN_MOFCR200L   (*(_PAGE_080_MEM_TYPE(0x202900))) /* Message Object 200 Function Control Register Low */


#define CAN_MOFCR201L   (*(_PAGE_080_MEM_TYPE(0x202920))) /* Message Object 201 Function Control Register Low */


#define CAN_MOFCR202L   (*(_PAGE_080_MEM_TYPE(0x202940))) /* Message Object 202 Function Control Register Low */


#define CAN_MOFCR203L   (*(_PAGE_080_MEM_TYPE(0x202960))) /* Message Object 203 Function Control Register Low */


#define CAN_MOFCR204L   (*(_PAGE_080_MEM_TYPE(0x202980))) /* Message Object 204 Function Control Register Low */


#define CAN_MOFCR205L   (*(_PAGE_080_MEM_TYPE(0x2029A0))) /* Message Object 205 Function Control Register Low */


#define CAN_MOFCR206L   (*(_PAGE_080_MEM_TYPE(0x2029C0))) /* Message Object 206 Function Control Register Low */


#define CAN_MOFCR207L   (*(_PAGE_080_MEM_TYPE(0x2029E0))) /* Message Object 207 Function Control Register Low */


#define CAN_MOFCR208L   (*(_PAGE_080_MEM_TYPE(0x202A00))) /* Message Object 208 Function Control Register Low */


#define CAN_MOFCR209L   (*(_PAGE_080_MEM_TYPE(0x202A20))) /* Message Object 209 Function Control Register Low */


#define CAN_MOFCR210L   (*(_PAGE_080_MEM_TYPE(0x202A40))) /* Message Object 210 Function Control Register Low */


#define CAN_MOFCR211L   (*(_PAGE_080_MEM_TYPE(0x202A60))) /* Message Object 211 Function Control Register Low */


#define CAN_MOFCR212L   (*(_PAGE_080_MEM_TYPE(0x202A80))) /* Message Object 212 Function Control Register Low */


#define CAN_MOFCR213L   (*(_PAGE_080_MEM_TYPE(0x202AA0))) /* Message Object 213 Function Control Register Low */


#define CAN_MOFCR214L   (*(_PAGE_080_MEM_TYPE(0x202AC0))) /* Message Object 214 Function Control Register Low */


#define CAN_MOFCR215L   (*(_PAGE_080_MEM_TYPE(0x202AE0))) /* Message Object 215 Function Control Register Low */


#define CAN_MOFCR216L   (*(_PAGE_080_MEM_TYPE(0x202B00))) /* Message Object 216 Function Control Register Low */


#define CAN_MOFCR217L   (*(_PAGE_080_MEM_TYPE(0x202B20))) /* Message Object 217 Function Control Register Low */


#define CAN_MOFCR218L   (*(_PAGE_080_MEM_TYPE(0x202B40))) /* Message Object 218 Function Control Register Low */


#define CAN_MOFCR219L   (*(_PAGE_080_MEM_TYPE(0x202B60))) /* Message Object 219 Function Control Register Low */


#define CAN_MOFCR220L   (*(_PAGE_080_MEM_TYPE(0x202B80))) /* Message Object 220 Function Control Register Low */


#define CAN_MOFCR221L   (*(_PAGE_080_MEM_TYPE(0x202BA0))) /* Message Object 221 Function Control Register Low */


#define CAN_MOFCR222L   (*(_PAGE_080_MEM_TYPE(0x202BC0))) /* Message Object 222 Function Control Register Low */


#define CAN_MOFCR223L   (*(_PAGE_080_MEM_TYPE(0x202BE0))) /* Message Object 223 Function Control Register Low */


#define CAN_MOFCR224L   (*(_PAGE_080_MEM_TYPE(0x202C00))) /* Message Object 224 Function Control Register Low */


#define CAN_MOFCR225L   (*(_PAGE_080_MEM_TYPE(0x202C20))) /* Message Object 225 Function Control Register Low */


#define CAN_MOFCR226L   (*(_PAGE_080_MEM_TYPE(0x202C40))) /* Message Object 226 Function Control Register Low */


#define CAN_MOFCR227L   (*(_PAGE_080_MEM_TYPE(0x202C60))) /* Message Object 227 Function Control Register Low */


#define CAN_MOFCR228L   (*(_PAGE_080_MEM_TYPE(0x202C80))) /* Message Object 228 Function Control Register Low */


#define CAN_MOFCR229L   (*(_PAGE_080_MEM_TYPE(0x202CA0))) /* Message Object 229 Function Control Register Low */


#define CAN_MOFCR230L   (*(_PAGE_080_MEM_TYPE(0x202CC0))) /* Message Object 230 Function Control Register Low */


#define CAN_MOFCR231L   (*(_PAGE_080_MEM_TYPE(0x202CE0))) /* Message Object 231 Function Control Register Low */


#define CAN_MOFCR232L   (*(_PAGE_080_MEM_TYPE(0x202D00))) /* Message Object 232 Function Control Register Low */


#define CAN_MOFCR233L   (*(_PAGE_080_MEM_TYPE(0x202D20))) /* Message Object 233 Function Control Register Low */


#define CAN_MOFCR234L   (*(_PAGE_080_MEM_TYPE(0x202D40))) /* Message Object 234 Function Control Register Low */


#define CAN_MOFCR235L   (*(_PAGE_080_MEM_TYPE(0x202D60))) /* Message Object 235 Function Control Register Low */


#define CAN_MOFCR236L   (*(_PAGE_080_MEM_TYPE(0x202D80))) /* Message Object 236 Function Control Register Low */


#define CAN_MOFCR237L   (*(_PAGE_080_MEM_TYPE(0x202DA0))) /* Message Object 237 Function Control Register Low */


#define CAN_MOFCR238L   (*(_PAGE_080_MEM_TYPE(0x202DC0))) /* Message Object 238 Function Control Register Low */


#define CAN_MOFCR239L   (*(_PAGE_080_MEM_TYPE(0x202DE0))) /* Message Object 239 Function Control Register Low */


#define CAN_MOFCR240L   (*(_PAGE_080_MEM_TYPE(0x202E00))) /* Message Object 240 Function Control Register Low */


#define CAN_MOFCR241L   (*(_PAGE_080_MEM_TYPE(0x202E20))) /* Message Object 241 Function Control Register Low */


#define CAN_MOFCR242L   (*(_PAGE_080_MEM_TYPE(0x202E40))) /* Message Object 242 Function Control Register Low */


#define CAN_MOFCR243L   (*(_PAGE_080_MEM_TYPE(0x202E60))) /* Message Object 243 Function Control Register Low */


#define CAN_MOFCR244L   (*(_PAGE_080_MEM_TYPE(0x202E80))) /* Message Object 244 Function Control Register Low */


#define CAN_MOFCR245L   (*(_PAGE_080_MEM_TYPE(0x202EA0))) /* Message Object 245 Function Control Register Low */


#define CAN_MOFCR246L   (*(_PAGE_080_MEM_TYPE(0x202EC0))) /* Message Object 246 Function Control Register Low */


#define CAN_MOFCR247L   (*(_PAGE_080_MEM_TYPE(0x202EE0))) /* Message Object 247 Function Control Register Low */


#define CAN_MOFCR248L   (*(_PAGE_080_MEM_TYPE(0x202F00))) /* Message Object 248 Function Control Register Low */


#define CAN_MOFCR249L   (*(_PAGE_080_MEM_TYPE(0x202F20))) /* Message Object 249 Function Control Register Low */


#define CAN_MOFCR250L   (*(_PAGE_080_MEM_TYPE(0x202F40))) /* Message Object 250 Function Control Register Low */


#define CAN_MOFCR251L   (*(_PAGE_080_MEM_TYPE(0x202F60))) /* Message Object 251 Function Control Register Low */


#define CAN_MOFCR252L   (*(_PAGE_080_MEM_TYPE(0x202F80))) /* Message Object 252 Function Control Register Low */


#define CAN_MOFCR253L   (*(_PAGE_080_MEM_TYPE(0x202FA0))) /* Message Object 253 Function Control Register Low */


#define CAN_MOFCR254L   (*(_PAGE_080_MEM_TYPE(0x202FC0))) /* Message Object 254 Function Control Register Low */


#define CAN_MOFCR255L   (*(_PAGE_080_MEM_TYPE(0x202FE0))) /* Message Object 255 Function Control Register Low */


#define CAN_MOFGPR0H    (*(_PAGE_080_MEM_TYPE(0x201006))) /* Message Object 0 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR1H    (*(_PAGE_080_MEM_TYPE(0x201026))) /* Message Object 1 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR2H    (*(_PAGE_080_MEM_TYPE(0x201046))) /* Message Object 2 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR3H    (*(_PAGE_080_MEM_TYPE(0x201066))) /* Message Object 3 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR4H    (*(_PAGE_080_MEM_TYPE(0x201086))) /* Message Object 4 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR5H    (*(_PAGE_080_MEM_TYPE(0x2010A6))) /* Message Object 5 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR6H    (*(_PAGE_080_MEM_TYPE(0x2010C6))) /* Message Object 6 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR7H    (*(_PAGE_080_MEM_TYPE(0x2010E6))) /* Message Object 7 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR8H    (*(_PAGE_080_MEM_TYPE(0x201106))) /* Message Object 8 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR9H    (*(_PAGE_080_MEM_TYPE(0x201126))) /* Message Object 9 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR10H   (*(_PAGE_080_MEM_TYPE(0x201146))) /* Message Object 10 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR11H   (*(_PAGE_080_MEM_TYPE(0x201166))) /* Message Object 11 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR12H   (*(_PAGE_080_MEM_TYPE(0x201186))) /* Message Object 12 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR13H   (*(_PAGE_080_MEM_TYPE(0x2011A6))) /* Message Object 13 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR14H   (*(_PAGE_080_MEM_TYPE(0x2011C6))) /* Message Object 14 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR15H   (*(_PAGE_080_MEM_TYPE(0x2011E6))) /* Message Object 15 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR16H   (*(_PAGE_080_MEM_TYPE(0x201206))) /* Message Object 16 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR17H   (*(_PAGE_080_MEM_TYPE(0x201226))) /* Message Object 17 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR18H   (*(_PAGE_080_MEM_TYPE(0x201246))) /* Message Object 18 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR19H   (*(_PAGE_080_MEM_TYPE(0x201266))) /* Message Object 19 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR20H   (*(_PAGE_080_MEM_TYPE(0x201286))) /* Message Object 20 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR21H   (*(_PAGE_080_MEM_TYPE(0x2012A6))) /* Message Object 21 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR22H   (*(_PAGE_080_MEM_TYPE(0x2012C6))) /* Message Object 22 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR23H   (*(_PAGE_080_MEM_TYPE(0x2012E6))) /* Message Object 23 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR24H   (*(_PAGE_080_MEM_TYPE(0x201306))) /* Message Object 24 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR25H   (*(_PAGE_080_MEM_TYPE(0x201326))) /* Message Object 25 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR26H   (*(_PAGE_080_MEM_TYPE(0x201346))) /* Message Object 26 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR27H   (*(_PAGE_080_MEM_TYPE(0x201366))) /* Message Object 27 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR28H   (*(_PAGE_080_MEM_TYPE(0x201386))) /* Message Object 28 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR29H   (*(_PAGE_080_MEM_TYPE(0x2013A6))) /* Message Object 29 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR30H   (*(_PAGE_080_MEM_TYPE(0x2013C6))) /* Message Object 30 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR31H   (*(_PAGE_080_MEM_TYPE(0x2013E6))) /* Message Object 31 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR32H   (*(_PAGE_080_MEM_TYPE(0x201406))) /* Message Object 32 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR33H   (*(_PAGE_080_MEM_TYPE(0x201426))) /* Message Object 33 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR34H   (*(_PAGE_080_MEM_TYPE(0x201446))) /* Message Object 34 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR35H   (*(_PAGE_080_MEM_TYPE(0x201466))) /* Message Object 35 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR36H   (*(_PAGE_080_MEM_TYPE(0x201486))) /* Message Object 36 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR37H   (*(_PAGE_080_MEM_TYPE(0x2014A6))) /* Message Object 37 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR38H   (*(_PAGE_080_MEM_TYPE(0x2014C6))) /* Message Object 38 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR39H   (*(_PAGE_080_MEM_TYPE(0x2014E6))) /* Message Object 39 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR40H   (*(_PAGE_080_MEM_TYPE(0x201506))) /* Message Object 40 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR41H   (*(_PAGE_080_MEM_TYPE(0x201526))) /* Message Object 41 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR42H   (*(_PAGE_080_MEM_TYPE(0x201546))) /* Message Object 42 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR43H   (*(_PAGE_080_MEM_TYPE(0x201566))) /* Message Object 43 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR44H   (*(_PAGE_080_MEM_TYPE(0x201586))) /* Message Object 44 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR45H   (*(_PAGE_080_MEM_TYPE(0x2015A6))) /* Message Object 45 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR46H   (*(_PAGE_080_MEM_TYPE(0x2015C6))) /* Message Object 46 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR47H   (*(_PAGE_080_MEM_TYPE(0x2015E6))) /* Message Object 47 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR48H   (*(_PAGE_080_MEM_TYPE(0x201606))) /* Message Object 48 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR49H   (*(_PAGE_080_MEM_TYPE(0x201626))) /* Message Object 49 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR50H   (*(_PAGE_080_MEM_TYPE(0x201646))) /* Message Object 50 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR51H   (*(_PAGE_080_MEM_TYPE(0x201666))) /* Message Object 51 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR52H   (*(_PAGE_080_MEM_TYPE(0x201686))) /* Message Object 52 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR53H   (*(_PAGE_080_MEM_TYPE(0x2016A6))) /* Message Object 53 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR54H   (*(_PAGE_080_MEM_TYPE(0x2016C6))) /* Message Object 54 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR55H   (*(_PAGE_080_MEM_TYPE(0x2016E6))) /* Message Object 55 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR56H   (*(_PAGE_080_MEM_TYPE(0x201706))) /* Message Object 56 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR57H   (*(_PAGE_080_MEM_TYPE(0x201726))) /* Message Object 57 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR58H   (*(_PAGE_080_MEM_TYPE(0x201746))) /* Message Object 58 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR59H   (*(_PAGE_080_MEM_TYPE(0x201766))) /* Message Object 59 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR60H   (*(_PAGE_080_MEM_TYPE(0x201786))) /* Message Object 60 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR61H   (*(_PAGE_080_MEM_TYPE(0x2017A6))) /* Message Object 61 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR62H   (*(_PAGE_080_MEM_TYPE(0x2017C6))) /* Message Object 62 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR63H   (*(_PAGE_080_MEM_TYPE(0x2017E6))) /* Message Object 63 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR64H   (*(_PAGE_080_MEM_TYPE(0x201806))) /* Message Object 64 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR65H   (*(_PAGE_080_MEM_TYPE(0x201826))) /* Message Object 65 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR66H   (*(_PAGE_080_MEM_TYPE(0x201846))) /* Message Object 66 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR67H   (*(_PAGE_080_MEM_TYPE(0x201866))) /* Message Object 67 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR68H   (*(_PAGE_080_MEM_TYPE(0x201886))) /* Message Object 68 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR69H   (*(_PAGE_080_MEM_TYPE(0x2018A6))) /* Message Object 69 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR70H   (*(_PAGE_080_MEM_TYPE(0x2018C6))) /* Message Object 70 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR71H   (*(_PAGE_080_MEM_TYPE(0x2018E6))) /* Message Object 71 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR72H   (*(_PAGE_080_MEM_TYPE(0x201906))) /* Message Object 72 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR73H   (*(_PAGE_080_MEM_TYPE(0x201926))) /* Message Object 73 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR74H   (*(_PAGE_080_MEM_TYPE(0x201946))) /* Message Object 74 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR75H   (*(_PAGE_080_MEM_TYPE(0x201966))) /* Message Object 75 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR76H   (*(_PAGE_080_MEM_TYPE(0x201986))) /* Message Object 76 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR77H   (*(_PAGE_080_MEM_TYPE(0x2019A6))) /* Message Object 77 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR78H   (*(_PAGE_080_MEM_TYPE(0x2019C6))) /* Message Object 78 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR79H   (*(_PAGE_080_MEM_TYPE(0x2019E6))) /* Message Object 79 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR80H   (*(_PAGE_080_MEM_TYPE(0x201A06))) /* Message Object 80 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR81H   (*(_PAGE_080_MEM_TYPE(0x201A26))) /* Message Object 81 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR82H   (*(_PAGE_080_MEM_TYPE(0x201A46))) /* Message Object 82 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR83H   (*(_PAGE_080_MEM_TYPE(0x201A66))) /* Message Object 83 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR84H   (*(_PAGE_080_MEM_TYPE(0x201A86))) /* Message Object 84 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR85H   (*(_PAGE_080_MEM_TYPE(0x201AA6))) /* Message Object 85 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR86H   (*(_PAGE_080_MEM_TYPE(0x201AC6))) /* Message Object 86 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR87H   (*(_PAGE_080_MEM_TYPE(0x201AE6))) /* Message Object 87 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR88H   (*(_PAGE_080_MEM_TYPE(0x201B06))) /* Message Object 88 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR89H   (*(_PAGE_080_MEM_TYPE(0x201B26))) /* Message Object 89 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR90H   (*(_PAGE_080_MEM_TYPE(0x201B46))) /* Message Object 90 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR91H   (*(_PAGE_080_MEM_TYPE(0x201B66))) /* Message Object 91 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR92H   (*(_PAGE_080_MEM_TYPE(0x201B86))) /* Message Object 92 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR93H   (*(_PAGE_080_MEM_TYPE(0x201BA6))) /* Message Object 93 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR94H   (*(_PAGE_080_MEM_TYPE(0x201BC6))) /* Message Object 94 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR95H   (*(_PAGE_080_MEM_TYPE(0x201BE6))) /* Message Object 95 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR96H   (*(_PAGE_080_MEM_TYPE(0x201C06))) /* Message Object 96 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR97H   (*(_PAGE_080_MEM_TYPE(0x201C26))) /* Message Object 97 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR98H   (*(_PAGE_080_MEM_TYPE(0x201C46))) /* Message Object 98 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR99H   (*(_PAGE_080_MEM_TYPE(0x201C66))) /* Message Object 99 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR100H  (*(_PAGE_080_MEM_TYPE(0x201C86))) /* Message Object 100 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR101H  (*(_PAGE_080_MEM_TYPE(0x201CA6))) /* Message Object 101 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR102H  (*(_PAGE_080_MEM_TYPE(0x201CC6))) /* Message Object 102 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR103H  (*(_PAGE_080_MEM_TYPE(0x201CE6))) /* Message Object 103 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR104H  (*(_PAGE_080_MEM_TYPE(0x201D06))) /* Message Object 104 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR105H  (*(_PAGE_080_MEM_TYPE(0x201D26))) /* Message Object 105 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR106H  (*(_PAGE_080_MEM_TYPE(0x201D46))) /* Message Object 106 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR107H  (*(_PAGE_080_MEM_TYPE(0x201D66))) /* Message Object 107 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR108H  (*(_PAGE_080_MEM_TYPE(0x201D86))) /* Message Object 108 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR109H  (*(_PAGE_080_MEM_TYPE(0x201DA6))) /* Message Object 109 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR110H  (*(_PAGE_080_MEM_TYPE(0x201DC6))) /* Message Object 110 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR111H  (*(_PAGE_080_MEM_TYPE(0x201DE6))) /* Message Object 111 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR112H  (*(_PAGE_080_MEM_TYPE(0x201E06))) /* Message Object 112 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR113H  (*(_PAGE_080_MEM_TYPE(0x201E26))) /* Message Object 113 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR114H  (*(_PAGE_080_MEM_TYPE(0x201E46))) /* Message Object 114 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR115H  (*(_PAGE_080_MEM_TYPE(0x201E66))) /* Message Object 115 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR116H  (*(_PAGE_080_MEM_TYPE(0x201E86))) /* Message Object 116 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR117H  (*(_PAGE_080_MEM_TYPE(0x201EA6))) /* Message Object 117 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR118H  (*(_PAGE_080_MEM_TYPE(0x201EC6))) /* Message Object 118 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR119H  (*(_PAGE_080_MEM_TYPE(0x201EE6))) /* Message Object 119 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR120H  (*(_PAGE_080_MEM_TYPE(0x201F06))) /* Message Object 120 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR121H  (*(_PAGE_080_MEM_TYPE(0x201F26))) /* Message Object 121 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR122H  (*(_PAGE_080_MEM_TYPE(0x201F46))) /* Message Object 122 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR123H  (*(_PAGE_080_MEM_TYPE(0x201F66))) /* Message Object 123 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR124H  (*(_PAGE_080_MEM_TYPE(0x201F86))) /* Message Object 124 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR125H  (*(_PAGE_080_MEM_TYPE(0x201FA6))) /* Message Object 125 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR126H  (*(_PAGE_080_MEM_TYPE(0x201FC6))) /* Message Object 126 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR127H  (*(_PAGE_080_MEM_TYPE(0x201FE6))) /* Message Object 127 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR128H  (*(_PAGE_080_MEM_TYPE(0x202006))) /* Message Object 128 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR129H  (*(_PAGE_080_MEM_TYPE(0x202026))) /* Message Object 129 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR130H  (*(_PAGE_080_MEM_TYPE(0x202046))) /* Message Object 130 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR131H  (*(_PAGE_080_MEM_TYPE(0x202066))) /* Message Object 131 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR132H  (*(_PAGE_080_MEM_TYPE(0x202086))) /* Message Object 132 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR133H  (*(_PAGE_080_MEM_TYPE(0x2020A6))) /* Message Object 133 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR134H  (*(_PAGE_080_MEM_TYPE(0x2020C6))) /* Message Object 134 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR135H  (*(_PAGE_080_MEM_TYPE(0x2020E6))) /* Message Object 135 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR136H  (*(_PAGE_080_MEM_TYPE(0x202106))) /* Message Object 136 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR137H  (*(_PAGE_080_MEM_TYPE(0x202126))) /* Message Object 137 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR138H  (*(_PAGE_080_MEM_TYPE(0x202146))) /* Message Object 138 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR139H  (*(_PAGE_080_MEM_TYPE(0x202166))) /* Message Object 139 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR140H  (*(_PAGE_080_MEM_TYPE(0x202186))) /* Message Object 140 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR141H  (*(_PAGE_080_MEM_TYPE(0x2021A6))) /* Message Object 141 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR142H  (*(_PAGE_080_MEM_TYPE(0x2021C6))) /* Message Object 142 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR143H  (*(_PAGE_080_MEM_TYPE(0x2021E6))) /* Message Object 143 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR144H  (*(_PAGE_080_MEM_TYPE(0x202206))) /* Message Object 144 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR145H  (*(_PAGE_080_MEM_TYPE(0x202226))) /* Message Object 145 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR146H  (*(_PAGE_080_MEM_TYPE(0x202246))) /* Message Object 146 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR147H  (*(_PAGE_080_MEM_TYPE(0x202266))) /* Message Object 147 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR148H  (*(_PAGE_080_MEM_TYPE(0x202286))) /* Message Object 148 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR149H  (*(_PAGE_080_MEM_TYPE(0x2022A6))) /* Message Object 149 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR150H  (*(_PAGE_080_MEM_TYPE(0x2022C6))) /* Message Object 150 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR151H  (*(_PAGE_080_MEM_TYPE(0x2022E6))) /* Message Object 151 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR152H  (*(_PAGE_080_MEM_TYPE(0x202306))) /* Message Object 152 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR153H  (*(_PAGE_080_MEM_TYPE(0x202326))) /* Message Object 153 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR154H  (*(_PAGE_080_MEM_TYPE(0x202346))) /* Message Object 154 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR155H  (*(_PAGE_080_MEM_TYPE(0x202366))) /* Message Object 155 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR156H  (*(_PAGE_080_MEM_TYPE(0x202386))) /* Message Object 156 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR157H  (*(_PAGE_080_MEM_TYPE(0x2023A6))) /* Message Object 157 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR158H  (*(_PAGE_080_MEM_TYPE(0x2023C6))) /* Message Object 158 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR159H  (*(_PAGE_080_MEM_TYPE(0x2023E6))) /* Message Object 159 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR160H  (*(_PAGE_080_MEM_TYPE(0x202406))) /* Message Object 160 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR161H  (*(_PAGE_080_MEM_TYPE(0x202426))) /* Message Object 161 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR162H  (*(_PAGE_080_MEM_TYPE(0x202446))) /* Message Object 162 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR163H  (*(_PAGE_080_MEM_TYPE(0x202466))) /* Message Object 163 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR164H  (*(_PAGE_080_MEM_TYPE(0x202486))) /* Message Object 164 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR165H  (*(_PAGE_080_MEM_TYPE(0x2024A6))) /* Message Object 165 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR166H  (*(_PAGE_080_MEM_TYPE(0x2024C6))) /* Message Object 166 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR167H  (*(_PAGE_080_MEM_TYPE(0x2024E6))) /* Message Object 167 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR168H  (*(_PAGE_080_MEM_TYPE(0x202506))) /* Message Object 168 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR169H  (*(_PAGE_080_MEM_TYPE(0x202526))) /* Message Object 169 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR170H  (*(_PAGE_080_MEM_TYPE(0x202546))) /* Message Object 170 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR171H  (*(_PAGE_080_MEM_TYPE(0x202566))) /* Message Object 171 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR172H  (*(_PAGE_080_MEM_TYPE(0x202586))) /* Message Object 172 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR173H  (*(_PAGE_080_MEM_TYPE(0x2025A6))) /* Message Object 173 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR174H  (*(_PAGE_080_MEM_TYPE(0x2025C6))) /* Message Object 174 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR175H  (*(_PAGE_080_MEM_TYPE(0x2025E6))) /* Message Object 175 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR176H  (*(_PAGE_080_MEM_TYPE(0x202606))) /* Message Object 176 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR177H  (*(_PAGE_080_MEM_TYPE(0x202626))) /* Message Object 177 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR178H  (*(_PAGE_080_MEM_TYPE(0x202646))) /* Message Object 178 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR179H  (*(_PAGE_080_MEM_TYPE(0x202666))) /* Message Object 179 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR180H  (*(_PAGE_080_MEM_TYPE(0x202686))) /* Message Object 180 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR181H  (*(_PAGE_080_MEM_TYPE(0x2026A6))) /* Message Object 181 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR182H  (*(_PAGE_080_MEM_TYPE(0x2026C6))) /* Message Object 182 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR183H  (*(_PAGE_080_MEM_TYPE(0x2026E6))) /* Message Object 183 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR184H  (*(_PAGE_080_MEM_TYPE(0x202706))) /* Message Object 184 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR185H  (*(_PAGE_080_MEM_TYPE(0x202726))) /* Message Object 185 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR186H  (*(_PAGE_080_MEM_TYPE(0x202746))) /* Message Object 186 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR187H  (*(_PAGE_080_MEM_TYPE(0x202766))) /* Message Object 187 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR188H  (*(_PAGE_080_MEM_TYPE(0x202786))) /* Message Object 188 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR189H  (*(_PAGE_080_MEM_TYPE(0x2027A6))) /* Message Object 189 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR190H  (*(_PAGE_080_MEM_TYPE(0x2027C6))) /* Message Object 190 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR191H  (*(_PAGE_080_MEM_TYPE(0x2027E6))) /* Message Object 191 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR192H  (*(_PAGE_080_MEM_TYPE(0x202806))) /* Message Object 192 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR193H  (*(_PAGE_080_MEM_TYPE(0x202826))) /* Message Object 193 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR194H  (*(_PAGE_080_MEM_TYPE(0x202846))) /* Message Object 194 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR195H  (*(_PAGE_080_MEM_TYPE(0x202866))) /* Message Object 195 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR196H  (*(_PAGE_080_MEM_TYPE(0x202886))) /* Message Object 196 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR197H  (*(_PAGE_080_MEM_TYPE(0x2028A6))) /* Message Object 197 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR198H  (*(_PAGE_080_MEM_TYPE(0x2028C6))) /* Message Object 198 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR199H  (*(_PAGE_080_MEM_TYPE(0x2028E6))) /* Message Object 199 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR200H  (*(_PAGE_080_MEM_TYPE(0x202906))) /* Message Object 200 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR201H  (*(_PAGE_080_MEM_TYPE(0x202926))) /* Message Object 201 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR202H  (*(_PAGE_080_MEM_TYPE(0x202946))) /* Message Object 202 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR203H  (*(_PAGE_080_MEM_TYPE(0x202966))) /* Message Object 203 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR204H  (*(_PAGE_080_MEM_TYPE(0x202986))) /* Message Object 204 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR205H  (*(_PAGE_080_MEM_TYPE(0x2029A6))) /* Message Object 205 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR206H  (*(_PAGE_080_MEM_TYPE(0x2029C6))) /* Message Object 206 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR207H  (*(_PAGE_080_MEM_TYPE(0x2029E6))) /* Message Object 207 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR208H  (*(_PAGE_080_MEM_TYPE(0x202A06))) /* Message Object 208 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR209H  (*(_PAGE_080_MEM_TYPE(0x202A26))) /* Message Object 209 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR210H  (*(_PAGE_080_MEM_TYPE(0x202A46))) /* Message Object 210 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR211H  (*(_PAGE_080_MEM_TYPE(0x202A66))) /* Message Object 211 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR212H  (*(_PAGE_080_MEM_TYPE(0x202A86))) /* Message Object 212 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR213H  (*(_PAGE_080_MEM_TYPE(0x202AA6))) /* Message Object 213 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR214H  (*(_PAGE_080_MEM_TYPE(0x202AC6))) /* Message Object 214 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR215H  (*(_PAGE_080_MEM_TYPE(0x202AE6))) /* Message Object 215 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR216H  (*(_PAGE_080_MEM_TYPE(0x202B06))) /* Message Object 216 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR217H  (*(_PAGE_080_MEM_TYPE(0x202B26))) /* Message Object 217 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR218H  (*(_PAGE_080_MEM_TYPE(0x202B46))) /* Message Object 218 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR219H  (*(_PAGE_080_MEM_TYPE(0x202B66))) /* Message Object 219 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR220H  (*(_PAGE_080_MEM_TYPE(0x202B86))) /* Message Object 220 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR221H  (*(_PAGE_080_MEM_TYPE(0x202BA6))) /* Message Object 221 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR222H  (*(_PAGE_080_MEM_TYPE(0x202BC6))) /* Message Object 222 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR223H  (*(_PAGE_080_MEM_TYPE(0x202BE6))) /* Message Object 223 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR224H  (*(_PAGE_080_MEM_TYPE(0x202C06))) /* Message Object 224 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR225H  (*(_PAGE_080_MEM_TYPE(0x202C26))) /* Message Object 225 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR226H  (*(_PAGE_080_MEM_TYPE(0x202C46))) /* Message Object 226 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR227H  (*(_PAGE_080_MEM_TYPE(0x202C66))) /* Message Object 227 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR228H  (*(_PAGE_080_MEM_TYPE(0x202C86))) /* Message Object 228 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR229H  (*(_PAGE_080_MEM_TYPE(0x202CA6))) /* Message Object 229 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR230H  (*(_PAGE_080_MEM_TYPE(0x202CC6))) /* Message Object 230 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR231H  (*(_PAGE_080_MEM_TYPE(0x202CE6))) /* Message Object 231 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR232H  (*(_PAGE_080_MEM_TYPE(0x202D06))) /* Message Object 232 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR233H  (*(_PAGE_080_MEM_TYPE(0x202D26))) /* Message Object 233 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR234H  (*(_PAGE_080_MEM_TYPE(0x202D46))) /* Message Object 234 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR235H  (*(_PAGE_080_MEM_TYPE(0x202D66))) /* Message Object 235 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR236H  (*(_PAGE_080_MEM_TYPE(0x202D86))) /* Message Object 236 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR237H  (*(_PAGE_080_MEM_TYPE(0x202DA6))) /* Message Object 237 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR238H  (*(_PAGE_080_MEM_TYPE(0x202DC6))) /* Message Object 238 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR239H  (*(_PAGE_080_MEM_TYPE(0x202DE6))) /* Message Object 239 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR240H  (*(_PAGE_080_MEM_TYPE(0x202E06))) /* Message Object 240 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR241H  (*(_PAGE_080_MEM_TYPE(0x202E26))) /* Message Object 241 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR242H  (*(_PAGE_080_MEM_TYPE(0x202E46))) /* Message Object 242 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR243H  (*(_PAGE_080_MEM_TYPE(0x202E66))) /* Message Object 243 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR244H  (*(_PAGE_080_MEM_TYPE(0x202E86))) /* Message Object 244 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR245H  (*(_PAGE_080_MEM_TYPE(0x202EA6))) /* Message Object 245 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR246H  (*(_PAGE_080_MEM_TYPE(0x202EC6))) /* Message Object 246 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR247H  (*(_PAGE_080_MEM_TYPE(0x202EE6))) /* Message Object 247 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR248H  (*(_PAGE_080_MEM_TYPE(0x202F06))) /* Message Object 248 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR249H  (*(_PAGE_080_MEM_TYPE(0x202F26))) /* Message Object 249 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR250H  (*(_PAGE_080_MEM_TYPE(0x202F46))) /* Message Object 250 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR251H  (*(_PAGE_080_MEM_TYPE(0x202F66))) /* Message Object 251 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR252H  (*(_PAGE_080_MEM_TYPE(0x202F86))) /* Message Object 252 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR253H  (*(_PAGE_080_MEM_TYPE(0x202FA6))) /* Message Object 253 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR254H  (*(_PAGE_080_MEM_TYPE(0x202FC6))) /* Message Object 254 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR255H  (*(_PAGE_080_MEM_TYPE(0x202FE6))) /* Message Object 255 FIFO/Gateway Pointer Register High */


#define CAN_MOFGPR0L    (*(_PAGE_080_MEM_TYPE(0x201004))) /* Message Object 0 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR1L    (*(_PAGE_080_MEM_TYPE(0x201024))) /* Message Object 1 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR2L    (*(_PAGE_080_MEM_TYPE(0x201044))) /* Message Object 2 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR3L    (*(_PAGE_080_MEM_TYPE(0x201064))) /* Message Object 3 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR4L    (*(_PAGE_080_MEM_TYPE(0x201084))) /* Message Object 4 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR5L    (*(_PAGE_080_MEM_TYPE(0x2010A4))) /* Message Object 5 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR6L    (*(_PAGE_080_MEM_TYPE(0x2010C4))) /* Message Object 6 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR7L    (*(_PAGE_080_MEM_TYPE(0x2010E4))) /* Message Object 7 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR8L    (*(_PAGE_080_MEM_TYPE(0x201104))) /* Message Object 8 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR9L    (*(_PAGE_080_MEM_TYPE(0x201124))) /* Message Object 9 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR10L   (*(_PAGE_080_MEM_TYPE(0x201144))) /* Message Object 10 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR11L   (*(_PAGE_080_MEM_TYPE(0x201164))) /* Message Object 11 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR12L   (*(_PAGE_080_MEM_TYPE(0x201184))) /* Message Object 12 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR13L   (*(_PAGE_080_MEM_TYPE(0x2011A4))) /* Message Object 13 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR14L   (*(_PAGE_080_MEM_TYPE(0x2011C4))) /* Message Object 14 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR15L   (*(_PAGE_080_MEM_TYPE(0x2011E4))) /* Message Object 15 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR16L   (*(_PAGE_080_MEM_TYPE(0x201204))) /* Message Object 16 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR17L   (*(_PAGE_080_MEM_TYPE(0x201224))) /* Message Object 17 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR18L   (*(_PAGE_080_MEM_TYPE(0x201244))) /* Message Object 18 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR19L   (*(_PAGE_080_MEM_TYPE(0x201264))) /* Message Object 19 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR20L   (*(_PAGE_080_MEM_TYPE(0x201284))) /* Message Object 20 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR21L   (*(_PAGE_080_MEM_TYPE(0x2012A4))) /* Message Object 21 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR22L   (*(_PAGE_080_MEM_TYPE(0x2012C4))) /* Message Object 22 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR23L   (*(_PAGE_080_MEM_TYPE(0x2012E4))) /* Message Object 23 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR24L   (*(_PAGE_080_MEM_TYPE(0x201304))) /* Message Object 24 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR25L   (*(_PAGE_080_MEM_TYPE(0x201324))) /* Message Object 25 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR26L   (*(_PAGE_080_MEM_TYPE(0x201344))) /* Message Object 26 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR27L   (*(_PAGE_080_MEM_TYPE(0x201364))) /* Message Object 27 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR28L   (*(_PAGE_080_MEM_TYPE(0x201384))) /* Message Object 28 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR29L   (*(_PAGE_080_MEM_TYPE(0x2013A4))) /* Message Object 29 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR30L   (*(_PAGE_080_MEM_TYPE(0x2013C4))) /* Message Object 30 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR31L   (*(_PAGE_080_MEM_TYPE(0x2013E4))) /* Message Object 31 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR32L   (*(_PAGE_080_MEM_TYPE(0x201404))) /* Message Object 32 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR33L   (*(_PAGE_080_MEM_TYPE(0x201424))) /* Message Object 33 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR34L   (*(_PAGE_080_MEM_TYPE(0x201444))) /* Message Object 34 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR35L   (*(_PAGE_080_MEM_TYPE(0x201464))) /* Message Object 35 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR36L   (*(_PAGE_080_MEM_TYPE(0x201484))) /* Message Object 36 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR37L   (*(_PAGE_080_MEM_TYPE(0x2014A4))) /* Message Object 37 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR38L   (*(_PAGE_080_MEM_TYPE(0x2014C4))) /* Message Object 38 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR39L   (*(_PAGE_080_MEM_TYPE(0x2014E4))) /* Message Object 39 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR40L   (*(_PAGE_080_MEM_TYPE(0x201504))) /* Message Object 40 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR41L   (*(_PAGE_080_MEM_TYPE(0x201524))) /* Message Object 41 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR42L   (*(_PAGE_080_MEM_TYPE(0x201544))) /* Message Object 42 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR43L   (*(_PAGE_080_MEM_TYPE(0x201564))) /* Message Object 43 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR44L   (*(_PAGE_080_MEM_TYPE(0x201584))) /* Message Object 44 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR45L   (*(_PAGE_080_MEM_TYPE(0x2015A4))) /* Message Object 45 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR46L   (*(_PAGE_080_MEM_TYPE(0x2015C4))) /* Message Object 46 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR47L   (*(_PAGE_080_MEM_TYPE(0x2015E4))) /* Message Object 47 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR48L   (*(_PAGE_080_MEM_TYPE(0x201604))) /* Message Object 48 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR49L   (*(_PAGE_080_MEM_TYPE(0x201624))) /* Message Object 49 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR50L   (*(_PAGE_080_MEM_TYPE(0x201644))) /* Message Object 50 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR51L   (*(_PAGE_080_MEM_TYPE(0x201664))) /* Message Object 51 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR52L   (*(_PAGE_080_MEM_TYPE(0x201684))) /* Message Object 52 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR53L   (*(_PAGE_080_MEM_TYPE(0x2016A4))) /* Message Object 53 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR54L   (*(_PAGE_080_MEM_TYPE(0x2016C4))) /* Message Object 54 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR55L   (*(_PAGE_080_MEM_TYPE(0x2016E4))) /* Message Object 55 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR56L   (*(_PAGE_080_MEM_TYPE(0x201704))) /* Message Object 56 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR57L   (*(_PAGE_080_MEM_TYPE(0x201724))) /* Message Object 57 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR58L   (*(_PAGE_080_MEM_TYPE(0x201744))) /* Message Object 58 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR59L   (*(_PAGE_080_MEM_TYPE(0x201764))) /* Message Object 59 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR60L   (*(_PAGE_080_MEM_TYPE(0x201784))) /* Message Object 60 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR61L   (*(_PAGE_080_MEM_TYPE(0x2017A4))) /* Message Object 61 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR62L   (*(_PAGE_080_MEM_TYPE(0x2017C4))) /* Message Object 62 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR63L   (*(_PAGE_080_MEM_TYPE(0x2017E4))) /* Message Object 63 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR64L   (*(_PAGE_080_MEM_TYPE(0x201804))) /* Message Object 64 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR65L   (*(_PAGE_080_MEM_TYPE(0x201824))) /* Message Object 65 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR66L   (*(_PAGE_080_MEM_TYPE(0x201844))) /* Message Object 66 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR67L   (*(_PAGE_080_MEM_TYPE(0x201864))) /* Message Object 67 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR68L   (*(_PAGE_080_MEM_TYPE(0x201884))) /* Message Object 68 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR69L   (*(_PAGE_080_MEM_TYPE(0x2018A4))) /* Message Object 69 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR70L   (*(_PAGE_080_MEM_TYPE(0x2018C4))) /* Message Object 70 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR71L   (*(_PAGE_080_MEM_TYPE(0x2018E4))) /* Message Object 71 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR72L   (*(_PAGE_080_MEM_TYPE(0x201904))) /* Message Object 72 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR73L   (*(_PAGE_080_MEM_TYPE(0x201924))) /* Message Object 73 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR74L   (*(_PAGE_080_MEM_TYPE(0x201944))) /* Message Object 74 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR75L   (*(_PAGE_080_MEM_TYPE(0x201964))) /* Message Object 75 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR76L   (*(_PAGE_080_MEM_TYPE(0x201984))) /* Message Object 76 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR77L   (*(_PAGE_080_MEM_TYPE(0x2019A4))) /* Message Object 77 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR78L   (*(_PAGE_080_MEM_TYPE(0x2019C4))) /* Message Object 78 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR79L   (*(_PAGE_080_MEM_TYPE(0x2019E4))) /* Message Object 79 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR80L   (*(_PAGE_080_MEM_TYPE(0x201A04))) /* Message Object 80 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR81L   (*(_PAGE_080_MEM_TYPE(0x201A24))) /* Message Object 81 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR82L   (*(_PAGE_080_MEM_TYPE(0x201A44))) /* Message Object 82 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR83L   (*(_PAGE_080_MEM_TYPE(0x201A64))) /* Message Object 83 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR84L   (*(_PAGE_080_MEM_TYPE(0x201A84))) /* Message Object 84 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR85L   (*(_PAGE_080_MEM_TYPE(0x201AA4))) /* Message Object 85 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR86L   (*(_PAGE_080_MEM_TYPE(0x201AC4))) /* Message Object 86 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR87L   (*(_PAGE_080_MEM_TYPE(0x201AE4))) /* Message Object 87 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR88L   (*(_PAGE_080_MEM_TYPE(0x201B04))) /* Message Object 88 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR89L   (*(_PAGE_080_MEM_TYPE(0x201B24))) /* Message Object 89 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR90L   (*(_PAGE_080_MEM_TYPE(0x201B44))) /* Message Object 90 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR91L   (*(_PAGE_080_MEM_TYPE(0x201B64))) /* Message Object 91 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR92L   (*(_PAGE_080_MEM_TYPE(0x201B84))) /* Message Object 92 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR93L   (*(_PAGE_080_MEM_TYPE(0x201BA4))) /* Message Object 93 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR94L   (*(_PAGE_080_MEM_TYPE(0x201BC4))) /* Message Object 94 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR95L   (*(_PAGE_080_MEM_TYPE(0x201BE4))) /* Message Object 95 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR96L   (*(_PAGE_080_MEM_TYPE(0x201C04))) /* Message Object 96 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR97L   (*(_PAGE_080_MEM_TYPE(0x201C24))) /* Message Object 97 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR98L   (*(_PAGE_080_MEM_TYPE(0x201C44))) /* Message Object 98 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR99L   (*(_PAGE_080_MEM_TYPE(0x201C64))) /* Message Object 99 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR100L  (*(_PAGE_080_MEM_TYPE(0x201C84))) /* Message Object 100 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR101L  (*(_PAGE_080_MEM_TYPE(0x201CA4))) /* Message Object 101 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR102L  (*(_PAGE_080_MEM_TYPE(0x201CC4))) /* Message Object 102 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR103L  (*(_PAGE_080_MEM_TYPE(0x201CE4))) /* Message Object 103 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR104L  (*(_PAGE_080_MEM_TYPE(0x201D04))) /* Message Object 104 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR105L  (*(_PAGE_080_MEM_TYPE(0x201D24))) /* Message Object 105 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR106L  (*(_PAGE_080_MEM_TYPE(0x201D44))) /* Message Object 106 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR107L  (*(_PAGE_080_MEM_TYPE(0x201D64))) /* Message Object 107 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR108L  (*(_PAGE_080_MEM_TYPE(0x201D84))) /* Message Object 108 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR109L  (*(_PAGE_080_MEM_TYPE(0x201DA4))) /* Message Object 109 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR110L  (*(_PAGE_080_MEM_TYPE(0x201DC4))) /* Message Object 110 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR111L  (*(_PAGE_080_MEM_TYPE(0x201DE4))) /* Message Object 111 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR112L  (*(_PAGE_080_MEM_TYPE(0x201E04))) /* Message Object 112 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR113L  (*(_PAGE_080_MEM_TYPE(0x201E24))) /* Message Object 113 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR114L  (*(_PAGE_080_MEM_TYPE(0x201E44))) /* Message Object 114 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR115L  (*(_PAGE_080_MEM_TYPE(0x201E64))) /* Message Object 115 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR116L  (*(_PAGE_080_MEM_TYPE(0x201E84))) /* Message Object 116 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR117L  (*(_PAGE_080_MEM_TYPE(0x201EA4))) /* Message Object 117 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR118L  (*(_PAGE_080_MEM_TYPE(0x201EC4))) /* Message Object 118 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR119L  (*(_PAGE_080_MEM_TYPE(0x201EE4))) /* Message Object 119 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR120L  (*(_PAGE_080_MEM_TYPE(0x201F04))) /* Message Object 120 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR121L  (*(_PAGE_080_MEM_TYPE(0x201F24))) /* Message Object 121 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR122L  (*(_PAGE_080_MEM_TYPE(0x201F44))) /* Message Object 122 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR123L  (*(_PAGE_080_MEM_TYPE(0x201F64))) /* Message Object 123 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR124L  (*(_PAGE_080_MEM_TYPE(0x201F84))) /* Message Object 124 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR125L  (*(_PAGE_080_MEM_TYPE(0x201FA4))) /* Message Object 125 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR126L  (*(_PAGE_080_MEM_TYPE(0x201FC4))) /* Message Object 126 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR127L  (*(_PAGE_080_MEM_TYPE(0x201FE4))) /* Message Object 127 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR128L  (*(_PAGE_080_MEM_TYPE(0x202004))) /* Message Object 128 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR129L  (*(_PAGE_080_MEM_TYPE(0x202024))) /* Message Object 129 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR130L  (*(_PAGE_080_MEM_TYPE(0x202044))) /* Message Object 130 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR131L  (*(_PAGE_080_MEM_TYPE(0x202064))) /* Message Object 131 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR132L  (*(_PAGE_080_MEM_TYPE(0x202084))) /* Message Object 132 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR133L  (*(_PAGE_080_MEM_TYPE(0x2020A4))) /* Message Object 133 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR134L  (*(_PAGE_080_MEM_TYPE(0x2020C4))) /* Message Object 134 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR135L  (*(_PAGE_080_MEM_TYPE(0x2020E4))) /* Message Object 135 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR136L  (*(_PAGE_080_MEM_TYPE(0x202104))) /* Message Object 136 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR137L  (*(_PAGE_080_MEM_TYPE(0x202124))) /* Message Object 137 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR138L  (*(_PAGE_080_MEM_TYPE(0x202144))) /* Message Object 138 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR139L  (*(_PAGE_080_MEM_TYPE(0x202164))) /* Message Object 139 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR140L  (*(_PAGE_080_MEM_TYPE(0x202184))) /* Message Object 140 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR141L  (*(_PAGE_080_MEM_TYPE(0x2021A4))) /* Message Object 141 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR142L  (*(_PAGE_080_MEM_TYPE(0x2021C4))) /* Message Object 142 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR143L  (*(_PAGE_080_MEM_TYPE(0x2021E4))) /* Message Object 143 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR144L  (*(_PAGE_080_MEM_TYPE(0x202204))) /* Message Object 144 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR145L  (*(_PAGE_080_MEM_TYPE(0x202224))) /* Message Object 145 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR146L  (*(_PAGE_080_MEM_TYPE(0x202244))) /* Message Object 146 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR147L  (*(_PAGE_080_MEM_TYPE(0x202264))) /* Message Object 147 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR148L  (*(_PAGE_080_MEM_TYPE(0x202284))) /* Message Object 148 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR149L  (*(_PAGE_080_MEM_TYPE(0x2022A4))) /* Message Object 149 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR150L  (*(_PAGE_080_MEM_TYPE(0x2022C4))) /* Message Object 150 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR151L  (*(_PAGE_080_MEM_TYPE(0x2022E4))) /* Message Object 151 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR152L  (*(_PAGE_080_MEM_TYPE(0x202304))) /* Message Object 152 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR153L  (*(_PAGE_080_MEM_TYPE(0x202324))) /* Message Object 153 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR154L  (*(_PAGE_080_MEM_TYPE(0x202344))) /* Message Object 154 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR155L  (*(_PAGE_080_MEM_TYPE(0x202364))) /* Message Object 155 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR156L  (*(_PAGE_080_MEM_TYPE(0x202384))) /* Message Object 156 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR157L  (*(_PAGE_080_MEM_TYPE(0x2023A4))) /* Message Object 157 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR158L  (*(_PAGE_080_MEM_TYPE(0x2023C4))) /* Message Object 158 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR159L  (*(_PAGE_080_MEM_TYPE(0x2023E4))) /* Message Object 159 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR160L  (*(_PAGE_080_MEM_TYPE(0x202404))) /* Message Object 160 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR161L  (*(_PAGE_080_MEM_TYPE(0x202424))) /* Message Object 161 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR162L  (*(_PAGE_080_MEM_TYPE(0x202444))) /* Message Object 162 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR163L  (*(_PAGE_080_MEM_TYPE(0x202464))) /* Message Object 163 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR164L  (*(_PAGE_080_MEM_TYPE(0x202484))) /* Message Object 164 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR165L  (*(_PAGE_080_MEM_TYPE(0x2024A4))) /* Message Object 165 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR166L  (*(_PAGE_080_MEM_TYPE(0x2024C4))) /* Message Object 166 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR167L  (*(_PAGE_080_MEM_TYPE(0x2024E4))) /* Message Object 167 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR168L  (*(_PAGE_080_MEM_TYPE(0x202504))) /* Message Object 168 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR169L  (*(_PAGE_080_MEM_TYPE(0x202524))) /* Message Object 169 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR170L  (*(_PAGE_080_MEM_TYPE(0x202544))) /* Message Object 170 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR171L  (*(_PAGE_080_MEM_TYPE(0x202564))) /* Message Object 171 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR172L  (*(_PAGE_080_MEM_TYPE(0x202584))) /* Message Object 172 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR173L  (*(_PAGE_080_MEM_TYPE(0x2025A4))) /* Message Object 173 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR174L  (*(_PAGE_080_MEM_TYPE(0x2025C4))) /* Message Object 174 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR175L  (*(_PAGE_080_MEM_TYPE(0x2025E4))) /* Message Object 175 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR176L  (*(_PAGE_080_MEM_TYPE(0x202604))) /* Message Object 176 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR177L  (*(_PAGE_080_MEM_TYPE(0x202624))) /* Message Object 177 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR178L  (*(_PAGE_080_MEM_TYPE(0x202644))) /* Message Object 178 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR179L  (*(_PAGE_080_MEM_TYPE(0x202664))) /* Message Object 179 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR180L  (*(_PAGE_080_MEM_TYPE(0x202684))) /* Message Object 180 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR181L  (*(_PAGE_080_MEM_TYPE(0x2026A4))) /* Message Object 181 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR182L  (*(_PAGE_080_MEM_TYPE(0x2026C4))) /* Message Object 182 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR183L  (*(_PAGE_080_MEM_TYPE(0x2026E4))) /* Message Object 183 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR184L  (*(_PAGE_080_MEM_TYPE(0x202704))) /* Message Object 184 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR185L  (*(_PAGE_080_MEM_TYPE(0x202724))) /* Message Object 185 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR186L  (*(_PAGE_080_MEM_TYPE(0x202744))) /* Message Object 186 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR187L  (*(_PAGE_080_MEM_TYPE(0x202764))) /* Message Object 187 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR188L  (*(_PAGE_080_MEM_TYPE(0x202784))) /* Message Object 188 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR189L  (*(_PAGE_080_MEM_TYPE(0x2027A4))) /* Message Object 189 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR190L  (*(_PAGE_080_MEM_TYPE(0x2027C4))) /* Message Object 190 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR191L  (*(_PAGE_080_MEM_TYPE(0x2027E4))) /* Message Object 191 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR192L  (*(_PAGE_080_MEM_TYPE(0x202804))) /* Message Object 192 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR193L  (*(_PAGE_080_MEM_TYPE(0x202824))) /* Message Object 193 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR194L  (*(_PAGE_080_MEM_TYPE(0x202844))) /* Message Object 194 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR195L  (*(_PAGE_080_MEM_TYPE(0x202864))) /* Message Object 195 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR196L  (*(_PAGE_080_MEM_TYPE(0x202884))) /* Message Object 196 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR197L  (*(_PAGE_080_MEM_TYPE(0x2028A4))) /* Message Object 197 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR198L  (*(_PAGE_080_MEM_TYPE(0x2028C4))) /* Message Object 198 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR199L  (*(_PAGE_080_MEM_TYPE(0x2028E4))) /* Message Object 199 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR200L  (*(_PAGE_080_MEM_TYPE(0x202904))) /* Message Object 200 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR201L  (*(_PAGE_080_MEM_TYPE(0x202924))) /* Message Object 201 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR202L  (*(_PAGE_080_MEM_TYPE(0x202944))) /* Message Object 202 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR203L  (*(_PAGE_080_MEM_TYPE(0x202964))) /* Message Object 203 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR204L  (*(_PAGE_080_MEM_TYPE(0x202984))) /* Message Object 204 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR205L  (*(_PAGE_080_MEM_TYPE(0x2029A4))) /* Message Object 205 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR206L  (*(_PAGE_080_MEM_TYPE(0x2029C4))) /* Message Object 206 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR207L  (*(_PAGE_080_MEM_TYPE(0x2029E4))) /* Message Object 207 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR208L  (*(_PAGE_080_MEM_TYPE(0x202A04))) /* Message Object 208 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR209L  (*(_PAGE_080_MEM_TYPE(0x202A24))) /* Message Object 209 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR210L  (*(_PAGE_080_MEM_TYPE(0x202A44))) /* Message Object 210 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR211L  (*(_PAGE_080_MEM_TYPE(0x202A64))) /* Message Object 211 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR212L  (*(_PAGE_080_MEM_TYPE(0x202A84))) /* Message Object 212 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR213L  (*(_PAGE_080_MEM_TYPE(0x202AA4))) /* Message Object 213 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR214L  (*(_PAGE_080_MEM_TYPE(0x202AC4))) /* Message Object 214 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR215L  (*(_PAGE_080_MEM_TYPE(0x202AE4))) /* Message Object 215 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR216L  (*(_PAGE_080_MEM_TYPE(0x202B04))) /* Message Object 216 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR217L  (*(_PAGE_080_MEM_TYPE(0x202B24))) /* Message Object 217 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR218L  (*(_PAGE_080_MEM_TYPE(0x202B44))) /* Message Object 218 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR219L  (*(_PAGE_080_MEM_TYPE(0x202B64))) /* Message Object 219 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR220L  (*(_PAGE_080_MEM_TYPE(0x202B84))) /* Message Object 220 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR221L  (*(_PAGE_080_MEM_TYPE(0x202BA4))) /* Message Object 221 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR222L  (*(_PAGE_080_MEM_TYPE(0x202BC4))) /* Message Object 222 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR223L  (*(_PAGE_080_MEM_TYPE(0x202BE4))) /* Message Object 223 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR224L  (*(_PAGE_080_MEM_TYPE(0x202C04))) /* Message Object 224 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR225L  (*(_PAGE_080_MEM_TYPE(0x202C24))) /* Message Object 225 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR226L  (*(_PAGE_080_MEM_TYPE(0x202C44))) /* Message Object 226 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR227L  (*(_PAGE_080_MEM_TYPE(0x202C64))) /* Message Object 227 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR228L  (*(_PAGE_080_MEM_TYPE(0x202C84))) /* Message Object 228 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR229L  (*(_PAGE_080_MEM_TYPE(0x202CA4))) /* Message Object 229 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR230L  (*(_PAGE_080_MEM_TYPE(0x202CC4))) /* Message Object 230 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR231L  (*(_PAGE_080_MEM_TYPE(0x202CE4))) /* Message Object 231 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR232L  (*(_PAGE_080_MEM_TYPE(0x202D04))) /* Message Object 232 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR233L  (*(_PAGE_080_MEM_TYPE(0x202D24))) /* Message Object 233 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR234L  (*(_PAGE_080_MEM_TYPE(0x202D44))) /* Message Object 234 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR235L  (*(_PAGE_080_MEM_TYPE(0x202D64))) /* Message Object 235 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR236L  (*(_PAGE_080_MEM_TYPE(0x202D84))) /* Message Object 236 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR237L  (*(_PAGE_080_MEM_TYPE(0x202DA4))) /* Message Object 237 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR238L  (*(_PAGE_080_MEM_TYPE(0x202DC4))) /* Message Object 238 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR239L  (*(_PAGE_080_MEM_TYPE(0x202DE4))) /* Message Object 239 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR240L  (*(_PAGE_080_MEM_TYPE(0x202E04))) /* Message Object 240 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR241L  (*(_PAGE_080_MEM_TYPE(0x202E24))) /* Message Object 241 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR242L  (*(_PAGE_080_MEM_TYPE(0x202E44))) /* Message Object 242 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR243L  (*(_PAGE_080_MEM_TYPE(0x202E64))) /* Message Object 243 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR244L  (*(_PAGE_080_MEM_TYPE(0x202E84))) /* Message Object 244 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR245L  (*(_PAGE_080_MEM_TYPE(0x202EA4))) /* Message Object 245 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR246L  (*(_PAGE_080_MEM_TYPE(0x202EC4))) /* Message Object 246 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR247L  (*(_PAGE_080_MEM_TYPE(0x202EE4))) /* Message Object 247 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR248L  (*(_PAGE_080_MEM_TYPE(0x202F04))) /* Message Object 248 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR249L  (*(_PAGE_080_MEM_TYPE(0x202F24))) /* Message Object 249 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR250L  (*(_PAGE_080_MEM_TYPE(0x202F44))) /* Message Object 250 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR251L  (*(_PAGE_080_MEM_TYPE(0x202F64))) /* Message Object 251 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR252L  (*(_PAGE_080_MEM_TYPE(0x202F84))) /* Message Object 252 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR253L  (*(_PAGE_080_MEM_TYPE(0x202FA4))) /* Message Object 253 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR254L  (*(_PAGE_080_MEM_TYPE(0x202FC4))) /* Message Object 254 FIFO/Gateway Pointer Register Low */


#define CAN_MOFGPR255L  (*(_PAGE_080_MEM_TYPE(0x202FE4))) /* Message Object 255 FIFO/Gateway Pointer Register Low */


#define CAN_MOAMR0H     (*(_PAGE_080_MEM_TYPE(0x20100E))) /* Message Object 0 Acceptance Mask Register High */


#define CAN_MOAMR1H     (*(_PAGE_080_MEM_TYPE(0x20102E))) /* Message Object 1 Acceptance Mask Register High */


#define CAN_MOAMR2H     (*(_PAGE_080_MEM_TYPE(0x20104E))) /* Message Object 2 Acceptance Mask Register High */


#define CAN_MOAMR3H     (*(_PAGE_080_MEM_TYPE(0x20106E))) /* Message Object 3 Acceptance Mask Register High */


#define CAN_MOAMR4H     (*(_PAGE_080_MEM_TYPE(0x20108E))) /* Message Object 4 Acceptance Mask Register High */


#define CAN_MOAMR5H     (*(_PAGE_080_MEM_TYPE(0x2010AE))) /* Message Object 5 Acceptance Mask Register High */


#define CAN_MOAMR6H     (*(_PAGE_080_MEM_TYPE(0x2010CE))) /* Message Object 6 Acceptance Mask Register High */


#define CAN_MOAMR7H     (*(_PAGE_080_MEM_TYPE(0x2010EE))) /* Message Object 7 Acceptance Mask Register High */


#define CAN_MOAMR8H     (*(_PAGE_080_MEM_TYPE(0x20110E))) /* Message Object 8 Acceptance Mask Register High */


#define CAN_MOAMR9H     (*(_PAGE_080_MEM_TYPE(0x20112E))) /* Message Object 9 Acceptance Mask Register High */


#define CAN_MOAMR10H    (*(_PAGE_080_MEM_TYPE(0x20114E))) /* Message Object 10 Acceptance Mask Register High */


#define CAN_MOAMR11H    (*(_PAGE_080_MEM_TYPE(0x20116E))) /* Message Object 11 Acceptance Mask Register High */


#define CAN_MOAMR12H    (*(_PAGE_080_MEM_TYPE(0x20118E))) /* Message Object 12 Acceptance Mask Register High */


#define CAN_MOAMR13H    (*(_PAGE_080_MEM_TYPE(0x2011AE))) /* Message Object 13 Acceptance Mask Register High */


#define CAN_MOAMR14H    (*(_PAGE_080_MEM_TYPE(0x2011CE))) /* Message Object 14 Acceptance Mask Register High */


#define CAN_MOAMR15H    (*(_PAGE_080_MEM_TYPE(0x2011EE))) /* Message Object 15 Acceptance Mask Register High */


#define CAN_MOAMR16H    (*(_PAGE_080_MEM_TYPE(0x20120E))) /* Message Object 16 Acceptance Mask Register High */


#define CAN_MOAMR17H    (*(_PAGE_080_MEM_TYPE(0x20122E))) /* Message Object 17 Acceptance Mask Register High */


#define CAN_MOAMR18H    (*(_PAGE_080_MEM_TYPE(0x20124E))) /* Message Object 18 Acceptance Mask Register High */


#define CAN_MOAMR19H    (*(_PAGE_080_MEM_TYPE(0x20126E))) /* Message Object 19 Acceptance Mask Register High */


#define CAN_MOAMR20H    (*(_PAGE_080_MEM_TYPE(0x20128E))) /* Message Object 20 Acceptance Mask Register High */


#define CAN_MOAMR21H    (*(_PAGE_080_MEM_TYPE(0x2012AE))) /* Message Object 21 Acceptance Mask Register High */


#define CAN_MOAMR22H    (*(_PAGE_080_MEM_TYPE(0x2012CE))) /* Message Object 22 Acceptance Mask Register High */


#define CAN_MOAMR23H    (*(_PAGE_080_MEM_TYPE(0x2012EE))) /* Message Object 23 Acceptance Mask Register High */


#define CAN_MOAMR24H    (*(_PAGE_080_MEM_TYPE(0x20130E))) /* Message Object 24 Acceptance Mask Register High */


#define CAN_MOAMR25H    (*(_PAGE_080_MEM_TYPE(0x20132E))) /* Message Object 25 Acceptance Mask Register High */


#define CAN_MOAMR26H    (*(_PAGE_080_MEM_TYPE(0x20134E))) /* Message Object 26 Acceptance Mask Register High */


#define CAN_MOAMR27H    (*(_PAGE_080_MEM_TYPE(0x20136E))) /* Message Object 27 Acceptance Mask Register High */


#define CAN_MOAMR28H    (*(_PAGE_080_MEM_TYPE(0x20138E))) /* Message Object 28 Acceptance Mask Register High */


#define CAN_MOAMR29H    (*(_PAGE_080_MEM_TYPE(0x2013AE))) /* Message Object 29 Acceptance Mask Register High */


#define CAN_MOAMR30H    (*(_PAGE_080_MEM_TYPE(0x2013CE))) /* Message Object 30 Acceptance Mask Register High */


#define CAN_MOAMR31H    (*(_PAGE_080_MEM_TYPE(0x2013EE))) /* Message Object 31 Acceptance Mask Register High */


#define CAN_MOAMR32H    (*(_PAGE_080_MEM_TYPE(0x20140E))) /* Message Object 32 Acceptance Mask Register High */


#define CAN_MOAMR33H    (*(_PAGE_080_MEM_TYPE(0x20142E))) /* Message Object 33 Acceptance Mask Register High */


#define CAN_MOAMR34H    (*(_PAGE_080_MEM_TYPE(0x20144E))) /* Message Object 34 Acceptance Mask Register High */


#define CAN_MOAMR35H    (*(_PAGE_080_MEM_TYPE(0x20146E))) /* Message Object 35 Acceptance Mask Register High */


#define CAN_MOAMR36H    (*(_PAGE_080_MEM_TYPE(0x20148E))) /* Message Object 36 Acceptance Mask Register High */


#define CAN_MOAMR37H    (*(_PAGE_080_MEM_TYPE(0x2014AE))) /* Message Object 37 Acceptance Mask Register High */


#define CAN_MOAMR38H    (*(_PAGE_080_MEM_TYPE(0x2014CE))) /* Message Object 38 Acceptance Mask Register High */


#define CAN_MOAMR39H    (*(_PAGE_080_MEM_TYPE(0x2014EE))) /* Message Object 39 Acceptance Mask Register High */


#define CAN_MOAMR40H    (*(_PAGE_080_MEM_TYPE(0x20150E))) /* Message Object 40 Acceptance Mask Register High */


#define CAN_MOAMR41H    (*(_PAGE_080_MEM_TYPE(0x20152E))) /* Message Object 41 Acceptance Mask Register High */


#define CAN_MOAMR42H    (*(_PAGE_080_MEM_TYPE(0x20154E))) /* Message Object 42 Acceptance Mask Register High */


#define CAN_MOAMR43H    (*(_PAGE_080_MEM_TYPE(0x20156E))) /* Message Object 43 Acceptance Mask Register High */


#define CAN_MOAMR44H    (*(_PAGE_080_MEM_TYPE(0x20158E))) /* Message Object 44 Acceptance Mask Register High */


#define CAN_MOAMR45H    (*(_PAGE_080_MEM_TYPE(0x2015AE))) /* Message Object 45 Acceptance Mask Register High */


#define CAN_MOAMR46H    (*(_PAGE_080_MEM_TYPE(0x2015CE))) /* Message Object 46 Acceptance Mask Register High */


#define CAN_MOAMR47H    (*(_PAGE_080_MEM_TYPE(0x2015EE))) /* Message Object 47 Acceptance Mask Register High */


#define CAN_MOAMR48H    (*(_PAGE_080_MEM_TYPE(0x20160E))) /* Message Object 48 Acceptance Mask Register High */


#define CAN_MOAMR49H    (*(_PAGE_080_MEM_TYPE(0x20162E))) /* Message Object 49 Acceptance Mask Register High */


#define CAN_MOAMR50H    (*(_PAGE_080_MEM_TYPE(0x20164E))) /* Message Object 50 Acceptance Mask Register High */


#define CAN_MOAMR51H    (*(_PAGE_080_MEM_TYPE(0x20166E))) /* Message Object 51 Acceptance Mask Register High */


#define CAN_MOAMR52H    (*(_PAGE_080_MEM_TYPE(0x20168E))) /* Message Object 52 Acceptance Mask Register High */


#define CAN_MOAMR53H    (*(_PAGE_080_MEM_TYPE(0x2016AE))) /* Message Object 53 Acceptance Mask Register High */


#define CAN_MOAMR54H    (*(_PAGE_080_MEM_TYPE(0x2016CE))) /* Message Object 54 Acceptance Mask Register High */


#define CAN_MOAMR55H    (*(_PAGE_080_MEM_TYPE(0x2016EE))) /* Message Object 55 Acceptance Mask Register High */


#define CAN_MOAMR56H    (*(_PAGE_080_MEM_TYPE(0x20170E))) /* Message Object 56 Acceptance Mask Register High */


#define CAN_MOAMR57H    (*(_PAGE_080_MEM_TYPE(0x20172E))) /* Message Object 57 Acceptance Mask Register High */


#define CAN_MOAMR58H    (*(_PAGE_080_MEM_TYPE(0x20174E))) /* Message Object 58 Acceptance Mask Register High */


#define CAN_MOAMR59H    (*(_PAGE_080_MEM_TYPE(0x20176E))) /* Message Object 59 Acceptance Mask Register High */


#define CAN_MOAMR60H    (*(_PAGE_080_MEM_TYPE(0x20178E))) /* Message Object 60 Acceptance Mask Register High */


#define CAN_MOAMR61H    (*(_PAGE_080_MEM_TYPE(0x2017AE))) /* Message Object 61 Acceptance Mask Register High */


#define CAN_MOAMR62H    (*(_PAGE_080_MEM_TYPE(0x2017CE))) /* Message Object 62 Acceptance Mask Register High */


#define CAN_MOAMR63H    (*(_PAGE_080_MEM_TYPE(0x2017EE))) /* Message Object 63 Acceptance Mask Register High */


#define CAN_MOAMR64H    (*(_PAGE_080_MEM_TYPE(0x20180E))) /* Message Object 64 Acceptance Mask Register High */


#define CAN_MOAMR65H    (*(_PAGE_080_MEM_TYPE(0x20182E))) /* Message Object 65 Acceptance Mask Register High */


#define CAN_MOAMR66H    (*(_PAGE_080_MEM_TYPE(0x20184E))) /* Message Object 66 Acceptance Mask Register High */


#define CAN_MOAMR67H    (*(_PAGE_080_MEM_TYPE(0x20186E))) /* Message Object 67 Acceptance Mask Register High */


#define CAN_MOAMR68H    (*(_PAGE_080_MEM_TYPE(0x20188E))) /* Message Object 68 Acceptance Mask Register High */


#define CAN_MOAMR69H    (*(_PAGE_080_MEM_TYPE(0x2018AE))) /* Message Object 69 Acceptance Mask Register High */


#define CAN_MOAMR70H    (*(_PAGE_080_MEM_TYPE(0x2018CE))) /* Message Object 70 Acceptance Mask Register High */


#define CAN_MOAMR71H    (*(_PAGE_080_MEM_TYPE(0x2018EE))) /* Message Object 71 Acceptance Mask Register High */


#define CAN_MOAMR72H    (*(_PAGE_080_MEM_TYPE(0x20190E))) /* Message Object 72 Acceptance Mask Register High */


#define CAN_MOAMR73H    (*(_PAGE_080_MEM_TYPE(0x20192E))) /* Message Object 73 Acceptance Mask Register High */


#define CAN_MOAMR74H    (*(_PAGE_080_MEM_TYPE(0x20194E))) /* Message Object 74 Acceptance Mask Register High */


#define CAN_MOAMR75H    (*(_PAGE_080_MEM_TYPE(0x20196E))) /* Message Object 75 Acceptance Mask Register High */


#define CAN_MOAMR76H    (*(_PAGE_080_MEM_TYPE(0x20198E))) /* Message Object 76 Acceptance Mask Register High */


#define CAN_MOAMR77H    (*(_PAGE_080_MEM_TYPE(0x2019AE))) /* Message Object 77 Acceptance Mask Register High */


#define CAN_MOAMR78H    (*(_PAGE_080_MEM_TYPE(0x2019CE))) /* Message Object 78 Acceptance Mask Register High */


#define CAN_MOAMR79H    (*(_PAGE_080_MEM_TYPE(0x2019EE))) /* Message Object 79 Acceptance Mask Register High */


#define CAN_MOAMR80H    (*(_PAGE_080_MEM_TYPE(0x201A0E))) /* Message Object 80 Acceptance Mask Register High */


#define CAN_MOAMR81H    (*(_PAGE_080_MEM_TYPE(0x201A2E))) /* Message Object 81 Acceptance Mask Register High */


#define CAN_MOAMR82H    (*(_PAGE_080_MEM_TYPE(0x201A4E))) /* Message Object 82 Acceptance Mask Register High */


#define CAN_MOAMR83H    (*(_PAGE_080_MEM_TYPE(0x201A6E))) /* Message Object 83 Acceptance Mask Register High */


#define CAN_MOAMR84H    (*(_PAGE_080_MEM_TYPE(0x201A8E))) /* Message Object 84 Acceptance Mask Register High */


#define CAN_MOAMR85H    (*(_PAGE_080_MEM_TYPE(0x201AAE))) /* Message Object 85 Acceptance Mask Register High */


#define CAN_MOAMR86H    (*(_PAGE_080_MEM_TYPE(0x201ACE))) /* Message Object 86 Acceptance Mask Register High */


#define CAN_MOAMR87H    (*(_PAGE_080_MEM_TYPE(0x201AEE))) /* Message Object 87 Acceptance Mask Register High */


#define CAN_MOAMR88H    (*(_PAGE_080_MEM_TYPE(0x201B0E))) /* Message Object 88 Acceptance Mask Register High */


#define CAN_MOAMR89H    (*(_PAGE_080_MEM_TYPE(0x201B2E))) /* Message Object 89 Acceptance Mask Register High */


#define CAN_MOAMR90H    (*(_PAGE_080_MEM_TYPE(0x201B4E))) /* Message Object 90 Acceptance Mask Register High */


#define CAN_MOAMR91H    (*(_PAGE_080_MEM_TYPE(0x201B6E))) /* Message Object 91 Acceptance Mask Register High */


#define CAN_MOAMR92H    (*(_PAGE_080_MEM_TYPE(0x201B8E))) /* Message Object 92 Acceptance Mask Register High */


#define CAN_MOAMR93H    (*(_PAGE_080_MEM_TYPE(0x201BAE))) /* Message Object 93 Acceptance Mask Register High */


#define CAN_MOAMR94H    (*(_PAGE_080_MEM_TYPE(0x201BCE))) /* Message Object 94 Acceptance Mask Register High */


#define CAN_MOAMR95H    (*(_PAGE_080_MEM_TYPE(0x201BEE))) /* Message Object 95 Acceptance Mask Register High */


#define CAN_MOAMR96H    (*(_PAGE_080_MEM_TYPE(0x201C0E))) /* Message Object 96 Acceptance Mask Register High */


#define CAN_MOAMR97H    (*(_PAGE_080_MEM_TYPE(0x201C2E))) /* Message Object 97 Acceptance Mask Register High */


#define CAN_MOAMR98H    (*(_PAGE_080_MEM_TYPE(0x201C4E))) /* Message Object 98 Acceptance Mask Register High */


#define CAN_MOAMR99H    (*(_PAGE_080_MEM_TYPE(0x201C6E))) /* Message Object 99 Acceptance Mask Register High */


#define CAN_MOAMR100H   (*(_PAGE_080_MEM_TYPE(0x201C8E))) /* Message Object 100 Acceptance Mask Register High */


#define CAN_MOAMR101H   (*(_PAGE_080_MEM_TYPE(0x201CAE))) /* Message Object 101 Acceptance Mask Register High */


#define CAN_MOAMR102H   (*(_PAGE_080_MEM_TYPE(0x201CCE))) /* Message Object 102 Acceptance Mask Register High */


#define CAN_MOAMR103H   (*(_PAGE_080_MEM_TYPE(0x201CEE))) /* Message Object 103 Acceptance Mask Register High */


#define CAN_MOAMR104H   (*(_PAGE_080_MEM_TYPE(0x201D0E))) /* Message Object 104 Acceptance Mask Register High */


#define CAN_MOAMR105H   (*(_PAGE_080_MEM_TYPE(0x201D2E))) /* Message Object 105 Acceptance Mask Register High */


#define CAN_MOAMR106H   (*(_PAGE_080_MEM_TYPE(0x201D4E))) /* Message Object 106 Acceptance Mask Register High */


#define CAN_MOAMR107H   (*(_PAGE_080_MEM_TYPE(0x201D6E))) /* Message Object 107 Acceptance Mask Register High */


#define CAN_MOAMR108H   (*(_PAGE_080_MEM_TYPE(0x201D8E))) /* Message Object 108 Acceptance Mask Register High */


#define CAN_MOAMR109H   (*(_PAGE_080_MEM_TYPE(0x201DAE))) /* Message Object 109 Acceptance Mask Register High */


#define CAN_MOAMR110H   (*(_PAGE_080_MEM_TYPE(0x201DCE))) /* Message Object 110 Acceptance Mask Register High */


#define CAN_MOAMR111H   (*(_PAGE_080_MEM_TYPE(0x201DEE))) /* Message Object 111 Acceptance Mask Register High */


#define CAN_MOAMR112H   (*(_PAGE_080_MEM_TYPE(0x201E0E))) /* Message Object 112 Acceptance Mask Register High */


#define CAN_MOAMR113H   (*(_PAGE_080_MEM_TYPE(0x201E2E))) /* Message Object 113 Acceptance Mask Register High */


#define CAN_MOAMR114H   (*(_PAGE_080_MEM_TYPE(0x201E4E))) /* Message Object 114 Acceptance Mask Register High */


#define CAN_MOAMR115H   (*(_PAGE_080_MEM_TYPE(0x201E6E))) /* Message Object 115 Acceptance Mask Register High */


#define CAN_MOAMR116H   (*(_PAGE_080_MEM_TYPE(0x201E8E))) /* Message Object 116 Acceptance Mask Register High */


#define CAN_MOAMR117H   (*(_PAGE_080_MEM_TYPE(0x201EAE))) /* Message Object 117 Acceptance Mask Register High */


#define CAN_MOAMR118H   (*(_PAGE_080_MEM_TYPE(0x201ECE))) /* Message Object 118 Acceptance Mask Register High */


#define CAN_MOAMR119H   (*(_PAGE_080_MEM_TYPE(0x201EEE))) /* Message Object 119 Acceptance Mask Register High */


#define CAN_MOAMR120H   (*(_PAGE_080_MEM_TYPE(0x201F0E))) /* Message Object 120 Acceptance Mask Register High */


#define CAN_MOAMR121H   (*(_PAGE_080_MEM_TYPE(0x201F2E))) /* Message Object 121 Acceptance Mask Register High */


#define CAN_MOAMR122H   (*(_PAGE_080_MEM_TYPE(0x201F4E))) /* Message Object 122 Acceptance Mask Register High */


#define CAN_MOAMR123H   (*(_PAGE_080_MEM_TYPE(0x201F6E))) /* Message Object 123 Acceptance Mask Register High */


#define CAN_MOAMR124H   (*(_PAGE_080_MEM_TYPE(0x201F8E))) /* Message Object 124 Acceptance Mask Register High */


#define CAN_MOAMR125H   (*(_PAGE_080_MEM_TYPE(0x201FAE))) /* Message Object 125 Acceptance Mask Register High */


#define CAN_MOAMR126H   (*(_PAGE_080_MEM_TYPE(0x201FCE))) /* Message Object 126 Acceptance Mask Register High */


#define CAN_MOAMR127H   (*(_PAGE_080_MEM_TYPE(0x201FEE))) /* Message Object 127 Acceptance Mask Register High */


#define CAN_MOAMR128H   (*(_PAGE_080_MEM_TYPE(0x20200E))) /* Message Object 128 Acceptance Mask Register High */


#define CAN_MOAMR129H   (*(_PAGE_080_MEM_TYPE(0x20202E))) /* Message Object 129 Acceptance Mask Register High */


#define CAN_MOAMR130H   (*(_PAGE_080_MEM_TYPE(0x20204E))) /* Message Object 130 Acceptance Mask Register High */


#define CAN_MOAMR131H   (*(_PAGE_080_MEM_TYPE(0x20206E))) /* Message Object 131 Acceptance Mask Register High */


#define CAN_MOAMR132H   (*(_PAGE_080_MEM_TYPE(0x20208E))) /* Message Object 132 Acceptance Mask Register High */


#define CAN_MOAMR133H   (*(_PAGE_080_MEM_TYPE(0x2020AE))) /* Message Object 133 Acceptance Mask Register High */


#define CAN_MOAMR134H   (*(_PAGE_080_MEM_TYPE(0x2020CE))) /* Message Object 134 Acceptance Mask Register High */


#define CAN_MOAMR135H   (*(_PAGE_080_MEM_TYPE(0x2020EE))) /* Message Object 135 Acceptance Mask Register High */


#define CAN_MOAMR136H   (*(_PAGE_080_MEM_TYPE(0x20210E))) /* Message Object 136 Acceptance Mask Register High */


#define CAN_MOAMR137H   (*(_PAGE_080_MEM_TYPE(0x20212E))) /* Message Object 137 Acceptance Mask Register High */


#define CAN_MOAMR138H   (*(_PAGE_080_MEM_TYPE(0x20214E))) /* Message Object 138 Acceptance Mask Register High */


#define CAN_MOAMR139H   (*(_PAGE_080_MEM_TYPE(0x20216E))) /* Message Object 139 Acceptance Mask Register High */


#define CAN_MOAMR140H   (*(_PAGE_080_MEM_TYPE(0x20218E))) /* Message Object 140 Acceptance Mask Register High */


#define CAN_MOAMR141H   (*(_PAGE_080_MEM_TYPE(0x2021AE))) /* Message Object 141 Acceptance Mask Register High */


#define CAN_MOAMR142H   (*(_PAGE_080_MEM_TYPE(0x2021CE))) /* Message Object 142 Acceptance Mask Register High */


#define CAN_MOAMR143H   (*(_PAGE_080_MEM_TYPE(0x2021EE))) /* Message Object 143 Acceptance Mask Register High */


#define CAN_MOAMR144H   (*(_PAGE_080_MEM_TYPE(0x20220E))) /* Message Object 144 Acceptance Mask Register High */


#define CAN_MOAMR145H   (*(_PAGE_080_MEM_TYPE(0x20222E))) /* Message Object 145 Acceptance Mask Register High */


#define CAN_MOAMR146H   (*(_PAGE_080_MEM_TYPE(0x20224E))) /* Message Object 146 Acceptance Mask Register High */


#define CAN_MOAMR147H   (*(_PAGE_080_MEM_TYPE(0x20226E))) /* Message Object 147 Acceptance Mask Register High */


#define CAN_MOAMR148H   (*(_PAGE_080_MEM_TYPE(0x20228E))) /* Message Object 148 Acceptance Mask Register High */


#define CAN_MOAMR149H   (*(_PAGE_080_MEM_TYPE(0x2022AE))) /* Message Object 149 Acceptance Mask Register High */


#define CAN_MOAMR150H   (*(_PAGE_080_MEM_TYPE(0x2022CE))) /* Message Object 150 Acceptance Mask Register High */


#define CAN_MOAMR151H   (*(_PAGE_080_MEM_TYPE(0x2022EE))) /* Message Object 151 Acceptance Mask Register High */


#define CAN_MOAMR152H   (*(_PAGE_080_MEM_TYPE(0x20230E))) /* Message Object 152 Acceptance Mask Register High */


#define CAN_MOAMR153H   (*(_PAGE_080_MEM_TYPE(0x20232E))) /* Message Object 153 Acceptance Mask Register High */


#define CAN_MOAMR154H   (*(_PAGE_080_MEM_TYPE(0x20234E))) /* Message Object 154 Acceptance Mask Register High */


#define CAN_MOAMR155H   (*(_PAGE_080_MEM_TYPE(0x20236E))) /* Message Object 155 Acceptance Mask Register High */


#define CAN_MOAMR156H   (*(_PAGE_080_MEM_TYPE(0x20238E))) /* Message Object 156 Acceptance Mask Register High */


#define CAN_MOAMR157H   (*(_PAGE_080_MEM_TYPE(0x2023AE))) /* Message Object 157 Acceptance Mask Register High */


#define CAN_MOAMR158H   (*(_PAGE_080_MEM_TYPE(0x2023CE))) /* Message Object 158 Acceptance Mask Register High */


#define CAN_MOAMR159H   (*(_PAGE_080_MEM_TYPE(0x2023EE))) /* Message Object 159 Acceptance Mask Register High */


#define CAN_MOAMR160H   (*(_PAGE_080_MEM_TYPE(0x20240E))) /* Message Object 160 Acceptance Mask Register High */


#define CAN_MOAMR161H   (*(_PAGE_080_MEM_TYPE(0x20242E))) /* Message Object 161 Acceptance Mask Register High */


#define CAN_MOAMR162H   (*(_PAGE_080_MEM_TYPE(0x20244E))) /* Message Object 162 Acceptance Mask Register High */


#define CAN_MOAMR163H   (*(_PAGE_080_MEM_TYPE(0x20246E))) /* Message Object 163 Acceptance Mask Register High */


#define CAN_MOAMR164H   (*(_PAGE_080_MEM_TYPE(0x20248E))) /* Message Object 164 Acceptance Mask Register High */


#define CAN_MOAMR165H   (*(_PAGE_080_MEM_TYPE(0x2024AE))) /* Message Object 165 Acceptance Mask Register High */


#define CAN_MOAMR166H   (*(_PAGE_080_MEM_TYPE(0x2024CE))) /* Message Object 166 Acceptance Mask Register High */


#define CAN_MOAMR167H   (*(_PAGE_080_MEM_TYPE(0x2024EE))) /* Message Object 167 Acceptance Mask Register High */


#define CAN_MOAMR168H   (*(_PAGE_080_MEM_TYPE(0x20250E))) /* Message Object 168 Acceptance Mask Register High */


#define CAN_MOAMR169H   (*(_PAGE_080_MEM_TYPE(0x20252E))) /* Message Object 169 Acceptance Mask Register High */


#define CAN_MOAMR170H   (*(_PAGE_080_MEM_TYPE(0x20254E))) /* Message Object 170 Acceptance Mask Register High */


#define CAN_MOAMR171H   (*(_PAGE_080_MEM_TYPE(0x20256E))) /* Message Object 171 Acceptance Mask Register High */


#define CAN_MOAMR172H   (*(_PAGE_080_MEM_TYPE(0x20258E))) /* Message Object 172 Acceptance Mask Register High */


#define CAN_MOAMR173H   (*(_PAGE_080_MEM_TYPE(0x2025AE))) /* Message Object 173 Acceptance Mask Register High */


#define CAN_MOAMR174H   (*(_PAGE_080_MEM_TYPE(0x2025CE))) /* Message Object 174 Acceptance Mask Register High */


#define CAN_MOAMR175H   (*(_PAGE_080_MEM_TYPE(0x2025EE))) /* Message Object 175 Acceptance Mask Register High */


#define CAN_MOAMR176H   (*(_PAGE_080_MEM_TYPE(0x20260E))) /* Message Object 176 Acceptance Mask Register High */


#define CAN_MOAMR177H   (*(_PAGE_080_MEM_TYPE(0x20262E))) /* Message Object 177 Acceptance Mask Register High */


#define CAN_MOAMR178H   (*(_PAGE_080_MEM_TYPE(0x20264E))) /* Message Object 178 Acceptance Mask Register High */


#define CAN_MOAMR179H   (*(_PAGE_080_MEM_TYPE(0x20266E))) /* Message Object 179 Acceptance Mask Register High */


#define CAN_MOAMR180H   (*(_PAGE_080_MEM_TYPE(0x20268E))) /* Message Object 180 Acceptance Mask Register High */


#define CAN_MOAMR181H   (*(_PAGE_080_MEM_TYPE(0x2026AE))) /* Message Object 181 Acceptance Mask Register High */


#define CAN_MOAMR182H   (*(_PAGE_080_MEM_TYPE(0x2026CE))) /* Message Object 182 Acceptance Mask Register High */


#define CAN_MOAMR183H   (*(_PAGE_080_MEM_TYPE(0x2026EE))) /* Message Object 183 Acceptance Mask Register High */


#define CAN_MOAMR184H   (*(_PAGE_080_MEM_TYPE(0x20270E))) /* Message Object 184 Acceptance Mask Register High */


#define CAN_MOAMR185H   (*(_PAGE_080_MEM_TYPE(0x20272E))) /* Message Object 185 Acceptance Mask Register High */


#define CAN_MOAMR186H   (*(_PAGE_080_MEM_TYPE(0x20274E))) /* Message Object 186 Acceptance Mask Register High */


#define CAN_MOAMR187H   (*(_PAGE_080_MEM_TYPE(0x20276E))) /* Message Object 187 Acceptance Mask Register High */


#define CAN_MOAMR188H   (*(_PAGE_080_MEM_TYPE(0x20278E))) /* Message Object 188 Acceptance Mask Register High */


#define CAN_MOAMR189H   (*(_PAGE_080_MEM_TYPE(0x2027AE))) /* Message Object 189 Acceptance Mask Register High */


#define CAN_MOAMR190H   (*(_PAGE_080_MEM_TYPE(0x2027CE))) /* Message Object 190 Acceptance Mask Register High */


#define CAN_MOAMR191H   (*(_PAGE_080_MEM_TYPE(0x2027EE))) /* Message Object 191 Acceptance Mask Register High */


#define CAN_MOAMR192H   (*(_PAGE_080_MEM_TYPE(0x20280E))) /* Message Object 192 Acceptance Mask Register High */


#define CAN_MOAMR193H   (*(_PAGE_080_MEM_TYPE(0x20282E))) /* Message Object 193 Acceptance Mask Register High */


#define CAN_MOAMR194H   (*(_PAGE_080_MEM_TYPE(0x20284E))) /* Message Object 194 Acceptance Mask Register High */


#define CAN_MOAMR195H   (*(_PAGE_080_MEM_TYPE(0x20286E))) /* Message Object 195 Acceptance Mask Register High */


#define CAN_MOAMR196H   (*(_PAGE_080_MEM_TYPE(0x20288E))) /* Message Object 196 Acceptance Mask Register High */


#define CAN_MOAMR197H   (*(_PAGE_080_MEM_TYPE(0x2028AE))) /* Message Object 197 Acceptance Mask Register High */


#define CAN_MOAMR198H   (*(_PAGE_080_MEM_TYPE(0x2028CE))) /* Message Object 198 Acceptance Mask Register High */


#define CAN_MOAMR199H   (*(_PAGE_080_MEM_TYPE(0x2028EE))) /* Message Object 199 Acceptance Mask Register High */


#define CAN_MOAMR200H   (*(_PAGE_080_MEM_TYPE(0x20290E))) /* Message Object 200 Acceptance Mask Register High */


#define CAN_MOAMR201H   (*(_PAGE_080_MEM_TYPE(0x20292E))) /* Message Object 201 Acceptance Mask Register High */


#define CAN_MOAMR202H   (*(_PAGE_080_MEM_TYPE(0x20294E))) /* Message Object 202 Acceptance Mask Register High */


#define CAN_MOAMR203H   (*(_PAGE_080_MEM_TYPE(0x20296E))) /* Message Object 203 Acceptance Mask Register High */


#define CAN_MOAMR204H   (*(_PAGE_080_MEM_TYPE(0x20298E))) /* Message Object 204 Acceptance Mask Register High */


#define CAN_MOAMR205H   (*(_PAGE_080_MEM_TYPE(0x2029AE))) /* Message Object 205 Acceptance Mask Register High */


#define CAN_MOAMR206H   (*(_PAGE_080_MEM_TYPE(0x2029CE))) /* Message Object 206 Acceptance Mask Register High */


#define CAN_MOAMR207H   (*(_PAGE_080_MEM_TYPE(0x2029EE))) /* Message Object 207 Acceptance Mask Register High */


#define CAN_MOAMR208H   (*(_PAGE_080_MEM_TYPE(0x202A0E))) /* Message Object 208 Acceptance Mask Register High */


#define CAN_MOAMR209H   (*(_PAGE_080_MEM_TYPE(0x202A2E))) /* Message Object 209 Acceptance Mask Register High */


#define CAN_MOAMR210H   (*(_PAGE_080_MEM_TYPE(0x202A4E))) /* Message Object 210 Acceptance Mask Register High */


#define CAN_MOAMR211H   (*(_PAGE_080_MEM_TYPE(0x202A6E))) /* Message Object 211 Acceptance Mask Register High */


#define CAN_MOAMR212H   (*(_PAGE_080_MEM_TYPE(0x202A8E))) /* Message Object 212 Acceptance Mask Register High */


#define CAN_MOAMR213H   (*(_PAGE_080_MEM_TYPE(0x202AAE))) /* Message Object 213 Acceptance Mask Register High */


#define CAN_MOAMR214H   (*(_PAGE_080_MEM_TYPE(0x202ACE))) /* Message Object 214 Acceptance Mask Register High */


#define CAN_MOAMR215H   (*(_PAGE_080_MEM_TYPE(0x202AEE))) /* Message Object 215 Acceptance Mask Register High */


#define CAN_MOAMR216H   (*(_PAGE_080_MEM_TYPE(0x202B0E))) /* Message Object 216 Acceptance Mask Register High */


#define CAN_MOAMR217H   (*(_PAGE_080_MEM_TYPE(0x202B2E))) /* Message Object 217 Acceptance Mask Register High */


#define CAN_MOAMR218H   (*(_PAGE_080_MEM_TYPE(0x202B4E))) /* Message Object 218 Acceptance Mask Register High */


#define CAN_MOAMR219H   (*(_PAGE_080_MEM_TYPE(0x202B6E))) /* Message Object 219 Acceptance Mask Register High */


#define CAN_MOAMR220H   (*(_PAGE_080_MEM_TYPE(0x202B8E))) /* Message Object 220 Acceptance Mask Register High */


#define CAN_MOAMR221H   (*(_PAGE_080_MEM_TYPE(0x202BAE))) /* Message Object 221 Acceptance Mask Register High */


#define CAN_MOAMR222H   (*(_PAGE_080_MEM_TYPE(0x202BCE))) /* Message Object 222 Acceptance Mask Register High */


#define CAN_MOAMR223H   (*(_PAGE_080_MEM_TYPE(0x202BEE))) /* Message Object 223 Acceptance Mask Register High */


#define CAN_MOAMR224H   (*(_PAGE_080_MEM_TYPE(0x202C0E))) /* Message Object 224 Acceptance Mask Register High */


#define CAN_MOAMR225H   (*(_PAGE_080_MEM_TYPE(0x202C2E))) /* Message Object 225 Acceptance Mask Register High */


#define CAN_MOAMR226H   (*(_PAGE_080_MEM_TYPE(0x202C4E))) /* Message Object 226 Acceptance Mask Register High */


#define CAN_MOAMR227H   (*(_PAGE_080_MEM_TYPE(0x202C6E))) /* Message Object 227 Acceptance Mask Register High */


#define CAN_MOAMR228H   (*(_PAGE_080_MEM_TYPE(0x202C8E))) /* Message Object 228 Acceptance Mask Register High */


#define CAN_MOAMR229H   (*(_PAGE_080_MEM_TYPE(0x202CAE))) /* Message Object 229 Acceptance Mask Register High */


#define CAN_MOAMR230H   (*(_PAGE_080_MEM_TYPE(0x202CCE))) /* Message Object 230 Acceptance Mask Register High */


#define CAN_MOAMR231H   (*(_PAGE_080_MEM_TYPE(0x202CEE))) /* Message Object 231 Acceptance Mask Register High */


#define CAN_MOAMR232H   (*(_PAGE_080_MEM_TYPE(0x202D0E))) /* Message Object 232 Acceptance Mask Register High */


#define CAN_MOAMR233H   (*(_PAGE_080_MEM_TYPE(0x202D2E))) /* Message Object 233 Acceptance Mask Register High */


#define CAN_MOAMR234H   (*(_PAGE_080_MEM_TYPE(0x202D4E))) /* Message Object 234 Acceptance Mask Register High */


#define CAN_MOAMR235H   (*(_PAGE_080_MEM_TYPE(0x202D6E))) /* Message Object 235 Acceptance Mask Register High */


#define CAN_MOAMR236H   (*(_PAGE_080_MEM_TYPE(0x202D8E))) /* Message Object 236 Acceptance Mask Register High */


#define CAN_MOAMR237H   (*(_PAGE_080_MEM_TYPE(0x202DAE))) /* Message Object 237 Acceptance Mask Register High */


#define CAN_MOAMR238H   (*(_PAGE_080_MEM_TYPE(0x202DCE))) /* Message Object 238 Acceptance Mask Register High */


#define CAN_MOAMR239H   (*(_PAGE_080_MEM_TYPE(0x202DEE))) /* Message Object 239 Acceptance Mask Register High */


#define CAN_MOAMR240H   (*(_PAGE_080_MEM_TYPE(0x202E0E))) /* Message Object 240 Acceptance Mask Register High */


#define CAN_MOAMR241H   (*(_PAGE_080_MEM_TYPE(0x202E2E))) /* Message Object 241 Acceptance Mask Register High */


#define CAN_MOAMR242H   (*(_PAGE_080_MEM_TYPE(0x202E4E))) /* Message Object 242 Acceptance Mask Register High */


#define CAN_MOAMR243H   (*(_PAGE_080_MEM_TYPE(0x202E6E))) /* Message Object 243 Acceptance Mask Register High */


#define CAN_MOAMR244H   (*(_PAGE_080_MEM_TYPE(0x202E8E))) /* Message Object 244 Acceptance Mask Register High */


#define CAN_MOAMR245H   (*(_PAGE_080_MEM_TYPE(0x202EAE))) /* Message Object 245 Acceptance Mask Register High */


#define CAN_MOAMR246H   (*(_PAGE_080_MEM_TYPE(0x202ECE))) /* Message Object 246 Acceptance Mask Register High */


#define CAN_MOAMR247H   (*(_PAGE_080_MEM_TYPE(0x202EEE))) /* Message Object 247 Acceptance Mask Register High */


#define CAN_MOAMR248H   (*(_PAGE_080_MEM_TYPE(0x202F0E))) /* Message Object 248 Acceptance Mask Register High */


#define CAN_MOAMR249H   (*(_PAGE_080_MEM_TYPE(0x202F2E))) /* Message Object 249 Acceptance Mask Register High */


#define CAN_MOAMR250H   (*(_PAGE_080_MEM_TYPE(0x202F4E))) /* Message Object 250 Acceptance Mask Register High */


#define CAN_MOAMR251H   (*(_PAGE_080_MEM_TYPE(0x202F6E))) /* Message Object 251 Acceptance Mask Register High */


#define CAN_MOAMR252H   (*(_PAGE_080_MEM_TYPE(0x202F8E))) /* Message Object 252 Acceptance Mask Register High */


#define CAN_MOAMR253H   (*(_PAGE_080_MEM_TYPE(0x202FAE))) /* Message Object 253 Acceptance Mask Register High */


#define CAN_MOAMR254H   (*(_PAGE_080_MEM_TYPE(0x202FCE))) /* Message Object 254 Acceptance Mask Register High */


#define CAN_MOAMR255H   (*(_PAGE_080_MEM_TYPE(0x202FEE))) /* Message Object 255 Acceptance Mask Register High */


#define CAN_MOAMR0L     (*(_PAGE_080_MEM_TYPE(0x20100C))) /* Message Object 0 Acceptance Mask Register Low */


#define CAN_MOAMR1L     (*(_PAGE_080_MEM_TYPE(0x20102C))) /* Message Object 1 Acceptance Mask Register Low */


#define CAN_MOAMR2L     (*(_PAGE_080_MEM_TYPE(0x20104C))) /* Message Object 2 Acceptance Mask Register Low */


#define CAN_MOAMR3L     (*(_PAGE_080_MEM_TYPE(0x20106C))) /* Message Object 3 Acceptance Mask Register Low */


#define CAN_MOAMR4L     (*(_PAGE_080_MEM_TYPE(0x20108C))) /* Message Object 4 Acceptance Mask Register Low */


#define CAN_MOAMR5L     (*(_PAGE_080_MEM_TYPE(0x2010AC))) /* Message Object 5 Acceptance Mask Register Low */


#define CAN_MOAMR6L     (*(_PAGE_080_MEM_TYPE(0x2010CC))) /* Message Object 6 Acceptance Mask Register Low */


#define CAN_MOAMR7L     (*(_PAGE_080_MEM_TYPE(0x2010EC))) /* Message Object 7 Acceptance Mask Register Low */


#define CAN_MOAMR8L     (*(_PAGE_080_MEM_TYPE(0x20110C))) /* Message Object 8 Acceptance Mask Register Low */


#define CAN_MOAMR9L     (*(_PAGE_080_MEM_TYPE(0x20112C))) /* Message Object 9 Acceptance Mask Register Low */


#define CAN_MOAMR10L    (*(_PAGE_080_MEM_TYPE(0x20114C))) /* Message Object 10 Acceptance Mask Register Low */


#define CAN_MOAMR11L    (*(_PAGE_080_MEM_TYPE(0x20116C))) /* Message Object 11 Acceptance Mask Register Low */


#define CAN_MOAMR12L    (*(_PAGE_080_MEM_TYPE(0x20118C))) /* Message Object 12 Acceptance Mask Register Low */


#define CAN_MOAMR13L    (*(_PAGE_080_MEM_TYPE(0x2011AC))) /* Message Object 13 Acceptance Mask Register Low */


#define CAN_MOAMR14L    (*(_PAGE_080_MEM_TYPE(0x2011CC))) /* Message Object 14 Acceptance Mask Register Low */


#define CAN_MOAMR15L    (*(_PAGE_080_MEM_TYPE(0x2011EC))) /* Message Object 15 Acceptance Mask Register Low */


#define CAN_MOAMR16L    (*(_PAGE_080_MEM_TYPE(0x20120C))) /* Message Object 16 Acceptance Mask Register Low */


#define CAN_MOAMR17L    (*(_PAGE_080_MEM_TYPE(0x20122C))) /* Message Object 17 Acceptance Mask Register Low */


#define CAN_MOAMR18L    (*(_PAGE_080_MEM_TYPE(0x20124C))) /* Message Object 18 Acceptance Mask Register Low */


#define CAN_MOAMR19L    (*(_PAGE_080_MEM_TYPE(0x20126C))) /* Message Object 19 Acceptance Mask Register Low */


#define CAN_MOAMR20L    (*(_PAGE_080_MEM_TYPE(0x20128C))) /* Message Object 20 Acceptance Mask Register Low */


#define CAN_MOAMR21L    (*(_PAGE_080_MEM_TYPE(0x2012AC))) /* Message Object 21 Acceptance Mask Register Low */


#define CAN_MOAMR22L    (*(_PAGE_080_MEM_TYPE(0x2012CC))) /* Message Object 22 Acceptance Mask Register Low */


#define CAN_MOAMR23L    (*(_PAGE_080_MEM_TYPE(0x2012EC))) /* Message Object 23 Acceptance Mask Register Low */


#define CAN_MOAMR24L    (*(_PAGE_080_MEM_TYPE(0x20130C))) /* Message Object 24 Acceptance Mask Register Low */


#define CAN_MOAMR25L    (*(_PAGE_080_MEM_TYPE(0x20132C))) /* Message Object 25 Acceptance Mask Register Low */


#define CAN_MOAMR26L    (*(_PAGE_080_MEM_TYPE(0x20134C))) /* Message Object 26 Acceptance Mask Register Low */


#define CAN_MOAMR27L    (*(_PAGE_080_MEM_TYPE(0x20136C))) /* Message Object 27 Acceptance Mask Register Low */


#define CAN_MOAMR28L    (*(_PAGE_080_MEM_TYPE(0x20138C))) /* Message Object 28 Acceptance Mask Register Low */


#define CAN_MOAMR29L    (*(_PAGE_080_MEM_TYPE(0x2013AC))) /* Message Object 29 Acceptance Mask Register Low */


#define CAN_MOAMR30L    (*(_PAGE_080_MEM_TYPE(0x2013CC))) /* Message Object 30 Acceptance Mask Register Low */


#define CAN_MOAMR31L    (*(_PAGE_080_MEM_TYPE(0x2013EC))) /* Message Object 31 Acceptance Mask Register Low */


#define CAN_MOAMR32L    (*(_PAGE_080_MEM_TYPE(0x20140C))) /* Message Object 32 Acceptance Mask Register Low */


#define CAN_MOAMR33L    (*(_PAGE_080_MEM_TYPE(0x20142C))) /* Message Object 33 Acceptance Mask Register Low */


#define CAN_MOAMR34L    (*(_PAGE_080_MEM_TYPE(0x20144C))) /* Message Object 34 Acceptance Mask Register Low */


#define CAN_MOAMR35L    (*(_PAGE_080_MEM_TYPE(0x20146C))) /* Message Object 35 Acceptance Mask Register Low */


#define CAN_MOAMR36L    (*(_PAGE_080_MEM_TYPE(0x20148C))) /* Message Object 36 Acceptance Mask Register Low */


#define CAN_MOAMR37L    (*(_PAGE_080_MEM_TYPE(0x2014AC))) /* Message Object 37 Acceptance Mask Register Low */


#define CAN_MOAMR38L    (*(_PAGE_080_MEM_TYPE(0x2014CC))) /* Message Object 38 Acceptance Mask Register Low */


#define CAN_MOAMR39L    (*(_PAGE_080_MEM_TYPE(0x2014EC))) /* Message Object 39 Acceptance Mask Register Low */


#define CAN_MOAMR40L    (*(_PAGE_080_MEM_TYPE(0x20150C))) /* Message Object 40 Acceptance Mask Register Low */


#define CAN_MOAMR41L    (*(_PAGE_080_MEM_TYPE(0x20152C))) /* Message Object 41 Acceptance Mask Register Low */


#define CAN_MOAMR42L    (*(_PAGE_080_MEM_TYPE(0x20154C))) /* Message Object 42 Acceptance Mask Register Low */


#define CAN_MOAMR43L    (*(_PAGE_080_MEM_TYPE(0x20156C))) /* Message Object 43 Acceptance Mask Register Low */


#define CAN_MOAMR44L    (*(_PAGE_080_MEM_TYPE(0x20158C))) /* Message Object 44 Acceptance Mask Register Low */


#define CAN_MOAMR45L    (*(_PAGE_080_MEM_TYPE(0x2015AC))) /* Message Object 45 Acceptance Mask Register Low */


#define CAN_MOAMR46L    (*(_PAGE_080_MEM_TYPE(0x2015CC))) /* Message Object 46 Acceptance Mask Register Low */


#define CAN_MOAMR47L    (*(_PAGE_080_MEM_TYPE(0x2015EC))) /* Message Object 47 Acceptance Mask Register Low */


#define CAN_MOAMR48L    (*(_PAGE_080_MEM_TYPE(0x20160C))) /* Message Object 48 Acceptance Mask Register Low */


#define CAN_MOAMR49L    (*(_PAGE_080_MEM_TYPE(0x20162C))) /* Message Object 49 Acceptance Mask Register Low */


#define CAN_MOAMR50L    (*(_PAGE_080_MEM_TYPE(0x20164C))) /* Message Object 50 Acceptance Mask Register Low */


#define CAN_MOAMR51L    (*(_PAGE_080_MEM_TYPE(0x20166C))) /* Message Object 51 Acceptance Mask Register Low */


#define CAN_MOAMR52L    (*(_PAGE_080_MEM_TYPE(0x20168C))) /* Message Object 52 Acceptance Mask Register Low */


#define CAN_MOAMR53L    (*(_PAGE_080_MEM_TYPE(0x2016AC))) /* Message Object 53 Acceptance Mask Register Low */


#define CAN_MOAMR54L    (*(_PAGE_080_MEM_TYPE(0x2016CC))) /* Message Object 54 Acceptance Mask Register Low */


#define CAN_MOAMR55L    (*(_PAGE_080_MEM_TYPE(0x2016EC))) /* Message Object 55 Acceptance Mask Register Low */


#define CAN_MOAMR56L    (*(_PAGE_080_MEM_TYPE(0x20170C))) /* Message Object 56 Acceptance Mask Register Low */


#define CAN_MOAMR57L    (*(_PAGE_080_MEM_TYPE(0x20172C))) /* Message Object 57 Acceptance Mask Register Low */


#define CAN_MOAMR58L    (*(_PAGE_080_MEM_TYPE(0x20174C))) /* Message Object 58 Acceptance Mask Register Low */


#define CAN_MOAMR59L    (*(_PAGE_080_MEM_TYPE(0x20176C))) /* Message Object 59 Acceptance Mask Register Low */


#define CAN_MOAMR60L    (*(_PAGE_080_MEM_TYPE(0x20178C))) /* Message Object 60 Acceptance Mask Register Low */


#define CAN_MOAMR61L    (*(_PAGE_080_MEM_TYPE(0x2017AC))) /* Message Object 61 Acceptance Mask Register Low */


#define CAN_MOAMR62L    (*(_PAGE_080_MEM_TYPE(0x2017CC))) /* Message Object 62 Acceptance Mask Register Low */


#define CAN_MOAMR63L    (*(_PAGE_080_MEM_TYPE(0x2017EC))) /* Message Object 63 Acceptance Mask Register Low */


#define CAN_MOAMR64L    (*(_PAGE_080_MEM_TYPE(0x20180C))) /* Message Object 64 Acceptance Mask Register Low */


#define CAN_MOAMR65L    (*(_PAGE_080_MEM_TYPE(0x20182C))) /* Message Object 65 Acceptance Mask Register Low */


#define CAN_MOAMR66L    (*(_PAGE_080_MEM_TYPE(0x20184C))) /* Message Object 66 Acceptance Mask Register Low */


#define CAN_MOAMR67L    (*(_PAGE_080_MEM_TYPE(0x20186C))) /* Message Object 67 Acceptance Mask Register Low */


#define CAN_MOAMR68L    (*(_PAGE_080_MEM_TYPE(0x20188C))) /* Message Object 68 Acceptance Mask Register Low */


#define CAN_MOAMR69L    (*(_PAGE_080_MEM_TYPE(0x2018AC))) /* Message Object 69 Acceptance Mask Register Low */


#define CAN_MOAMR70L    (*(_PAGE_080_MEM_TYPE(0x2018CC))) /* Message Object 70 Acceptance Mask Register Low */


#define CAN_MOAMR71L    (*(_PAGE_080_MEM_TYPE(0x2018EC))) /* Message Object 71 Acceptance Mask Register Low */


#define CAN_MOAMR72L    (*(_PAGE_080_MEM_TYPE(0x20190C))) /* Message Object 72 Acceptance Mask Register Low */


#define CAN_MOAMR73L    (*(_PAGE_080_MEM_TYPE(0x20192C))) /* Message Object 73 Acceptance Mask Register Low */


#define CAN_MOAMR74L    (*(_PAGE_080_MEM_TYPE(0x20194C))) /* Message Object 74 Acceptance Mask Register Low */


#define CAN_MOAMR75L    (*(_PAGE_080_MEM_TYPE(0x20196C))) /* Message Object 75 Acceptance Mask Register Low */


#define CAN_MOAMR76L    (*(_PAGE_080_MEM_TYPE(0x20198C))) /* Message Object 76 Acceptance Mask Register Low */


#define CAN_MOAMR77L    (*(_PAGE_080_MEM_TYPE(0x2019AC))) /* Message Object 77 Acceptance Mask Register Low */


#define CAN_MOAMR78L    (*(_PAGE_080_MEM_TYPE(0x2019CC))) /* Message Object 78 Acceptance Mask Register Low */


#define CAN_MOAMR79L    (*(_PAGE_080_MEM_TYPE(0x2019EC))) /* Message Object 79 Acceptance Mask Register Low */


#define CAN_MOAMR80L    (*(_PAGE_080_MEM_TYPE(0x201A0C))) /* Message Object 80 Acceptance Mask Register Low */


#define CAN_MOAMR81L    (*(_PAGE_080_MEM_TYPE(0x201A2C))) /* Message Object 81 Acceptance Mask Register Low */


#define CAN_MOAMR82L    (*(_PAGE_080_MEM_TYPE(0x201A4C))) /* Message Object 82 Acceptance Mask Register Low */


#define CAN_MOAMR83L    (*(_PAGE_080_MEM_TYPE(0x201A6C))) /* Message Object 83 Acceptance Mask Register Low */


#define CAN_MOAMR84L    (*(_PAGE_080_MEM_TYPE(0x201A8C))) /* Message Object 84 Acceptance Mask Register Low */


#define CAN_MOAMR85L    (*(_PAGE_080_MEM_TYPE(0x201AAC))) /* Message Object 85 Acceptance Mask Register Low */


#define CAN_MOAMR86L    (*(_PAGE_080_MEM_TYPE(0x201ACC))) /* Message Object 86 Acceptance Mask Register Low */


#define CAN_MOAMR87L    (*(_PAGE_080_MEM_TYPE(0x201AEC))) /* Message Object 87 Acceptance Mask Register Low */


#define CAN_MOAMR88L    (*(_PAGE_080_MEM_TYPE(0x201B0C))) /* Message Object 88 Acceptance Mask Register Low */


#define CAN_MOAMR89L    (*(_PAGE_080_MEM_TYPE(0x201B2C))) /* Message Object 89 Acceptance Mask Register Low */


#define CAN_MOAMR90L    (*(_PAGE_080_MEM_TYPE(0x201B4C))) /* Message Object 90 Acceptance Mask Register Low */


#define CAN_MOAMR91L    (*(_PAGE_080_MEM_TYPE(0x201B6C))) /* Message Object 91 Acceptance Mask Register Low */


#define CAN_MOAMR92L    (*(_PAGE_080_MEM_TYPE(0x201B8C))) /* Message Object 92 Acceptance Mask Register Low */


#define CAN_MOAMR93L    (*(_PAGE_080_MEM_TYPE(0x201BAC))) /* Message Object 93 Acceptance Mask Register Low */


#define CAN_MOAMR94L    (*(_PAGE_080_MEM_TYPE(0x201BCC))) /* Message Object 94 Acceptance Mask Register Low */


#define CAN_MOAMR95L    (*(_PAGE_080_MEM_TYPE(0x201BEC))) /* Message Object 95 Acceptance Mask Register Low */


#define CAN_MOAMR96L    (*(_PAGE_080_MEM_TYPE(0x201C0C))) /* Message Object 96 Acceptance Mask Register Low */


#define CAN_MOAMR97L    (*(_PAGE_080_MEM_TYPE(0x201C2C))) /* Message Object 97 Acceptance Mask Register Low */


#define CAN_MOAMR98L    (*(_PAGE_080_MEM_TYPE(0x201C4C))) /* Message Object 98 Acceptance Mask Register Low */


#define CAN_MOAMR99L    (*(_PAGE_080_MEM_TYPE(0x201C6C))) /* Message Object 99 Acceptance Mask Register Low */


#define CAN_MOAMR100L   (*(_PAGE_080_MEM_TYPE(0x201C8C))) /* Message Object 100 Acceptance Mask Register Low */


#define CAN_MOAMR101L   (*(_PAGE_080_MEM_TYPE(0x201CAC))) /* Message Object 101 Acceptance Mask Register Low */


#define CAN_MOAMR102L   (*(_PAGE_080_MEM_TYPE(0x201CCC))) /* Message Object 102 Acceptance Mask Register Low */


#define CAN_MOAMR103L   (*(_PAGE_080_MEM_TYPE(0x201CEC))) /* Message Object 103 Acceptance Mask Register Low */


#define CAN_MOAMR104L   (*(_PAGE_080_MEM_TYPE(0x201D0C))) /* Message Object 104 Acceptance Mask Register Low */


#define CAN_MOAMR105L   (*(_PAGE_080_MEM_TYPE(0x201D2C))) /* Message Object 105 Acceptance Mask Register Low */


#define CAN_MOAMR106L   (*(_PAGE_080_MEM_TYPE(0x201D4C))) /* Message Object 106 Acceptance Mask Register Low */


#define CAN_MOAMR107L   (*(_PAGE_080_MEM_TYPE(0x201D6C))) /* Message Object 107 Acceptance Mask Register Low */


#define CAN_MOAMR108L   (*(_PAGE_080_MEM_TYPE(0x201D8C))) /* Message Object 108 Acceptance Mask Register Low */


#define CAN_MOAMR109L   (*(_PAGE_080_MEM_TYPE(0x201DAC))) /* Message Object 109 Acceptance Mask Register Low */


#define CAN_MOAMR110L   (*(_PAGE_080_MEM_TYPE(0x201DCC))) /* Message Object 110 Acceptance Mask Register Low */


#define CAN_MOAMR111L   (*(_PAGE_080_MEM_TYPE(0x201DEC))) /* Message Object 111 Acceptance Mask Register Low */


#define CAN_MOAMR112L   (*(_PAGE_080_MEM_TYPE(0x201E0C))) /* Message Object 112 Acceptance Mask Register Low */


#define CAN_MOAMR113L   (*(_PAGE_080_MEM_TYPE(0x201E2C))) /* Message Object 113 Acceptance Mask Register Low */


#define CAN_MOAMR114L   (*(_PAGE_080_MEM_TYPE(0x201E4C))) /* Message Object 114 Acceptance Mask Register Low */


#define CAN_MOAMR115L   (*(_PAGE_080_MEM_TYPE(0x201E6C))) /* Message Object 115 Acceptance Mask Register Low */


#define CAN_MOAMR116L   (*(_PAGE_080_MEM_TYPE(0x201E8C))) /* Message Object 116 Acceptance Mask Register Low */


#define CAN_MOAMR117L   (*(_PAGE_080_MEM_TYPE(0x201EAC))) /* Message Object 117 Acceptance Mask Register Low */


#define CAN_MOAMR118L   (*(_PAGE_080_MEM_TYPE(0x201ECC))) /* Message Object 118 Acceptance Mask Register Low */


#define CAN_MOAMR119L   (*(_PAGE_080_MEM_TYPE(0x201EEC))) /* Message Object 119 Acceptance Mask Register Low */


#define CAN_MOAMR120L   (*(_PAGE_080_MEM_TYPE(0x201F0C))) /* Message Object 120 Acceptance Mask Register Low */


#define CAN_MOAMR121L   (*(_PAGE_080_MEM_TYPE(0x201F2C))) /* Message Object 121 Acceptance Mask Register Low */


#define CAN_MOAMR122L   (*(_PAGE_080_MEM_TYPE(0x201F4C))) /* Message Object 122 Acceptance Mask Register Low */


#define CAN_MOAMR123L   (*(_PAGE_080_MEM_TYPE(0x201F6C))) /* Message Object 123 Acceptance Mask Register Low */


#define CAN_MOAMR124L   (*(_PAGE_080_MEM_TYPE(0x201F8C))) /* Message Object 124 Acceptance Mask Register Low */


#define CAN_MOAMR125L   (*(_PAGE_080_MEM_TYPE(0x201FAC))) /* Message Object 125 Acceptance Mask Register Low */


#define CAN_MOAMR126L   (*(_PAGE_080_MEM_TYPE(0x201FCC))) /* Message Object 126 Acceptance Mask Register Low */


#define CAN_MOAMR127L   (*(_PAGE_080_MEM_TYPE(0x201FEC))) /* Message Object 127 Acceptance Mask Register Low */


#define CAN_MOAMR128L   (*(_PAGE_080_MEM_TYPE(0x20200C))) /* Message Object 128 Acceptance Mask Register Low */


#define CAN_MOAMR129L   (*(_PAGE_080_MEM_TYPE(0x20202C))) /* Message Object 129 Acceptance Mask Register Low */


#define CAN_MOAMR130L   (*(_PAGE_080_MEM_TYPE(0x20204C))) /* Message Object 130 Acceptance Mask Register Low */


#define CAN_MOAMR131L   (*(_PAGE_080_MEM_TYPE(0x20206C))) /* Message Object 131 Acceptance Mask Register Low */


#define CAN_MOAMR132L   (*(_PAGE_080_MEM_TYPE(0x20208C))) /* Message Object 132 Acceptance Mask Register Low */


#define CAN_MOAMR133L   (*(_PAGE_080_MEM_TYPE(0x2020AC))) /* Message Object 133 Acceptance Mask Register Low */


#define CAN_MOAMR134L   (*(_PAGE_080_MEM_TYPE(0x2020CC))) /* Message Object 134 Acceptance Mask Register Low */


#define CAN_MOAMR135L   (*(_PAGE_080_MEM_TYPE(0x2020EC))) /* Message Object 135 Acceptance Mask Register Low */


#define CAN_MOAMR136L   (*(_PAGE_080_MEM_TYPE(0x20210C))) /* Message Object 136 Acceptance Mask Register Low */


#define CAN_MOAMR137L   (*(_PAGE_080_MEM_TYPE(0x20212C))) /* Message Object 137 Acceptance Mask Register Low */


#define CAN_MOAMR138L   (*(_PAGE_080_MEM_TYPE(0x20214C))) /* Message Object 138 Acceptance Mask Register Low */


#define CAN_MOAMR139L   (*(_PAGE_080_MEM_TYPE(0x20216C))) /* Message Object 139 Acceptance Mask Register Low */


#define CAN_MOAMR140L   (*(_PAGE_080_MEM_TYPE(0x20218C))) /* Message Object 140 Acceptance Mask Register Low */


#define CAN_MOAMR141L   (*(_PAGE_080_MEM_TYPE(0x2021AC))) /* Message Object 141 Acceptance Mask Register Low */


#define CAN_MOAMR142L   (*(_PAGE_080_MEM_TYPE(0x2021CC))) /* Message Object 142 Acceptance Mask Register Low */


#define CAN_MOAMR143L   (*(_PAGE_080_MEM_TYPE(0x2021EC))) /* Message Object 143 Acceptance Mask Register Low */


#define CAN_MOAMR144L   (*(_PAGE_080_MEM_TYPE(0x20220C))) /* Message Object 144 Acceptance Mask Register Low */


#define CAN_MOAMR145L   (*(_PAGE_080_MEM_TYPE(0x20222C))) /* Message Object 145 Acceptance Mask Register Low */


#define CAN_MOAMR146L   (*(_PAGE_080_MEM_TYPE(0x20224C))) /* Message Object 146 Acceptance Mask Register Low */


#define CAN_MOAMR147L   (*(_PAGE_080_MEM_TYPE(0x20226C))) /* Message Object 147 Acceptance Mask Register Low */


#define CAN_MOAMR148L   (*(_PAGE_080_MEM_TYPE(0x20228C))) /* Message Object 148 Acceptance Mask Register Low */


#define CAN_MOAMR149L   (*(_PAGE_080_MEM_TYPE(0x2022AC))) /* Message Object 149 Acceptance Mask Register Low */


#define CAN_MOAMR150L   (*(_PAGE_080_MEM_TYPE(0x2022CC))) /* Message Object 150 Acceptance Mask Register Low */


#define CAN_MOAMR151L   (*(_PAGE_080_MEM_TYPE(0x2022EC))) /* Message Object 151 Acceptance Mask Register Low */


#define CAN_MOAMR152L   (*(_PAGE_080_MEM_TYPE(0x20230C))) /* Message Object 152 Acceptance Mask Register Low */


#define CAN_MOAMR153L   (*(_PAGE_080_MEM_TYPE(0x20232C))) /* Message Object 153 Acceptance Mask Register Low */


#define CAN_MOAMR154L   (*(_PAGE_080_MEM_TYPE(0x20234C))) /* Message Object 154 Acceptance Mask Register Low */


#define CAN_MOAMR155L   (*(_PAGE_080_MEM_TYPE(0x20236C))) /* Message Object 155 Acceptance Mask Register Low */


#define CAN_MOAMR156L   (*(_PAGE_080_MEM_TYPE(0x20238C))) /* Message Object 156 Acceptance Mask Register Low */


#define CAN_MOAMR157L   (*(_PAGE_080_MEM_TYPE(0x2023AC))) /* Message Object 157 Acceptance Mask Register Low */


#define CAN_MOAMR158L   (*(_PAGE_080_MEM_TYPE(0x2023CC))) /* Message Object 158 Acceptance Mask Register Low */


#define CAN_MOAMR159L   (*(_PAGE_080_MEM_TYPE(0x2023EC))) /* Message Object 159 Acceptance Mask Register Low */


#define CAN_MOAMR160L   (*(_PAGE_080_MEM_TYPE(0x20240C))) /* Message Object 160 Acceptance Mask Register Low */


#define CAN_MOAMR161L   (*(_PAGE_080_MEM_TYPE(0x20242C))) /* Message Object 161 Acceptance Mask Register Low */


#define CAN_MOAMR162L   (*(_PAGE_080_MEM_TYPE(0x20244C))) /* Message Object 162 Acceptance Mask Register Low */


#define CAN_MOAMR163L   (*(_PAGE_080_MEM_TYPE(0x20246C))) /* Message Object 163 Acceptance Mask Register Low */


#define CAN_MOAMR164L   (*(_PAGE_080_MEM_TYPE(0x20248C))) /* Message Object 164 Acceptance Mask Register Low */


#define CAN_MOAMR165L   (*(_PAGE_080_MEM_TYPE(0x2024AC))) /* Message Object 165 Acceptance Mask Register Low */


#define CAN_MOAMR166L   (*(_PAGE_080_MEM_TYPE(0x2024CC))) /* Message Object 166 Acceptance Mask Register Low */


#define CAN_MOAMR167L   (*(_PAGE_080_MEM_TYPE(0x2024EC))) /* Message Object 167 Acceptance Mask Register Low */


#define CAN_MOAMR168L   (*(_PAGE_080_MEM_TYPE(0x20250C))) /* Message Object 168 Acceptance Mask Register Low */


#define CAN_MOAMR169L   (*(_PAGE_080_MEM_TYPE(0x20252C))) /* Message Object 169 Acceptance Mask Register Low */


#define CAN_MOAMR170L   (*(_PAGE_080_MEM_TYPE(0x20254C))) /* Message Object 170 Acceptance Mask Register Low */


#define CAN_MOAMR171L   (*(_PAGE_080_MEM_TYPE(0x20256C))) /* Message Object 171 Acceptance Mask Register Low */


#define CAN_MOAMR172L   (*(_PAGE_080_MEM_TYPE(0x20258C))) /* Message Object 172 Acceptance Mask Register Low */


#define CAN_MOAMR173L   (*(_PAGE_080_MEM_TYPE(0x2025AC))) /* Message Object 173 Acceptance Mask Register Low */


#define CAN_MOAMR174L   (*(_PAGE_080_MEM_TYPE(0x2025CC))) /* Message Object 174 Acceptance Mask Register Low */


#define CAN_MOAMR175L   (*(_PAGE_080_MEM_TYPE(0x2025EC))) /* Message Object 175 Acceptance Mask Register Low */


#define CAN_MOAMR176L   (*(_PAGE_080_MEM_TYPE(0x20260C))) /* Message Object 176 Acceptance Mask Register Low */


#define CAN_MOAMR177L   (*(_PAGE_080_MEM_TYPE(0x20262C))) /* Message Object 177 Acceptance Mask Register Low */


#define CAN_MOAMR178L   (*(_PAGE_080_MEM_TYPE(0x20264C))) /* Message Object 178 Acceptance Mask Register Low */


#define CAN_MOAMR179L   (*(_PAGE_080_MEM_TYPE(0x20266C))) /* Message Object 179 Acceptance Mask Register Low */


#define CAN_MOAMR180L   (*(_PAGE_080_MEM_TYPE(0x20268C))) /* Message Object 180 Acceptance Mask Register Low */


#define CAN_MOAMR181L   (*(_PAGE_080_MEM_TYPE(0x2026AC))) /* Message Object 181 Acceptance Mask Register Low */


#define CAN_MOAMR182L   (*(_PAGE_080_MEM_TYPE(0x2026CC))) /* Message Object 182 Acceptance Mask Register Low */


#define CAN_MOAMR183L   (*(_PAGE_080_MEM_TYPE(0x2026EC))) /* Message Object 183 Acceptance Mask Register Low */


#define CAN_MOAMR184L   (*(_PAGE_080_MEM_TYPE(0x20270C))) /* Message Object 184 Acceptance Mask Register Low */


#define CAN_MOAMR185L   (*(_PAGE_080_MEM_TYPE(0x20272C))) /* Message Object 185 Acceptance Mask Register Low */


#define CAN_MOAMR186L   (*(_PAGE_080_MEM_TYPE(0x20274C))) /* Message Object 186 Acceptance Mask Register Low */


#define CAN_MOAMR187L   (*(_PAGE_080_MEM_TYPE(0x20276C))) /* Message Object 187 Acceptance Mask Register Low */


#define CAN_MOAMR188L   (*(_PAGE_080_MEM_TYPE(0x20278C))) /* Message Object 188 Acceptance Mask Register Low */


#define CAN_MOAMR189L   (*(_PAGE_080_MEM_TYPE(0x2027AC))) /* Message Object 189 Acceptance Mask Register Low */


#define CAN_MOAMR190L   (*(_PAGE_080_MEM_TYPE(0x2027CC))) /* Message Object 190 Acceptance Mask Register Low */


#define CAN_MOAMR191L   (*(_PAGE_080_MEM_TYPE(0x2027EC))) /* Message Object 191 Acceptance Mask Register Low */


#define CAN_MOAMR192L   (*(_PAGE_080_MEM_TYPE(0x20280C))) /* Message Object 192 Acceptance Mask Register Low */


#define CAN_MOAMR193L   (*(_PAGE_080_MEM_TYPE(0x20282C))) /* Message Object 193 Acceptance Mask Register Low */


#define CAN_MOAMR194L   (*(_PAGE_080_MEM_TYPE(0x20284C))) /* Message Object 194 Acceptance Mask Register Low */


#define CAN_MOAMR195L   (*(_PAGE_080_MEM_TYPE(0x20286C))) /* Message Object 195 Acceptance Mask Register Low */


#define CAN_MOAMR196L   (*(_PAGE_080_MEM_TYPE(0x20288C))) /* Message Object 196 Acceptance Mask Register Low */


#define CAN_MOAMR197L   (*(_PAGE_080_MEM_TYPE(0x2028AC))) /* Message Object 197 Acceptance Mask Register Low */


#define CAN_MOAMR198L   (*(_PAGE_080_MEM_TYPE(0x2028CC))) /* Message Object 198 Acceptance Mask Register Low */


#define CAN_MOAMR199L   (*(_PAGE_080_MEM_TYPE(0x2028EC))) /* Message Object 199 Acceptance Mask Register Low */


#define CAN_MOAMR200L   (*(_PAGE_080_MEM_TYPE(0x20290C))) /* Message Object 200 Acceptance Mask Register Low */


#define CAN_MOAMR201L   (*(_PAGE_080_MEM_TYPE(0x20292C))) /* Message Object 201 Acceptance Mask Register Low */


#define CAN_MOAMR202L   (*(_PAGE_080_MEM_TYPE(0x20294C))) /* Message Object 202 Acceptance Mask Register Low */


#define CAN_MOAMR203L   (*(_PAGE_080_MEM_TYPE(0x20296C))) /* Message Object 203 Acceptance Mask Register Low */


#define CAN_MOAMR204L   (*(_PAGE_080_MEM_TYPE(0x20298C))) /* Message Object 204 Acceptance Mask Register Low */


#define CAN_MOAMR205L   (*(_PAGE_080_MEM_TYPE(0x2029AC))) /* Message Object 205 Acceptance Mask Register Low */


#define CAN_MOAMR206L   (*(_PAGE_080_MEM_TYPE(0x2029CC))) /* Message Object 206 Acceptance Mask Register Low */


#define CAN_MOAMR207L   (*(_PAGE_080_MEM_TYPE(0x2029EC))) /* Message Object 207 Acceptance Mask Register Low */


#define CAN_MOAMR208L   (*(_PAGE_080_MEM_TYPE(0x202A0C))) /* Message Object 208 Acceptance Mask Register Low */


#define CAN_MOAMR209L   (*(_PAGE_080_MEM_TYPE(0x202A2C))) /* Message Object 209 Acceptance Mask Register Low */


#define CAN_MOAMR210L   (*(_PAGE_080_MEM_TYPE(0x202A4C))) /* Message Object 210 Acceptance Mask Register Low */


#define CAN_MOAMR211L   (*(_PAGE_080_MEM_TYPE(0x202A6C))) /* Message Object 211 Acceptance Mask Register Low */


#define CAN_MOAMR212L   (*(_PAGE_080_MEM_TYPE(0x202A8C))) /* Message Object 212 Acceptance Mask Register Low */


#define CAN_MOAMR213L   (*(_PAGE_080_MEM_TYPE(0x202AAC))) /* Message Object 213 Acceptance Mask Register Low */


#define CAN_MOAMR214L   (*(_PAGE_080_MEM_TYPE(0x202ACC))) /* Message Object 214 Acceptance Mask Register Low */


#define CAN_MOAMR215L   (*(_PAGE_080_MEM_TYPE(0x202AEC))) /* Message Object 215 Acceptance Mask Register Low */


#define CAN_MOAMR216L   (*(_PAGE_080_MEM_TYPE(0x202B0C))) /* Message Object 216 Acceptance Mask Register Low */


#define CAN_MOAMR217L   (*(_PAGE_080_MEM_TYPE(0x202B2C))) /* Message Object 217 Acceptance Mask Register Low */


#define CAN_MOAMR218L   (*(_PAGE_080_MEM_TYPE(0x202B4C))) /* Message Object 218 Acceptance Mask Register Low */


#define CAN_MOAMR219L   (*(_PAGE_080_MEM_TYPE(0x202B6C))) /* Message Object 219 Acceptance Mask Register Low */


#define CAN_MOAMR220L   (*(_PAGE_080_MEM_TYPE(0x202B8C))) /* Message Object 220 Acceptance Mask Register Low */


#define CAN_MOAMR221L   (*(_PAGE_080_MEM_TYPE(0x202BAC))) /* Message Object 221 Acceptance Mask Register Low */


#define CAN_MOAMR222L   (*(_PAGE_080_MEM_TYPE(0x202BCC))) /* Message Object 222 Acceptance Mask Register Low */


#define CAN_MOAMR223L   (*(_PAGE_080_MEM_TYPE(0x202BEC))) /* Message Object 223 Acceptance Mask Register Low */


#define CAN_MOAMR224L   (*(_PAGE_080_MEM_TYPE(0x202C0C))) /* Message Object 224 Acceptance Mask Register Low */


#define CAN_MOAMR225L   (*(_PAGE_080_MEM_TYPE(0x202C2C))) /* Message Object 225 Acceptance Mask Register Low */


#define CAN_MOAMR226L   (*(_PAGE_080_MEM_TYPE(0x202C4C))) /* Message Object 226 Acceptance Mask Register Low */


#define CAN_MOAMR227L   (*(_PAGE_080_MEM_TYPE(0x202C6C))) /* Message Object 227 Acceptance Mask Register Low */


#define CAN_MOAMR228L   (*(_PAGE_080_MEM_TYPE(0x202C8C))) /* Message Object 228 Acceptance Mask Register Low */


#define CAN_MOAMR229L   (*(_PAGE_080_MEM_TYPE(0x202CAC))) /* Message Object 229 Acceptance Mask Register Low */


#define CAN_MOAMR230L   (*(_PAGE_080_MEM_TYPE(0x202CCC))) /* Message Object 230 Acceptance Mask Register Low */


#define CAN_MOAMR231L   (*(_PAGE_080_MEM_TYPE(0x202CEC))) /* Message Object 231 Acceptance Mask Register Low */


#define CAN_MOAMR232L   (*(_PAGE_080_MEM_TYPE(0x202D0C))) /* Message Object 232 Acceptance Mask Register Low */


#define CAN_MOAMR233L   (*(_PAGE_080_MEM_TYPE(0x202D2C))) /* Message Object 233 Acceptance Mask Register Low */


#define CAN_MOAMR234L   (*(_PAGE_080_MEM_TYPE(0x202D4C))) /* Message Object 234 Acceptance Mask Register Low */


#define CAN_MOAMR235L   (*(_PAGE_080_MEM_TYPE(0x202D6C))) /* Message Object 235 Acceptance Mask Register Low */


#define CAN_MOAMR236L   (*(_PAGE_080_MEM_TYPE(0x202D8C))) /* Message Object 236 Acceptance Mask Register Low */


#define CAN_MOAMR237L   (*(_PAGE_080_MEM_TYPE(0x202DAC))) /* Message Object 237 Acceptance Mask Register Low */


#define CAN_MOAMR238L   (*(_PAGE_080_MEM_TYPE(0x202DCC))) /* Message Object 238 Acceptance Mask Register Low */


#define CAN_MOAMR239L   (*(_PAGE_080_MEM_TYPE(0x202DEC))) /* Message Object 239 Acceptance Mask Register Low */


#define CAN_MOAMR240L   (*(_PAGE_080_MEM_TYPE(0x202E0C))) /* Message Object 240 Acceptance Mask Register Low */


#define CAN_MOAMR241L   (*(_PAGE_080_MEM_TYPE(0x202E2C))) /* Message Object 241 Acceptance Mask Register Low */


#define CAN_MOAMR242L   (*(_PAGE_080_MEM_TYPE(0x202E4C))) /* Message Object 242 Acceptance Mask Register Low */


#define CAN_MOAMR243L   (*(_PAGE_080_MEM_TYPE(0x202E6C))) /* Message Object 243 Acceptance Mask Register Low */


#define CAN_MOAMR244L   (*(_PAGE_080_MEM_TYPE(0x202E8C))) /* Message Object 244 Acceptance Mask Register Low */


#define CAN_MOAMR245L   (*(_PAGE_080_MEM_TYPE(0x202EAC))) /* Message Object 245 Acceptance Mask Register Low */


#define CAN_MOAMR246L   (*(_PAGE_080_MEM_TYPE(0x202ECC))) /* Message Object 246 Acceptance Mask Register Low */


#define CAN_MOAMR247L   (*(_PAGE_080_MEM_TYPE(0x202EEC))) /* Message Object 247 Acceptance Mask Register Low */


#define CAN_MOAMR248L   (*(_PAGE_080_MEM_TYPE(0x202F0C))) /* Message Object 248 Acceptance Mask Register Low */


#define CAN_MOAMR249L   (*(_PAGE_080_MEM_TYPE(0x202F2C))) /* Message Object 249 Acceptance Mask Register Low */


#define CAN_MOAMR250L   (*(_PAGE_080_MEM_TYPE(0x202F4C))) /* Message Object 250 Acceptance Mask Register Low */


#define CAN_MOAMR251L   (*(_PAGE_080_MEM_TYPE(0x202F6C))) /* Message Object 251 Acceptance Mask Register Low */


#define CAN_MOAMR252L   (*(_PAGE_080_MEM_TYPE(0x202F8C))) /* Message Object 252 Acceptance Mask Register Low */


#define CAN_MOAMR253L   (*(_PAGE_080_MEM_TYPE(0x202FAC))) /* Message Object 253 Acceptance Mask Register Low */


#define CAN_MOAMR254L   (*(_PAGE_080_MEM_TYPE(0x202FCC))) /* Message Object 254 Acceptance Mask Register Low */


#define CAN_MOAMR255L   (*(_PAGE_080_MEM_TYPE(0x202FEC))) /* Message Object 255 Acceptance Mask Register Low */


#define CAN_MOAR0H      (*(_PAGE_080_MEM_TYPE(0x20101A))) /* Message Object 0 Arbitration Register High */


#define CAN_MOAR1H      (*(_PAGE_080_MEM_TYPE(0x20103A))) /* Message Object 1 Arbitration Register High */


#define CAN_MOAR2H      (*(_PAGE_080_MEM_TYPE(0x20105A))) /* Message Object 2 Arbitration Register High */


#define CAN_MOAR3H      (*(_PAGE_080_MEM_TYPE(0x20107A))) /* Message Object 3 Arbitration Register High */


#define CAN_MOAR4H      (*(_PAGE_080_MEM_TYPE(0x20109A))) /* Message Object 4 Arbitration Register High */


#define CAN_MOAR5H      (*(_PAGE_080_MEM_TYPE(0x2010BA))) /* Message Object 5 Arbitration Register High */


#define CAN_MOAR6H      (*(_PAGE_080_MEM_TYPE(0x2010DA))) /* Message Object 6 Arbitration Register High */


#define CAN_MOAR7H      (*(_PAGE_080_MEM_TYPE(0x2010FA))) /* Message Object 7 Arbitration Register High */


#define CAN_MOAR8H      (*(_PAGE_080_MEM_TYPE(0x20111A))) /* Message Object 8 Arbitration Register High */


#define CAN_MOAR9H      (*(_PAGE_080_MEM_TYPE(0x20113A))) /* Message Object 9 Arbitration Register High */


#define CAN_MOAR10H     (*(_PAGE_080_MEM_TYPE(0x20115A))) /* Message Object 10 Arbitration Register High */


#define CAN_MOAR11H     (*(_PAGE_080_MEM_TYPE(0x20117A))) /* Message Object 11 Arbitration Register High */


#define CAN_MOAR12H     (*(_PAGE_080_MEM_TYPE(0x20119A))) /* Message Object 12 Arbitration Register High */


#define CAN_MOAR13H     (*(_PAGE_080_MEM_TYPE(0x2011BA))) /* Message Object 13 Arbitration Register High */


#define CAN_MOAR14H     (*(_PAGE_080_MEM_TYPE(0x2011DA))) /* Message Object 14 Arbitration Register High */


#define CAN_MOAR15H     (*(_PAGE_080_MEM_TYPE(0x2011FA))) /* Message Object 15 Arbitration Register High */


#define CAN_MOAR16H     (*(_PAGE_080_MEM_TYPE(0x20121A))) /* Message Object 16 Arbitration Register High */


#define CAN_MOAR17H     (*(_PAGE_080_MEM_TYPE(0x20123A))) /* Message Object 17 Arbitration Register High */


#define CAN_MOAR18H     (*(_PAGE_080_MEM_TYPE(0x20125A))) /* Message Object 18 Arbitration Register High */


#define CAN_MOAR19H     (*(_PAGE_080_MEM_TYPE(0x20127A))) /* Message Object 19 Arbitration Register High */


#define CAN_MOAR20H     (*(_PAGE_080_MEM_TYPE(0x20129A))) /* Message Object 20 Arbitration Register High */


#define CAN_MOAR21H     (*(_PAGE_080_MEM_TYPE(0x2012BA))) /* Message Object 21 Arbitration Register High */


#define CAN_MOAR22H     (*(_PAGE_080_MEM_TYPE(0x2012DA))) /* Message Object 22 Arbitration Register High */


#define CAN_MOAR23H     (*(_PAGE_080_MEM_TYPE(0x2012FA))) /* Message Object 23 Arbitration Register High */


#define CAN_MOAR24H     (*(_PAGE_080_MEM_TYPE(0x20131A))) /* Message Object 24 Arbitration Register High */


#define CAN_MOAR25H     (*(_PAGE_080_MEM_TYPE(0x20133A))) /* Message Object 25 Arbitration Register High */


#define CAN_MOAR26H     (*(_PAGE_080_MEM_TYPE(0x20135A))) /* Message Object 26 Arbitration Register High */


#define CAN_MOAR27H     (*(_PAGE_080_MEM_TYPE(0x20137A))) /* Message Object 27 Arbitration Register High */


#define CAN_MOAR28H     (*(_PAGE_080_MEM_TYPE(0x20139A))) /* Message Object 28 Arbitration Register High */


#define CAN_MOAR29H     (*(_PAGE_080_MEM_TYPE(0x2013BA))) /* Message Object 29 Arbitration Register High */


#define CAN_MOAR30H     (*(_PAGE_080_MEM_TYPE(0x2013DA))) /* Message Object 30 Arbitration Register High */


#define CAN_MOAR31H     (*(_PAGE_080_MEM_TYPE(0x2013FA))) /* Message Object 31 Arbitration Register High */


#define CAN_MOAR32H     (*(_PAGE_080_MEM_TYPE(0x20141A))) /* Message Object 32 Arbitration Register High */


#define CAN_MOAR33H     (*(_PAGE_080_MEM_TYPE(0x20143A))) /* Message Object 33 Arbitration Register High */


#define CAN_MOAR34H     (*(_PAGE_080_MEM_TYPE(0x20145A))) /* Message Object 34 Arbitration Register High */


#define CAN_MOAR35H     (*(_PAGE_080_MEM_TYPE(0x20147A))) /* Message Object 35 Arbitration Register High */


#define CAN_MOAR36H     (*(_PAGE_080_MEM_TYPE(0x20149A))) /* Message Object 36 Arbitration Register High */


#define CAN_MOAR37H     (*(_PAGE_080_MEM_TYPE(0x2014BA))) /* Message Object 37 Arbitration Register High */


#define CAN_MOAR38H     (*(_PAGE_080_MEM_TYPE(0x2014DA))) /* Message Object 38 Arbitration Register High */


#define CAN_MOAR39H     (*(_PAGE_080_MEM_TYPE(0x2014FA))) /* Message Object 39 Arbitration Register High */


#define CAN_MOAR40H     (*(_PAGE_080_MEM_TYPE(0x20151A))) /* Message Object 40 Arbitration Register High */


#define CAN_MOAR41H     (*(_PAGE_080_MEM_TYPE(0x20153A))) /* Message Object 41 Arbitration Register High */


#define CAN_MOAR42H     (*(_PAGE_080_MEM_TYPE(0x20155A))) /* Message Object 42 Arbitration Register High */


#define CAN_MOAR43H     (*(_PAGE_080_MEM_TYPE(0x20157A))) /* Message Object 43 Arbitration Register High */


#define CAN_MOAR44H     (*(_PAGE_080_MEM_TYPE(0x20159A))) /* Message Object 44 Arbitration Register High */


#define CAN_MOAR45H     (*(_PAGE_080_MEM_TYPE(0x2015BA))) /* Message Object 45 Arbitration Register High */


#define CAN_MOAR46H     (*(_PAGE_080_MEM_TYPE(0x2015DA))) /* Message Object 46 Arbitration Register High */


#define CAN_MOAR47H     (*(_PAGE_080_MEM_TYPE(0x2015FA))) /* Message Object 47 Arbitration Register High */


#define CAN_MOAR48H     (*(_PAGE_080_MEM_TYPE(0x20161A))) /* Message Object 48 Arbitration Register High */


#define CAN_MOAR49H     (*(_PAGE_080_MEM_TYPE(0x20163A))) /* Message Object 49 Arbitration Register High */


#define CAN_MOAR50H     (*(_PAGE_080_MEM_TYPE(0x20165A))) /* Message Object 50 Arbitration Register High */


#define CAN_MOAR51H     (*(_PAGE_080_MEM_TYPE(0x20167A))) /* Message Object 51 Arbitration Register High */


#define CAN_MOAR52H     (*(_PAGE_080_MEM_TYPE(0x20169A))) /* Message Object 52 Arbitration Register High */


#define CAN_MOAR53H     (*(_PAGE_080_MEM_TYPE(0x2016BA))) /* Message Object 53 Arbitration Register High */


#define CAN_MOAR54H     (*(_PAGE_080_MEM_TYPE(0x2016DA))) /* Message Object 54 Arbitration Register High */


#define CAN_MOAR55H     (*(_PAGE_080_MEM_TYPE(0x2016FA))) /* Message Object 55 Arbitration Register High */


#define CAN_MOAR56H     (*(_PAGE_080_MEM_TYPE(0x20171A))) /* Message Object 56 Arbitration Register High */


#define CAN_MOAR57H     (*(_PAGE_080_MEM_TYPE(0x20173A))) /* Message Object 57 Arbitration Register High */


#define CAN_MOAR58H     (*(_PAGE_080_MEM_TYPE(0x20175A))) /* Message Object 58 Arbitration Register High */


#define CAN_MOAR59H     (*(_PAGE_080_MEM_TYPE(0x20177A))) /* Message Object 59 Arbitration Register High */


#define CAN_MOAR60H     (*(_PAGE_080_MEM_TYPE(0x20179A))) /* Message Object 60 Arbitration Register High */


#define CAN_MOAR61H     (*(_PAGE_080_MEM_TYPE(0x2017BA))) /* Message Object 61 Arbitration Register High */


#define CAN_MOAR62H     (*(_PAGE_080_MEM_TYPE(0x2017DA))) /* Message Object 62 Arbitration Register High */


#define CAN_MOAR63H     (*(_PAGE_080_MEM_TYPE(0x2017FA))) /* Message Object 63 Arbitration Register High */


#define CAN_MOAR64H     (*(_PAGE_080_MEM_TYPE(0x20181A))) /* Message Object 64 Arbitration Register High */


#define CAN_MOAR65H     (*(_PAGE_080_MEM_TYPE(0x20183A))) /* Message Object 65 Arbitration Register High */


#define CAN_MOAR66H     (*(_PAGE_080_MEM_TYPE(0x20185A))) /* Message Object 66 Arbitration Register High */


#define CAN_MOAR67H     (*(_PAGE_080_MEM_TYPE(0x20187A))) /* Message Object 67 Arbitration Register High */


#define CAN_MOAR68H     (*(_PAGE_080_MEM_TYPE(0x20189A))) /* Message Object 68 Arbitration Register High */


#define CAN_MOAR69H     (*(_PAGE_080_MEM_TYPE(0x2018BA))) /* Message Object 69 Arbitration Register High */


#define CAN_MOAR70H     (*(_PAGE_080_MEM_TYPE(0x2018DA))) /* Message Object 70 Arbitration Register High */


#define CAN_MOAR71H     (*(_PAGE_080_MEM_TYPE(0x2018FA))) /* Message Object 71 Arbitration Register High */


#define CAN_MOAR72H     (*(_PAGE_080_MEM_TYPE(0x20191A))) /* Message Object 72 Arbitration Register High */


#define CAN_MOAR73H     (*(_PAGE_080_MEM_TYPE(0x20193A))) /* Message Object 73 Arbitration Register High */


#define CAN_MOAR74H     (*(_PAGE_080_MEM_TYPE(0x20195A))) /* Message Object 74 Arbitration Register High */


#define CAN_MOAR75H     (*(_PAGE_080_MEM_TYPE(0x20197A))) /* Message Object 75 Arbitration Register High */


#define CAN_MOAR76H     (*(_PAGE_080_MEM_TYPE(0x20199A))) /* Message Object 76 Arbitration Register High */


#define CAN_MOAR77H     (*(_PAGE_080_MEM_TYPE(0x2019BA))) /* Message Object 77 Arbitration Register High */


#define CAN_MOAR78H     (*(_PAGE_080_MEM_TYPE(0x2019DA))) /* Message Object 78 Arbitration Register High */


#define CAN_MOAR79H     (*(_PAGE_080_MEM_TYPE(0x2019FA))) /* Message Object 79 Arbitration Register High */


#define CAN_MOAR80H     (*(_PAGE_080_MEM_TYPE(0x201A1A))) /* Message Object 80 Arbitration Register High */


#define CAN_MOAR81H     (*(_PAGE_080_MEM_TYPE(0x201A3A))) /* Message Object 81 Arbitration Register High */


#define CAN_MOAR82H     (*(_PAGE_080_MEM_TYPE(0x201A5A))) /* Message Object 82 Arbitration Register High */


#define CAN_MOAR83H     (*(_PAGE_080_MEM_TYPE(0x201A7A))) /* Message Object 83 Arbitration Register High */


#define CAN_MOAR84H     (*(_PAGE_080_MEM_TYPE(0x201A9A))) /* Message Object 84 Arbitration Register High */


#define CAN_MOAR85H     (*(_PAGE_080_MEM_TYPE(0x201ABA))) /* Message Object 85 Arbitration Register High */


#define CAN_MOAR86H     (*(_PAGE_080_MEM_TYPE(0x201ADA))) /* Message Object 86 Arbitration Register High */


#define CAN_MOAR87H     (*(_PAGE_080_MEM_TYPE(0x201AFA))) /* Message Object 87 Arbitration Register High */


#define CAN_MOAR88H     (*(_PAGE_080_MEM_TYPE(0x201B1A))) /* Message Object 88 Arbitration Register High */


#define CAN_MOAR89H     (*(_PAGE_080_MEM_TYPE(0x201B3A))) /* Message Object 89 Arbitration Register High */


#define CAN_MOAR90H     (*(_PAGE_080_MEM_TYPE(0x201B5A))) /* Message Object 90 Arbitration Register High */


#define CAN_MOAR91H     (*(_PAGE_080_MEM_TYPE(0x201B7A))) /* Message Object 91 Arbitration Register High */


#define CAN_MOAR92H     (*(_PAGE_080_MEM_TYPE(0x201B9A))) /* Message Object 92 Arbitration Register High */


#define CAN_MOAR93H     (*(_PAGE_080_MEM_TYPE(0x201BBA))) /* Message Object 93 Arbitration Register High */


#define CAN_MOAR94H     (*(_PAGE_080_MEM_TYPE(0x201BDA))) /* Message Object 94 Arbitration Register High */


#define CAN_MOAR95H     (*(_PAGE_080_MEM_TYPE(0x201BFA))) /* Message Object 95 Arbitration Register High */


#define CAN_MOAR96H     (*(_PAGE_080_MEM_TYPE(0x201C1A))) /* Message Object 96 Arbitration Register High */


#define CAN_MOAR97H     (*(_PAGE_080_MEM_TYPE(0x201C3A))) /* Message Object 97 Arbitration Register High */


#define CAN_MOAR98H     (*(_PAGE_080_MEM_TYPE(0x201C5A))) /* Message Object 98 Arbitration Register High */


#define CAN_MOAR99H     (*(_PAGE_080_MEM_TYPE(0x201C7A))) /* Message Object 99 Arbitration Register High */


#define CAN_MOAR100H    (*(_PAGE_080_MEM_TYPE(0x201C9A))) /* Message Object 100 Arbitration Register High */


#define CAN_MOAR101H    (*(_PAGE_080_MEM_TYPE(0x201CBA))) /* Message Object 101 Arbitration Register High */


#define CAN_MOAR102H    (*(_PAGE_080_MEM_TYPE(0x201CDA))) /* Message Object 102 Arbitration Register High */


#define CAN_MOAR103H    (*(_PAGE_080_MEM_TYPE(0x201CFA))) /* Message Object 103 Arbitration Register High */


#define CAN_MOAR104H    (*(_PAGE_080_MEM_TYPE(0x201D1A))) /* Message Object 104 Arbitration Register High */


#define CAN_MOAR105H    (*(_PAGE_080_MEM_TYPE(0x201D3A))) /* Message Object 105 Arbitration Register High */


#define CAN_MOAR106H    (*(_PAGE_080_MEM_TYPE(0x201D5A))) /* Message Object 106 Arbitration Register High */


#define CAN_MOAR107H    (*(_PAGE_080_MEM_TYPE(0x201D7A))) /* Message Object 107 Arbitration Register High */


#define CAN_MOAR108H    (*(_PAGE_080_MEM_TYPE(0x201D9A))) /* Message Object 108 Arbitration Register High */


#define CAN_MOAR109H    (*(_PAGE_080_MEM_TYPE(0x201DBA))) /* Message Object 109 Arbitration Register High */


#define CAN_MOAR110H    (*(_PAGE_080_MEM_TYPE(0x201DDA))) /* Message Object 110 Arbitration Register High */


#define CAN_MOAR111H    (*(_PAGE_080_MEM_TYPE(0x201DFA))) /* Message Object 111 Arbitration Register High */


#define CAN_MOAR112H    (*(_PAGE_080_MEM_TYPE(0x201E1A))) /* Message Object 112 Arbitration Register High */


#define CAN_MOAR113H    (*(_PAGE_080_MEM_TYPE(0x201E3A))) /* Message Object 113 Arbitration Register High */


#define CAN_MOAR114H    (*(_PAGE_080_MEM_TYPE(0x201E5A))) /* Message Object 114 Arbitration Register High */


#define CAN_MOAR115H    (*(_PAGE_080_MEM_TYPE(0x201E7A))) /* Message Object 115 Arbitration Register High */


#define CAN_MOAR116H    (*(_PAGE_080_MEM_TYPE(0x201E9A))) /* Message Object 116 Arbitration Register High */


#define CAN_MOAR117H    (*(_PAGE_080_MEM_TYPE(0x201EBA))) /* Message Object 117 Arbitration Register High */


#define CAN_MOAR118H    (*(_PAGE_080_MEM_TYPE(0x201EDA))) /* Message Object 118 Arbitration Register High */


#define CAN_MOAR119H    (*(_PAGE_080_MEM_TYPE(0x201EFA))) /* Message Object 119 Arbitration Register High */


#define CAN_MOAR120H    (*(_PAGE_080_MEM_TYPE(0x201F1A))) /* Message Object 120 Arbitration Register High */


#define CAN_MOAR121H    (*(_PAGE_080_MEM_TYPE(0x201F3A))) /* Message Object 121 Arbitration Register High */


#define CAN_MOAR122H    (*(_PAGE_080_MEM_TYPE(0x201F5A))) /* Message Object 122 Arbitration Register High */


#define CAN_MOAR123H    (*(_PAGE_080_MEM_TYPE(0x201F7A))) /* Message Object 123 Arbitration Register High */


#define CAN_MOAR124H    (*(_PAGE_080_MEM_TYPE(0x201F9A))) /* Message Object 124 Arbitration Register High */


#define CAN_MOAR125H    (*(_PAGE_080_MEM_TYPE(0x201FBA))) /* Message Object 125 Arbitration Register High */


#define CAN_MOAR126H    (*(_PAGE_080_MEM_TYPE(0x201FDA))) /* Message Object 126 Arbitration Register High */


#define CAN_MOAR127H    (*(_PAGE_080_MEM_TYPE(0x201FFA))) /* Message Object 127 Arbitration Register High */


#define CAN_MOAR128H    (*(_PAGE_080_MEM_TYPE(0x20201A))) /* Message Object 128 Arbitration Register High */


#define CAN_MOAR129H    (*(_PAGE_080_MEM_TYPE(0x20203A))) /* Message Object 129 Arbitration Register High */


#define CAN_MOAR130H    (*(_PAGE_080_MEM_TYPE(0x20205A))) /* Message Object 130 Arbitration Register High */


#define CAN_MOAR131H    (*(_PAGE_080_MEM_TYPE(0x20207A))) /* Message Object 131 Arbitration Register High */


#define CAN_MOAR132H    (*(_PAGE_080_MEM_TYPE(0x20209A))) /* Message Object 132 Arbitration Register High */


#define CAN_MOAR133H    (*(_PAGE_080_MEM_TYPE(0x2020BA))) /* Message Object 133 Arbitration Register High */


#define CAN_MOAR134H    (*(_PAGE_080_MEM_TYPE(0x2020DA))) /* Message Object 134 Arbitration Register High */


#define CAN_MOAR135H    (*(_PAGE_080_MEM_TYPE(0x2020FA))) /* Message Object 135 Arbitration Register High */


#define CAN_MOAR136H    (*(_PAGE_080_MEM_TYPE(0x20211A))) /* Message Object 136 Arbitration Register High */


#define CAN_MOAR137H    (*(_PAGE_080_MEM_TYPE(0x20213A))) /* Message Object 137 Arbitration Register High */


#define CAN_MOAR138H    (*(_PAGE_080_MEM_TYPE(0x20215A))) /* Message Object 138 Arbitration Register High */


#define CAN_MOAR139H    (*(_PAGE_080_MEM_TYPE(0x20217A))) /* Message Object 139 Arbitration Register High */


#define CAN_MOAR140H    (*(_PAGE_080_MEM_TYPE(0x20219A))) /* Message Object 140 Arbitration Register High */


#define CAN_MOAR141H    (*(_PAGE_080_MEM_TYPE(0x2021BA))) /* Message Object 141 Arbitration Register High */


#define CAN_MOAR142H    (*(_PAGE_080_MEM_TYPE(0x2021DA))) /* Message Object 142 Arbitration Register High */


#define CAN_MOAR143H    (*(_PAGE_080_MEM_TYPE(0x2021FA))) /* Message Object 143 Arbitration Register High */


#define CAN_MOAR144H    (*(_PAGE_080_MEM_TYPE(0x20221A))) /* Message Object 144 Arbitration Register High */


#define CAN_MOAR145H    (*(_PAGE_080_MEM_TYPE(0x20223A))) /* Message Object 145 Arbitration Register High */


#define CAN_MOAR146H    (*(_PAGE_080_MEM_TYPE(0x20225A))) /* Message Object 146 Arbitration Register High */


#define CAN_MOAR147H    (*(_PAGE_080_MEM_TYPE(0x20227A))) /* Message Object 147 Arbitration Register High */


#define CAN_MOAR148H    (*(_PAGE_080_MEM_TYPE(0x20229A))) /* Message Object 148 Arbitration Register High */


#define CAN_MOAR149H    (*(_PAGE_080_MEM_TYPE(0x2022BA))) /* Message Object 149 Arbitration Register High */


#define CAN_MOAR150H    (*(_PAGE_080_MEM_TYPE(0x2022DA))) /* Message Object 150 Arbitration Register High */


#define CAN_MOAR151H    (*(_PAGE_080_MEM_TYPE(0x2022FA))) /* Message Object 151 Arbitration Register High */


#define CAN_MOAR152H    (*(_PAGE_080_MEM_TYPE(0x20231A))) /* Message Object 152 Arbitration Register High */


#define CAN_MOAR153H    (*(_PAGE_080_MEM_TYPE(0x20233A))) /* Message Object 153 Arbitration Register High */


#define CAN_MOAR154H    (*(_PAGE_080_MEM_TYPE(0x20235A))) /* Message Object 154 Arbitration Register High */


#define CAN_MOAR155H    (*(_PAGE_080_MEM_TYPE(0x20237A))) /* Message Object 155 Arbitration Register High */


#define CAN_MOAR156H    (*(_PAGE_080_MEM_TYPE(0x20239A))) /* Message Object 156 Arbitration Register High */


#define CAN_MOAR157H    (*(_PAGE_080_MEM_TYPE(0x2023BA))) /* Message Object 157 Arbitration Register High */


#define CAN_MOAR158H    (*(_PAGE_080_MEM_TYPE(0x2023DA))) /* Message Object 158 Arbitration Register High */


#define CAN_MOAR159H    (*(_PAGE_080_MEM_TYPE(0x2023FA))) /* Message Object 159 Arbitration Register High */


#define CAN_MOAR160H    (*(_PAGE_080_MEM_TYPE(0x20241A))) /* Message Object 160 Arbitration Register High */


#define CAN_MOAR161H    (*(_PAGE_080_MEM_TYPE(0x20243A))) /* Message Object 161 Arbitration Register High */


#define CAN_MOAR162H    (*(_PAGE_080_MEM_TYPE(0x20245A))) /* Message Object 162 Arbitration Register High */


#define CAN_MOAR163H    (*(_PAGE_080_MEM_TYPE(0x20247A))) /* Message Object 163 Arbitration Register High */


#define CAN_MOAR164H    (*(_PAGE_080_MEM_TYPE(0x20249A))) /* Message Object 164 Arbitration Register High */


#define CAN_MOAR165H    (*(_PAGE_080_MEM_TYPE(0x2024BA))) /* Message Object 165 Arbitration Register High */


#define CAN_MOAR166H    (*(_PAGE_080_MEM_TYPE(0x2024DA))) /* Message Object 166 Arbitration Register High */


#define CAN_MOAR167H    (*(_PAGE_080_MEM_TYPE(0x2024FA))) /* Message Object 167 Arbitration Register High */


#define CAN_MOAR168H    (*(_PAGE_080_MEM_TYPE(0x20251A))) /* Message Object 168 Arbitration Register High */


#define CAN_MOAR169H    (*(_PAGE_080_MEM_TYPE(0x20253A))) /* Message Object 169 Arbitration Register High */


#define CAN_MOAR170H    (*(_PAGE_080_MEM_TYPE(0x20255A))) /* Message Object 170 Arbitration Register High */


#define CAN_MOAR171H    (*(_PAGE_080_MEM_TYPE(0x20257A))) /* Message Object 171 Arbitration Register High */


#define CAN_MOAR172H    (*(_PAGE_080_MEM_TYPE(0x20259A))) /* Message Object 172 Arbitration Register High */


#define CAN_MOAR173H    (*(_PAGE_080_MEM_TYPE(0x2025BA))) /* Message Object 173 Arbitration Register High */


#define CAN_MOAR174H    (*(_PAGE_080_MEM_TYPE(0x2025DA))) /* Message Object 174 Arbitration Register High */


#define CAN_MOAR175H    (*(_PAGE_080_MEM_TYPE(0x2025FA))) /* Message Object 175 Arbitration Register High */


#define CAN_MOAR176H    (*(_PAGE_080_MEM_TYPE(0x20261A))) /* Message Object 176 Arbitration Register High */


#define CAN_MOAR177H    (*(_PAGE_080_MEM_TYPE(0x20263A))) /* Message Object 177 Arbitration Register High */


#define CAN_MOAR178H    (*(_PAGE_080_MEM_TYPE(0x20265A))) /* Message Object 178 Arbitration Register High */


#define CAN_MOAR179H    (*(_PAGE_080_MEM_TYPE(0x20267A))) /* Message Object 179 Arbitration Register High */


#define CAN_MOAR180H    (*(_PAGE_080_MEM_TYPE(0x20269A))) /* Message Object 180 Arbitration Register High */


#define CAN_MOAR181H    (*(_PAGE_080_MEM_TYPE(0x2026BA))) /* Message Object 181 Arbitration Register High */


#define CAN_MOAR182H    (*(_PAGE_080_MEM_TYPE(0x2026DA))) /* Message Object 182 Arbitration Register High */


#define CAN_MOAR183H    (*(_PAGE_080_MEM_TYPE(0x2026FA))) /* Message Object 183 Arbitration Register High */


#define CAN_MOAR184H    (*(_PAGE_080_MEM_TYPE(0x20271A))) /* Message Object 184 Arbitration Register High */


#define CAN_MOAR185H    (*(_PAGE_080_MEM_TYPE(0x20273A))) /* Message Object 185 Arbitration Register High */


#define CAN_MOAR186H    (*(_PAGE_080_MEM_TYPE(0x20275A))) /* Message Object 186 Arbitration Register High */


#define CAN_MOAR187H    (*(_PAGE_080_MEM_TYPE(0x20277A))) /* Message Object 187 Arbitration Register High */


#define CAN_MOAR188H    (*(_PAGE_080_MEM_TYPE(0x20279A))) /* Message Object 188 Arbitration Register High */


#define CAN_MOAR189H    (*(_PAGE_080_MEM_TYPE(0x2027BA))) /* Message Object 189 Arbitration Register High */


#define CAN_MOAR190H    (*(_PAGE_080_MEM_TYPE(0x2027DA))) /* Message Object 190 Arbitration Register High */


#define CAN_MOAR191H    (*(_PAGE_080_MEM_TYPE(0x2027FA))) /* Message Object 191 Arbitration Register High */


#define CAN_MOAR192H    (*(_PAGE_080_MEM_TYPE(0x20281A))) /* Message Object 192 Arbitration Register High */


#define CAN_MOAR193H    (*(_PAGE_080_MEM_TYPE(0x20283A))) /* Message Object 193 Arbitration Register High */


#define CAN_MOAR194H    (*(_PAGE_080_MEM_TYPE(0x20285A))) /* Message Object 194 Arbitration Register High */


#define CAN_MOAR195H    (*(_PAGE_080_MEM_TYPE(0x20287A))) /* Message Object 195 Arbitration Register High */


#define CAN_MOAR196H    (*(_PAGE_080_MEM_TYPE(0x20289A))) /* Message Object 196 Arbitration Register High */


#define CAN_MOAR197H    (*(_PAGE_080_MEM_TYPE(0x2028BA))) /* Message Object 197 Arbitration Register High */


#define CAN_MOAR198H    (*(_PAGE_080_MEM_TYPE(0x2028DA))) /* Message Object 198 Arbitration Register High */


#define CAN_MOAR199H    (*(_PAGE_080_MEM_TYPE(0x2028FA))) /* Message Object 199 Arbitration Register High */


#define CAN_MOAR200H    (*(_PAGE_080_MEM_TYPE(0x20291A))) /* Message Object 200 Arbitration Register High */


#define CAN_MOAR201H    (*(_PAGE_080_MEM_TYPE(0x20293A))) /* Message Object 201 Arbitration Register High */


#define CAN_MOAR202H    (*(_PAGE_080_MEM_TYPE(0x20295A))) /* Message Object 202 Arbitration Register High */


#define CAN_MOAR203H    (*(_PAGE_080_MEM_TYPE(0x20297A))) /* Message Object 203 Arbitration Register High */


#define CAN_MOAR204H    (*(_PAGE_080_MEM_TYPE(0x20299A))) /* Message Object 204 Arbitration Register High */


#define CAN_MOAR205H    (*(_PAGE_080_MEM_TYPE(0x2029BA))) /* Message Object 205 Arbitration Register High */


#define CAN_MOAR206H    (*(_PAGE_080_MEM_TYPE(0x2029DA))) /* Message Object 206 Arbitration Register High */


#define CAN_MOAR207H    (*(_PAGE_080_MEM_TYPE(0x2029FA))) /* Message Object 207 Arbitration Register High */


#define CAN_MOAR208H    (*(_PAGE_080_MEM_TYPE(0x202A1A))) /* Message Object 208 Arbitration Register High */


#define CAN_MOAR209H    (*(_PAGE_080_MEM_TYPE(0x202A3A))) /* Message Object 209 Arbitration Register High */


#define CAN_MOAR210H    (*(_PAGE_080_MEM_TYPE(0x202A5A))) /* Message Object 210 Arbitration Register High */


#define CAN_MOAR211H    (*(_PAGE_080_MEM_TYPE(0x202A7A))) /* Message Object 211 Arbitration Register High */


#define CAN_MOAR212H    (*(_PAGE_080_MEM_TYPE(0x202A9A))) /* Message Object 212 Arbitration Register High */


#define CAN_MOAR213H    (*(_PAGE_080_MEM_TYPE(0x202ABA))) /* Message Object 213 Arbitration Register High */


#define CAN_MOAR214H    (*(_PAGE_080_MEM_TYPE(0x202ADA))) /* Message Object 214 Arbitration Register High */


#define CAN_MOAR215H    (*(_PAGE_080_MEM_TYPE(0x202AFA))) /* Message Object 215 Arbitration Register High */


#define CAN_MOAR216H    (*(_PAGE_080_MEM_TYPE(0x202B1A))) /* Message Object 216 Arbitration Register High */


#define CAN_MOAR217H    (*(_PAGE_080_MEM_TYPE(0x202B3A))) /* Message Object 217 Arbitration Register High */


#define CAN_MOAR218H    (*(_PAGE_080_MEM_TYPE(0x202B5A))) /* Message Object 218 Arbitration Register High */


#define CAN_MOAR219H    (*(_PAGE_080_MEM_TYPE(0x202B7A))) /* Message Object 219 Arbitration Register High */


#define CAN_MOAR220H    (*(_PAGE_080_MEM_TYPE(0x202B9A))) /* Message Object 220 Arbitration Register High */


#define CAN_MOAR221H    (*(_PAGE_080_MEM_TYPE(0x202BBA))) /* Message Object 221 Arbitration Register High */


#define CAN_MOAR222H    (*(_PAGE_080_MEM_TYPE(0x202BDA))) /* Message Object 222 Arbitration Register High */


#define CAN_MOAR223H    (*(_PAGE_080_MEM_TYPE(0x202BFA))) /* Message Object 223 Arbitration Register High */


#define CAN_MOAR224H    (*(_PAGE_080_MEM_TYPE(0x202C1A))) /* Message Object 224 Arbitration Register High */


#define CAN_MOAR225H    (*(_PAGE_080_MEM_TYPE(0x202C3A))) /* Message Object 225 Arbitration Register High */


#define CAN_MOAR226H    (*(_PAGE_080_MEM_TYPE(0x202C5A))) /* Message Object 226 Arbitration Register High */


#define CAN_MOAR227H    (*(_PAGE_080_MEM_TYPE(0x202C7A))) /* Message Object 227 Arbitration Register High */


#define CAN_MOAR228H    (*(_PAGE_080_MEM_TYPE(0x202C9A))) /* Message Object 228 Arbitration Register High */


#define CAN_MOAR229H    (*(_PAGE_080_MEM_TYPE(0x202CBA))) /* Message Object 229 Arbitration Register High */


#define CAN_MOAR230H    (*(_PAGE_080_MEM_TYPE(0x202CDA))) /* Message Object 230 Arbitration Register High */


#define CAN_MOAR231H    (*(_PAGE_080_MEM_TYPE(0x202CFA))) /* Message Object 231 Arbitration Register High */


#define CAN_MOAR232H    (*(_PAGE_080_MEM_TYPE(0x202D1A))) /* Message Object 232 Arbitration Register High */


#define CAN_MOAR233H    (*(_PAGE_080_MEM_TYPE(0x202D3A))) /* Message Object 233 Arbitration Register High */


#define CAN_MOAR234H    (*(_PAGE_080_MEM_TYPE(0x202D5A))) /* Message Object 234 Arbitration Register High */


#define CAN_MOAR235H    (*(_PAGE_080_MEM_TYPE(0x202D7A))) /* Message Object 235 Arbitration Register High */


#define CAN_MOAR236H    (*(_PAGE_080_MEM_TYPE(0x202D9A))) /* Message Object 236 Arbitration Register High */


#define CAN_MOAR237H    (*(_PAGE_080_MEM_TYPE(0x202DBA))) /* Message Object 237 Arbitration Register High */


#define CAN_MOAR238H    (*(_PAGE_080_MEM_TYPE(0x202DDA))) /* Message Object 238 Arbitration Register High */


#define CAN_MOAR239H    (*(_PAGE_080_MEM_TYPE(0x202DFA))) /* Message Object 239 Arbitration Register High */


#define CAN_MOAR240H    (*(_PAGE_080_MEM_TYPE(0x202E1A))) /* Message Object 240 Arbitration Register High */


#define CAN_MOAR241H    (*(_PAGE_080_MEM_TYPE(0x202E3A))) /* Message Object 241 Arbitration Register High */


#define CAN_MOAR242H    (*(_PAGE_080_MEM_TYPE(0x202E5A))) /* Message Object 242 Arbitration Register High */


#define CAN_MOAR243H    (*(_PAGE_080_MEM_TYPE(0x202E7A))) /* Message Object 243 Arbitration Register High */


#define CAN_MOAR244H    (*(_PAGE_080_MEM_TYPE(0x202E9A))) /* Message Object 244 Arbitration Register High */


#define CAN_MOAR245H    (*(_PAGE_080_MEM_TYPE(0x202EBA))) /* Message Object 245 Arbitration Register High */


#define CAN_MOAR246H    (*(_PAGE_080_MEM_TYPE(0x202EDA))) /* Message Object 246 Arbitration Register High */


#define CAN_MOAR247H    (*(_PAGE_080_MEM_TYPE(0x202EFA))) /* Message Object 247 Arbitration Register High */


#define CAN_MOAR248H    (*(_PAGE_080_MEM_TYPE(0x202F1A))) /* Message Object 248 Arbitration Register High */


#define CAN_MOAR249H    (*(_PAGE_080_MEM_TYPE(0x202F3A))) /* Message Object 249 Arbitration Register High */


#define CAN_MOAR250H    (*(_PAGE_080_MEM_TYPE(0x202F5A))) /* Message Object 250 Arbitration Register High */


#define CAN_MOAR251H    (*(_PAGE_080_MEM_TYPE(0x202F7A))) /* Message Object 251 Arbitration Register High */


#define CAN_MOAR252H    (*(_PAGE_080_MEM_TYPE(0x202F9A))) /* Message Object 252 Arbitration Register High */


#define CAN_MOAR253H    (*(_PAGE_080_MEM_TYPE(0x202FBA))) /* Message Object 253 Arbitration Register High */


#define CAN_MOAR254H    (*(_PAGE_080_MEM_TYPE(0x202FDA))) /* Message Object 254 Arbitration Register High */


#define CAN_MOAR255H    (*(_PAGE_080_MEM_TYPE(0x202FFA))) /* Message Object 255 Arbitration Register High */


#define CAN_MOAR0L      (*(_PAGE_080_MEM_TYPE(0x201018))) /* Message Object 0 Arbitration Register Low */


#define CAN_MOAR1L      (*(_PAGE_080_MEM_TYPE(0x201038))) /* Message Object 1 Arbitration Register Low */


#define CAN_MOAR2L      (*(_PAGE_080_MEM_TYPE(0x201058))) /* Message Object 2 Arbitration Register Low */


#define CAN_MOAR3L      (*(_PAGE_080_MEM_TYPE(0x201078))) /* Message Object 3 Arbitration Register Low */


#define CAN_MOAR4L      (*(_PAGE_080_MEM_TYPE(0x201098))) /* Message Object 4 Arbitration Register Low */


#define CAN_MOAR5L      (*(_PAGE_080_MEM_TYPE(0x2010B8))) /* Message Object 5 Arbitration Register Low */


#define CAN_MOAR6L      (*(_PAGE_080_MEM_TYPE(0x2010D8))) /* Message Object 6 Arbitration Register Low */


#define CAN_MOAR7L      (*(_PAGE_080_MEM_TYPE(0x2010F8))) /* Message Object 7 Arbitration Register Low */


#define CAN_MOAR8L      (*(_PAGE_080_MEM_TYPE(0x201118))) /* Message Object 8 Arbitration Register Low */


#define CAN_MOAR9L      (*(_PAGE_080_MEM_TYPE(0x201138))) /* Message Object 9 Arbitration Register Low */


#define CAN_MOAR10L     (*(_PAGE_080_MEM_TYPE(0x201158))) /* Message Object 10 Arbitration Register Low */


#define CAN_MOAR11L     (*(_PAGE_080_MEM_TYPE(0x201178))) /* Message Object 11 Arbitration Register Low */


#define CAN_MOAR12L     (*(_PAGE_080_MEM_TYPE(0x201198))) /* Message Object 12 Arbitration Register Low */


#define CAN_MOAR13L     (*(_PAGE_080_MEM_TYPE(0x2011B8))) /* Message Object 13 Arbitration Register Low */


#define CAN_MOAR14L     (*(_PAGE_080_MEM_TYPE(0x2011D8))) /* Message Object 14 Arbitration Register Low */


#define CAN_MOAR15L     (*(_PAGE_080_MEM_TYPE(0x2011F8))) /* Message Object 15 Arbitration Register Low */


#define CAN_MOAR16L     (*(_PAGE_080_MEM_TYPE(0x201218))) /* Message Object 16 Arbitration Register Low */


#define CAN_MOAR17L     (*(_PAGE_080_MEM_TYPE(0x201238))) /* Message Object 17 Arbitration Register Low */


#define CAN_MOAR18L     (*(_PAGE_080_MEM_TYPE(0x201258))) /* Message Object 18 Arbitration Register Low */


#define CAN_MOAR19L     (*(_PAGE_080_MEM_TYPE(0x201278))) /* Message Object 19 Arbitration Register Low */


#define CAN_MOAR20L     (*(_PAGE_080_MEM_TYPE(0x201298))) /* Message Object 20 Arbitration Register Low */


#define CAN_MOAR21L     (*(_PAGE_080_MEM_TYPE(0x2012B8))) /* Message Object 21 Arbitration Register Low */


#define CAN_MOAR22L     (*(_PAGE_080_MEM_TYPE(0x2012D8))) /* Message Object 22 Arbitration Register Low */


#define CAN_MOAR23L     (*(_PAGE_080_MEM_TYPE(0x2012F8))) /* Message Object 23 Arbitration Register Low */


#define CAN_MOAR24L     (*(_PAGE_080_MEM_TYPE(0x201318))) /* Message Object 24 Arbitration Register Low */


#define CAN_MOAR25L     (*(_PAGE_080_MEM_TYPE(0x201338))) /* Message Object 25 Arbitration Register Low */


#define CAN_MOAR26L     (*(_PAGE_080_MEM_TYPE(0x201358))) /* Message Object 26 Arbitration Register Low */


#define CAN_MOAR27L     (*(_PAGE_080_MEM_TYPE(0x201378))) /* Message Object 27 Arbitration Register Low */


#define CAN_MOAR28L     (*(_PAGE_080_MEM_TYPE(0x201398))) /* Message Object 28 Arbitration Register Low */


#define CAN_MOAR29L     (*(_PAGE_080_MEM_TYPE(0x2013B8))) /* Message Object 29 Arbitration Register Low */


#define CAN_MOAR30L     (*(_PAGE_080_MEM_TYPE(0x2013D8))) /* Message Object 30 Arbitration Register Low */


#define CAN_MOAR31L     (*(_PAGE_080_MEM_TYPE(0x2013F8))) /* Message Object 31 Arbitration Register Low */


#define CAN_MOAR32L     (*(_PAGE_080_MEM_TYPE(0x201418))) /* Message Object 32 Arbitration Register Low */


#define CAN_MOAR33L     (*(_PAGE_080_MEM_TYPE(0x201438))) /* Message Object 33 Arbitration Register Low */


#define CAN_MOAR34L     (*(_PAGE_080_MEM_TYPE(0x201458))) /* Message Object 34 Arbitration Register Low */


#define CAN_MOAR35L     (*(_PAGE_080_MEM_TYPE(0x201478))) /* Message Object 35 Arbitration Register Low */


#define CAN_MOAR36L     (*(_PAGE_080_MEM_TYPE(0x201498))) /* Message Object 36 Arbitration Register Low */


#define CAN_MOAR37L     (*(_PAGE_080_MEM_TYPE(0x2014B8))) /* Message Object 37 Arbitration Register Low */


#define CAN_MOAR38L     (*(_PAGE_080_MEM_TYPE(0x2014D8))) /* Message Object 38 Arbitration Register Low */


#define CAN_MOAR39L     (*(_PAGE_080_MEM_TYPE(0x2014F8))) /* Message Object 39 Arbitration Register Low */


#define CAN_MOAR40L     (*(_PAGE_080_MEM_TYPE(0x201518))) /* Message Object 40 Arbitration Register Low */


#define CAN_MOAR41L     (*(_PAGE_080_MEM_TYPE(0x201538))) /* Message Object 41 Arbitration Register Low */


#define CAN_MOAR42L     (*(_PAGE_080_MEM_TYPE(0x201558))) /* Message Object 42 Arbitration Register Low */


#define CAN_MOAR43L     (*(_PAGE_080_MEM_TYPE(0x201578))) /* Message Object 43 Arbitration Register Low */


#define CAN_MOAR44L     (*(_PAGE_080_MEM_TYPE(0x201598))) /* Message Object 44 Arbitration Register Low */


#define CAN_MOAR45L     (*(_PAGE_080_MEM_TYPE(0x2015B8))) /* Message Object 45 Arbitration Register Low */


#define CAN_MOAR46L     (*(_PAGE_080_MEM_TYPE(0x2015D8))) /* Message Object 46 Arbitration Register Low */


#define CAN_MOAR47L     (*(_PAGE_080_MEM_TYPE(0x2015F8))) /* Message Object 47 Arbitration Register Low */


#define CAN_MOAR48L     (*(_PAGE_080_MEM_TYPE(0x201618))) /* Message Object 48 Arbitration Register Low */


#define CAN_MOAR49L     (*(_PAGE_080_MEM_TYPE(0x201638))) /* Message Object 49 Arbitration Register Low */


#define CAN_MOAR50L     (*(_PAGE_080_MEM_TYPE(0x201658))) /* Message Object 50 Arbitration Register Low */


#define CAN_MOAR51L     (*(_PAGE_080_MEM_TYPE(0x201678))) /* Message Object 51 Arbitration Register Low */


#define CAN_MOAR52L     (*(_PAGE_080_MEM_TYPE(0x201698))) /* Message Object 52 Arbitration Register Low */


#define CAN_MOAR53L     (*(_PAGE_080_MEM_TYPE(0x2016B8))) /* Message Object 53 Arbitration Register Low */


#define CAN_MOAR54L     (*(_PAGE_080_MEM_TYPE(0x2016D8))) /* Message Object 54 Arbitration Register Low */


#define CAN_MOAR55L     (*(_PAGE_080_MEM_TYPE(0x2016F8))) /* Message Object 55 Arbitration Register Low */


#define CAN_MOAR56L     (*(_PAGE_080_MEM_TYPE(0x201718))) /* Message Object 56 Arbitration Register Low */


#define CAN_MOAR57L     (*(_PAGE_080_MEM_TYPE(0x201738))) /* Message Object 57 Arbitration Register Low */


#define CAN_MOAR58L     (*(_PAGE_080_MEM_TYPE(0x201758))) /* Message Object 58 Arbitration Register Low */


#define CAN_MOAR59L     (*(_PAGE_080_MEM_TYPE(0x201778))) /* Message Object 59 Arbitration Register Low */


#define CAN_MOAR60L     (*(_PAGE_080_MEM_TYPE(0x201798))) /* Message Object 60 Arbitration Register Low */


#define CAN_MOAR61L     (*(_PAGE_080_MEM_TYPE(0x2017B8))) /* Message Object 61 Arbitration Register Low */


#define CAN_MOAR62L     (*(_PAGE_080_MEM_TYPE(0x2017D8))) /* Message Object 62 Arbitration Register Low */


#define CAN_MOAR63L     (*(_PAGE_080_MEM_TYPE(0x2017F8))) /* Message Object 63 Arbitration Register Low */


#define CAN_MOAR64L     (*(_PAGE_080_MEM_TYPE(0x201818))) /* Message Object 64 Arbitration Register Low */


#define CAN_MOAR65L     (*(_PAGE_080_MEM_TYPE(0x201838))) /* Message Object 65 Arbitration Register Low */


#define CAN_MOAR66L     (*(_PAGE_080_MEM_TYPE(0x201858))) /* Message Object 66 Arbitration Register Low */


#define CAN_MOAR67L     (*(_PAGE_080_MEM_TYPE(0x201878))) /* Message Object 67 Arbitration Register Low */


#define CAN_MOAR68L     (*(_PAGE_080_MEM_TYPE(0x201898))) /* Message Object 68 Arbitration Register Low */


#define CAN_MOAR69L     (*(_PAGE_080_MEM_TYPE(0x2018B8))) /* Message Object 69 Arbitration Register Low */


#define CAN_MOAR70L     (*(_PAGE_080_MEM_TYPE(0x2018D8))) /* Message Object 70 Arbitration Register Low */


#define CAN_MOAR71L     (*(_PAGE_080_MEM_TYPE(0x2018F8))) /* Message Object 71 Arbitration Register Low */


#define CAN_MOAR72L     (*(_PAGE_080_MEM_TYPE(0x201918))) /* Message Object 72 Arbitration Register Low */


#define CAN_MOAR73L     (*(_PAGE_080_MEM_TYPE(0x201938))) /* Message Object 73 Arbitration Register Low */


#define CAN_MOAR74L     (*(_PAGE_080_MEM_TYPE(0x201958))) /* Message Object 74 Arbitration Register Low */


#define CAN_MOAR75L     (*(_PAGE_080_MEM_TYPE(0x201978))) /* Message Object 75 Arbitration Register Low */


#define CAN_MOAR76L     (*(_PAGE_080_MEM_TYPE(0x201998))) /* Message Object 76 Arbitration Register Low */


#define CAN_MOAR77L     (*(_PAGE_080_MEM_TYPE(0x2019B8))) /* Message Object 77 Arbitration Register Low */


#define CAN_MOAR78L     (*(_PAGE_080_MEM_TYPE(0x2019D8))) /* Message Object 78 Arbitration Register Low */


#define CAN_MOAR79L     (*(_PAGE_080_MEM_TYPE(0x2019F8))) /* Message Object 79 Arbitration Register Low */


#define CAN_MOAR80L     (*(_PAGE_080_MEM_TYPE(0x201A18))) /* Message Object 80 Arbitration Register Low */


#define CAN_MOAR81L     (*(_PAGE_080_MEM_TYPE(0x201A38))) /* Message Object 81 Arbitration Register Low */


#define CAN_MOAR82L     (*(_PAGE_080_MEM_TYPE(0x201A58))) /* Message Object 82 Arbitration Register Low */


#define CAN_MOAR83L     (*(_PAGE_080_MEM_TYPE(0x201A78))) /* Message Object 83 Arbitration Register Low */


#define CAN_MOAR84L     (*(_PAGE_080_MEM_TYPE(0x201A98))) /* Message Object 84 Arbitration Register Low */


#define CAN_MOAR85L     (*(_PAGE_080_MEM_TYPE(0x201AB8))) /* Message Object 85 Arbitration Register Low */


#define CAN_MOAR86L     (*(_PAGE_080_MEM_TYPE(0x201AD8))) /* Message Object 86 Arbitration Register Low */


#define CAN_MOAR87L     (*(_PAGE_080_MEM_TYPE(0x201AF8))) /* Message Object 87 Arbitration Register Low */


#define CAN_MOAR88L     (*(_PAGE_080_MEM_TYPE(0x201B18))) /* Message Object 88 Arbitration Register Low */


#define CAN_MOAR89L     (*(_PAGE_080_MEM_TYPE(0x201B38))) /* Message Object 89 Arbitration Register Low */


#define CAN_MOAR90L     (*(_PAGE_080_MEM_TYPE(0x201B58))) /* Message Object 90 Arbitration Register Low */


#define CAN_MOAR91L     (*(_PAGE_080_MEM_TYPE(0x201B78))) /* Message Object 91 Arbitration Register Low */


#define CAN_MOAR92L     (*(_PAGE_080_MEM_TYPE(0x201B98))) /* Message Object 92 Arbitration Register Low */


#define CAN_MOAR93L     (*(_PAGE_080_MEM_TYPE(0x201BB8))) /* Message Object 93 Arbitration Register Low */


#define CAN_MOAR94L     (*(_PAGE_080_MEM_TYPE(0x201BD8))) /* Message Object 94 Arbitration Register Low */


#define CAN_MOAR95L     (*(_PAGE_080_MEM_TYPE(0x201BF8))) /* Message Object 95 Arbitration Register Low */


#define CAN_MOAR96L     (*(_PAGE_080_MEM_TYPE(0x201C18))) /* Message Object 96 Arbitration Register Low */


#define CAN_MOAR97L     (*(_PAGE_080_MEM_TYPE(0x201C38))) /* Message Object 97 Arbitration Register Low */


#define CAN_MOAR98L     (*(_PAGE_080_MEM_TYPE(0x201C58))) /* Message Object 98 Arbitration Register Low */


#define CAN_MOAR99L     (*(_PAGE_080_MEM_TYPE(0x201C78))) /* Message Object 99 Arbitration Register Low */


#define CAN_MOAR100L    (*(_PAGE_080_MEM_TYPE(0x201C98))) /* Message Object 100 Arbitration Register Low */


#define CAN_MOAR101L    (*(_PAGE_080_MEM_TYPE(0x201CB8))) /* Message Object 101 Arbitration Register Low */


#define CAN_MOAR102L    (*(_PAGE_080_MEM_TYPE(0x201CD8))) /* Message Object 102 Arbitration Register Low */


#define CAN_MOAR103L    (*(_PAGE_080_MEM_TYPE(0x201CF8))) /* Message Object 103 Arbitration Register Low */


#define CAN_MOAR104L    (*(_PAGE_080_MEM_TYPE(0x201D18))) /* Message Object 104 Arbitration Register Low */


#define CAN_MOAR105L    (*(_PAGE_080_MEM_TYPE(0x201D38))) /* Message Object 105 Arbitration Register Low */


#define CAN_MOAR106L    (*(_PAGE_080_MEM_TYPE(0x201D58))) /* Message Object 106 Arbitration Register Low */


#define CAN_MOAR107L    (*(_PAGE_080_MEM_TYPE(0x201D78))) /* Message Object 107 Arbitration Register Low */


#define CAN_MOAR108L    (*(_PAGE_080_MEM_TYPE(0x201D98))) /* Message Object 108 Arbitration Register Low */


#define CAN_MOAR109L    (*(_PAGE_080_MEM_TYPE(0x201DB8))) /* Message Object 109 Arbitration Register Low */


#define CAN_MOAR110L    (*(_PAGE_080_MEM_TYPE(0x201DD8))) /* Message Object 110 Arbitration Register Low */


#define CAN_MOAR111L    (*(_PAGE_080_MEM_TYPE(0x201DF8))) /* Message Object 111 Arbitration Register Low */


#define CAN_MOAR112L    (*(_PAGE_080_MEM_TYPE(0x201E18))) /* Message Object 112 Arbitration Register Low */


#define CAN_MOAR113L    (*(_PAGE_080_MEM_TYPE(0x201E38))) /* Message Object 113 Arbitration Register Low */


#define CAN_MOAR114L    (*(_PAGE_080_MEM_TYPE(0x201E58))) /* Message Object 114 Arbitration Register Low */


#define CAN_MOAR115L    (*(_PAGE_080_MEM_TYPE(0x201E78))) /* Message Object 115 Arbitration Register Low */


#define CAN_MOAR116L    (*(_PAGE_080_MEM_TYPE(0x201E98))) /* Message Object 116 Arbitration Register Low */


#define CAN_MOAR117L    (*(_PAGE_080_MEM_TYPE(0x201EB8))) /* Message Object 117 Arbitration Register Low */


#define CAN_MOAR118L    (*(_PAGE_080_MEM_TYPE(0x201ED8))) /* Message Object 118 Arbitration Register Low */


#define CAN_MOAR119L    (*(_PAGE_080_MEM_TYPE(0x201EF8))) /* Message Object 119 Arbitration Register Low */


#define CAN_MOAR120L    (*(_PAGE_080_MEM_TYPE(0x201F18))) /* Message Object 120 Arbitration Register Low */


#define CAN_MOAR121L    (*(_PAGE_080_MEM_TYPE(0x201F38))) /* Message Object 121 Arbitration Register Low */


#define CAN_MOAR122L    (*(_PAGE_080_MEM_TYPE(0x201F58))) /* Message Object 122 Arbitration Register Low */


#define CAN_MOAR123L    (*(_PAGE_080_MEM_TYPE(0x201F78))) /* Message Object 123 Arbitration Register Low */


#define CAN_MOAR124L    (*(_PAGE_080_MEM_TYPE(0x201F98))) /* Message Object 124 Arbitration Register Low */


#define CAN_MOAR125L    (*(_PAGE_080_MEM_TYPE(0x201FB8))) /* Message Object 125 Arbitration Register Low */


#define CAN_MOAR126L    (*(_PAGE_080_MEM_TYPE(0x201FD8))) /* Message Object 126 Arbitration Register Low */


#define CAN_MOAR127L    (*(_PAGE_080_MEM_TYPE(0x201FF8))) /* Message Object 127 Arbitration Register Low */


#define CAN_MOAR128L    (*(_PAGE_080_MEM_TYPE(0x202018))) /* Message Object 128 Arbitration Register Low */


#define CAN_MOAR129L    (*(_PAGE_080_MEM_TYPE(0x202038))) /* Message Object 129 Arbitration Register Low */


#define CAN_MOAR130L    (*(_PAGE_080_MEM_TYPE(0x202058))) /* Message Object 130 Arbitration Register Low */


#define CAN_MOAR131L    (*(_PAGE_080_MEM_TYPE(0x202078))) /* Message Object 131 Arbitration Register Low */


#define CAN_MOAR132L    (*(_PAGE_080_MEM_TYPE(0x202098))) /* Message Object 132 Arbitration Register Low */


#define CAN_MOAR133L    (*(_PAGE_080_MEM_TYPE(0x2020B8))) /* Message Object 133 Arbitration Register Low */


#define CAN_MOAR134L    (*(_PAGE_080_MEM_TYPE(0x2020D8))) /* Message Object 134 Arbitration Register Low */


#define CAN_MOAR135L    (*(_PAGE_080_MEM_TYPE(0x2020F8))) /* Message Object 135 Arbitration Register Low */


#define CAN_MOAR136L    (*(_PAGE_080_MEM_TYPE(0x202118))) /* Message Object 136 Arbitration Register Low */


#define CAN_MOAR137L    (*(_PAGE_080_MEM_TYPE(0x202138))) /* Message Object 137 Arbitration Register Low */


#define CAN_MOAR138L    (*(_PAGE_080_MEM_TYPE(0x202158))) /* Message Object 138 Arbitration Register Low */


#define CAN_MOAR139L    (*(_PAGE_080_MEM_TYPE(0x202178))) /* Message Object 139 Arbitration Register Low */


#define CAN_MOAR140L    (*(_PAGE_080_MEM_TYPE(0x202198))) /* Message Object 140 Arbitration Register Low */


#define CAN_MOAR141L    (*(_PAGE_080_MEM_TYPE(0x2021B8))) /* Message Object 141 Arbitration Register Low */


#define CAN_MOAR142L    (*(_PAGE_080_MEM_TYPE(0x2021D8))) /* Message Object 142 Arbitration Register Low */


#define CAN_MOAR143L    (*(_PAGE_080_MEM_TYPE(0x2021F8))) /* Message Object 143 Arbitration Register Low */


#define CAN_MOAR144L    (*(_PAGE_080_MEM_TYPE(0x202218))) /* Message Object 144 Arbitration Register Low */


#define CAN_MOAR145L    (*(_PAGE_080_MEM_TYPE(0x202238))) /* Message Object 145 Arbitration Register Low */


#define CAN_MOAR146L    (*(_PAGE_080_MEM_TYPE(0x202258))) /* Message Object 146 Arbitration Register Low */


#define CAN_MOAR147L    (*(_PAGE_080_MEM_TYPE(0x202278))) /* Message Object 147 Arbitration Register Low */


#define CAN_MOAR148L    (*(_PAGE_080_MEM_TYPE(0x202298))) /* Message Object 148 Arbitration Register Low */


#define CAN_MOAR149L    (*(_PAGE_080_MEM_TYPE(0x2022B8))) /* Message Object 149 Arbitration Register Low */


#define CAN_MOAR150L    (*(_PAGE_080_MEM_TYPE(0x2022D8))) /* Message Object 150 Arbitration Register Low */


#define CAN_MOAR151L    (*(_PAGE_080_MEM_TYPE(0x2022F8))) /* Message Object 151 Arbitration Register Low */


#define CAN_MOAR152L    (*(_PAGE_080_MEM_TYPE(0x202318))) /* Message Object 152 Arbitration Register Low */


#define CAN_MOAR153L    (*(_PAGE_080_MEM_TYPE(0x202338))) /* Message Object 153 Arbitration Register Low */


#define CAN_MOAR154L    (*(_PAGE_080_MEM_TYPE(0x202358))) /* Message Object 154 Arbitration Register Low */


#define CAN_MOAR155L    (*(_PAGE_080_MEM_TYPE(0x202378))) /* Message Object 155 Arbitration Register Low */


#define CAN_MOAR156L    (*(_PAGE_080_MEM_TYPE(0x202398))) /* Message Object 156 Arbitration Register Low */


#define CAN_MOAR157L    (*(_PAGE_080_MEM_TYPE(0x2023B8))) /* Message Object 157 Arbitration Register Low */


#define CAN_MOAR158L    (*(_PAGE_080_MEM_TYPE(0x2023D8))) /* Message Object 158 Arbitration Register Low */


#define CAN_MOAR159L    (*(_PAGE_080_MEM_TYPE(0x2023F8))) /* Message Object 159 Arbitration Register Low */


#define CAN_MOAR160L    (*(_PAGE_080_MEM_TYPE(0x202418))) /* Message Object 160 Arbitration Register Low */


#define CAN_MOAR161L    (*(_PAGE_080_MEM_TYPE(0x202438))) /* Message Object 161 Arbitration Register Low */


#define CAN_MOAR162L    (*(_PAGE_080_MEM_TYPE(0x202458))) /* Message Object 162 Arbitration Register Low */


#define CAN_MOAR163L    (*(_PAGE_080_MEM_TYPE(0x202478))) /* Message Object 163 Arbitration Register Low */


#define CAN_MOAR164L    (*(_PAGE_080_MEM_TYPE(0x202498))) /* Message Object 164 Arbitration Register Low */


#define CAN_MOAR165L    (*(_PAGE_080_MEM_TYPE(0x2024B8))) /* Message Object 165 Arbitration Register Low */


#define CAN_MOAR166L    (*(_PAGE_080_MEM_TYPE(0x2024D8))) /* Message Object 166 Arbitration Register Low */


#define CAN_MOAR167L    (*(_PAGE_080_MEM_TYPE(0x2024F8))) /* Message Object 167 Arbitration Register Low */


#define CAN_MOAR168L    (*(_PAGE_080_MEM_TYPE(0x202518))) /* Message Object 168 Arbitration Register Low */


#define CAN_MOAR169L    (*(_PAGE_080_MEM_TYPE(0x202538))) /* Message Object 169 Arbitration Register Low */


#define CAN_MOAR170L    (*(_PAGE_080_MEM_TYPE(0x202558))) /* Message Object 170 Arbitration Register Low */


#define CAN_MOAR171L    (*(_PAGE_080_MEM_TYPE(0x202578))) /* Message Object 171 Arbitration Register Low */


#define CAN_MOAR172L    (*(_PAGE_080_MEM_TYPE(0x202598))) /* Message Object 172 Arbitration Register Low */


#define CAN_MOAR173L    (*(_PAGE_080_MEM_TYPE(0x2025B8))) /* Message Object 173 Arbitration Register Low */


#define CAN_MOAR174L    (*(_PAGE_080_MEM_TYPE(0x2025D8))) /* Message Object 174 Arbitration Register Low */


#define CAN_MOAR175L    (*(_PAGE_080_MEM_TYPE(0x2025F8))) /* Message Object 175 Arbitration Register Low */


#define CAN_MOAR176L    (*(_PAGE_080_MEM_TYPE(0x202618))) /* Message Object 176 Arbitration Register Low */


#define CAN_MOAR177L    (*(_PAGE_080_MEM_TYPE(0x202638))) /* Message Object 177 Arbitration Register Low */


#define CAN_MOAR178L    (*(_PAGE_080_MEM_TYPE(0x202658))) /* Message Object 178 Arbitration Register Low */


#define CAN_MOAR179L    (*(_PAGE_080_MEM_TYPE(0x202678))) /* Message Object 179 Arbitration Register Low */


#define CAN_MOAR180L    (*(_PAGE_080_MEM_TYPE(0x202698))) /* Message Object 180 Arbitration Register Low */


#define CAN_MOAR181L    (*(_PAGE_080_MEM_TYPE(0x2026B8))) /* Message Object 181 Arbitration Register Low */


#define CAN_MOAR182L    (*(_PAGE_080_MEM_TYPE(0x2026D8))) /* Message Object 182 Arbitration Register Low */


#define CAN_MOAR183L    (*(_PAGE_080_MEM_TYPE(0x2026F8))) /* Message Object 183 Arbitration Register Low */


#define CAN_MOAR184L    (*(_PAGE_080_MEM_TYPE(0x202718))) /* Message Object 184 Arbitration Register Low */


#define CAN_MOAR185L    (*(_PAGE_080_MEM_TYPE(0x202738))) /* Message Object 185 Arbitration Register Low */


#define CAN_MOAR186L    (*(_PAGE_080_MEM_TYPE(0x202758))) /* Message Object 186 Arbitration Register Low */


#define CAN_MOAR187L    (*(_PAGE_080_MEM_TYPE(0x202778))) /* Message Object 187 Arbitration Register Low */


#define CAN_MOAR188L    (*(_PAGE_080_MEM_TYPE(0x202798))) /* Message Object 188 Arbitration Register Low */


#define CAN_MOAR189L    (*(_PAGE_080_MEM_TYPE(0x2027B8))) /* Message Object 189 Arbitration Register Low */


#define CAN_MOAR190L    (*(_PAGE_080_MEM_TYPE(0x2027D8))) /* Message Object 190 Arbitration Register Low */


#define CAN_MOAR191L    (*(_PAGE_080_MEM_TYPE(0x2027F8))) /* Message Object 191 Arbitration Register Low */


#define CAN_MOAR192L    (*(_PAGE_080_MEM_TYPE(0x202818))) /* Message Object 192 Arbitration Register Low */


#define CAN_MOAR193L    (*(_PAGE_080_MEM_TYPE(0x202838))) /* Message Object 193 Arbitration Register Low */


#define CAN_MOAR194L    (*(_PAGE_080_MEM_TYPE(0x202858))) /* Message Object 194 Arbitration Register Low */


#define CAN_MOAR195L    (*(_PAGE_080_MEM_TYPE(0x202878))) /* Message Object 195 Arbitration Register Low */


#define CAN_MOAR196L    (*(_PAGE_080_MEM_TYPE(0x202898))) /* Message Object 196 Arbitration Register Low */


#define CAN_MOAR197L    (*(_PAGE_080_MEM_TYPE(0x2028B8))) /* Message Object 197 Arbitration Register Low */


#define CAN_MOAR198L    (*(_PAGE_080_MEM_TYPE(0x2028D8))) /* Message Object 198 Arbitration Register Low */


#define CAN_MOAR199L    (*(_PAGE_080_MEM_TYPE(0x2028F8))) /* Message Object 199 Arbitration Register Low */


#define CAN_MOAR200L    (*(_PAGE_080_MEM_TYPE(0x202918))) /* Message Object 200 Arbitration Register Low */


#define CAN_MOAR201L    (*(_PAGE_080_MEM_TYPE(0x202938))) /* Message Object 201 Arbitration Register Low */


#define CAN_MOAR202L    (*(_PAGE_080_MEM_TYPE(0x202958))) /* Message Object 202 Arbitration Register Low */


#define CAN_MOAR203L    (*(_PAGE_080_MEM_TYPE(0x202978))) /* Message Object 203 Arbitration Register Low */


#define CAN_MOAR204L    (*(_PAGE_080_MEM_TYPE(0x202998))) /* Message Object 204 Arbitration Register Low */


#define CAN_MOAR205L    (*(_PAGE_080_MEM_TYPE(0x2029B8))) /* Message Object 205 Arbitration Register Low */


#define CAN_MOAR206L    (*(_PAGE_080_MEM_TYPE(0x2029D8))) /* Message Object 206 Arbitration Register Low */


#define CAN_MOAR207L    (*(_PAGE_080_MEM_TYPE(0x2029F8))) /* Message Object 207 Arbitration Register Low */


#define CAN_MOAR208L    (*(_PAGE_080_MEM_TYPE(0x202A18))) /* Message Object 208 Arbitration Register Low */


#define CAN_MOAR209L    (*(_PAGE_080_MEM_TYPE(0x202A38))) /* Message Object 209 Arbitration Register Low */


#define CAN_MOAR210L    (*(_PAGE_080_MEM_TYPE(0x202A58))) /* Message Object 210 Arbitration Register Low */


#define CAN_MOAR211L    (*(_PAGE_080_MEM_TYPE(0x202A78))) /* Message Object 211 Arbitration Register Low */


#define CAN_MOAR212L    (*(_PAGE_080_MEM_TYPE(0x202A98))) /* Message Object 212 Arbitration Register Low */


#define CAN_MOAR213L    (*(_PAGE_080_MEM_TYPE(0x202AB8))) /* Message Object 213 Arbitration Register Low */


#define CAN_MOAR214L    (*(_PAGE_080_MEM_TYPE(0x202AD8))) /* Message Object 214 Arbitration Register Low */


#define CAN_MOAR215L    (*(_PAGE_080_MEM_TYPE(0x202AF8))) /* Message Object 215 Arbitration Register Low */


#define CAN_MOAR216L    (*(_PAGE_080_MEM_TYPE(0x202B18))) /* Message Object 216 Arbitration Register Low */


#define CAN_MOAR217L    (*(_PAGE_080_MEM_TYPE(0x202B38))) /* Message Object 217 Arbitration Register Low */


#define CAN_MOAR218L    (*(_PAGE_080_MEM_TYPE(0x202B58))) /* Message Object 218 Arbitration Register Low */


#define CAN_MOAR219L    (*(_PAGE_080_MEM_TYPE(0x202B78))) /* Message Object 219 Arbitration Register Low */


#define CAN_MOAR220L    (*(_PAGE_080_MEM_TYPE(0x202B98))) /* Message Object 220 Arbitration Register Low */


#define CAN_MOAR221L    (*(_PAGE_080_MEM_TYPE(0x202BB8))) /* Message Object 221 Arbitration Register Low */


#define CAN_MOAR222L    (*(_PAGE_080_MEM_TYPE(0x202BD8))) /* Message Object 222 Arbitration Register Low */


#define CAN_MOAR223L    (*(_PAGE_080_MEM_TYPE(0x202BF8))) /* Message Object 223 Arbitration Register Low */


#define CAN_MOAR224L    (*(_PAGE_080_MEM_TYPE(0x202C18))) /* Message Object 224 Arbitration Register Low */


#define CAN_MOAR225L    (*(_PAGE_080_MEM_TYPE(0x202C38))) /* Message Object 225 Arbitration Register Low */


#define CAN_MOAR226L    (*(_PAGE_080_MEM_TYPE(0x202C58))) /* Message Object 226 Arbitration Register Low */


#define CAN_MOAR227L    (*(_PAGE_080_MEM_TYPE(0x202C78))) /* Message Object 227 Arbitration Register Low */


#define CAN_MOAR228L    (*(_PAGE_080_MEM_TYPE(0x202C98))) /* Message Object 228 Arbitration Register Low */


#define CAN_MOAR229L    (*(_PAGE_080_MEM_TYPE(0x202CB8))) /* Message Object 229 Arbitration Register Low */


#define CAN_MOAR230L    (*(_PAGE_080_MEM_TYPE(0x202CD8))) /* Message Object 230 Arbitration Register Low */


#define CAN_MOAR231L    (*(_PAGE_080_MEM_TYPE(0x202CF8))) /* Message Object 231 Arbitration Register Low */


#define CAN_MOAR232L    (*(_PAGE_080_MEM_TYPE(0x202D18))) /* Message Object 232 Arbitration Register Low */


#define CAN_MOAR233L    (*(_PAGE_080_MEM_TYPE(0x202D38))) /* Message Object 233 Arbitration Register Low */


#define CAN_MOAR234L    (*(_PAGE_080_MEM_TYPE(0x202D58))) /* Message Object 234 Arbitration Register Low */


#define CAN_MOAR235L    (*(_PAGE_080_MEM_TYPE(0x202D78))) /* Message Object 235 Arbitration Register Low */


#define CAN_MOAR236L    (*(_PAGE_080_MEM_TYPE(0x202D98))) /* Message Object 236 Arbitration Register Low */


#define CAN_MOAR237L    (*(_PAGE_080_MEM_TYPE(0x202DB8))) /* Message Object 237 Arbitration Register Low */


#define CAN_MOAR238L    (*(_PAGE_080_MEM_TYPE(0x202DD8))) /* Message Object 238 Arbitration Register Low */


#define CAN_MOAR239L    (*(_PAGE_080_MEM_TYPE(0x202DF8))) /* Message Object 239 Arbitration Register Low */


#define CAN_MOAR240L    (*(_PAGE_080_MEM_TYPE(0x202E18))) /* Message Object 240 Arbitration Register Low */


#define CAN_MOAR241L    (*(_PAGE_080_MEM_TYPE(0x202E38))) /* Message Object 241 Arbitration Register Low */


#define CAN_MOAR242L    (*(_PAGE_080_MEM_TYPE(0x202E58))) /* Message Object 242 Arbitration Register Low */


#define CAN_MOAR243L    (*(_PAGE_080_MEM_TYPE(0x202E78))) /* Message Object 243 Arbitration Register Low */


#define CAN_MOAR244L    (*(_PAGE_080_MEM_TYPE(0x202E98))) /* Message Object 244 Arbitration Register Low */


#define CAN_MOAR245L    (*(_PAGE_080_MEM_TYPE(0x202EB8))) /* Message Object 245 Arbitration Register Low */


#define CAN_MOAR246L    (*(_PAGE_080_MEM_TYPE(0x202ED8))) /* Message Object 246 Arbitration Register Low */


#define CAN_MOAR247L    (*(_PAGE_080_MEM_TYPE(0x202EF8))) /* Message Object 247 Arbitration Register Low */


#define CAN_MOAR248L    (*(_PAGE_080_MEM_TYPE(0x202F18))) /* Message Object 248 Arbitration Register Low */


#define CAN_MOAR249L    (*(_PAGE_080_MEM_TYPE(0x202F38))) /* Message Object 249 Arbitration Register Low */


#define CAN_MOAR250L    (*(_PAGE_080_MEM_TYPE(0x202F58))) /* Message Object 250 Arbitration Register Low */


#define CAN_MOAR251L    (*(_PAGE_080_MEM_TYPE(0x202F78))) /* Message Object 251 Arbitration Register Low */


#define CAN_MOAR252L    (*(_PAGE_080_MEM_TYPE(0x202F98))) /* Message Object 252 Arbitration Register Low */


#define CAN_MOAR253L    (*(_PAGE_080_MEM_TYPE(0x202FB8))) /* Message Object 253 Arbitration Register Low */


#define CAN_MOAR254L    (*(_PAGE_080_MEM_TYPE(0x202FD8))) /* Message Object 254 Arbitration Register Low */


#define CAN_MOAR255L    (*(_PAGE_080_MEM_TYPE(0x202FF8))) /* Message Object 255 Arbitration Register Low */


#define CAN_MODATA0LH   (*(_PAGE_080_MEM_TYPE(0x201012))) /* Message Object 0 Data Register Low High */


#define CAN_MODATA1LH   (*(_PAGE_080_MEM_TYPE(0x201032))) /* Message Object 1 Data Register Low High */


#define CAN_MODATA2LH   (*(_PAGE_080_MEM_TYPE(0x201052))) /* Message Object 2 Data Register Low High */


#define CAN_MODATA3LH   (*(_PAGE_080_MEM_TYPE(0x201072))) /* Message Object 3 Data Register Low High */


#define CAN_MODATA4LH   (*(_PAGE_080_MEM_TYPE(0x201092))) /* Message Object 4 Data Register Low High */


#define CAN_MODATA5LH   (*(_PAGE_080_MEM_TYPE(0x2010B2))) /* Message Object 5 Data Register Low High */


#define CAN_MODATA6LH   (*(_PAGE_080_MEM_TYPE(0x2010D2))) /* Message Object 6 Data Register Low High */


#define CAN_MODATA7LH   (*(_PAGE_080_MEM_TYPE(0x2010F2))) /* Message Object 7 Data Register Low High */


#define CAN_MODATA8LH   (*(_PAGE_080_MEM_TYPE(0x201112))) /* Message Object 8 Data Register Low High */


#define CAN_MODATA9LH   (*(_PAGE_080_MEM_TYPE(0x201132))) /* Message Object 9 Data Register Low High */


#define CAN_MODATA10LH  (*(_PAGE_080_MEM_TYPE(0x201152))) /* Message Object 10 Data Register Low High */


#define CAN_MODATA11LH  (*(_PAGE_080_MEM_TYPE(0x201172))) /* Message Object 11 Data Register Low High */


#define CAN_MODATA12LH  (*(_PAGE_080_MEM_TYPE(0x201192))) /* Message Object 12 Data Register Low High */


#define CAN_MODATA13LH  (*(_PAGE_080_MEM_TYPE(0x2011B2))) /* Message Object 13 Data Register Low High */


#define CAN_MODATA14LH  (*(_PAGE_080_MEM_TYPE(0x2011D2))) /* Message Object 14 Data Register Low High */


#define CAN_MODATA15LH  (*(_PAGE_080_MEM_TYPE(0x2011F2))) /* Message Object 15 Data Register Low High */


#define CAN_MODATA16LH  (*(_PAGE_080_MEM_TYPE(0x201212))) /* Message Object 16 Data Register Low High */


#define CAN_MODATA17LH  (*(_PAGE_080_MEM_TYPE(0x201232))) /* Message Object 17 Data Register Low High */


#define CAN_MODATA18LH  (*(_PAGE_080_MEM_TYPE(0x201252))) /* Message Object 18 Data Register Low High */


#define CAN_MODATA19LH  (*(_PAGE_080_MEM_TYPE(0x201272))) /* Message Object 19 Data Register Low High */


#define CAN_MODATA20LH  (*(_PAGE_080_MEM_TYPE(0x201292))) /* Message Object 20 Data Register Low High */


#define CAN_MODATA21LH  (*(_PAGE_080_MEM_TYPE(0x2012B2))) /* Message Object 21 Data Register Low High */


#define CAN_MODATA22LH  (*(_PAGE_080_MEM_TYPE(0x2012D2))) /* Message Object 22 Data Register Low High */


#define CAN_MODATA23LH  (*(_PAGE_080_MEM_TYPE(0x2012F2))) /* Message Object 23 Data Register Low High */


#define CAN_MODATA24LH  (*(_PAGE_080_MEM_TYPE(0x201312))) /* Message Object 24 Data Register Low High */


#define CAN_MODATA25LH  (*(_PAGE_080_MEM_TYPE(0x201332))) /* Message Object 25 Data Register Low High */


#define CAN_MODATA26LH  (*(_PAGE_080_MEM_TYPE(0x201352))) /* Message Object 26 Data Register Low High */


#define CAN_MODATA27LH  (*(_PAGE_080_MEM_TYPE(0x201372))) /* Message Object 27 Data Register Low High */


#define CAN_MODATA28LH  (*(_PAGE_080_MEM_TYPE(0x201392))) /* Message Object 28 Data Register Low High */


#define CAN_MODATA29LH  (*(_PAGE_080_MEM_TYPE(0x2013B2))) /* Message Object 29 Data Register Low High */


#define CAN_MODATA30LH  (*(_PAGE_080_MEM_TYPE(0x2013D2))) /* Message Object 30 Data Register Low High */


#define CAN_MODATA31LH  (*(_PAGE_080_MEM_TYPE(0x2013F2))) /* Message Object 31 Data Register Low High */


#define CAN_MODATA32LH  (*(_PAGE_080_MEM_TYPE(0x201412))) /* Message Object 32 Data Register Low High */


#define CAN_MODATA33LH  (*(_PAGE_080_MEM_TYPE(0x201432))) /* Message Object 33 Data Register Low High */


#define CAN_MODATA34LH  (*(_PAGE_080_MEM_TYPE(0x201452))) /* Message Object 34 Data Register Low High */


#define CAN_MODATA35LH  (*(_PAGE_080_MEM_TYPE(0x201472))) /* Message Object 35 Data Register Low High */


#define CAN_MODATA36LH  (*(_PAGE_080_MEM_TYPE(0x201492))) /* Message Object 36 Data Register Low High */


#define CAN_MODATA37LH  (*(_PAGE_080_MEM_TYPE(0x2014B2))) /* Message Object 37 Data Register Low High */


#define CAN_MODATA38LH  (*(_PAGE_080_MEM_TYPE(0x2014D2))) /* Message Object 38 Data Register Low High */


#define CAN_MODATA39LH  (*(_PAGE_080_MEM_TYPE(0x2014F2))) /* Message Object 39 Data Register Low High */


#define CAN_MODATA40LH  (*(_PAGE_080_MEM_TYPE(0x201512))) /* Message Object 40 Data Register Low High */


#define CAN_MODATA41LH  (*(_PAGE_080_MEM_TYPE(0x201532))) /* Message Object 41 Data Register Low High */


#define CAN_MODATA42LH  (*(_PAGE_080_MEM_TYPE(0x201552))) /* Message Object 42 Data Register Low High */


#define CAN_MODATA43LH  (*(_PAGE_080_MEM_TYPE(0x201572))) /* Message Object 43 Data Register Low High */


#define CAN_MODATA44LH  (*(_PAGE_080_MEM_TYPE(0x201592))) /* Message Object 44 Data Register Low High */


#define CAN_MODATA45LH  (*(_PAGE_080_MEM_TYPE(0x2015B2))) /* Message Object 45 Data Register Low High */


#define CAN_MODATA46LH  (*(_PAGE_080_MEM_TYPE(0x2015D2))) /* Message Object 46 Data Register Low High */


#define CAN_MODATA47LH  (*(_PAGE_080_MEM_TYPE(0x2015F2))) /* Message Object 47 Data Register Low High */


#define CAN_MODATA48LH  (*(_PAGE_080_MEM_TYPE(0x201612))) /* Message Object 48 Data Register Low High */


#define CAN_MODATA49LH  (*(_PAGE_080_MEM_TYPE(0x201632))) /* Message Object 49 Data Register Low High */


#define CAN_MODATA50LH  (*(_PAGE_080_MEM_TYPE(0x201652))) /* Message Object 50 Data Register Low High */


#define CAN_MODATA51LH  (*(_PAGE_080_MEM_TYPE(0x201672))) /* Message Object 51 Data Register Low High */


#define CAN_MODATA52LH  (*(_PAGE_080_MEM_TYPE(0x201692))) /* Message Object 52 Data Register Low High */


#define CAN_MODATA53LH  (*(_PAGE_080_MEM_TYPE(0x2016B2))) /* Message Object 53 Data Register Low High */


#define CAN_MODATA54LH  (*(_PAGE_080_MEM_TYPE(0x2016D2))) /* Message Object 54 Data Register Low High */


#define CAN_MODATA55LH  (*(_PAGE_080_MEM_TYPE(0x2016F2))) /* Message Object 55 Data Register Low High */


#define CAN_MODATA56LH  (*(_PAGE_080_MEM_TYPE(0x201712))) /* Message Object 56 Data Register Low High */


#define CAN_MODATA57LH  (*(_PAGE_080_MEM_TYPE(0x201732))) /* Message Object 57 Data Register Low High */


#define CAN_MODATA58LH  (*(_PAGE_080_MEM_TYPE(0x201752))) /* Message Object 58 Data Register Low High */


#define CAN_MODATA59LH  (*(_PAGE_080_MEM_TYPE(0x201772))) /* Message Object 59 Data Register Low High */


#define CAN_MODATA60LH  (*(_PAGE_080_MEM_TYPE(0x201792))) /* Message Object 60 Data Register Low High */


#define CAN_MODATA61LH  (*(_PAGE_080_MEM_TYPE(0x2017B2))) /* Message Object 61 Data Register Low High */


#define CAN_MODATA62LH  (*(_PAGE_080_MEM_TYPE(0x2017D2))) /* Message Object 62 Data Register Low High */


#define CAN_MODATA63LH  (*(_PAGE_080_MEM_TYPE(0x2017F2))) /* Message Object 63 Data Register Low High */


#define CAN_MODATA64LH  (*(_PAGE_080_MEM_TYPE(0x201812))) /* Message Object 64 Data Register Low High */


#define CAN_MODATA65LH  (*(_PAGE_080_MEM_TYPE(0x201832))) /* Message Object 65 Data Register Low High */


#define CAN_MODATA66LH  (*(_PAGE_080_MEM_TYPE(0x201852))) /* Message Object 66 Data Register Low High */


#define CAN_MODATA67LH  (*(_PAGE_080_MEM_TYPE(0x201872))) /* Message Object 67 Data Register Low High */


#define CAN_MODATA68LH  (*(_PAGE_080_MEM_TYPE(0x201892))) /* Message Object 68 Data Register Low High */


#define CAN_MODATA69LH  (*(_PAGE_080_MEM_TYPE(0x2018B2))) /* Message Object 69 Data Register Low High */


#define CAN_MODATA70LH  (*(_PAGE_080_MEM_TYPE(0x2018D2))) /* Message Object 70 Data Register Low High */


#define CAN_MODATA71LH  (*(_PAGE_080_MEM_TYPE(0x2018F2))) /* Message Object 71 Data Register Low High */


#define CAN_MODATA72LH  (*(_PAGE_080_MEM_TYPE(0x201912))) /* Message Object 72 Data Register Low High */


#define CAN_MODATA73LH  (*(_PAGE_080_MEM_TYPE(0x201932))) /* Message Object 73 Data Register Low High */


#define CAN_MODATA74LH  (*(_PAGE_080_MEM_TYPE(0x201952))) /* Message Object 74 Data Register Low High */


#define CAN_MODATA75LH  (*(_PAGE_080_MEM_TYPE(0x201972))) /* Message Object 75 Data Register Low High */


#define CAN_MODATA76LH  (*(_PAGE_080_MEM_TYPE(0x201992))) /* Message Object 76 Data Register Low High */


#define CAN_MODATA77LH  (*(_PAGE_080_MEM_TYPE(0x2019B2))) /* Message Object 77 Data Register Low High */


#define CAN_MODATA78LH  (*(_PAGE_080_MEM_TYPE(0x2019D2))) /* Message Object 78 Data Register Low High */


#define CAN_MODATA79LH  (*(_PAGE_080_MEM_TYPE(0x2019F2))) /* Message Object 79 Data Register Low High */


#define CAN_MODATA80LH  (*(_PAGE_080_MEM_TYPE(0x201A12))) /* Message Object 80 Data Register Low High */


#define CAN_MODATA81LH  (*(_PAGE_080_MEM_TYPE(0x201A32))) /* Message Object 81 Data Register Low High */


#define CAN_MODATA82LH  (*(_PAGE_080_MEM_TYPE(0x201A52))) /* Message Object 82 Data Register Low High */


#define CAN_MODATA83LH  (*(_PAGE_080_MEM_TYPE(0x201A72))) /* Message Object 83 Data Register Low High */


#define CAN_MODATA84LH  (*(_PAGE_080_MEM_TYPE(0x201A92))) /* Message Object 84 Data Register Low High */


#define CAN_MODATA85LH  (*(_PAGE_080_MEM_TYPE(0x201AB2))) /* Message Object 85 Data Register Low High */


#define CAN_MODATA86LH  (*(_PAGE_080_MEM_TYPE(0x201AD2))) /* Message Object 86 Data Register Low High */


#define CAN_MODATA87LH  (*(_PAGE_080_MEM_TYPE(0x201AF2))) /* Message Object 87 Data Register Low High */


#define CAN_MODATA88LH  (*(_PAGE_080_MEM_TYPE(0x201B12))) /* Message Object 88 Data Register Low High */


#define CAN_MODATA89LH  (*(_PAGE_080_MEM_TYPE(0x201B32))) /* Message Object 89 Data Register Low High */


#define CAN_MODATA90LH  (*(_PAGE_080_MEM_TYPE(0x201B52))) /* Message Object 90 Data Register Low High */


#define CAN_MODATA91LH  (*(_PAGE_080_MEM_TYPE(0x201B72))) /* Message Object 91 Data Register Low High */


#define CAN_MODATA92LH  (*(_PAGE_080_MEM_TYPE(0x201B92))) /* Message Object 92 Data Register Low High */


#define CAN_MODATA93LH  (*(_PAGE_080_MEM_TYPE(0x201BB2))) /* Message Object 93 Data Register Low High */


#define CAN_MODATA94LH  (*(_PAGE_080_MEM_TYPE(0x201BD2))) /* Message Object 94 Data Register Low High */


#define CAN_MODATA95LH  (*(_PAGE_080_MEM_TYPE(0x201BF2))) /* Message Object 95 Data Register Low High */


#define CAN_MODATA96LH  (*(_PAGE_080_MEM_TYPE(0x201C12))) /* Message Object 96 Data Register Low High */


#define CAN_MODATA97LH  (*(_PAGE_080_MEM_TYPE(0x201C32))) /* Message Object 97 Data Register Low High */


#define CAN_MODATA98LH  (*(_PAGE_080_MEM_TYPE(0x201C52))) /* Message Object 98 Data Register Low High */


#define CAN_MODATA99LH  (*(_PAGE_080_MEM_TYPE(0x201C72))) /* Message Object 99 Data Register Low High */


#define CAN_MODATA100LH (*(_PAGE_080_MEM_TYPE(0x201C92))) /* Message Object 100 Data Register Low High */


#define CAN_MODATA101LH (*(_PAGE_080_MEM_TYPE(0x201CB2))) /* Message Object 101 Data Register Low High */


#define CAN_MODATA102LH (*(_PAGE_080_MEM_TYPE(0x201CD2))) /* Message Object 102 Data Register Low High */


#define CAN_MODATA103LH (*(_PAGE_080_MEM_TYPE(0x201CF2))) /* Message Object 103 Data Register Low High */


#define CAN_MODATA104LH (*(_PAGE_080_MEM_TYPE(0x201D12))) /* Message Object 104 Data Register Low High */


#define CAN_MODATA105LH (*(_PAGE_080_MEM_TYPE(0x201D32))) /* Message Object 105 Data Register Low High */


#define CAN_MODATA106LH (*(_PAGE_080_MEM_TYPE(0x201D52))) /* Message Object 106 Data Register Low High */


#define CAN_MODATA107LH (*(_PAGE_080_MEM_TYPE(0x201D72))) /* Message Object 107 Data Register Low High */


#define CAN_MODATA108LH (*(_PAGE_080_MEM_TYPE(0x201D92))) /* Message Object 108 Data Register Low High */


#define CAN_MODATA109LH (*(_PAGE_080_MEM_TYPE(0x201DB2))) /* Message Object 109 Data Register Low High */


#define CAN_MODATA110LH (*(_PAGE_080_MEM_TYPE(0x201DD2))) /* Message Object 110 Data Register Low High */


#define CAN_MODATA111LH (*(_PAGE_080_MEM_TYPE(0x201DF2))) /* Message Object 111 Data Register Low High */


#define CAN_MODATA112LH (*(_PAGE_080_MEM_TYPE(0x201E12))) /* Message Object 112 Data Register Low High */


#define CAN_MODATA113LH (*(_PAGE_080_MEM_TYPE(0x201E32))) /* Message Object 113 Data Register Low High */


#define CAN_MODATA114LH (*(_PAGE_080_MEM_TYPE(0x201E52))) /* Message Object 114 Data Register Low High */


#define CAN_MODATA115LH (*(_PAGE_080_MEM_TYPE(0x201E72))) /* Message Object 115 Data Register Low High */


#define CAN_MODATA116LH (*(_PAGE_080_MEM_TYPE(0x201E92))) /* Message Object 116 Data Register Low High */


#define CAN_MODATA117LH (*(_PAGE_080_MEM_TYPE(0x201EB2))) /* Message Object 117 Data Register Low High */


#define CAN_MODATA118LH (*(_PAGE_080_MEM_TYPE(0x201ED2))) /* Message Object 118 Data Register Low High */


#define CAN_MODATA119LH (*(_PAGE_080_MEM_TYPE(0x201EF2))) /* Message Object 119 Data Register Low High */


#define CAN_MODATA120LH (*(_PAGE_080_MEM_TYPE(0x201F12))) /* Message Object 120 Data Register Low High */


#define CAN_MODATA121LH (*(_PAGE_080_MEM_TYPE(0x201F32))) /* Message Object 121 Data Register Low High */


#define CAN_MODATA122LH (*(_PAGE_080_MEM_TYPE(0x201F52))) /* Message Object 122 Data Register Low High */


#define CAN_MODATA123LH (*(_PAGE_080_MEM_TYPE(0x201F72))) /* Message Object 123 Data Register Low High */


#define CAN_MODATA124LH (*(_PAGE_080_MEM_TYPE(0x201F92))) /* Message Object 124 Data Register Low High */


#define CAN_MODATA125LH (*(_PAGE_080_MEM_TYPE(0x201FB2))) /* Message Object 125 Data Register Low High */


#define CAN_MODATA126LH (*(_PAGE_080_MEM_TYPE(0x201FD2))) /* Message Object 126 Data Register Low High */


#define CAN_MODATA127LH (*(_PAGE_080_MEM_TYPE(0x201FF2))) /* Message Object 127 Data Register Low High */


#define CAN_MODATA128LH (*(_PAGE_080_MEM_TYPE(0x202012))) /* Message Object 128 Data Register Low High */


#define CAN_MODATA129LH (*(_PAGE_080_MEM_TYPE(0x202032))) /* Message Object 129 Data Register Low High */


#define CAN_MODATA130LH (*(_PAGE_080_MEM_TYPE(0x202052))) /* Message Object 130 Data Register Low High */


#define CAN_MODATA131LH (*(_PAGE_080_MEM_TYPE(0x202072))) /* Message Object 131 Data Register Low High */


#define CAN_MODATA132LH (*(_PAGE_080_MEM_TYPE(0x202092))) /* Message Object 132 Data Register Low High */


#define CAN_MODATA133LH (*(_PAGE_080_MEM_TYPE(0x2020B2))) /* Message Object 133 Data Register Low High */


#define CAN_MODATA134LH (*(_PAGE_080_MEM_TYPE(0x2020D2))) /* Message Object 134 Data Register Low High */


#define CAN_MODATA135LH (*(_PAGE_080_MEM_TYPE(0x2020F2))) /* Message Object 135 Data Register Low High */


#define CAN_MODATA136LH (*(_PAGE_080_MEM_TYPE(0x202112))) /* Message Object 136 Data Register Low High */


#define CAN_MODATA137LH (*(_PAGE_080_MEM_TYPE(0x202132))) /* Message Object 137 Data Register Low High */


#define CAN_MODATA138LH (*(_PAGE_080_MEM_TYPE(0x202152))) /* Message Object 138 Data Register Low High */


#define CAN_MODATA139LH (*(_PAGE_080_MEM_TYPE(0x202172))) /* Message Object 139 Data Register Low High */


#define CAN_MODATA140LH (*(_PAGE_080_MEM_TYPE(0x202192))) /* Message Object 140 Data Register Low High */


#define CAN_MODATA141LH (*(_PAGE_080_MEM_TYPE(0x2021B2))) /* Message Object 141 Data Register Low High */


#define CAN_MODATA142LH (*(_PAGE_080_MEM_TYPE(0x2021D2))) /* Message Object 142 Data Register Low High */


#define CAN_MODATA143LH (*(_PAGE_080_MEM_TYPE(0x2021F2))) /* Message Object 143 Data Register Low High */


#define CAN_MODATA144LH (*(_PAGE_080_MEM_TYPE(0x202212))) /* Message Object 144 Data Register Low High */


#define CAN_MODATA145LH (*(_PAGE_080_MEM_TYPE(0x202232))) /* Message Object 145 Data Register Low High */


#define CAN_MODATA146LH (*(_PAGE_080_MEM_TYPE(0x202252))) /* Message Object 146 Data Register Low High */


#define CAN_MODATA147LH (*(_PAGE_080_MEM_TYPE(0x202272))) /* Message Object 147 Data Register Low High */


#define CAN_MODATA148LH (*(_PAGE_080_MEM_TYPE(0x202292))) /* Message Object 148 Data Register Low High */


#define CAN_MODATA149LH (*(_PAGE_080_MEM_TYPE(0x2022B2))) /* Message Object 149 Data Register Low High */


#define CAN_MODATA150LH (*(_PAGE_080_MEM_TYPE(0x2022D2))) /* Message Object 150 Data Register Low High */


#define CAN_MODATA151LH (*(_PAGE_080_MEM_TYPE(0x2022F2))) /* Message Object 151 Data Register Low High */


#define CAN_MODATA152LH (*(_PAGE_080_MEM_TYPE(0x202312))) /* Message Object 152 Data Register Low High */


#define CAN_MODATA153LH (*(_PAGE_080_MEM_TYPE(0x202332))) /* Message Object 153 Data Register Low High */


#define CAN_MODATA154LH (*(_PAGE_080_MEM_TYPE(0x202352))) /* Message Object 154 Data Register Low High */


#define CAN_MODATA155LH (*(_PAGE_080_MEM_TYPE(0x202372))) /* Message Object 155 Data Register Low High */


#define CAN_MODATA156LH (*(_PAGE_080_MEM_TYPE(0x202392))) /* Message Object 156 Data Register Low High */


#define CAN_MODATA157LH (*(_PAGE_080_MEM_TYPE(0x2023B2))) /* Message Object 157 Data Register Low High */


#define CAN_MODATA158LH (*(_PAGE_080_MEM_TYPE(0x2023D2))) /* Message Object 158 Data Register Low High */


#define CAN_MODATA159LH (*(_PAGE_080_MEM_TYPE(0x2023F2))) /* Message Object 159 Data Register Low High */


#define CAN_MODATA160LH (*(_PAGE_080_MEM_TYPE(0x202412))) /* Message Object 160 Data Register Low High */


#define CAN_MODATA161LH (*(_PAGE_080_MEM_TYPE(0x202432))) /* Message Object 161 Data Register Low High */


#define CAN_MODATA162LH (*(_PAGE_080_MEM_TYPE(0x202452))) /* Message Object 162 Data Register Low High */


#define CAN_MODATA163LH (*(_PAGE_080_MEM_TYPE(0x202472))) /* Message Object 163 Data Register Low High */


#define CAN_MODATA164LH (*(_PAGE_080_MEM_TYPE(0x202492))) /* Message Object 164 Data Register Low High */


#define CAN_MODATA165LH (*(_PAGE_080_MEM_TYPE(0x2024B2))) /* Message Object 165 Data Register Low High */


#define CAN_MODATA166LH (*(_PAGE_080_MEM_TYPE(0x2024D2))) /* Message Object 166 Data Register Low High */


#define CAN_MODATA167LH (*(_PAGE_080_MEM_TYPE(0x2024F2))) /* Message Object 167 Data Register Low High */


#define CAN_MODATA168LH (*(_PAGE_080_MEM_TYPE(0x202512))) /* Message Object 168 Data Register Low High */


#define CAN_MODATA169LH (*(_PAGE_080_MEM_TYPE(0x202532))) /* Message Object 169 Data Register Low High */


#define CAN_MODATA170LH (*(_PAGE_080_MEM_TYPE(0x202552))) /* Message Object 170 Data Register Low High */


#define CAN_MODATA171LH (*(_PAGE_080_MEM_TYPE(0x202572))) /* Message Object 171 Data Register Low High */


#define CAN_MODATA172LH (*(_PAGE_080_MEM_TYPE(0x202592))) /* Message Object 172 Data Register Low High */


#define CAN_MODATA173LH (*(_PAGE_080_MEM_TYPE(0x2025B2))) /* Message Object 173 Data Register Low High */


#define CAN_MODATA174LH (*(_PAGE_080_MEM_TYPE(0x2025D2))) /* Message Object 174 Data Register Low High */


#define CAN_MODATA175LH (*(_PAGE_080_MEM_TYPE(0x2025F2))) /* Message Object 175 Data Register Low High */


#define CAN_MODATA176LH (*(_PAGE_080_MEM_TYPE(0x202612))) /* Message Object 176 Data Register Low High */


#define CAN_MODATA177LH (*(_PAGE_080_MEM_TYPE(0x202632))) /* Message Object 177 Data Register Low High */


#define CAN_MODATA178LH (*(_PAGE_080_MEM_TYPE(0x202652))) /* Message Object 178 Data Register Low High */


#define CAN_MODATA179LH (*(_PAGE_080_MEM_TYPE(0x202672))) /* Message Object 179 Data Register Low High */


#define CAN_MODATA180LH (*(_PAGE_080_MEM_TYPE(0x202692))) /* Message Object 180 Data Register Low High */


#define CAN_MODATA181LH (*(_PAGE_080_MEM_TYPE(0x2026B2))) /* Message Object 181 Data Register Low High */


#define CAN_MODATA182LH (*(_PAGE_080_MEM_TYPE(0x2026D2))) /* Message Object 182 Data Register Low High */


#define CAN_MODATA183LH (*(_PAGE_080_MEM_TYPE(0x2026F2))) /* Message Object 183 Data Register Low High */


#define CAN_MODATA184LH (*(_PAGE_080_MEM_TYPE(0x202712))) /* Message Object 184 Data Register Low High */


#define CAN_MODATA185LH (*(_PAGE_080_MEM_TYPE(0x202732))) /* Message Object 185 Data Register Low High */


#define CAN_MODATA186LH (*(_PAGE_080_MEM_TYPE(0x202752))) /* Message Object 186 Data Register Low High */


#define CAN_MODATA187LH (*(_PAGE_080_MEM_TYPE(0x202772))) /* Message Object 187 Data Register Low High */


#define CAN_MODATA188LH (*(_PAGE_080_MEM_TYPE(0x202792))) /* Message Object 188 Data Register Low High */


#define CAN_MODATA189LH (*(_PAGE_080_MEM_TYPE(0x2027B2))) /* Message Object 189 Data Register Low High */


#define CAN_MODATA190LH (*(_PAGE_080_MEM_TYPE(0x2027D2))) /* Message Object 190 Data Register Low High */


#define CAN_MODATA191LH (*(_PAGE_080_MEM_TYPE(0x2027F2))) /* Message Object 191 Data Register Low High */


#define CAN_MODATA192LH (*(_PAGE_080_MEM_TYPE(0x202812))) /* Message Object 192 Data Register Low High */


#define CAN_MODATA193LH (*(_PAGE_080_MEM_TYPE(0x202832))) /* Message Object 193 Data Register Low High */


#define CAN_MODATA194LH (*(_PAGE_080_MEM_TYPE(0x202852))) /* Message Object 194 Data Register Low High */


#define CAN_MODATA195LH (*(_PAGE_080_MEM_TYPE(0x202872))) /* Message Object 195 Data Register Low High */


#define CAN_MODATA196LH (*(_PAGE_080_MEM_TYPE(0x202892))) /* Message Object 196 Data Register Low High */


#define CAN_MODATA197LH (*(_PAGE_080_MEM_TYPE(0x2028B2))) /* Message Object 197 Data Register Low High */


#define CAN_MODATA198LH (*(_PAGE_080_MEM_TYPE(0x2028D2))) /* Message Object 198 Data Register Low High */


#define CAN_MODATA199LH (*(_PAGE_080_MEM_TYPE(0x2028F2))) /* Message Object 199 Data Register Low High */


#define CAN_MODATA200LH (*(_PAGE_080_MEM_TYPE(0x202912))) /* Message Object 200 Data Register Low High */


#define CAN_MODATA201LH (*(_PAGE_080_MEM_TYPE(0x202932))) /* Message Object 201 Data Register Low High */


#define CAN_MODATA202LH (*(_PAGE_080_MEM_TYPE(0x202952))) /* Message Object 202 Data Register Low High */


#define CAN_MODATA203LH (*(_PAGE_080_MEM_TYPE(0x202972))) /* Message Object 203 Data Register Low High */


#define CAN_MODATA204LH (*(_PAGE_080_MEM_TYPE(0x202992))) /* Message Object 204 Data Register Low High */


#define CAN_MODATA205LH (*(_PAGE_080_MEM_TYPE(0x2029B2))) /* Message Object 205 Data Register Low High */


#define CAN_MODATA206LH (*(_PAGE_080_MEM_TYPE(0x2029D2))) /* Message Object 206 Data Register Low High */


#define CAN_MODATA207LH (*(_PAGE_080_MEM_TYPE(0x2029F2))) /* Message Object 207 Data Register Low High */


#define CAN_MODATA208LH (*(_PAGE_080_MEM_TYPE(0x202A12))) /* Message Object 208 Data Register Low High */


#define CAN_MODATA209LH (*(_PAGE_080_MEM_TYPE(0x202A32))) /* Message Object 209 Data Register Low High */


#define CAN_MODATA210LH (*(_PAGE_080_MEM_TYPE(0x202A52))) /* Message Object 210 Data Register Low High */


#define CAN_MODATA211LH (*(_PAGE_080_MEM_TYPE(0x202A72))) /* Message Object 211 Data Register Low High */


#define CAN_MODATA212LH (*(_PAGE_080_MEM_TYPE(0x202A92))) /* Message Object 212 Data Register Low High */


#define CAN_MODATA213LH (*(_PAGE_080_MEM_TYPE(0x202AB2))) /* Message Object 213 Data Register Low High */


#define CAN_MODATA214LH (*(_PAGE_080_MEM_TYPE(0x202AD2))) /* Message Object 214 Data Register Low High */


#define CAN_MODATA215LH (*(_PAGE_080_MEM_TYPE(0x202AF2))) /* Message Object 215 Data Register Low High */


#define CAN_MODATA216LH (*(_PAGE_080_MEM_TYPE(0x202B12))) /* Message Object 216 Data Register Low High */


#define CAN_MODATA217LH (*(_PAGE_080_MEM_TYPE(0x202B32))) /* Message Object 217 Data Register Low High */


#define CAN_MODATA218LH (*(_PAGE_080_MEM_TYPE(0x202B52))) /* Message Object 218 Data Register Low High */


#define CAN_MODATA219LH (*(_PAGE_080_MEM_TYPE(0x202B72))) /* Message Object 219 Data Register Low High */


#define CAN_MODATA220LH (*(_PAGE_080_MEM_TYPE(0x202B92))) /* Message Object 220 Data Register Low High */


#define CAN_MODATA221LH (*(_PAGE_080_MEM_TYPE(0x202BB2))) /* Message Object 221 Data Register Low High */


#define CAN_MODATA222LH (*(_PAGE_080_MEM_TYPE(0x202BD2))) /* Message Object 222 Data Register Low High */


#define CAN_MODATA223LH (*(_PAGE_080_MEM_TYPE(0x202BF2))) /* Message Object 223 Data Register Low High */


#define CAN_MODATA224LH (*(_PAGE_080_MEM_TYPE(0x202C12))) /* Message Object 224 Data Register Low High */


#define CAN_MODATA225LH (*(_PAGE_080_MEM_TYPE(0x202C32))) /* Message Object 225 Data Register Low High */


#define CAN_MODATA226LH (*(_PAGE_080_MEM_TYPE(0x202C52))) /* Message Object 226 Data Register Low High */


#define CAN_MODATA227LH (*(_PAGE_080_MEM_TYPE(0x202C72))) /* Message Object 227 Data Register Low High */


#define CAN_MODATA228LH (*(_PAGE_080_MEM_TYPE(0x202C92))) /* Message Object 228 Data Register Low High */


#define CAN_MODATA229LH (*(_PAGE_080_MEM_TYPE(0x202CB2))) /* Message Object 229 Data Register Low High */


#define CAN_MODATA230LH (*(_PAGE_080_MEM_TYPE(0x202CD2))) /* Message Object 230 Data Register Low High */


#define CAN_MODATA231LH (*(_PAGE_080_MEM_TYPE(0x202CF2))) /* Message Object 231 Data Register Low High */


#define CAN_MODATA232LH (*(_PAGE_080_MEM_TYPE(0x202D12))) /* Message Object 232 Data Register Low High */


#define CAN_MODATA233LH (*(_PAGE_080_MEM_TYPE(0x202D32))) /* Message Object 233 Data Register Low High */


#define CAN_MODATA234LH (*(_PAGE_080_MEM_TYPE(0x202D52))) /* Message Object 234 Data Register Low High */


#define CAN_MODATA235LH (*(_PAGE_080_MEM_TYPE(0x202D72))) /* Message Object 235 Data Register Low High */


#define CAN_MODATA236LH (*(_PAGE_080_MEM_TYPE(0x202D92))) /* Message Object 236 Data Register Low High */


#define CAN_MODATA237LH (*(_PAGE_080_MEM_TYPE(0x202DB2))) /* Message Object 237 Data Register Low High */


#define CAN_MODATA238LH (*(_PAGE_080_MEM_TYPE(0x202DD2))) /* Message Object 238 Data Register Low High */


#define CAN_MODATA239LH (*(_PAGE_080_MEM_TYPE(0x202DF2))) /* Message Object 239 Data Register Low High */


#define CAN_MODATA240LH (*(_PAGE_080_MEM_TYPE(0x202E12))) /* Message Object 240 Data Register Low High */


#define CAN_MODATA241LH (*(_PAGE_080_MEM_TYPE(0x202E32))) /* Message Object 241 Data Register Low High */


#define CAN_MODATA242LH (*(_PAGE_080_MEM_TYPE(0x202E52))) /* Message Object 242 Data Register Low High */


#define CAN_MODATA243LH (*(_PAGE_080_MEM_TYPE(0x202E72))) /* Message Object 243 Data Register Low High */


#define CAN_MODATA244LH (*(_PAGE_080_MEM_TYPE(0x202E92))) /* Message Object 244 Data Register Low High */


#define CAN_MODATA245LH (*(_PAGE_080_MEM_TYPE(0x202EB2))) /* Message Object 245 Data Register Low High */


#define CAN_MODATA246LH (*(_PAGE_080_MEM_TYPE(0x202ED2))) /* Message Object 246 Data Register Low High */


#define CAN_MODATA247LH (*(_PAGE_080_MEM_TYPE(0x202EF2))) /* Message Object 247 Data Register Low High */


#define CAN_MODATA248LH (*(_PAGE_080_MEM_TYPE(0x202F12))) /* Message Object 248 Data Register Low High */


#define CAN_MODATA249LH (*(_PAGE_080_MEM_TYPE(0x202F32))) /* Message Object 249 Data Register Low High */


#define CAN_MODATA250LH (*(_PAGE_080_MEM_TYPE(0x202F52))) /* Message Object 250 Data Register Low High */


#define CAN_MODATA251LH (*(_PAGE_080_MEM_TYPE(0x202F72))) /* Message Object 251 Data Register Low High */


#define CAN_MODATA252LH (*(_PAGE_080_MEM_TYPE(0x202F92))) /* Message Object 252 Data Register Low High */


#define CAN_MODATA253LH (*(_PAGE_080_MEM_TYPE(0x202FB2))) /* Message Object 253 Data Register Low High */


#define CAN_MODATA254LH (*(_PAGE_080_MEM_TYPE(0x202FD2))) /* Message Object 254 Data Register Low High */


#define CAN_MODATA255LH (*(_PAGE_080_MEM_TYPE(0x202FF2))) /* Message Object 255 Data Register Low High */


#define CAN_MODATA0LL   (*(_PAGE_080_MEM_TYPE(0x201010))) /* Message Object 0 Data Register Low Low */


#define CAN_MODATA1LL   (*(_PAGE_080_MEM_TYPE(0x201030))) /* Message Object 1 Data Register Low Low */


#define CAN_MODATA2LL   (*(_PAGE_080_MEM_TYPE(0x201050))) /* Message Object 2 Data Register Low Low */


#define CAN_MODATA3LL   (*(_PAGE_080_MEM_TYPE(0x201070))) /* Message Object 3 Data Register Low Low */


#define CAN_MODATA4LL   (*(_PAGE_080_MEM_TYPE(0x201090))) /* Message Object 4 Data Register Low Low */


#define CAN_MODATA5LL   (*(_PAGE_080_MEM_TYPE(0x2010B0))) /* Message Object 5 Data Register Low Low */


#define CAN_MODATA6LL   (*(_PAGE_080_MEM_TYPE(0x2010D0))) /* Message Object 6 Data Register Low Low */


#define CAN_MODATA7LL   (*(_PAGE_080_MEM_TYPE(0x2010F0))) /* Message Object 7 Data Register Low Low */


#define CAN_MODATA8LL   (*(_PAGE_080_MEM_TYPE(0x201110))) /* Message Object 8 Data Register Low Low */


#define CAN_MODATA9LL   (*(_PAGE_080_MEM_TYPE(0x201130))) /* Message Object 9 Data Register Low Low */


#define CAN_MODATA10LL  (*(_PAGE_080_MEM_TYPE(0x201150))) /* Message Object 10 Data Register Low Low */


#define CAN_MODATA11LL  (*(_PAGE_080_MEM_TYPE(0x201170))) /* Message Object 11 Data Register Low Low */


#define CAN_MODATA12LL  (*(_PAGE_080_MEM_TYPE(0x201190))) /* Message Object 12 Data Register Low Low */


#define CAN_MODATA13LL  (*(_PAGE_080_MEM_TYPE(0x2011B0))) /* Message Object 13 Data Register Low Low */


#define CAN_MODATA14LL  (*(_PAGE_080_MEM_TYPE(0x2011D0))) /* Message Object 14 Data Register Low Low */


#define CAN_MODATA15LL  (*(_PAGE_080_MEM_TYPE(0x2011F0))) /* Message Object 15 Data Register Low Low */


#define CAN_MODATA16LL  (*(_PAGE_080_MEM_TYPE(0x201210))) /* Message Object 16 Data Register Low Low */


#define CAN_MODATA17LL  (*(_PAGE_080_MEM_TYPE(0x201230))) /* Message Object 17 Data Register Low Low */


#define CAN_MODATA18LL  (*(_PAGE_080_MEM_TYPE(0x201250))) /* Message Object 18 Data Register Low Low */


#define CAN_MODATA19LL  (*(_PAGE_080_MEM_TYPE(0x201270))) /* Message Object 19 Data Register Low Low */


#define CAN_MODATA20LL  (*(_PAGE_080_MEM_TYPE(0x201290))) /* Message Object 20 Data Register Low Low */


#define CAN_MODATA21LL  (*(_PAGE_080_MEM_TYPE(0x2012B0))) /* Message Object 21 Data Register Low Low */


#define CAN_MODATA22LL  (*(_PAGE_080_MEM_TYPE(0x2012D0))) /* Message Object 22 Data Register Low Low */


#define CAN_MODATA23LL  (*(_PAGE_080_MEM_TYPE(0x2012F0))) /* Message Object 23 Data Register Low Low */


#define CAN_MODATA24LL  (*(_PAGE_080_MEM_TYPE(0x201310))) /* Message Object 24 Data Register Low Low */


#define CAN_MODATA25LL  (*(_PAGE_080_MEM_TYPE(0x201330))) /* Message Object 25 Data Register Low Low */


#define CAN_MODATA26LL  (*(_PAGE_080_MEM_TYPE(0x201350))) /* Message Object 26 Data Register Low Low */


#define CAN_MODATA27LL  (*(_PAGE_080_MEM_TYPE(0x201370))) /* Message Object 27 Data Register Low Low */


#define CAN_MODATA28LL  (*(_PAGE_080_MEM_TYPE(0x201390))) /* Message Object 28 Data Register Low Low */


#define CAN_MODATA29LL  (*(_PAGE_080_MEM_TYPE(0x2013B0))) /* Message Object 29 Data Register Low Low */


#define CAN_MODATA30LL  (*(_PAGE_080_MEM_TYPE(0x2013D0))) /* Message Object 30 Data Register Low Low */


#define CAN_MODATA31LL  (*(_PAGE_080_MEM_TYPE(0x2013F0))) /* Message Object 31 Data Register Low Low */


#define CAN_MODATA32LL  (*(_PAGE_080_MEM_TYPE(0x201410))) /* Message Object 32 Data Register Low Low */


#define CAN_MODATA33LL  (*(_PAGE_080_MEM_TYPE(0x201430))) /* Message Object 33 Data Register Low Low */


#define CAN_MODATA34LL  (*(_PAGE_080_MEM_TYPE(0x201450))) /* Message Object 34 Data Register Low Low */


#define CAN_MODATA35LL  (*(_PAGE_080_MEM_TYPE(0x201470))) /* Message Object 35 Data Register Low Low */


#define CAN_MODATA36LL  (*(_PAGE_080_MEM_TYPE(0x201490))) /* Message Object 36 Data Register Low Low */


#define CAN_MODATA37LL  (*(_PAGE_080_MEM_TYPE(0x2014B0))) /* Message Object 37 Data Register Low Low */


#define CAN_MODATA38LL  (*(_PAGE_080_MEM_TYPE(0x2014D0))) /* Message Object 38 Data Register Low Low */


#define CAN_MODATA39LL  (*(_PAGE_080_MEM_TYPE(0x2014F0))) /* Message Object 39 Data Register Low Low */


#define CAN_MODATA40LL  (*(_PAGE_080_MEM_TYPE(0x201510))) /* Message Object 40 Data Register Low Low */


#define CAN_MODATA41LL  (*(_PAGE_080_MEM_TYPE(0x201530))) /* Message Object 41 Data Register Low Low */


#define CAN_MODATA42LL  (*(_PAGE_080_MEM_TYPE(0x201550))) /* Message Object 42 Data Register Low Low */


#define CAN_MODATA43LL  (*(_PAGE_080_MEM_TYPE(0x201570))) /* Message Object 43 Data Register Low Low */


#define CAN_MODATA44LL  (*(_PAGE_080_MEM_TYPE(0x201590))) /* Message Object 44 Data Register Low Low */


#define CAN_MODATA45LL  (*(_PAGE_080_MEM_TYPE(0x2015B0))) /* Message Object 45 Data Register Low Low */


#define CAN_MODATA46LL  (*(_PAGE_080_MEM_TYPE(0x2015D0))) /* Message Object 46 Data Register Low Low */


#define CAN_MODATA47LL  (*(_PAGE_080_MEM_TYPE(0x2015F0))) /* Message Object 47 Data Register Low Low */


#define CAN_MODATA48LL  (*(_PAGE_080_MEM_TYPE(0x201610))) /* Message Object 48 Data Register Low Low */


#define CAN_MODATA49LL  (*(_PAGE_080_MEM_TYPE(0x201630))) /* Message Object 49 Data Register Low Low */


#define CAN_MODATA50LL  (*(_PAGE_080_MEM_TYPE(0x201650))) /* Message Object 50 Data Register Low Low */


#define CAN_MODATA51LL  (*(_PAGE_080_MEM_TYPE(0x201670))) /* Message Object 51 Data Register Low Low */


#define CAN_MODATA52LL  (*(_PAGE_080_MEM_TYPE(0x201690))) /* Message Object 52 Data Register Low Low */


#define CAN_MODATA53LL  (*(_PAGE_080_MEM_TYPE(0x2016B0))) /* Message Object 53 Data Register Low Low */


#define CAN_MODATA54LL  (*(_PAGE_080_MEM_TYPE(0x2016D0))) /* Message Object 54 Data Register Low Low */


#define CAN_MODATA55LL  (*(_PAGE_080_MEM_TYPE(0x2016F0))) /* Message Object 55 Data Register Low Low */


#define CAN_MODATA56LL  (*(_PAGE_080_MEM_TYPE(0x201710))) /* Message Object 56 Data Register Low Low */


#define CAN_MODATA57LL  (*(_PAGE_080_MEM_TYPE(0x201730))) /* Message Object 57 Data Register Low Low */


#define CAN_MODATA58LL  (*(_PAGE_080_MEM_TYPE(0x201750))) /* Message Object 58 Data Register Low Low */


#define CAN_MODATA59LL  (*(_PAGE_080_MEM_TYPE(0x201770))) /* Message Object 59 Data Register Low Low */


#define CAN_MODATA60LL  (*(_PAGE_080_MEM_TYPE(0x201790))) /* Message Object 60 Data Register Low Low */


#define CAN_MODATA61LL  (*(_PAGE_080_MEM_TYPE(0x2017B0))) /* Message Object 61 Data Register Low Low */


#define CAN_MODATA62LL  (*(_PAGE_080_MEM_TYPE(0x2017D0))) /* Message Object 62 Data Register Low Low */


#define CAN_MODATA63LL  (*(_PAGE_080_MEM_TYPE(0x2017F0))) /* Message Object 63 Data Register Low Low */


#define CAN_MODATA64LL  (*(_PAGE_080_MEM_TYPE(0x201810))) /* Message Object 64 Data Register Low Low */


#define CAN_MODATA65LL  (*(_PAGE_080_MEM_TYPE(0x201830))) /* Message Object 65 Data Register Low Low */


#define CAN_MODATA66LL  (*(_PAGE_080_MEM_TYPE(0x201850))) /* Message Object 66 Data Register Low Low */


#define CAN_MODATA67LL  (*(_PAGE_080_MEM_TYPE(0x201870))) /* Message Object 67 Data Register Low Low */


#define CAN_MODATA68LL  (*(_PAGE_080_MEM_TYPE(0x201890))) /* Message Object 68 Data Register Low Low */


#define CAN_MODATA69LL  (*(_PAGE_080_MEM_TYPE(0x2018B0))) /* Message Object 69 Data Register Low Low */


#define CAN_MODATA70LL  (*(_PAGE_080_MEM_TYPE(0x2018D0))) /* Message Object 70 Data Register Low Low */


#define CAN_MODATA71LL  (*(_PAGE_080_MEM_TYPE(0x2018F0))) /* Message Object 71 Data Register Low Low */


#define CAN_MODATA72LL  (*(_PAGE_080_MEM_TYPE(0x201910))) /* Message Object 72 Data Register Low Low */


#define CAN_MODATA73LL  (*(_PAGE_080_MEM_TYPE(0x201930))) /* Message Object 73 Data Register Low Low */


#define CAN_MODATA74LL  (*(_PAGE_080_MEM_TYPE(0x201950))) /* Message Object 74 Data Register Low Low */


#define CAN_MODATA75LL  (*(_PAGE_080_MEM_TYPE(0x201970))) /* Message Object 75 Data Register Low Low */


#define CAN_MODATA76LL  (*(_PAGE_080_MEM_TYPE(0x201990))) /* Message Object 76 Data Register Low Low */


#define CAN_MODATA77LL  (*(_PAGE_080_MEM_TYPE(0x2019B0))) /* Message Object 77 Data Register Low Low */


#define CAN_MODATA78LL  (*(_PAGE_080_MEM_TYPE(0x2019D0))) /* Message Object 78 Data Register Low Low */


#define CAN_MODATA79LL  (*(_PAGE_080_MEM_TYPE(0x2019F0))) /* Message Object 79 Data Register Low Low */


#define CAN_MODATA80LL  (*(_PAGE_080_MEM_TYPE(0x201A10))) /* Message Object 80 Data Register Low Low */


#define CAN_MODATA81LL  (*(_PAGE_080_MEM_TYPE(0x201A30))) /* Message Object 81 Data Register Low Low */


#define CAN_MODATA82LL  (*(_PAGE_080_MEM_TYPE(0x201A50))) /* Message Object 82 Data Register Low Low */


#define CAN_MODATA83LL  (*(_PAGE_080_MEM_TYPE(0x201A70))) /* Message Object 83 Data Register Low Low */


#define CAN_MODATA84LL  (*(_PAGE_080_MEM_TYPE(0x201A90))) /* Message Object 84 Data Register Low Low */


#define CAN_MODATA85LL  (*(_PAGE_080_MEM_TYPE(0x201AB0))) /* Message Object 85 Data Register Low Low */


#define CAN_MODATA86LL  (*(_PAGE_080_MEM_TYPE(0x201AD0))) /* Message Object 86 Data Register Low Low */


#define CAN_MODATA87LL  (*(_PAGE_080_MEM_TYPE(0x201AF0))) /* Message Object 87 Data Register Low Low */


#define CAN_MODATA88LL  (*(_PAGE_080_MEM_TYPE(0x201B10))) /* Message Object 88 Data Register Low Low */


#define CAN_MODATA89LL  (*(_PAGE_080_MEM_TYPE(0x201B30))) /* Message Object 89 Data Register Low Low */


#define CAN_MODATA90LL  (*(_PAGE_080_MEM_TYPE(0x201B50))) /* Message Object 90 Data Register Low Low */


#define CAN_MODATA91LL  (*(_PAGE_080_MEM_TYPE(0x201B70))) /* Message Object 91 Data Register Low Low */


#define CAN_MODATA92LL  (*(_PAGE_080_MEM_TYPE(0x201B90))) /* Message Object 92 Data Register Low Low */


#define CAN_MODATA93LL  (*(_PAGE_080_MEM_TYPE(0x201BB0))) /* Message Object 93 Data Register Low Low */


#define CAN_MODATA94LL  (*(_PAGE_080_MEM_TYPE(0x201BD0))) /* Message Object 94 Data Register Low Low */


#define CAN_MODATA95LL  (*(_PAGE_080_MEM_TYPE(0x201BF0))) /* Message Object 95 Data Register Low Low */


#define CAN_MODATA96LL  (*(_PAGE_080_MEM_TYPE(0x201C10))) /* Message Object 96 Data Register Low Low */


#define CAN_MODATA97LL  (*(_PAGE_080_MEM_TYPE(0x201C30))) /* Message Object 97 Data Register Low Low */


#define CAN_MODATA98LL  (*(_PAGE_080_MEM_TYPE(0x201C50))) /* Message Object 98 Data Register Low Low */


#define CAN_MODATA99LL  (*(_PAGE_080_MEM_TYPE(0x201C70))) /* Message Object 99 Data Register Low Low */


#define CAN_MODATA100LL (*(_PAGE_080_MEM_TYPE(0x201C90))) /* Message Object 100 Data Register Low Low */


#define CAN_MODATA101LL (*(_PAGE_080_MEM_TYPE(0x201CB0))) /* Message Object 101 Data Register Low Low */


#define CAN_MODATA102LL (*(_PAGE_080_MEM_TYPE(0x201CD0))) /* Message Object 102 Data Register Low Low */


#define CAN_MODATA103LL (*(_PAGE_080_MEM_TYPE(0x201CF0))) /* Message Object 103 Data Register Low Low */


#define CAN_MODATA104LL (*(_PAGE_080_MEM_TYPE(0x201D10))) /* Message Object 104 Data Register Low Low */


#define CAN_MODATA105LL (*(_PAGE_080_MEM_TYPE(0x201D30))) /* Message Object 105 Data Register Low Low */


#define CAN_MODATA106LL (*(_PAGE_080_MEM_TYPE(0x201D50))) /* Message Object 106 Data Register Low Low */


#define CAN_MODATA107LL (*(_PAGE_080_MEM_TYPE(0x201D70))) /* Message Object 107 Data Register Low Low */


#define CAN_MODATA108LL (*(_PAGE_080_MEM_TYPE(0x201D90))) /* Message Object 108 Data Register Low Low */


#define CAN_MODATA109LL (*(_PAGE_080_MEM_TYPE(0x201DB0))) /* Message Object 109 Data Register Low Low */


#define CAN_MODATA110LL (*(_PAGE_080_MEM_TYPE(0x201DD0))) /* Message Object 110 Data Register Low Low */


#define CAN_MODATA111LL (*(_PAGE_080_MEM_TYPE(0x201DF0))) /* Message Object 111 Data Register Low Low */


#define CAN_MODATA112LL (*(_PAGE_080_MEM_TYPE(0x201E10))) /* Message Object 112 Data Register Low Low */


#define CAN_MODATA113LL (*(_PAGE_080_MEM_TYPE(0x201E30))) /* Message Object 113 Data Register Low Low */


#define CAN_MODATA114LL (*(_PAGE_080_MEM_TYPE(0x201E50))) /* Message Object 114 Data Register Low Low */


#define CAN_MODATA115LL (*(_PAGE_080_MEM_TYPE(0x201E70))) /* Message Object 115 Data Register Low Low */


#define CAN_MODATA116LL (*(_PAGE_080_MEM_TYPE(0x201E90))) /* Message Object 116 Data Register Low Low */


#define CAN_MODATA117LL (*(_PAGE_080_MEM_TYPE(0x201EB0))) /* Message Object 117 Data Register Low Low */


#define CAN_MODATA118LL (*(_PAGE_080_MEM_TYPE(0x201ED0))) /* Message Object 118 Data Register Low Low */


#define CAN_MODATA119LL (*(_PAGE_080_MEM_TYPE(0x201EF0))) /* Message Object 119 Data Register Low Low */


#define CAN_MODATA120LL (*(_PAGE_080_MEM_TYPE(0x201F10))) /* Message Object 120 Data Register Low Low */


#define CAN_MODATA121LL (*(_PAGE_080_MEM_TYPE(0x201F30))) /* Message Object 121 Data Register Low Low */


#define CAN_MODATA122LL (*(_PAGE_080_MEM_TYPE(0x201F50))) /* Message Object 122 Data Register Low Low */


#define CAN_MODATA123LL (*(_PAGE_080_MEM_TYPE(0x201F70))) /* Message Object 123 Data Register Low Low */


#define CAN_MODATA124LL (*(_PAGE_080_MEM_TYPE(0x201F90))) /* Message Object 124 Data Register Low Low */


#define CAN_MODATA125LL (*(_PAGE_080_MEM_TYPE(0x201FB0))) /* Message Object 125 Data Register Low Low */


#define CAN_MODATA126LL (*(_PAGE_080_MEM_TYPE(0x201FD0))) /* Message Object 126 Data Register Low Low */


#define CAN_MODATA127LL (*(_PAGE_080_MEM_TYPE(0x201FF0))) /* Message Object 127 Data Register Low Low */


#define CAN_MODATA128LL (*(_PAGE_080_MEM_TYPE(0x202010))) /* Message Object 128 Data Register Low Low */


#define CAN_MODATA129LL (*(_PAGE_080_MEM_TYPE(0x202030))) /* Message Object 129 Data Register Low Low */


#define CAN_MODATA130LL (*(_PAGE_080_MEM_TYPE(0x202050))) /* Message Object 130 Data Register Low Low */


#define CAN_MODATA131LL (*(_PAGE_080_MEM_TYPE(0x202070))) /* Message Object 131 Data Register Low Low */


#define CAN_MODATA132LL (*(_PAGE_080_MEM_TYPE(0x202090))) /* Message Object 132 Data Register Low Low */


#define CAN_MODATA133LL (*(_PAGE_080_MEM_TYPE(0x2020B0))) /* Message Object 133 Data Register Low Low */


#define CAN_MODATA134LL (*(_PAGE_080_MEM_TYPE(0x2020D0))) /* Message Object 134 Data Register Low Low */


#define CAN_MODATA135LL (*(_PAGE_080_MEM_TYPE(0x2020F0))) /* Message Object 135 Data Register Low Low */


#define CAN_MODATA136LL (*(_PAGE_080_MEM_TYPE(0x202110))) /* Message Object 136 Data Register Low Low */


#define CAN_MODATA137LL (*(_PAGE_080_MEM_TYPE(0x202130))) /* Message Object 137 Data Register Low Low */


#define CAN_MODATA138LL (*(_PAGE_080_MEM_TYPE(0x202150))) /* Message Object 138 Data Register Low Low */


#define CAN_MODATA139LL (*(_PAGE_080_MEM_TYPE(0x202170))) /* Message Object 139 Data Register Low Low */


#define CAN_MODATA140LL (*(_PAGE_080_MEM_TYPE(0x202190))) /* Message Object 140 Data Register Low Low */


#define CAN_MODATA141LL (*(_PAGE_080_MEM_TYPE(0x2021B0))) /* Message Object 141 Data Register Low Low */


#define CAN_MODATA142LL (*(_PAGE_080_MEM_TYPE(0x2021D0))) /* Message Object 142 Data Register Low Low */


#define CAN_MODATA143LL (*(_PAGE_080_MEM_TYPE(0x2021F0))) /* Message Object 143 Data Register Low Low */


#define CAN_MODATA144LL (*(_PAGE_080_MEM_TYPE(0x202210))) /* Message Object 144 Data Register Low Low */


#define CAN_MODATA145LL (*(_PAGE_080_MEM_TYPE(0x202230))) /* Message Object 145 Data Register Low Low */


#define CAN_MODATA146LL (*(_PAGE_080_MEM_TYPE(0x202250))) /* Message Object 146 Data Register Low Low */


#define CAN_MODATA147LL (*(_PAGE_080_MEM_TYPE(0x202270))) /* Message Object 147 Data Register Low Low */


#define CAN_MODATA148LL (*(_PAGE_080_MEM_TYPE(0x202290))) /* Message Object 148 Data Register Low Low */


#define CAN_MODATA149LL (*(_PAGE_080_MEM_TYPE(0x2022B0))) /* Message Object 149 Data Register Low Low */


#define CAN_MODATA150LL (*(_PAGE_080_MEM_TYPE(0x2022D0))) /* Message Object 150 Data Register Low Low */


#define CAN_MODATA151LL (*(_PAGE_080_MEM_TYPE(0x2022F0))) /* Message Object 151 Data Register Low Low */


#define CAN_MODATA152LL (*(_PAGE_080_MEM_TYPE(0x202310))) /* Message Object 152 Data Register Low Low */


#define CAN_MODATA153LL (*(_PAGE_080_MEM_TYPE(0x202330))) /* Message Object 153 Data Register Low Low */


#define CAN_MODATA154LL (*(_PAGE_080_MEM_TYPE(0x202350))) /* Message Object 154 Data Register Low Low */


#define CAN_MODATA155LL (*(_PAGE_080_MEM_TYPE(0x202370))) /* Message Object 155 Data Register Low Low */


#define CAN_MODATA156LL (*(_PAGE_080_MEM_TYPE(0x202390))) /* Message Object 156 Data Register Low Low */


#define CAN_MODATA157LL (*(_PAGE_080_MEM_TYPE(0x2023B0))) /* Message Object 157 Data Register Low Low */


#define CAN_MODATA158LL (*(_PAGE_080_MEM_TYPE(0x2023D0))) /* Message Object 158 Data Register Low Low */


#define CAN_MODATA159LL (*(_PAGE_080_MEM_TYPE(0x2023F0))) /* Message Object 159 Data Register Low Low */


#define CAN_MODATA160LL (*(_PAGE_080_MEM_TYPE(0x202410))) /* Message Object 160 Data Register Low Low */


#define CAN_MODATA161LL (*(_PAGE_080_MEM_TYPE(0x202430))) /* Message Object 161 Data Register Low Low */


#define CAN_MODATA162LL (*(_PAGE_080_MEM_TYPE(0x202450))) /* Message Object 162 Data Register Low Low */


#define CAN_MODATA163LL (*(_PAGE_080_MEM_TYPE(0x202470))) /* Message Object 163 Data Register Low Low */


#define CAN_MODATA164LL (*(_PAGE_080_MEM_TYPE(0x202490))) /* Message Object 164 Data Register Low Low */


#define CAN_MODATA165LL (*(_PAGE_080_MEM_TYPE(0x2024B0))) /* Message Object 165 Data Register Low Low */


#define CAN_MODATA166LL (*(_PAGE_080_MEM_TYPE(0x2024D0))) /* Message Object 166 Data Register Low Low */


#define CAN_MODATA167LL (*(_PAGE_080_MEM_TYPE(0x2024F0))) /* Message Object 167 Data Register Low Low */


#define CAN_MODATA168LL (*(_PAGE_080_MEM_TYPE(0x202510))) /* Message Object 168 Data Register Low Low */


#define CAN_MODATA169LL (*(_PAGE_080_MEM_TYPE(0x202530))) /* Message Object 169 Data Register Low Low */


#define CAN_MODATA170LL (*(_PAGE_080_MEM_TYPE(0x202550))) /* Message Object 170 Data Register Low Low */


#define CAN_MODATA171LL (*(_PAGE_080_MEM_TYPE(0x202570))) /* Message Object 171 Data Register Low Low */


#define CAN_MODATA172LL (*(_PAGE_080_MEM_TYPE(0x202590))) /* Message Object 172 Data Register Low Low */


#define CAN_MODATA173LL (*(_PAGE_080_MEM_TYPE(0x2025B0))) /* Message Object 173 Data Register Low Low */


#define CAN_MODATA174LL (*(_PAGE_080_MEM_TYPE(0x2025D0))) /* Message Object 174 Data Register Low Low */


#define CAN_MODATA175LL (*(_PAGE_080_MEM_TYPE(0x2025F0))) /* Message Object 175 Data Register Low Low */


#define CAN_MODATA176LL (*(_PAGE_080_MEM_TYPE(0x202610))) /* Message Object 176 Data Register Low Low */


#define CAN_MODATA177LL (*(_PAGE_080_MEM_TYPE(0x202630))) /* Message Object 177 Data Register Low Low */


#define CAN_MODATA178LL (*(_PAGE_080_MEM_TYPE(0x202650))) /* Message Object 178 Data Register Low Low */


#define CAN_MODATA179LL (*(_PAGE_080_MEM_TYPE(0x202670))) /* Message Object 179 Data Register Low Low */


#define CAN_MODATA180LL (*(_PAGE_080_MEM_TYPE(0x202690))) /* Message Object 180 Data Register Low Low */


#define CAN_MODATA181LL (*(_PAGE_080_MEM_TYPE(0x2026B0))) /* Message Object 181 Data Register Low Low */


#define CAN_MODATA182LL (*(_PAGE_080_MEM_TYPE(0x2026D0))) /* Message Object 182 Data Register Low Low */


#define CAN_MODATA183LL (*(_PAGE_080_MEM_TYPE(0x2026F0))) /* Message Object 183 Data Register Low Low */


#define CAN_MODATA184LL (*(_PAGE_080_MEM_TYPE(0x202710))) /* Message Object 184 Data Register Low Low */


#define CAN_MODATA185LL (*(_PAGE_080_MEM_TYPE(0x202730))) /* Message Object 185 Data Register Low Low */


#define CAN_MODATA186LL (*(_PAGE_080_MEM_TYPE(0x202750))) /* Message Object 186 Data Register Low Low */


#define CAN_MODATA187LL (*(_PAGE_080_MEM_TYPE(0x202770))) /* Message Object 187 Data Register Low Low */


#define CAN_MODATA188LL (*(_PAGE_080_MEM_TYPE(0x202790))) /* Message Object 188 Data Register Low Low */


#define CAN_MODATA189LL (*(_PAGE_080_MEM_TYPE(0x2027B0))) /* Message Object 189 Data Register Low Low */


#define CAN_MODATA190LL (*(_PAGE_080_MEM_TYPE(0x2027D0))) /* Message Object 190 Data Register Low Low */


#define CAN_MODATA191LL (*(_PAGE_080_MEM_TYPE(0x2027F0))) /* Message Object 191 Data Register Low Low */


#define CAN_MODATA192LL (*(_PAGE_080_MEM_TYPE(0x202810))) /* Message Object 192 Data Register Low Low */


#define CAN_MODATA193LL (*(_PAGE_080_MEM_TYPE(0x202830))) /* Message Object 193 Data Register Low Low */


#define CAN_MODATA194LL (*(_PAGE_080_MEM_TYPE(0x202850))) /* Message Object 194 Data Register Low Low */


#define CAN_MODATA195LL (*(_PAGE_080_MEM_TYPE(0x202870))) /* Message Object 195 Data Register Low Low */


#define CAN_MODATA196LL (*(_PAGE_080_MEM_TYPE(0x202890))) /* Message Object 196 Data Register Low Low */


#define CAN_MODATA197LL (*(_PAGE_080_MEM_TYPE(0x2028B0))) /* Message Object 197 Data Register Low Low */


#define CAN_MODATA198LL (*(_PAGE_080_MEM_TYPE(0x2028D0))) /* Message Object 198 Data Register Low Low */


#define CAN_MODATA199LL (*(_PAGE_080_MEM_TYPE(0x2028F0))) /* Message Object 199 Data Register Low Low */


#define CAN_MODATA200LL (*(_PAGE_080_MEM_TYPE(0x202910))) /* Message Object 200 Data Register Low Low */


#define CAN_MODATA201LL (*(_PAGE_080_MEM_TYPE(0x202930))) /* Message Object 201 Data Register Low Low */


#define CAN_MODATA202LL (*(_PAGE_080_MEM_TYPE(0x202950))) /* Message Object 202 Data Register Low Low */


#define CAN_MODATA203LL (*(_PAGE_080_MEM_TYPE(0x202970))) /* Message Object 203 Data Register Low Low */


#define CAN_MODATA204LL (*(_PAGE_080_MEM_TYPE(0x202990))) /* Message Object 204 Data Register Low Low */


#define CAN_MODATA205LL (*(_PAGE_080_MEM_TYPE(0x2029B0))) /* Message Object 205 Data Register Low Low */


#define CAN_MODATA206LL (*(_PAGE_080_MEM_TYPE(0x2029D0))) /* Message Object 206 Data Register Low Low */


#define CAN_MODATA207LL (*(_PAGE_080_MEM_TYPE(0x2029F0))) /* Message Object 207 Data Register Low Low */


#define CAN_MODATA208LL (*(_PAGE_080_MEM_TYPE(0x202A10))) /* Message Object 208 Data Register Low Low */


#define CAN_MODATA209LL (*(_PAGE_080_MEM_TYPE(0x202A30))) /* Message Object 209 Data Register Low Low */


#define CAN_MODATA210LL (*(_PAGE_080_MEM_TYPE(0x202A50))) /* Message Object 210 Data Register Low Low */


#define CAN_MODATA211LL (*(_PAGE_080_MEM_TYPE(0x202A70))) /* Message Object 211 Data Register Low Low */


#define CAN_MODATA212LL (*(_PAGE_080_MEM_TYPE(0x202A90))) /* Message Object 212 Data Register Low Low */


#define CAN_MODATA213LL (*(_PAGE_080_MEM_TYPE(0x202AB0))) /* Message Object 213 Data Register Low Low */


#define CAN_MODATA214LL (*(_PAGE_080_MEM_TYPE(0x202AD0))) /* Message Object 214 Data Register Low Low */


#define CAN_MODATA215LL (*(_PAGE_080_MEM_TYPE(0x202AF0))) /* Message Object 215 Data Register Low Low */


#define CAN_MODATA216LL (*(_PAGE_080_MEM_TYPE(0x202B10))) /* Message Object 216 Data Register Low Low */


#define CAN_MODATA217LL (*(_PAGE_080_MEM_TYPE(0x202B30))) /* Message Object 217 Data Register Low Low */


#define CAN_MODATA218LL (*(_PAGE_080_MEM_TYPE(0x202B50))) /* Message Object 218 Data Register Low Low */


#define CAN_MODATA219LL (*(_PAGE_080_MEM_TYPE(0x202B70))) /* Message Object 219 Data Register Low Low */


#define CAN_MODATA220LL (*(_PAGE_080_MEM_TYPE(0x202B90))) /* Message Object 220 Data Register Low Low */


#define CAN_MODATA221LL (*(_PAGE_080_MEM_TYPE(0x202BB0))) /* Message Object 221 Data Register Low Low */


#define CAN_MODATA222LL (*(_PAGE_080_MEM_TYPE(0x202BD0))) /* Message Object 222 Data Register Low Low */


#define CAN_MODATA223LL (*(_PAGE_080_MEM_TYPE(0x202BF0))) /* Message Object 223 Data Register Low Low */


#define CAN_MODATA224LL (*(_PAGE_080_MEM_TYPE(0x202C10))) /* Message Object 224 Data Register Low Low */


#define CAN_MODATA225LL (*(_PAGE_080_MEM_TYPE(0x202C30))) /* Message Object 225 Data Register Low Low */


#define CAN_MODATA226LL (*(_PAGE_080_MEM_TYPE(0x202C50))) /* Message Object 226 Data Register Low Low */


#define CAN_MODATA227LL (*(_PAGE_080_MEM_TYPE(0x202C70))) /* Message Object 227 Data Register Low Low */


#define CAN_MODATA228LL (*(_PAGE_080_MEM_TYPE(0x202C90))) /* Message Object 228 Data Register Low Low */


#define CAN_MODATA229LL (*(_PAGE_080_MEM_TYPE(0x202CB0))) /* Message Object 229 Data Register Low Low */


#define CAN_MODATA230LL (*(_PAGE_080_MEM_TYPE(0x202CD0))) /* Message Object 230 Data Register Low Low */


#define CAN_MODATA231LL (*(_PAGE_080_MEM_TYPE(0x202CF0))) /* Message Object 231 Data Register Low Low */


#define CAN_MODATA232LL (*(_PAGE_080_MEM_TYPE(0x202D10))) /* Message Object 232 Data Register Low Low */


#define CAN_MODATA233LL (*(_PAGE_080_MEM_TYPE(0x202D30))) /* Message Object 233 Data Register Low Low */


#define CAN_MODATA234LL (*(_PAGE_080_MEM_TYPE(0x202D50))) /* Message Object 234 Data Register Low Low */


#define CAN_MODATA235LL (*(_PAGE_080_MEM_TYPE(0x202D70))) /* Message Object 235 Data Register Low Low */


#define CAN_MODATA236LL (*(_PAGE_080_MEM_TYPE(0x202D90))) /* Message Object 236 Data Register Low Low */


#define CAN_MODATA237LL (*(_PAGE_080_MEM_TYPE(0x202DB0))) /* Message Object 237 Data Register Low Low */


#define CAN_MODATA238LL (*(_PAGE_080_MEM_TYPE(0x202DD0))) /* Message Object 238 Data Register Low Low */


#define CAN_MODATA239LL (*(_PAGE_080_MEM_TYPE(0x202DF0))) /* Message Object 239 Data Register Low Low */


#define CAN_MODATA240LL (*(_PAGE_080_MEM_TYPE(0x202E10))) /* Message Object 240 Data Register Low Low */


#define CAN_MODATA241LL (*(_PAGE_080_MEM_TYPE(0x202E30))) /* Message Object 241 Data Register Low Low */


#define CAN_MODATA242LL (*(_PAGE_080_MEM_TYPE(0x202E50))) /* Message Object 242 Data Register Low Low */


#define CAN_MODATA243LL (*(_PAGE_080_MEM_TYPE(0x202E70))) /* Message Object 243 Data Register Low Low */


#define CAN_MODATA244LL (*(_PAGE_080_MEM_TYPE(0x202E90))) /* Message Object 244 Data Register Low Low */


#define CAN_MODATA245LL (*(_PAGE_080_MEM_TYPE(0x202EB0))) /* Message Object 245 Data Register Low Low */


#define CAN_MODATA246LL (*(_PAGE_080_MEM_TYPE(0x202ED0))) /* Message Object 246 Data Register Low Low */


#define CAN_MODATA247LL (*(_PAGE_080_MEM_TYPE(0x202EF0))) /* Message Object 247 Data Register Low Low */


#define CAN_MODATA248LL (*(_PAGE_080_MEM_TYPE(0x202F10))) /* Message Object 248 Data Register Low Low */


#define CAN_MODATA249LL (*(_PAGE_080_MEM_TYPE(0x202F30))) /* Message Object 249 Data Register Low Low */


#define CAN_MODATA250LL (*(_PAGE_080_MEM_TYPE(0x202F50))) /* Message Object 250 Data Register Low Low */


#define CAN_MODATA251LL (*(_PAGE_080_MEM_TYPE(0x202F70))) /* Message Object 251 Data Register Low Low */


#define CAN_MODATA252LL (*(_PAGE_080_MEM_TYPE(0x202F90))) /* Message Object 252 Data Register Low Low */


#define CAN_MODATA253LL (*(_PAGE_080_MEM_TYPE(0x202FB0))) /* Message Object 253 Data Register Low Low */


#define CAN_MODATA254LL (*(_PAGE_080_MEM_TYPE(0x202FD0))) /* Message Object 254 Data Register Low Low */


#define CAN_MODATA255LL (*(_PAGE_080_MEM_TYPE(0x202FF0))) /* Message Object 255 Data Register Low Low */


#define CAN_MODATA0HH   (*(_PAGE_080_MEM_TYPE(0x201016))) /* Message Object 0 Data Register High High */


#define CAN_MODATA1HH   (*(_PAGE_080_MEM_TYPE(0x201036))) /* Message Object 1 Data Register High High */


#define CAN_MODATA2HH   (*(_PAGE_080_MEM_TYPE(0x201056))) /* Message Object 2 Data Register High High */


#define CAN_MODATA3HH   (*(_PAGE_080_MEM_TYPE(0x201076))) /* Message Object 3 Data Register High High */


#define CAN_MODATA4HH   (*(_PAGE_080_MEM_TYPE(0x201096))) /* Message Object 4 Data Register High High */


#define CAN_MODATA5HH   (*(_PAGE_080_MEM_TYPE(0x2010B6))) /* Message Object 5 Data Register High High */


#define CAN_MODATA6HH   (*(_PAGE_080_MEM_TYPE(0x2010D6))) /* Message Object 6 Data Register High High */


#define CAN_MODATA7HH   (*(_PAGE_080_MEM_TYPE(0x2010F6))) /* Message Object 7 Data Register High High */


#define CAN_MODATA8HH   (*(_PAGE_080_MEM_TYPE(0x201116))) /* Message Object 8 Data Register High High */


#define CAN_MODATA9HH   (*(_PAGE_080_MEM_TYPE(0x201136))) /* Message Object 9 Data Register High High */


#define CAN_MODATA10HH  (*(_PAGE_080_MEM_TYPE(0x201156))) /* Message Object 10 Data Register High High */


#define CAN_MODATA11HH  (*(_PAGE_080_MEM_TYPE(0x201176))) /* Message Object 11 Data Register High High */


#define CAN_MODATA12HH  (*(_PAGE_080_MEM_TYPE(0x201196))) /* Message Object 12 Data Register High High */


#define CAN_MODATA13HH  (*(_PAGE_080_MEM_TYPE(0x2011B6))) /* Message Object 13 Data Register High High */


#define CAN_MODATA14HH  (*(_PAGE_080_MEM_TYPE(0x2011D6))) /* Message Object 14 Data Register High High */


#define CAN_MODATA15HH  (*(_PAGE_080_MEM_TYPE(0x2011F6))) /* Message Object 15 Data Register High High */


#define CAN_MODATA16HH  (*(_PAGE_080_MEM_TYPE(0x201216))) /* Message Object 16 Data Register High High */


#define CAN_MODATA17HH  (*(_PAGE_080_MEM_TYPE(0x201236))) /* Message Object 17 Data Register High High */


#define CAN_MODATA18HH  (*(_PAGE_080_MEM_TYPE(0x201256))) /* Message Object 18 Data Register High High */


#define CAN_MODATA19HH  (*(_PAGE_080_MEM_TYPE(0x201276))) /* Message Object 19 Data Register High High */


#define CAN_MODATA20HH  (*(_PAGE_080_MEM_TYPE(0x201296))) /* Message Object 20 Data Register High High */


#define CAN_MODATA21HH  (*(_PAGE_080_MEM_TYPE(0x2012B6))) /* Message Object 21 Data Register High High */


#define CAN_MODATA22HH  (*(_PAGE_080_MEM_TYPE(0x2012D6))) /* Message Object 22 Data Register High High */


#define CAN_MODATA23HH  (*(_PAGE_080_MEM_TYPE(0x2012F6))) /* Message Object 23 Data Register High High */


#define CAN_MODATA24HH  (*(_PAGE_080_MEM_TYPE(0x201316))) /* Message Object 24 Data Register High High */


#define CAN_MODATA25HH  (*(_PAGE_080_MEM_TYPE(0x201336))) /* Message Object 25 Data Register High High */


#define CAN_MODATA26HH  (*(_PAGE_080_MEM_TYPE(0x201356))) /* Message Object 26 Data Register High High */


#define CAN_MODATA27HH  (*(_PAGE_080_MEM_TYPE(0x201376))) /* Message Object 27 Data Register High High */


#define CAN_MODATA28HH  (*(_PAGE_080_MEM_TYPE(0x201396))) /* Message Object 28 Data Register High High */


#define CAN_MODATA29HH  (*(_PAGE_080_MEM_TYPE(0x2013B6))) /* Message Object 29 Data Register High High */


#define CAN_MODATA30HH  (*(_PAGE_080_MEM_TYPE(0x2013D6))) /* Message Object 30 Data Register High High */


#define CAN_MODATA31HH  (*(_PAGE_080_MEM_TYPE(0x2013F6))) /* Message Object 31 Data Register High High */


#define CAN_MODATA32HH  (*(_PAGE_080_MEM_TYPE(0x201416))) /* Message Object 32 Data Register High High */


#define CAN_MODATA33HH  (*(_PAGE_080_MEM_TYPE(0x201436))) /* Message Object 33 Data Register High High */


#define CAN_MODATA34HH  (*(_PAGE_080_MEM_TYPE(0x201456))) /* Message Object 34 Data Register High High */


#define CAN_MODATA35HH  (*(_PAGE_080_MEM_TYPE(0x201476))) /* Message Object 35 Data Register High High */


#define CAN_MODATA36HH  (*(_PAGE_080_MEM_TYPE(0x201496))) /* Message Object 36 Data Register High High */


#define CAN_MODATA37HH  (*(_PAGE_080_MEM_TYPE(0x2014B6))) /* Message Object 37 Data Register High High */


#define CAN_MODATA38HH  (*(_PAGE_080_MEM_TYPE(0x2014D6))) /* Message Object 38 Data Register High High */


#define CAN_MODATA39HH  (*(_PAGE_080_MEM_TYPE(0x2014F6))) /* Message Object 39 Data Register High High */


#define CAN_MODATA40HH  (*(_PAGE_080_MEM_TYPE(0x201516))) /* Message Object 40 Data Register High High */


#define CAN_MODATA41HH  (*(_PAGE_080_MEM_TYPE(0x201536))) /* Message Object 41 Data Register High High */


#define CAN_MODATA42HH  (*(_PAGE_080_MEM_TYPE(0x201556))) /* Message Object 42 Data Register High High */


#define CAN_MODATA43HH  (*(_PAGE_080_MEM_TYPE(0x201576))) /* Message Object 43 Data Register High High */


#define CAN_MODATA44HH  (*(_PAGE_080_MEM_TYPE(0x201596))) /* Message Object 44 Data Register High High */


#define CAN_MODATA45HH  (*(_PAGE_080_MEM_TYPE(0x2015B6))) /* Message Object 45 Data Register High High */


#define CAN_MODATA46HH  (*(_PAGE_080_MEM_TYPE(0x2015D6))) /* Message Object 46 Data Register High High */


#define CAN_MODATA47HH  (*(_PAGE_080_MEM_TYPE(0x2015F6))) /* Message Object 47 Data Register High High */


#define CAN_MODATA48HH  (*(_PAGE_080_MEM_TYPE(0x201616))) /* Message Object 48 Data Register High High */


#define CAN_MODATA49HH  (*(_PAGE_080_MEM_TYPE(0x201636))) /* Message Object 49 Data Register High High */


#define CAN_MODATA50HH  (*(_PAGE_080_MEM_TYPE(0x201656))) /* Message Object 50 Data Register High High */


#define CAN_MODATA51HH  (*(_PAGE_080_MEM_TYPE(0x201676))) /* Message Object 51 Data Register High High */


#define CAN_MODATA52HH  (*(_PAGE_080_MEM_TYPE(0x201696))) /* Message Object 52 Data Register High High */


#define CAN_MODATA53HH  (*(_PAGE_080_MEM_TYPE(0x2016B6))) /* Message Object 53 Data Register High High */


#define CAN_MODATA54HH  (*(_PAGE_080_MEM_TYPE(0x2016D6))) /* Message Object 54 Data Register High High */


#define CAN_MODATA55HH  (*(_PAGE_080_MEM_TYPE(0x2016F6))) /* Message Object 55 Data Register High High */


#define CAN_MODATA56HH  (*(_PAGE_080_MEM_TYPE(0x201716))) /* Message Object 56 Data Register High High */


#define CAN_MODATA57HH  (*(_PAGE_080_MEM_TYPE(0x201736))) /* Message Object 57 Data Register High High */


#define CAN_MODATA58HH  (*(_PAGE_080_MEM_TYPE(0x201756))) /* Message Object 58 Data Register High High */


#define CAN_MODATA59HH  (*(_PAGE_080_MEM_TYPE(0x201776))) /* Message Object 59 Data Register High High */


#define CAN_MODATA60HH  (*(_PAGE_080_MEM_TYPE(0x201796))) /* Message Object 60 Data Register High High */


#define CAN_MODATA61HH  (*(_PAGE_080_MEM_TYPE(0x2017B6))) /* Message Object 61 Data Register High High */


#define CAN_MODATA62HH  (*(_PAGE_080_MEM_TYPE(0x2017D6))) /* Message Object 62 Data Register High High */


#define CAN_MODATA63HH  (*(_PAGE_080_MEM_TYPE(0x2017F6))) /* Message Object 63 Data Register High High */


#define CAN_MODATA64HH  (*(_PAGE_080_MEM_TYPE(0x201816))) /* Message Object 64 Data Register High High */


#define CAN_MODATA65HH  (*(_PAGE_080_MEM_TYPE(0x201836))) /* Message Object 65 Data Register High High */


#define CAN_MODATA66HH  (*(_PAGE_080_MEM_TYPE(0x201856))) /* Message Object 66 Data Register High High */


#define CAN_MODATA67HH  (*(_PAGE_080_MEM_TYPE(0x201876))) /* Message Object 67 Data Register High High */


#define CAN_MODATA68HH  (*(_PAGE_080_MEM_TYPE(0x201896))) /* Message Object 68 Data Register High High */


#define CAN_MODATA69HH  (*(_PAGE_080_MEM_TYPE(0x2018B6))) /* Message Object 69 Data Register High High */


#define CAN_MODATA70HH  (*(_PAGE_080_MEM_TYPE(0x2018D6))) /* Message Object 70 Data Register High High */


#define CAN_MODATA71HH  (*(_PAGE_080_MEM_TYPE(0x2018F6))) /* Message Object 71 Data Register High High */


#define CAN_MODATA72HH  (*(_PAGE_080_MEM_TYPE(0x201916))) /* Message Object 72 Data Register High High */


#define CAN_MODATA73HH  (*(_PAGE_080_MEM_TYPE(0x201936))) /* Message Object 73 Data Register High High */


#define CAN_MODATA74HH  (*(_PAGE_080_MEM_TYPE(0x201956))) /* Message Object 74 Data Register High High */


#define CAN_MODATA75HH  (*(_PAGE_080_MEM_TYPE(0x201976))) /* Message Object 75 Data Register High High */


#define CAN_MODATA76HH  (*(_PAGE_080_MEM_TYPE(0x201996))) /* Message Object 76 Data Register High High */


#define CAN_MODATA77HH  (*(_PAGE_080_MEM_TYPE(0x2019B6))) /* Message Object 77 Data Register High High */


#define CAN_MODATA78HH  (*(_PAGE_080_MEM_TYPE(0x2019D6))) /* Message Object 78 Data Register High High */


#define CAN_MODATA79HH  (*(_PAGE_080_MEM_TYPE(0x2019F6))) /* Message Object 79 Data Register High High */


#define CAN_MODATA80HH  (*(_PAGE_080_MEM_TYPE(0x201A16))) /* Message Object 80 Data Register High High */


#define CAN_MODATA81HH  (*(_PAGE_080_MEM_TYPE(0x201A36))) /* Message Object 81 Data Register High High */


#define CAN_MODATA82HH  (*(_PAGE_080_MEM_TYPE(0x201A56))) /* Message Object 82 Data Register High High */


#define CAN_MODATA83HH  (*(_PAGE_080_MEM_TYPE(0x201A76))) /* Message Object 83 Data Register High High */


#define CAN_MODATA84HH  (*(_PAGE_080_MEM_TYPE(0x201A96))) /* Message Object 84 Data Register High High */


#define CAN_MODATA85HH  (*(_PAGE_080_MEM_TYPE(0x201AB6))) /* Message Object 85 Data Register High High */


#define CAN_MODATA86HH  (*(_PAGE_080_MEM_TYPE(0x201AD6))) /* Message Object 86 Data Register High High */


#define CAN_MODATA87HH  (*(_PAGE_080_MEM_TYPE(0x201AF6))) /* Message Object 87 Data Register High High */


#define CAN_MODATA88HH  (*(_PAGE_080_MEM_TYPE(0x201B16))) /* Message Object 88 Data Register High High */


#define CAN_MODATA89HH  (*(_PAGE_080_MEM_TYPE(0x201B36))) /* Message Object 89 Data Register High High */


#define CAN_MODATA90HH  (*(_PAGE_080_MEM_TYPE(0x201B56))) /* Message Object 90 Data Register High High */


#define CAN_MODATA91HH  (*(_PAGE_080_MEM_TYPE(0x201B76))) /* Message Object 91 Data Register High High */


#define CAN_MODATA92HH  (*(_PAGE_080_MEM_TYPE(0x201B96))) /* Message Object 92 Data Register High High */


#define CAN_MODATA93HH  (*(_PAGE_080_MEM_TYPE(0x201BB6))) /* Message Object 93 Data Register High High */


#define CAN_MODATA94HH  (*(_PAGE_080_MEM_TYPE(0x201BD6))) /* Message Object 94 Data Register High High */


#define CAN_MODATA95HH  (*(_PAGE_080_MEM_TYPE(0x201BF6))) /* Message Object 95 Data Register High High */


#define CAN_MODATA96HH  (*(_PAGE_080_MEM_TYPE(0x201C16))) /* Message Object 96 Data Register High High */


#define CAN_MODATA97HH  (*(_PAGE_080_MEM_TYPE(0x201C36))) /* Message Object 97 Data Register High High */


#define CAN_MODATA98HH  (*(_PAGE_080_MEM_TYPE(0x201C56))) /* Message Object 98 Data Register High High */


#define CAN_MODATA99HH  (*(_PAGE_080_MEM_TYPE(0x201C76))) /* Message Object 99 Data Register High High */


#define CAN_MODATA100HH (*(_PAGE_080_MEM_TYPE(0x201C96))) /* Message Object 100 Data Register High High */


#define CAN_MODATA101HH (*(_PAGE_080_MEM_TYPE(0x201CB6))) /* Message Object 101 Data Register High High */


#define CAN_MODATA102HH (*(_PAGE_080_MEM_TYPE(0x201CD6))) /* Message Object 102 Data Register High High */


#define CAN_MODATA103HH (*(_PAGE_080_MEM_TYPE(0x201CF6))) /* Message Object 103 Data Register High High */


#define CAN_MODATA104HH (*(_PAGE_080_MEM_TYPE(0x201D16))) /* Message Object 104 Data Register High High */


#define CAN_MODATA105HH (*(_PAGE_080_MEM_TYPE(0x201D36))) /* Message Object 105 Data Register High High */


#define CAN_MODATA106HH (*(_PAGE_080_MEM_TYPE(0x201D56))) /* Message Object 106 Data Register High High */


#define CAN_MODATA107HH (*(_PAGE_080_MEM_TYPE(0x201D76))) /* Message Object 107 Data Register High High */


#define CAN_MODATA108HH (*(_PAGE_080_MEM_TYPE(0x201D96))) /* Message Object 108 Data Register High High */


#define CAN_MODATA109HH (*(_PAGE_080_MEM_TYPE(0x201DB6))) /* Message Object 109 Data Register High High */


#define CAN_MODATA110HH (*(_PAGE_080_MEM_TYPE(0x201DD6))) /* Message Object 110 Data Register High High */


#define CAN_MODATA111HH (*(_PAGE_080_MEM_TYPE(0x201DF6))) /* Message Object 111 Data Register High High */


#define CAN_MODATA112HH (*(_PAGE_080_MEM_TYPE(0x201E16))) /* Message Object 112 Data Register High High */


#define CAN_MODATA113HH (*(_PAGE_080_MEM_TYPE(0x201E36))) /* Message Object 113 Data Register High High */


#define CAN_MODATA114HH (*(_PAGE_080_MEM_TYPE(0x201E56))) /* Message Object 114 Data Register High High */


#define CAN_MODATA115HH (*(_PAGE_080_MEM_TYPE(0x201E76))) /* Message Object 115 Data Register High High */


#define CAN_MODATA116HH (*(_PAGE_080_MEM_TYPE(0x201E96))) /* Message Object 116 Data Register High High */


#define CAN_MODATA117HH (*(_PAGE_080_MEM_TYPE(0x201EB6))) /* Message Object 117 Data Register High High */


#define CAN_MODATA118HH (*(_PAGE_080_MEM_TYPE(0x201ED6))) /* Message Object 118 Data Register High High */


#define CAN_MODATA119HH (*(_PAGE_080_MEM_TYPE(0x201EF6))) /* Message Object 119 Data Register High High */


#define CAN_MODATA120HH (*(_PAGE_080_MEM_TYPE(0x201F16))) /* Message Object 120 Data Register High High */


#define CAN_MODATA121HH (*(_PAGE_080_MEM_TYPE(0x201F36))) /* Message Object 121 Data Register High High */


#define CAN_MODATA122HH (*(_PAGE_080_MEM_TYPE(0x201F56))) /* Message Object 122 Data Register High High */


#define CAN_MODATA123HH (*(_PAGE_080_MEM_TYPE(0x201F76))) /* Message Object 123 Data Register High High */


#define CAN_MODATA124HH (*(_PAGE_080_MEM_TYPE(0x201F96))) /* Message Object 124 Data Register High High */


#define CAN_MODATA125HH (*(_PAGE_080_MEM_TYPE(0x201FB6))) /* Message Object 125 Data Register High High */


#define CAN_MODATA126HH (*(_PAGE_080_MEM_TYPE(0x201FD6))) /* Message Object 126 Data Register High High */


#define CAN_MODATA127HH (*(_PAGE_080_MEM_TYPE(0x201FF6))) /* Message Object 127 Data Register High High */


#define CAN_MODATA128HH (*(_PAGE_080_MEM_TYPE(0x202016))) /* Message Object 128 Data Register High High */


#define CAN_MODATA129HH (*(_PAGE_080_MEM_TYPE(0x202036))) /* Message Object 129 Data Register High High */


#define CAN_MODATA130HH (*(_PAGE_080_MEM_TYPE(0x202056))) /* Message Object 130 Data Register High High */


#define CAN_MODATA131HH (*(_PAGE_080_MEM_TYPE(0x202076))) /* Message Object 131 Data Register High High */


#define CAN_MODATA132HH (*(_PAGE_080_MEM_TYPE(0x202096))) /* Message Object 132 Data Register High High */


#define CAN_MODATA133HH (*(_PAGE_080_MEM_TYPE(0x2020B6))) /* Message Object 133 Data Register High High */


#define CAN_MODATA134HH (*(_PAGE_080_MEM_TYPE(0x2020D6))) /* Message Object 134 Data Register High High */


#define CAN_MODATA135HH (*(_PAGE_080_MEM_TYPE(0x2020F6))) /* Message Object 135 Data Register High High */


#define CAN_MODATA136HH (*(_PAGE_080_MEM_TYPE(0x202116))) /* Message Object 136 Data Register High High */


#define CAN_MODATA137HH (*(_PAGE_080_MEM_TYPE(0x202136))) /* Message Object 137 Data Register High High */


#define CAN_MODATA138HH (*(_PAGE_080_MEM_TYPE(0x202156))) /* Message Object 138 Data Register High High */


#define CAN_MODATA139HH (*(_PAGE_080_MEM_TYPE(0x202176))) /* Message Object 139 Data Register High High */


#define CAN_MODATA140HH (*(_PAGE_080_MEM_TYPE(0x202196))) /* Message Object 140 Data Register High High */


#define CAN_MODATA141HH (*(_PAGE_080_MEM_TYPE(0x2021B6))) /* Message Object 141 Data Register High High */


#define CAN_MODATA142HH (*(_PAGE_080_MEM_TYPE(0x2021D6))) /* Message Object 142 Data Register High High */


#define CAN_MODATA143HH (*(_PAGE_080_MEM_TYPE(0x2021F6))) /* Message Object 143 Data Register High High */


#define CAN_MODATA144HH (*(_PAGE_080_MEM_TYPE(0x202216))) /* Message Object 144 Data Register High High */


#define CAN_MODATA145HH (*(_PAGE_080_MEM_TYPE(0x202236))) /* Message Object 145 Data Register High High */


#define CAN_MODATA146HH (*(_PAGE_080_MEM_TYPE(0x202256))) /* Message Object 146 Data Register High High */


#define CAN_MODATA147HH (*(_PAGE_080_MEM_TYPE(0x202276))) /* Message Object 147 Data Register High High */


#define CAN_MODATA148HH (*(_PAGE_080_MEM_TYPE(0x202296))) /* Message Object 148 Data Register High High */


#define CAN_MODATA149HH (*(_PAGE_080_MEM_TYPE(0x2022B6))) /* Message Object 149 Data Register High High */


#define CAN_MODATA150HH (*(_PAGE_080_MEM_TYPE(0x2022D6))) /* Message Object 150 Data Register High High */


#define CAN_MODATA151HH (*(_PAGE_080_MEM_TYPE(0x2022F6))) /* Message Object 151 Data Register High High */


#define CAN_MODATA152HH (*(_PAGE_080_MEM_TYPE(0x202316))) /* Message Object 152 Data Register High High */


#define CAN_MODATA153HH (*(_PAGE_080_MEM_TYPE(0x202336))) /* Message Object 153 Data Register High High */


#define CAN_MODATA154HH (*(_PAGE_080_MEM_TYPE(0x202356))) /* Message Object 154 Data Register High High */


#define CAN_MODATA155HH (*(_PAGE_080_MEM_TYPE(0x202376))) /* Message Object 155 Data Register High High */


#define CAN_MODATA156HH (*(_PAGE_080_MEM_TYPE(0x202396))) /* Message Object 156 Data Register High High */


#define CAN_MODATA157HH (*(_PAGE_080_MEM_TYPE(0x2023B6))) /* Message Object 157 Data Register High High */


#define CAN_MODATA158HH (*(_PAGE_080_MEM_TYPE(0x2023D6))) /* Message Object 158 Data Register High High */


#define CAN_MODATA159HH (*(_PAGE_080_MEM_TYPE(0x2023F6))) /* Message Object 159 Data Register High High */


#define CAN_MODATA160HH (*(_PAGE_080_MEM_TYPE(0x202416))) /* Message Object 160 Data Register High High */


#define CAN_MODATA161HH (*(_PAGE_080_MEM_TYPE(0x202436))) /* Message Object 161 Data Register High High */


#define CAN_MODATA162HH (*(_PAGE_080_MEM_TYPE(0x202456))) /* Message Object 162 Data Register High High */


#define CAN_MODATA163HH (*(_PAGE_080_MEM_TYPE(0x202476))) /* Message Object 163 Data Register High High */


#define CAN_MODATA164HH (*(_PAGE_080_MEM_TYPE(0x202496))) /* Message Object 164 Data Register High High */


#define CAN_MODATA165HH (*(_PAGE_080_MEM_TYPE(0x2024B6))) /* Message Object 165 Data Register High High */


#define CAN_MODATA166HH (*(_PAGE_080_MEM_TYPE(0x2024D6))) /* Message Object 166 Data Register High High */


#define CAN_MODATA167HH (*(_PAGE_080_MEM_TYPE(0x2024F6))) /* Message Object 167 Data Register High High */


#define CAN_MODATA168HH (*(_PAGE_080_MEM_TYPE(0x202516))) /* Message Object 168 Data Register High High */


#define CAN_MODATA169HH (*(_PAGE_080_MEM_TYPE(0x202536))) /* Message Object 169 Data Register High High */


#define CAN_MODATA170HH (*(_PAGE_080_MEM_TYPE(0x202556))) /* Message Object 170 Data Register High High */


#define CAN_MODATA171HH (*(_PAGE_080_MEM_TYPE(0x202576))) /* Message Object 171 Data Register High High */


#define CAN_MODATA172HH (*(_PAGE_080_MEM_TYPE(0x202596))) /* Message Object 172 Data Register High High */


#define CAN_MODATA173HH (*(_PAGE_080_MEM_TYPE(0x2025B6))) /* Message Object 173 Data Register High High */


#define CAN_MODATA174HH (*(_PAGE_080_MEM_TYPE(0x2025D6))) /* Message Object 174 Data Register High High */


#define CAN_MODATA175HH (*(_PAGE_080_MEM_TYPE(0x2025F6))) /* Message Object 175 Data Register High High */


#define CAN_MODATA176HH (*(_PAGE_080_MEM_TYPE(0x202616))) /* Message Object 176 Data Register High High */


#define CAN_MODATA177HH (*(_PAGE_080_MEM_TYPE(0x202636))) /* Message Object 177 Data Register High High */


#define CAN_MODATA178HH (*(_PAGE_080_MEM_TYPE(0x202656))) /* Message Object 178 Data Register High High */


#define CAN_MODATA179HH (*(_PAGE_080_MEM_TYPE(0x202676))) /* Message Object 179 Data Register High High */


#define CAN_MODATA180HH (*(_PAGE_080_MEM_TYPE(0x202696))) /* Message Object 180 Data Register High High */


#define CAN_MODATA181HH (*(_PAGE_080_MEM_TYPE(0x2026B6))) /* Message Object 181 Data Register High High */


#define CAN_MODATA182HH (*(_PAGE_080_MEM_TYPE(0x2026D6))) /* Message Object 182 Data Register High High */


#define CAN_MODATA183HH (*(_PAGE_080_MEM_TYPE(0x2026F6))) /* Message Object 183 Data Register High High */


#define CAN_MODATA184HH (*(_PAGE_080_MEM_TYPE(0x202716))) /* Message Object 184 Data Register High High */


#define CAN_MODATA185HH (*(_PAGE_080_MEM_TYPE(0x202736))) /* Message Object 185 Data Register High High */


#define CAN_MODATA186HH (*(_PAGE_080_MEM_TYPE(0x202756))) /* Message Object 186 Data Register High High */


#define CAN_MODATA187HH (*(_PAGE_080_MEM_TYPE(0x202776))) /* Message Object 187 Data Register High High */


#define CAN_MODATA188HH (*(_PAGE_080_MEM_TYPE(0x202796))) /* Message Object 188 Data Register High High */


#define CAN_MODATA189HH (*(_PAGE_080_MEM_TYPE(0x2027B6))) /* Message Object 189 Data Register High High */


#define CAN_MODATA190HH (*(_PAGE_080_MEM_TYPE(0x2027D6))) /* Message Object 190 Data Register High High */


#define CAN_MODATA191HH (*(_PAGE_080_MEM_TYPE(0x2027F6))) /* Message Object 191 Data Register High High */


#define CAN_MODATA192HH (*(_PAGE_080_MEM_TYPE(0x202816))) /* Message Object 192 Data Register High High */


#define CAN_MODATA193HH (*(_PAGE_080_MEM_TYPE(0x202836))) /* Message Object 193 Data Register High High */


#define CAN_MODATA194HH (*(_PAGE_080_MEM_TYPE(0x202856))) /* Message Object 194 Data Register High High */


#define CAN_MODATA195HH (*(_PAGE_080_MEM_TYPE(0x202876))) /* Message Object 195 Data Register High High */


#define CAN_MODATA196HH (*(_PAGE_080_MEM_TYPE(0x202896))) /* Message Object 196 Data Register High High */


#define CAN_MODATA197HH (*(_PAGE_080_MEM_TYPE(0x2028B6))) /* Message Object 197 Data Register High High */


#define CAN_MODATA198HH (*(_PAGE_080_MEM_TYPE(0x2028D6))) /* Message Object 198 Data Register High High */


#define CAN_MODATA199HH (*(_PAGE_080_MEM_TYPE(0x2028F6))) /* Message Object 199 Data Register High High */


#define CAN_MODATA200HH (*(_PAGE_080_MEM_TYPE(0x202916))) /* Message Object 200 Data Register High High */


#define CAN_MODATA201HH (*(_PAGE_080_MEM_TYPE(0x202936))) /* Message Object 201 Data Register High High */


#define CAN_MODATA202HH (*(_PAGE_080_MEM_TYPE(0x202956))) /* Message Object 202 Data Register High High */


#define CAN_MODATA203HH (*(_PAGE_080_MEM_TYPE(0x202976))) /* Message Object 203 Data Register High High */


#define CAN_MODATA204HH (*(_PAGE_080_MEM_TYPE(0x202996))) /* Message Object 204 Data Register High High */


#define CAN_MODATA205HH (*(_PAGE_080_MEM_TYPE(0x2029B6))) /* Message Object 205 Data Register High High */


#define CAN_MODATA206HH (*(_PAGE_080_MEM_TYPE(0x2029D6))) /* Message Object 206 Data Register High High */


#define CAN_MODATA207HH (*(_PAGE_080_MEM_TYPE(0x2029F6))) /* Message Object 207 Data Register High High */


#define CAN_MODATA208HH (*(_PAGE_080_MEM_TYPE(0x202A16))) /* Message Object 208 Data Register High High */


#define CAN_MODATA209HH (*(_PAGE_080_MEM_TYPE(0x202A36))) /* Message Object 209 Data Register High High */


#define CAN_MODATA210HH (*(_PAGE_080_MEM_TYPE(0x202A56))) /* Message Object 210 Data Register High High */


#define CAN_MODATA211HH (*(_PAGE_080_MEM_TYPE(0x202A76))) /* Message Object 211 Data Register High High */


#define CAN_MODATA212HH (*(_PAGE_080_MEM_TYPE(0x202A96))) /* Message Object 212 Data Register High High */


#define CAN_MODATA213HH (*(_PAGE_080_MEM_TYPE(0x202AB6))) /* Message Object 213 Data Register High High */


#define CAN_MODATA214HH (*(_PAGE_080_MEM_TYPE(0x202AD6))) /* Message Object 214 Data Register High High */


#define CAN_MODATA215HH (*(_PAGE_080_MEM_TYPE(0x202AF6))) /* Message Object 215 Data Register High High */


#define CAN_MODATA216HH (*(_PAGE_080_MEM_TYPE(0x202B16))) /* Message Object 216 Data Register High High */


#define CAN_MODATA217HH (*(_PAGE_080_MEM_TYPE(0x202B36))) /* Message Object 217 Data Register High High */


#define CAN_MODATA218HH (*(_PAGE_080_MEM_TYPE(0x202B56))) /* Message Object 218 Data Register High High */


#define CAN_MODATA219HH (*(_PAGE_080_MEM_TYPE(0x202B76))) /* Message Object 219 Data Register High High */


#define CAN_MODATA220HH (*(_PAGE_080_MEM_TYPE(0x202B96))) /* Message Object 220 Data Register High High */


#define CAN_MODATA221HH (*(_PAGE_080_MEM_TYPE(0x202BB6))) /* Message Object 221 Data Register High High */


#define CAN_MODATA222HH (*(_PAGE_080_MEM_TYPE(0x202BD6))) /* Message Object 222 Data Register High High */


#define CAN_MODATA223HH (*(_PAGE_080_MEM_TYPE(0x202BF6))) /* Message Object 223 Data Register High High */


#define CAN_MODATA224HH (*(_PAGE_080_MEM_TYPE(0x202C16))) /* Message Object 224 Data Register High High */


#define CAN_MODATA225HH (*(_PAGE_080_MEM_TYPE(0x202C36))) /* Message Object 225 Data Register High High */


#define CAN_MODATA226HH (*(_PAGE_080_MEM_TYPE(0x202C56))) /* Message Object 226 Data Register High High */


#define CAN_MODATA227HH (*(_PAGE_080_MEM_TYPE(0x202C76))) /* Message Object 227 Data Register High High */


#define CAN_MODATA228HH (*(_PAGE_080_MEM_TYPE(0x202C96))) /* Message Object 228 Data Register High High */


#define CAN_MODATA229HH (*(_PAGE_080_MEM_TYPE(0x202CB6))) /* Message Object 229 Data Register High High */


#define CAN_MODATA230HH (*(_PAGE_080_MEM_TYPE(0x202CD6))) /* Message Object 230 Data Register High High */


#define CAN_MODATA231HH (*(_PAGE_080_MEM_TYPE(0x202CF6))) /* Message Object 231 Data Register High High */


#define CAN_MODATA232HH (*(_PAGE_080_MEM_TYPE(0x202D16))) /* Message Object 232 Data Register High High */


#define CAN_MODATA233HH (*(_PAGE_080_MEM_TYPE(0x202D36))) /* Message Object 233 Data Register High High */


#define CAN_MODATA234HH (*(_PAGE_080_MEM_TYPE(0x202D56))) /* Message Object 234 Data Register High High */


#define CAN_MODATA235HH (*(_PAGE_080_MEM_TYPE(0x202D76))) /* Message Object 235 Data Register High High */


#define CAN_MODATA236HH (*(_PAGE_080_MEM_TYPE(0x202D96))) /* Message Object 236 Data Register High High */


#define CAN_MODATA237HH (*(_PAGE_080_MEM_TYPE(0x202DB6))) /* Message Object 237 Data Register High High */


#define CAN_MODATA238HH (*(_PAGE_080_MEM_TYPE(0x202DD6))) /* Message Object 238 Data Register High High */


#define CAN_MODATA239HH (*(_PAGE_080_MEM_TYPE(0x202DF6))) /* Message Object 239 Data Register High High */


#define CAN_MODATA240HH (*(_PAGE_080_MEM_TYPE(0x202E16))) /* Message Object 240 Data Register High High */


#define CAN_MODATA241HH (*(_PAGE_080_MEM_TYPE(0x202E36))) /* Message Object 241 Data Register High High */


#define CAN_MODATA242HH (*(_PAGE_080_MEM_TYPE(0x202E56))) /* Message Object 242 Data Register High High */


#define CAN_MODATA243HH (*(_PAGE_080_MEM_TYPE(0x202E76))) /* Message Object 243 Data Register High High */


#define CAN_MODATA244HH (*(_PAGE_080_MEM_TYPE(0x202E96))) /* Message Object 244 Data Register High High */


#define CAN_MODATA245HH (*(_PAGE_080_MEM_TYPE(0x202EB6))) /* Message Object 245 Data Register High High */


#define CAN_MODATA246HH (*(_PAGE_080_MEM_TYPE(0x202ED6))) /* Message Object 246 Data Register High High */


#define CAN_MODATA247HH (*(_PAGE_080_MEM_TYPE(0x202EF6))) /* Message Object 247 Data Register High High */


#define CAN_MODATA248HH (*(_PAGE_080_MEM_TYPE(0x202F16))) /* Message Object 248 Data Register High High */


#define CAN_MODATA249HH (*(_PAGE_080_MEM_TYPE(0x202F36))) /* Message Object 249 Data Register High High */


#define CAN_MODATA250HH (*(_PAGE_080_MEM_TYPE(0x202F56))) /* Message Object 250 Data Register High High */


#define CAN_MODATA251HH (*(_PAGE_080_MEM_TYPE(0x202F76))) /* Message Object 251 Data Register High High */


#define CAN_MODATA252HH (*(_PAGE_080_MEM_TYPE(0x202F96))) /* Message Object 252 Data Register High High */


#define CAN_MODATA253HH (*(_PAGE_080_MEM_TYPE(0x202FB6))) /* Message Object 253 Data Register High High */


#define CAN_MODATA254HH (*(_PAGE_080_MEM_TYPE(0x202FD6))) /* Message Object 254 Data Register High High */


#define CAN_MODATA255HH (*(_PAGE_080_MEM_TYPE(0x202FF6))) /* Message Object 255 Data Register High High */


#define CAN_MODATA0HL   (*(_PAGE_080_MEM_TYPE(0x201014))) /* Message Object 0 Data Register High Low */


#define CAN_MODATA1HL   (*(_PAGE_080_MEM_TYPE(0x201034))) /* Message Object 1 Data Register High Low */


#define CAN_MODATA2HL   (*(_PAGE_080_MEM_TYPE(0x201054))) /* Message Object 2 Data Register High Low */


#define CAN_MODATA3HL   (*(_PAGE_080_MEM_TYPE(0x201074))) /* Message Object 3 Data Register High Low */


#define CAN_MODATA4HL   (*(_PAGE_080_MEM_TYPE(0x201094))) /* Message Object 4 Data Register High Low */


#define CAN_MODATA5HL   (*(_PAGE_080_MEM_TYPE(0x2010B4))) /* Message Object 5 Data Register High Low */


#define CAN_MODATA6HL   (*(_PAGE_080_MEM_TYPE(0x2010D4))) /* Message Object 6 Data Register High Low */


#define CAN_MODATA7HL   (*(_PAGE_080_MEM_TYPE(0x2010F4))) /* Message Object 7 Data Register High Low */


#define CAN_MODATA8HL   (*(_PAGE_080_MEM_TYPE(0x201114))) /* Message Object 8 Data Register High Low */


#define CAN_MODATA9HL   (*(_PAGE_080_MEM_TYPE(0x201134))) /* Message Object 9 Data Register High Low */


#define CAN_MODATA10HL  (*(_PAGE_080_MEM_TYPE(0x201154))) /* Message Object 10 Data Register High Low */


#define CAN_MODATA11HL  (*(_PAGE_080_MEM_TYPE(0x201174))) /* Message Object 11 Data Register High Low */


#define CAN_MODATA12HL  (*(_PAGE_080_MEM_TYPE(0x201194))) /* Message Object 12 Data Register High Low */


#define CAN_MODATA13HL  (*(_PAGE_080_MEM_TYPE(0x2011B4))) /* Message Object 13 Data Register High Low */


#define CAN_MODATA14HL  (*(_PAGE_080_MEM_TYPE(0x2011D4))) /* Message Object 14 Data Register High Low */


#define CAN_MODATA15HL  (*(_PAGE_080_MEM_TYPE(0x2011F4))) /* Message Object 15 Data Register High Low */


#define CAN_MODATA16HL  (*(_PAGE_080_MEM_TYPE(0x201214))) /* Message Object 16 Data Register High Low */


#define CAN_MODATA17HL  (*(_PAGE_080_MEM_TYPE(0x201234))) /* Message Object 17 Data Register High Low */


#define CAN_MODATA18HL  (*(_PAGE_080_MEM_TYPE(0x201254))) /* Message Object 18 Data Register High Low */


#define CAN_MODATA19HL  (*(_PAGE_080_MEM_TYPE(0x201274))) /* Message Object 19 Data Register High Low */


#define CAN_MODATA20HL  (*(_PAGE_080_MEM_TYPE(0x201294))) /* Message Object 20 Data Register High Low */


#define CAN_MODATA21HL  (*(_PAGE_080_MEM_TYPE(0x2012B4))) /* Message Object 21 Data Register High Low */


#define CAN_MODATA22HL  (*(_PAGE_080_MEM_TYPE(0x2012D4))) /* Message Object 22 Data Register High Low */


#define CAN_MODATA23HL  (*(_PAGE_080_MEM_TYPE(0x2012F4))) /* Message Object 23 Data Register High Low */


#define CAN_MODATA24HL  (*(_PAGE_080_MEM_TYPE(0x201314))) /* Message Object 24 Data Register High Low */


#define CAN_MODATA25HL  (*(_PAGE_080_MEM_TYPE(0x201334))) /* Message Object 25 Data Register High Low */


#define CAN_MODATA26HL  (*(_PAGE_080_MEM_TYPE(0x201354))) /* Message Object 26 Data Register High Low */


#define CAN_MODATA27HL  (*(_PAGE_080_MEM_TYPE(0x201374))) /* Message Object 27 Data Register High Low */


#define CAN_MODATA28HL  (*(_PAGE_080_MEM_TYPE(0x201394))) /* Message Object 28 Data Register High Low */


#define CAN_MODATA29HL  (*(_PAGE_080_MEM_TYPE(0x2013B4))) /* Message Object 29 Data Register High Low */


#define CAN_MODATA30HL  (*(_PAGE_080_MEM_TYPE(0x2013D4))) /* Message Object 30 Data Register High Low */


#define CAN_MODATA31HL  (*(_PAGE_080_MEM_TYPE(0x2013F4))) /* Message Object 31 Data Register High Low */


#define CAN_MODATA32HL  (*(_PAGE_080_MEM_TYPE(0x201414))) /* Message Object 32 Data Register High Low */


#define CAN_MODATA33HL  (*(_PAGE_080_MEM_TYPE(0x201434))) /* Message Object 33 Data Register High Low */


#define CAN_MODATA34HL  (*(_PAGE_080_MEM_TYPE(0x201454))) /* Message Object 34 Data Register High Low */


#define CAN_MODATA35HL  (*(_PAGE_080_MEM_TYPE(0x201474))) /* Message Object 35 Data Register High Low */


#define CAN_MODATA36HL  (*(_PAGE_080_MEM_TYPE(0x201494))) /* Message Object 36 Data Register High Low */


#define CAN_MODATA37HL  (*(_PAGE_080_MEM_TYPE(0x2014B4))) /* Message Object 37 Data Register High Low */


#define CAN_MODATA38HL  (*(_PAGE_080_MEM_TYPE(0x2014D4))) /* Message Object 38 Data Register High Low */


#define CAN_MODATA39HL  (*(_PAGE_080_MEM_TYPE(0x2014F4))) /* Message Object 39 Data Register High Low */


#define CAN_MODATA40HL  (*(_PAGE_080_MEM_TYPE(0x201514))) /* Message Object 40 Data Register High Low */


#define CAN_MODATA41HL  (*(_PAGE_080_MEM_TYPE(0x201534))) /* Message Object 41 Data Register High Low */


#define CAN_MODATA42HL  (*(_PAGE_080_MEM_TYPE(0x201554))) /* Message Object 42 Data Register High Low */


#define CAN_MODATA43HL  (*(_PAGE_080_MEM_TYPE(0x201574))) /* Message Object 43 Data Register High Low */


#define CAN_MODATA44HL  (*(_PAGE_080_MEM_TYPE(0x201594))) /* Message Object 44 Data Register High Low */


#define CAN_MODATA45HL  (*(_PAGE_080_MEM_TYPE(0x2015B4))) /* Message Object 45 Data Register High Low */


#define CAN_MODATA46HL  (*(_PAGE_080_MEM_TYPE(0x2015D4))) /* Message Object 46 Data Register High Low */


#define CAN_MODATA47HL  (*(_PAGE_080_MEM_TYPE(0x2015F4))) /* Message Object 47 Data Register High Low */


#define CAN_MODATA48HL  (*(_PAGE_080_MEM_TYPE(0x201614))) /* Message Object 48 Data Register High Low */


#define CAN_MODATA49HL  (*(_PAGE_080_MEM_TYPE(0x201634))) /* Message Object 49 Data Register High Low */


#define CAN_MODATA50HL  (*(_PAGE_080_MEM_TYPE(0x201654))) /* Message Object 50 Data Register High Low */


#define CAN_MODATA51HL  (*(_PAGE_080_MEM_TYPE(0x201674))) /* Message Object 51 Data Register High Low */


#define CAN_MODATA52HL  (*(_PAGE_080_MEM_TYPE(0x201694))) /* Message Object 52 Data Register High Low */


#define CAN_MODATA53HL  (*(_PAGE_080_MEM_TYPE(0x2016B4))) /* Message Object 53 Data Register High Low */


#define CAN_MODATA54HL  (*(_PAGE_080_MEM_TYPE(0x2016D4))) /* Message Object 54 Data Register High Low */


#define CAN_MODATA55HL  (*(_PAGE_080_MEM_TYPE(0x2016F4))) /* Message Object 55 Data Register High Low */


#define CAN_MODATA56HL  (*(_PAGE_080_MEM_TYPE(0x201714))) /* Message Object 56 Data Register High Low */


#define CAN_MODATA57HL  (*(_PAGE_080_MEM_TYPE(0x201734))) /* Message Object 57 Data Register High Low */


#define CAN_MODATA58HL  (*(_PAGE_080_MEM_TYPE(0x201754))) /* Message Object 58 Data Register High Low */


#define CAN_MODATA59HL  (*(_PAGE_080_MEM_TYPE(0x201774))) /* Message Object 59 Data Register High Low */


#define CAN_MODATA60HL  (*(_PAGE_080_MEM_TYPE(0x201794))) /* Message Object 60 Data Register High Low */


#define CAN_MODATA61HL  (*(_PAGE_080_MEM_TYPE(0x2017B4))) /* Message Object 61 Data Register High Low */


#define CAN_MODATA62HL  (*(_PAGE_080_MEM_TYPE(0x2017D4))) /* Message Object 62 Data Register High Low */


#define CAN_MODATA63HL  (*(_PAGE_080_MEM_TYPE(0x2017F4))) /* Message Object 63 Data Register High Low */


#define CAN_MODATA64HL  (*(_PAGE_080_MEM_TYPE(0x201814))) /* Message Object 64 Data Register High Low */


#define CAN_MODATA65HL  (*(_PAGE_080_MEM_TYPE(0x201834))) /* Message Object 65 Data Register High Low */


#define CAN_MODATA66HL  (*(_PAGE_080_MEM_TYPE(0x201854))) /* Message Object 66 Data Register High Low */


#define CAN_MODATA67HL  (*(_PAGE_080_MEM_TYPE(0x201874))) /* Message Object 67 Data Register High Low */


#define CAN_MODATA68HL  (*(_PAGE_080_MEM_TYPE(0x201894))) /* Message Object 68 Data Register High Low */


#define CAN_MODATA69HL  (*(_PAGE_080_MEM_TYPE(0x2018B4))) /* Message Object 69 Data Register High Low */


#define CAN_MODATA70HL  (*(_PAGE_080_MEM_TYPE(0x2018D4))) /* Message Object 70 Data Register High Low */


#define CAN_MODATA71HL  (*(_PAGE_080_MEM_TYPE(0x2018F4))) /* Message Object 71 Data Register High Low */


#define CAN_MODATA72HL  (*(_PAGE_080_MEM_TYPE(0x201914))) /* Message Object 72 Data Register High Low */


#define CAN_MODATA73HL  (*(_PAGE_080_MEM_TYPE(0x201934))) /* Message Object 73 Data Register High Low */


#define CAN_MODATA74HL  (*(_PAGE_080_MEM_TYPE(0x201954))) /* Message Object 74 Data Register High Low */


#define CAN_MODATA75HL  (*(_PAGE_080_MEM_TYPE(0x201974))) /* Message Object 75 Data Register High Low */


#define CAN_MODATA76HL  (*(_PAGE_080_MEM_TYPE(0x201994))) /* Message Object 76 Data Register High Low */


#define CAN_MODATA77HL  (*(_PAGE_080_MEM_TYPE(0x2019B4))) /* Message Object 77 Data Register High Low */


#define CAN_MODATA78HL  (*(_PAGE_080_MEM_TYPE(0x2019D4))) /* Message Object 78 Data Register High Low */


#define CAN_MODATA79HL  (*(_PAGE_080_MEM_TYPE(0x2019F4))) /* Message Object 79 Data Register High Low */


#define CAN_MODATA80HL  (*(_PAGE_080_MEM_TYPE(0x201A14))) /* Message Object 80 Data Register High Low */


#define CAN_MODATA81HL  (*(_PAGE_080_MEM_TYPE(0x201A34))) /* Message Object 81 Data Register High Low */


#define CAN_MODATA82HL  (*(_PAGE_080_MEM_TYPE(0x201A54))) /* Message Object 82 Data Register High Low */


#define CAN_MODATA83HL  (*(_PAGE_080_MEM_TYPE(0x201A74))) /* Message Object 83 Data Register High Low */


#define CAN_MODATA84HL  (*(_PAGE_080_MEM_TYPE(0x201A94))) /* Message Object 84 Data Register High Low */


#define CAN_MODATA85HL  (*(_PAGE_080_MEM_TYPE(0x201AB4))) /* Message Object 85 Data Register High Low */


#define CAN_MODATA86HL  (*(_PAGE_080_MEM_TYPE(0x201AD4))) /* Message Object 86 Data Register High Low */


#define CAN_MODATA87HL  (*(_PAGE_080_MEM_TYPE(0x201AF4))) /* Message Object 87 Data Register High Low */


#define CAN_MODATA88HL  (*(_PAGE_080_MEM_TYPE(0x201B14))) /* Message Object 88 Data Register High Low */


#define CAN_MODATA89HL  (*(_PAGE_080_MEM_TYPE(0x201B34))) /* Message Object 89 Data Register High Low */


#define CAN_MODATA90HL  (*(_PAGE_080_MEM_TYPE(0x201B54))) /* Message Object 90 Data Register High Low */


#define CAN_MODATA91HL  (*(_PAGE_080_MEM_TYPE(0x201B74))) /* Message Object 91 Data Register High Low */


#define CAN_MODATA92HL  (*(_PAGE_080_MEM_TYPE(0x201B94))) /* Message Object 92 Data Register High Low */


#define CAN_MODATA93HL  (*(_PAGE_080_MEM_TYPE(0x201BB4))) /* Message Object 93 Data Register High Low */


#define CAN_MODATA94HL  (*(_PAGE_080_MEM_TYPE(0x201BD4))) /* Message Object 94 Data Register High Low */


#define CAN_MODATA95HL  (*(_PAGE_080_MEM_TYPE(0x201BF4))) /* Message Object 95 Data Register High Low */


#define CAN_MODATA96HL  (*(_PAGE_080_MEM_TYPE(0x201C14))) /* Message Object 96 Data Register High Low */


#define CAN_MODATA97HL  (*(_PAGE_080_MEM_TYPE(0x201C34))) /* Message Object 97 Data Register High Low */


#define CAN_MODATA98HL  (*(_PAGE_080_MEM_TYPE(0x201C54))) /* Message Object 98 Data Register High Low */


#define CAN_MODATA99HL  (*(_PAGE_080_MEM_TYPE(0x201C74))) /* Message Object 99 Data Register High Low */


#define CAN_MODATA100HL (*(_PAGE_080_MEM_TYPE(0x201C94))) /* Message Object 100 Data Register High Low */


#define CAN_MODATA101HL (*(_PAGE_080_MEM_TYPE(0x201CB4))) /* Message Object 101 Data Register High Low */


#define CAN_MODATA102HL (*(_PAGE_080_MEM_TYPE(0x201CD4))) /* Message Object 102 Data Register High Low */


#define CAN_MODATA103HL (*(_PAGE_080_MEM_TYPE(0x201CF4))) /* Message Object 103 Data Register High Low */


#define CAN_MODATA104HL (*(_PAGE_080_MEM_TYPE(0x201D14))) /* Message Object 104 Data Register High Low */


#define CAN_MODATA105HL (*(_PAGE_080_MEM_TYPE(0x201D34))) /* Message Object 105 Data Register High Low */


#define CAN_MODATA106HL (*(_PAGE_080_MEM_TYPE(0x201D54))) /* Message Object 106 Data Register High Low */


#define CAN_MODATA107HL (*(_PAGE_080_MEM_TYPE(0x201D74))) /* Message Object 107 Data Register High Low */


#define CAN_MODATA108HL (*(_PAGE_080_MEM_TYPE(0x201D94))) /* Message Object 108 Data Register High Low */


#define CAN_MODATA109HL (*(_PAGE_080_MEM_TYPE(0x201DB4))) /* Message Object 109 Data Register High Low */


#define CAN_MODATA110HL (*(_PAGE_080_MEM_TYPE(0x201DD4))) /* Message Object 110 Data Register High Low */


#define CAN_MODATA111HL (*(_PAGE_080_MEM_TYPE(0x201DF4))) /* Message Object 111 Data Register High Low */


#define CAN_MODATA112HL (*(_PAGE_080_MEM_TYPE(0x201E14))) /* Message Object 112 Data Register High Low */


#define CAN_MODATA113HL (*(_PAGE_080_MEM_TYPE(0x201E34))) /* Message Object 113 Data Register High Low */


#define CAN_MODATA114HL (*(_PAGE_080_MEM_TYPE(0x201E54))) /* Message Object 114 Data Register High Low */


#define CAN_MODATA115HL (*(_PAGE_080_MEM_TYPE(0x201E74))) /* Message Object 115 Data Register High Low */


#define CAN_MODATA116HL (*(_PAGE_080_MEM_TYPE(0x201E94))) /* Message Object 116 Data Register High Low */


#define CAN_MODATA117HL (*(_PAGE_080_MEM_TYPE(0x201EB4))) /* Message Object 117 Data Register High Low */


#define CAN_MODATA118HL (*(_PAGE_080_MEM_TYPE(0x201ED4))) /* Message Object 118 Data Register High Low */


#define CAN_MODATA119HL (*(_PAGE_080_MEM_TYPE(0x201EF4))) /* Message Object 119 Data Register High Low */


#define CAN_MODATA120HL (*(_PAGE_080_MEM_TYPE(0x201F14))) /* Message Object 120 Data Register High Low */


#define CAN_MODATA121HL (*(_PAGE_080_MEM_TYPE(0x201F34))) /* Message Object 121 Data Register High Low */


#define CAN_MODATA122HL (*(_PAGE_080_MEM_TYPE(0x201F54))) /* Message Object 122 Data Register High Low */


#define CAN_MODATA123HL (*(_PAGE_080_MEM_TYPE(0x201F74))) /* Message Object 123 Data Register High Low */


#define CAN_MODATA124HL (*(_PAGE_080_MEM_TYPE(0x201F94))) /* Message Object 124 Data Register High Low */


#define CAN_MODATA125HL (*(_PAGE_080_MEM_TYPE(0x201FB4))) /* Message Object 125 Data Register High Low */


#define CAN_MODATA126HL (*(_PAGE_080_MEM_TYPE(0x201FD4))) /* Message Object 126 Data Register High Low */


#define CAN_MODATA127HL (*(_PAGE_080_MEM_TYPE(0x201FF4))) /* Message Object 127 Data Register High Low */


#define CAN_MODATA128HL (*(_PAGE_080_MEM_TYPE(0x202014))) /* Message Object 128 Data Register High Low */


#define CAN_MODATA129HL (*(_PAGE_080_MEM_TYPE(0x202034))) /* Message Object 129 Data Register High Low */


#define CAN_MODATA130HL (*(_PAGE_080_MEM_TYPE(0x202054))) /* Message Object 130 Data Register High Low */


#define CAN_MODATA131HL (*(_PAGE_080_MEM_TYPE(0x202074))) /* Message Object 131 Data Register High Low */


#define CAN_MODATA132HL (*(_PAGE_080_MEM_TYPE(0x202094))) /* Message Object 132 Data Register High Low */


#define CAN_MODATA133HL (*(_PAGE_080_MEM_TYPE(0x2020B4))) /* Message Object 133 Data Register High Low */


#define CAN_MODATA134HL (*(_PAGE_080_MEM_TYPE(0x2020D4))) /* Message Object 134 Data Register High Low */


#define CAN_MODATA135HL (*(_PAGE_080_MEM_TYPE(0x2020F4))) /* Message Object 135 Data Register High Low */


#define CAN_MODATA136HL (*(_PAGE_080_MEM_TYPE(0x202114))) /* Message Object 136 Data Register High Low */


#define CAN_MODATA137HL (*(_PAGE_080_MEM_TYPE(0x202134))) /* Message Object 137 Data Register High Low */


#define CAN_MODATA138HL (*(_PAGE_080_MEM_TYPE(0x202154))) /* Message Object 138 Data Register High Low */


#define CAN_MODATA139HL (*(_PAGE_080_MEM_TYPE(0x202174))) /* Message Object 139 Data Register High Low */


#define CAN_MODATA140HL (*(_PAGE_080_MEM_TYPE(0x202194))) /* Message Object 140 Data Register High Low */


#define CAN_MODATA141HL (*(_PAGE_080_MEM_TYPE(0x2021B4))) /* Message Object 141 Data Register High Low */


#define CAN_MODATA142HL (*(_PAGE_080_MEM_TYPE(0x2021D4))) /* Message Object 142 Data Register High Low */


#define CAN_MODATA143HL (*(_PAGE_080_MEM_TYPE(0x2021F4))) /* Message Object 143 Data Register High Low */


#define CAN_MODATA144HL (*(_PAGE_080_MEM_TYPE(0x202214))) /* Message Object 144 Data Register High Low */


#define CAN_MODATA145HL (*(_PAGE_080_MEM_TYPE(0x202234))) /* Message Object 145 Data Register High Low */


#define CAN_MODATA146HL (*(_PAGE_080_MEM_TYPE(0x202254))) /* Message Object 146 Data Register High Low */


#define CAN_MODATA147HL (*(_PAGE_080_MEM_TYPE(0x202274))) /* Message Object 147 Data Register High Low */


#define CAN_MODATA148HL (*(_PAGE_080_MEM_TYPE(0x202294))) /* Message Object 148 Data Register High Low */


#define CAN_MODATA149HL (*(_PAGE_080_MEM_TYPE(0x2022B4))) /* Message Object 149 Data Register High Low */


#define CAN_MODATA150HL (*(_PAGE_080_MEM_TYPE(0x2022D4))) /* Message Object 150 Data Register High Low */


#define CAN_MODATA151HL (*(_PAGE_080_MEM_TYPE(0x2022F4))) /* Message Object 151 Data Register High Low */


#define CAN_MODATA152HL (*(_PAGE_080_MEM_TYPE(0x202314))) /* Message Object 152 Data Register High Low */


#define CAN_MODATA153HL (*(_PAGE_080_MEM_TYPE(0x202334))) /* Message Object 153 Data Register High Low */


#define CAN_MODATA154HL (*(_PAGE_080_MEM_TYPE(0x202354))) /* Message Object 154 Data Register High Low */


#define CAN_MODATA155HL (*(_PAGE_080_MEM_TYPE(0x202374))) /* Message Object 155 Data Register High Low */


#define CAN_MODATA156HL (*(_PAGE_080_MEM_TYPE(0x202394))) /* Message Object 156 Data Register High Low */


#define CAN_MODATA157HL (*(_PAGE_080_MEM_TYPE(0x2023B4))) /* Message Object 157 Data Register High Low */


#define CAN_MODATA158HL (*(_PAGE_080_MEM_TYPE(0x2023D4))) /* Message Object 158 Data Register High Low */


#define CAN_MODATA159HL (*(_PAGE_080_MEM_TYPE(0x2023F4))) /* Message Object 159 Data Register High Low */


#define CAN_MODATA160HL (*(_PAGE_080_MEM_TYPE(0x202414))) /* Message Object 160 Data Register High Low */


#define CAN_MODATA161HL (*(_PAGE_080_MEM_TYPE(0x202434))) /* Message Object 161 Data Register High Low */


#define CAN_MODATA162HL (*(_PAGE_080_MEM_TYPE(0x202454))) /* Message Object 162 Data Register High Low */


#define CAN_MODATA163HL (*(_PAGE_080_MEM_TYPE(0x202474))) /* Message Object 163 Data Register High Low */


#define CAN_MODATA164HL (*(_PAGE_080_MEM_TYPE(0x202494))) /* Message Object 164 Data Register High Low */


#define CAN_MODATA165HL (*(_PAGE_080_MEM_TYPE(0x2024B4))) /* Message Object 165 Data Register High Low */


#define CAN_MODATA166HL (*(_PAGE_080_MEM_TYPE(0x2024D4))) /* Message Object 166 Data Register High Low */


#define CAN_MODATA167HL (*(_PAGE_080_MEM_TYPE(0x2024F4))) /* Message Object 167 Data Register High Low */


#define CAN_MODATA168HL (*(_PAGE_080_MEM_TYPE(0x202514))) /* Message Object 168 Data Register High Low */


#define CAN_MODATA169HL (*(_PAGE_080_MEM_TYPE(0x202534))) /* Message Object 169 Data Register High Low */


#define CAN_MODATA170HL (*(_PAGE_080_MEM_TYPE(0x202554))) /* Message Object 170 Data Register High Low */


#define CAN_MODATA171HL (*(_PAGE_080_MEM_TYPE(0x202574))) /* Message Object 171 Data Register High Low */


#define CAN_MODATA172HL (*(_PAGE_080_MEM_TYPE(0x202594))) /* Message Object 172 Data Register High Low */


#define CAN_MODATA173HL (*(_PAGE_080_MEM_TYPE(0x2025B4))) /* Message Object 173 Data Register High Low */


#define CAN_MODATA174HL (*(_PAGE_080_MEM_TYPE(0x2025D4))) /* Message Object 174 Data Register High Low */


#define CAN_MODATA175HL (*(_PAGE_080_MEM_TYPE(0x2025F4))) /* Message Object 175 Data Register High Low */


#define CAN_MODATA176HL (*(_PAGE_080_MEM_TYPE(0x202614))) /* Message Object 176 Data Register High Low */


#define CAN_MODATA177HL (*(_PAGE_080_MEM_TYPE(0x202634))) /* Message Object 177 Data Register High Low */


#define CAN_MODATA178HL (*(_PAGE_080_MEM_TYPE(0x202654))) /* Message Object 178 Data Register High Low */


#define CAN_MODATA179HL (*(_PAGE_080_MEM_TYPE(0x202674))) /* Message Object 179 Data Register High Low */


#define CAN_MODATA180HL (*(_PAGE_080_MEM_TYPE(0x202694))) /* Message Object 180 Data Register High Low */


#define CAN_MODATA181HL (*(_PAGE_080_MEM_TYPE(0x2026B4))) /* Message Object 181 Data Register High Low */


#define CAN_MODATA182HL (*(_PAGE_080_MEM_TYPE(0x2026D4))) /* Message Object 182 Data Register High Low */


#define CAN_MODATA183HL (*(_PAGE_080_MEM_TYPE(0x2026F4))) /* Message Object 183 Data Register High Low */


#define CAN_MODATA184HL (*(_PAGE_080_MEM_TYPE(0x202714))) /* Message Object 184 Data Register High Low */


#define CAN_MODATA185HL (*(_PAGE_080_MEM_TYPE(0x202734))) /* Message Object 185 Data Register High Low */


#define CAN_MODATA186HL (*(_PAGE_080_MEM_TYPE(0x202754))) /* Message Object 186 Data Register High Low */


#define CAN_MODATA187HL (*(_PAGE_080_MEM_TYPE(0x202774))) /* Message Object 187 Data Register High Low */


#define CAN_MODATA188HL (*(_PAGE_080_MEM_TYPE(0x202794))) /* Message Object 188 Data Register High Low */


#define CAN_MODATA189HL (*(_PAGE_080_MEM_TYPE(0x2027B4))) /* Message Object 189 Data Register High Low */


#define CAN_MODATA190HL (*(_PAGE_080_MEM_TYPE(0x2027D4))) /* Message Object 190 Data Register High Low */


#define CAN_MODATA191HL (*(_PAGE_080_MEM_TYPE(0x2027F4))) /* Message Object 191 Data Register High Low */


#define CAN_MODATA192HL (*(_PAGE_080_MEM_TYPE(0x202814))) /* Message Object 192 Data Register High Low */


#define CAN_MODATA193HL (*(_PAGE_080_MEM_TYPE(0x202834))) /* Message Object 193 Data Register High Low */


#define CAN_MODATA194HL (*(_PAGE_080_MEM_TYPE(0x202854))) /* Message Object 194 Data Register High Low */


#define CAN_MODATA195HL (*(_PAGE_080_MEM_TYPE(0x202874))) /* Message Object 195 Data Register High Low */


#define CAN_MODATA196HL (*(_PAGE_080_MEM_TYPE(0x202894))) /* Message Object 196 Data Register High Low */


#define CAN_MODATA197HL (*(_PAGE_080_MEM_TYPE(0x2028B4))) /* Message Object 197 Data Register High Low */


#define CAN_MODATA198HL (*(_PAGE_080_MEM_TYPE(0x2028D4))) /* Message Object 198 Data Register High Low */


#define CAN_MODATA199HL (*(_PAGE_080_MEM_TYPE(0x2028F4))) /* Message Object 199 Data Register High Low */


#define CAN_MODATA200HL (*(_PAGE_080_MEM_TYPE(0x202914))) /* Message Object 200 Data Register High Low */


#define CAN_MODATA201HL (*(_PAGE_080_MEM_TYPE(0x202934))) /* Message Object 201 Data Register High Low */


#define CAN_MODATA202HL (*(_PAGE_080_MEM_TYPE(0x202954))) /* Message Object 202 Data Register High Low */


#define CAN_MODATA203HL (*(_PAGE_080_MEM_TYPE(0x202974))) /* Message Object 203 Data Register High Low */


#define CAN_MODATA204HL (*(_PAGE_080_MEM_TYPE(0x202994))) /* Message Object 204 Data Register High Low */


#define CAN_MODATA205HL (*(_PAGE_080_MEM_TYPE(0x2029B4))) /* Message Object 205 Data Register High Low */


#define CAN_MODATA206HL (*(_PAGE_080_MEM_TYPE(0x2029D4))) /* Message Object 206 Data Register High Low */


#define CAN_MODATA207HL (*(_PAGE_080_MEM_TYPE(0x2029F4))) /* Message Object 207 Data Register High Low */


#define CAN_MODATA208HL (*(_PAGE_080_MEM_TYPE(0x202A14))) /* Message Object 208 Data Register High Low */


#define CAN_MODATA209HL (*(_PAGE_080_MEM_TYPE(0x202A34))) /* Message Object 209 Data Register High Low */


#define CAN_MODATA210HL (*(_PAGE_080_MEM_TYPE(0x202A54))) /* Message Object 210 Data Register High Low */


#define CAN_MODATA211HL (*(_PAGE_080_MEM_TYPE(0x202A74))) /* Message Object 211 Data Register High Low */


#define CAN_MODATA212HL (*(_PAGE_080_MEM_TYPE(0x202A94))) /* Message Object 212 Data Register High Low */


#define CAN_MODATA213HL (*(_PAGE_080_MEM_TYPE(0x202AB4))) /* Message Object 213 Data Register High Low */


#define CAN_MODATA214HL (*(_PAGE_080_MEM_TYPE(0x202AD4))) /* Message Object 214 Data Register High Low */


#define CAN_MODATA215HL (*(_PAGE_080_MEM_TYPE(0x202AF4))) /* Message Object 215 Data Register High Low */


#define CAN_MODATA216HL (*(_PAGE_080_MEM_TYPE(0x202B14))) /* Message Object 216 Data Register High Low */


#define CAN_MODATA217HL (*(_PAGE_080_MEM_TYPE(0x202B34))) /* Message Object 217 Data Register High Low */


#define CAN_MODATA218HL (*(_PAGE_080_MEM_TYPE(0x202B54))) /* Message Object 218 Data Register High Low */


#define CAN_MODATA219HL (*(_PAGE_080_MEM_TYPE(0x202B74))) /* Message Object 219 Data Register High Low */


#define CAN_MODATA220HL (*(_PAGE_080_MEM_TYPE(0x202B94))) /* Message Object 220 Data Register High Low */


#define CAN_MODATA221HL (*(_PAGE_080_MEM_TYPE(0x202BB4))) /* Message Object 221 Data Register High Low */


#define CAN_MODATA222HL (*(_PAGE_080_MEM_TYPE(0x202BD4))) /* Message Object 222 Data Register High Low */


#define CAN_MODATA223HL (*(_PAGE_080_MEM_TYPE(0x202BF4))) /* Message Object 223 Data Register High Low */


#define CAN_MODATA224HL (*(_PAGE_080_MEM_TYPE(0x202C14))) /* Message Object 224 Data Register High Low */


#define CAN_MODATA225HL (*(_PAGE_080_MEM_TYPE(0x202C34))) /* Message Object 225 Data Register High Low */


#define CAN_MODATA226HL (*(_PAGE_080_MEM_TYPE(0x202C54))) /* Message Object 226 Data Register High Low */


#define CAN_MODATA227HL (*(_PAGE_080_MEM_TYPE(0x202C74))) /* Message Object 227 Data Register High Low */


#define CAN_MODATA228HL (*(_PAGE_080_MEM_TYPE(0x202C94))) /* Message Object 228 Data Register High Low */


#define CAN_MODATA229HL (*(_PAGE_080_MEM_TYPE(0x202CB4))) /* Message Object 229 Data Register High Low */


#define CAN_MODATA230HL (*(_PAGE_080_MEM_TYPE(0x202CD4))) /* Message Object 230 Data Register High Low */


#define CAN_MODATA231HL (*(_PAGE_080_MEM_TYPE(0x202CF4))) /* Message Object 231 Data Register High Low */


#define CAN_MODATA232HL (*(_PAGE_080_MEM_TYPE(0x202D14))) /* Message Object 232 Data Register High Low */


#define CAN_MODATA233HL (*(_PAGE_080_MEM_TYPE(0x202D34))) /* Message Object 233 Data Register High Low */


#define CAN_MODATA234HL (*(_PAGE_080_MEM_TYPE(0x202D54))) /* Message Object 234 Data Register High Low */


#define CAN_MODATA235HL (*(_PAGE_080_MEM_TYPE(0x202D74))) /* Message Object 235 Data Register High Low */


#define CAN_MODATA236HL (*(_PAGE_080_MEM_TYPE(0x202D94))) /* Message Object 236 Data Register High Low */


#define CAN_MODATA237HL (*(_PAGE_080_MEM_TYPE(0x202DB4))) /* Message Object 237 Data Register High Low */


#define CAN_MODATA238HL (*(_PAGE_080_MEM_TYPE(0x202DD4))) /* Message Object 238 Data Register High Low */


#define CAN_MODATA239HL (*(_PAGE_080_MEM_TYPE(0x202DF4))) /* Message Object 239 Data Register High Low */


#define CAN_MODATA240HL (*(_PAGE_080_MEM_TYPE(0x202E14))) /* Message Object 240 Data Register High Low */


#define CAN_MODATA241HL (*(_PAGE_080_MEM_TYPE(0x202E34))) /* Message Object 241 Data Register High Low */


#define CAN_MODATA242HL (*(_PAGE_080_MEM_TYPE(0x202E54))) /* Message Object 242 Data Register High Low */


#define CAN_MODATA243HL (*(_PAGE_080_MEM_TYPE(0x202E74))) /* Message Object 243 Data Register High Low */


#define CAN_MODATA244HL (*(_PAGE_080_MEM_TYPE(0x202E94))) /* Message Object 244 Data Register High Low */


#define CAN_MODATA245HL (*(_PAGE_080_MEM_TYPE(0x202EB4))) /* Message Object 245 Data Register High Low */


#define CAN_MODATA246HL (*(_PAGE_080_MEM_TYPE(0x202ED4))) /* Message Object 246 Data Register High Low */


#define CAN_MODATA247HL (*(_PAGE_080_MEM_TYPE(0x202EF4))) /* Message Object 247 Data Register High Low */


#define CAN_MODATA248HL (*(_PAGE_080_MEM_TYPE(0x202F14))) /* Message Object 248 Data Register High Low */


#define CAN_MODATA249HL (*(_PAGE_080_MEM_TYPE(0x202F34))) /* Message Object 249 Data Register High Low */


#define CAN_MODATA250HL (*(_PAGE_080_MEM_TYPE(0x202F54))) /* Message Object 250 Data Register High Low */


#define CAN_MODATA251HL (*(_PAGE_080_MEM_TYPE(0x202F74))) /* Message Object 251 Data Register High Low */


#define CAN_MODATA252HL (*(_PAGE_080_MEM_TYPE(0x202F94))) /* Message Object 252 Data Register High Low */


#define CAN_MODATA253HL (*(_PAGE_080_MEM_TYPE(0x202FB4))) /* Message Object 253 Data Register High Low */


#define CAN_MODATA254HL (*(_PAGE_080_MEM_TYPE(0x202FD4))) /* Message Object 254 Data Register High Low */


#define CAN_MODATA255HL (*(_PAGE_080_MEM_TYPE(0x202FF4))) /* Message Object 255 Data Register High Low */


#define CAN_FDRL        (*(_PAGE_080_MEM_TYPE(0x20000C))) /* Fractional Divider Register L */


#define CAN_FDRH        (*(_PAGE_080_MEM_TYPE(0x20000E))) /* Fractional Divider Register H */

#endif /* REGXC2361E_NOMULTICAN */

/********************************************************************************
 * MULTICAN
********************************************************************************/
#ifndef REGXC2361E_NOMULTICAN

_sfr CAN_KSCCFG;                        /* Kernel State Configuration Register */

#endif /* REGXC2361E_NOMULTICAN */

/********************************************************************************
 * ERAY
********************************************************************************/
#ifndef REGXC2361E_NOERAY


#define ERAY_IDL        (*(_PAGE_081_MEM_TYPE(0x207008))) /* Module Identification Register Low */


#define ERAY_IDH        (*(_PAGE_081_MEM_TYPE(0x20700A))) /* Module Identification Register High */


#define ERAY_CUST1L     (*(_PAGE_081_MEM_TYPE(0x207004))) /* Busy and Input Buffer Control Register Low */


#define ERAY_CUST3L     (*(_PAGE_081_MEM_TYPE(0x20700C))) /* Customer Interface Timeout Counter Low */


#define ERAY_CUST3H     (*(_PAGE_081_MEM_TYPE(0x20700E))) /* Customer Interface Timeout Counter High */


#define ERAY_TEST1L     (*(_PAGE_081_MEM_TYPE(0x207010))) /* Test Register 1 Low */


#define ERAY_TEST1H     (*(_PAGE_081_MEM_TYPE(0x207012))) /* Test Register 1 High */


#define ERAY_TEST2L     (*(_PAGE_081_MEM_TYPE(0x207014))) /* Test Register 2 Low */


#define ERAY_SECCONL    (*(_PAGE_081_MEM_TYPE(0x207800))) /* SEC Control Low */


#define ERAY_SEDCONL    (*(_PAGE_081_MEM_TYPE(0x207804))) /* SED Control Low */


#define ERAY_DEDCONL    (*(_PAGE_081_MEM_TYPE(0x207808))) /* DED Control Low */


#define ERAY_ECCRL      (*(_PAGE_081_MEM_TYPE(0x20780C))) /* ECC Data Read Register Low */


#define ERAY_ECCWL      (*(_PAGE_081_MEM_TYPE(0x207810))) /* ECC Data Write Register Low */


#define ERAY_LCKL       (*(_PAGE_081_MEM_TYPE(0x20701C))) /* Lock Register Low */


#define ERAY_EIRL       (*(_PAGE_081_MEM_TYPE(0x207020))) /* Error Service Request Register Low */


#define ERAY_EIRH       (*(_PAGE_081_MEM_TYPE(0x207022))) /* Error Service Request Register High */


#define ERAY_SIRL       (*(_PAGE_081_MEM_TYPE(0x207024))) /* Status Service Request Register Low */


#define ERAY_SIRH       (*(_PAGE_081_MEM_TYPE(0x207026))) /* Status Service Request Register High */


#define ERAY_EILSL      (*(_PAGE_081_MEM_TYPE(0x207028))) /* Error Service Request Line Select Low */


#define ERAY_EILSH      (*(_PAGE_081_MEM_TYPE(0x20702A))) /* Error Service Request Line Select High */


#define ERAY_SILSL      (*(_PAGE_081_MEM_TYPE(0x20702C))) /* Status Service Request Line Select Low */


#define ERAY_SILSH      (*(_PAGE_081_MEM_TYPE(0x20702E))) /* Status Service Request Line Select High */


#define ERAY_EIESL      (*(_PAGE_081_MEM_TYPE(0x207030))) /* Error Service Request Enable Set Low */


#define ERAY_EIESH      (*(_PAGE_081_MEM_TYPE(0x207032))) /* Error Service Request Enable Set High */


#define ERAY_EIERL      (*(_PAGE_081_MEM_TYPE(0x207034))) /* Error Service Request Enable Reset Low */


#define ERAY_EIERH      (*(_PAGE_081_MEM_TYPE(0x207036))) /* Error Service Request Enable Reset High */


#define ERAY_SIESL      (*(_PAGE_081_MEM_TYPE(0x207038))) /* Status Service Request Enable Set Low */


#define ERAY_SIESH      (*(_PAGE_081_MEM_TYPE(0x20703A))) /* Status Service Request Enable Set High */


#define ERAY_SIERL      (*(_PAGE_081_MEM_TYPE(0x20703C))) /* Status Service Request Enable Reset Low */


#define ERAY_SIERH      (*(_PAGE_081_MEM_TYPE(0x20703E))) /* Status Service Request Enable Reset High */


#define ERAY_ILEL       (*(_PAGE_081_MEM_TYPE(0x207040))) /* Service Request Line Enable Low */


#define ERAY_T0CL       (*(_PAGE_081_MEM_TYPE(0x207044))) /* Timer 0 Configuration Low */


#define ERAY_T0CH       (*(_PAGE_081_MEM_TYPE(0x207046))) /* Timer 0 Configuration High */


#define ERAY_T1CL       (*(_PAGE_081_MEM_TYPE(0x207048))) /* Timer 1 Configuration Low */


#define ERAY_T1CH       (*(_PAGE_081_MEM_TYPE(0x20704A))) /* Timer 1 Configuration High */


#define ERAY_STPW1L     (*(_PAGE_081_MEM_TYPE(0x20704C))) /* Stop Watch Register 1 Low */


#define ERAY_STPW1H     (*(_PAGE_081_MEM_TYPE(0x20704E))) /* Stop Watch Register 1High */


#define ERAY_STPW2L     (*(_PAGE_081_MEM_TYPE(0x207050))) /* Stop Watch Register 2 Low */


#define ERAY_STPW2H     (*(_PAGE_081_MEM_TYPE(0x207052))) /* Stop Watch Register 2 High */


#define ERAY_SUCC1L     (*(_PAGE_081_MEM_TYPE(0x207080))) /* SUC Configuration Register 1 Low */


#define ERAY_SUCC1H     (*(_PAGE_081_MEM_TYPE(0x207082))) /* SUC Configuration Register 1 High */


#define ERAY_SUCC2L     (*(_PAGE_081_MEM_TYPE(0x207084))) /* SUC Configuration Register 2 Low */


#define ERAY_SUCC2H     (*(_PAGE_081_MEM_TYPE(0x207086))) /* SUC Configuration Register 2 High */


#define ERAY_SUCC3L     (*(_PAGE_081_MEM_TYPE(0x207088))) /* SUC Configuration Register 3 Low */


#define ERAY_NEMCL      (*(_PAGE_081_MEM_TYPE(0x20708C))) /* NEM Configuration Register Low */


#define ERAY_PRTC1L     (*(_PAGE_081_MEM_TYPE(0x207090))) /* PRT Configuration Register 1 Low */


#define ERAY_PRTC1H     (*(_PAGE_081_MEM_TYPE(0x207092))) /* PRT Configuration Register 1 High */


#define ERAY_PRTC2L     (*(_PAGE_081_MEM_TYPE(0x207094))) /* PRT Configuration Register 2 Low */


#define ERAY_PRTC2H     (*(_PAGE_081_MEM_TYPE(0x207096))) /* PRT Configuration Register 2 High */


#define ERAY_MHDCL      (*(_PAGE_081_MEM_TYPE(0x207098))) /* MHD Configuration Register Low */


#define ERAY_MHDCH      (*(_PAGE_081_MEM_TYPE(0x20709A))) /* MHD Configuration Register High */


#define ERAY_GTUC01L    (*(_PAGE_081_MEM_TYPE(0x2070A0))) /* GTU Configuration Register 1Low */


#define ERAY_GTUC01H    (*(_PAGE_081_MEM_TYPE(0x2070A2))) /* GTU Configuration Register 1High */


#define ERAY_GTUC02L    (*(_PAGE_081_MEM_TYPE(0x2070A4))) /* GTU Configuration Register 2 Low */


#define ERAY_GTUC02H    (*(_PAGE_081_MEM_TYPE(0x2070A6))) /* GTU Configuration Register 2 High */


#define ERAY_GTUC03L    (*(_PAGE_081_MEM_TYPE(0x2070A8))) /* GTU Configuration Register 3 Low */


#define ERAY_GTUC03H    (*(_PAGE_081_MEM_TYPE(0x2070AA))) /* GTU Configuration Register 3 High */


#define ERAY_GTUC04L    (*(_PAGE_081_MEM_TYPE(0x2070AC))) /* GTU Configuration Register 4 Low */


#define ERAY_GTUC04H    (*(_PAGE_081_MEM_TYPE(0x2070AE))) /* GTU Configuration Register 4 High */


#define ERAY_GTUC05L    (*(_PAGE_081_MEM_TYPE(0x2070B0))) /* GTU Configuration Register 5 Low */


#define ERAY_GTUC05H    (*(_PAGE_081_MEM_TYPE(0x2070B2))) /* GTU Configuration Register 5 High */


#define ERAY_GTUC06L    (*(_PAGE_081_MEM_TYPE(0x2070B4))) /* GTU Configuration Register 6 Low */


#define ERAY_GTUC06H    (*(_PAGE_081_MEM_TYPE(0x2070B6))) /* GTU Configuration Register 6 High */


#define ERAY_GTUC07L    (*(_PAGE_081_MEM_TYPE(0x2070B8))) /* GTU Configuration Register 7 Low */


#define ERAY_GTUC07H    (*(_PAGE_081_MEM_TYPE(0x2070BA))) /* GTU Configuration Register 7 High */


#define ERAY_GTUC08L    (*(_PAGE_081_MEM_TYPE(0x2070BC))) /* GTU Configuration Register 8 Low */


#define ERAY_GTUC08H    (*(_PAGE_081_MEM_TYPE(0x2070BE))) /* GTU Configuration Register 8 High */


#define ERAY_GTUC09L    (*(_PAGE_081_MEM_TYPE(0x2070C0))) /* GTU Configuration Register 9 Low */


#define ERAY_GTUC09H    (*(_PAGE_081_MEM_TYPE(0x2070C2))) /* GTU Configuration Register 9 High */


#define ERAY_GTUC10L    (*(_PAGE_081_MEM_TYPE(0x2070C4))) /* GTU Configuration Register 10 Low */


#define ERAY_GTUC10H    (*(_PAGE_081_MEM_TYPE(0x2070C6))) /* GTU Configuration Register 10 High */


#define ERAY_GTUC11L    (*(_PAGE_081_MEM_TYPE(0x2070C8))) /* GTU Configuration Register 11 Low */


#define ERAY_GTUC11H    (*(_PAGE_081_MEM_TYPE(0x2070CA))) /* GTU Configuration Register 11 High */


#define ERAY_CCSVL      (*(_PAGE_081_MEM_TYPE(0x207100))) /* Communication Controller Status Vector Low */


#define ERAY_CCSVH      (*(_PAGE_081_MEM_TYPE(0x207102))) /* Communication Controller Status Vector High */


#define ERAY_CCEVL      (*(_PAGE_081_MEM_TYPE(0x207104))) /* Communication Controller Error Vector Low */


#define ERAY_SCVL       (*(_PAGE_081_MEM_TYPE(0x207110))) /* Slot Counter Value Low */


#define ERAY_SCVH       (*(_PAGE_081_MEM_TYPE(0x207112))) /* Slot Counter Value High */


#define ERAY_MTCCVL     (*(_PAGE_081_MEM_TYPE(0x207114))) /* Macrotick and Cycle Counter Value Low */


#define ERAY_MTCCVH     (*(_PAGE_081_MEM_TYPE(0x207116))) /* Macrotick and Cycle Counter Value High */


#define ERAY_RCVL       (*(_PAGE_081_MEM_TYPE(0x207118))) /* Rate Correction Value Low */


#define ERAY_OCVL       (*(_PAGE_081_MEM_TYPE(0x20711C))) /* Offset Correction Value Low */


#define ERAY_OCVH       (*(_PAGE_081_MEM_TYPE(0x20711E))) /* Offset Correction Value High */


#define ERAY_SFSL       (*(_PAGE_081_MEM_TYPE(0x207120))) /* SYNC Frame Status Low */


#define ERAY_SFSH       (*(_PAGE_081_MEM_TYPE(0x207122))) /* SYNC Frame Status High */


#define ERAY_SWNITL     (*(_PAGE_081_MEM_TYPE(0x207124))) /* Symbol Window and Network Idle Time Status Low */


#define ERAY_ACSL       (*(_PAGE_081_MEM_TYPE(0x207128))) /* Aggregated Channel Status Low */


#define ERAY_ESID01L    (*(_PAGE_081_MEM_TYPE(0x207130))) /* Even Sync ID Symbol Window 01 Low */


#define ERAY_ESID02L    (*(_PAGE_081_MEM_TYPE(0x207134))) /* Even Sync ID Symbol Window 02 Low */


#define ERAY_ESID03L    (*(_PAGE_081_MEM_TYPE(0x207138))) /* Even Sync ID Symbol Window 03 Low */


#define ERAY_ESID04L    (*(_PAGE_081_MEM_TYPE(0x20713C))) /* Even Sync ID Symbol Window 04 Low */


#define ERAY_ESID05L    (*(_PAGE_081_MEM_TYPE(0x207140))) /* Even Sync ID Symbol Window 05 Low */


#define ERAY_ESID06L    (*(_PAGE_081_MEM_TYPE(0x207144))) /* Even Sync ID Symbol Window 06 Low */


#define ERAY_ESID07L    (*(_PAGE_081_MEM_TYPE(0x207148))) /* Even Sync ID Symbol Window 07 Low */


#define ERAY_ESID08L    (*(_PAGE_081_MEM_TYPE(0x20714C))) /* Even Sync ID Symbol Window 08 Low */


#define ERAY_ESID09L    (*(_PAGE_081_MEM_TYPE(0x207150))) /* Even Sync ID Symbol Window 09 Low */


#define ERAY_ESID10L    (*(_PAGE_081_MEM_TYPE(0x207154))) /* Even Sync ID Symbol Window 10 Low */


#define ERAY_ESID11L    (*(_PAGE_081_MEM_TYPE(0x207158))) /* Even Sync ID Symbol Window 11 Low */


#define ERAY_ESID12L    (*(_PAGE_081_MEM_TYPE(0x20715C))) /* Even Sync ID Symbol Window 12 Low */


#define ERAY_ESID13L    (*(_PAGE_081_MEM_TYPE(0x207160))) /* Even Sync ID Symbol Window 13 Low */


#define ERAY_ESID14L    (*(_PAGE_081_MEM_TYPE(0x207164))) /* Even Sync ID Symbol Window 14 Low */


#define ERAY_ESID15L    (*(_PAGE_081_MEM_TYPE(0x207168))) /* Even Sync ID Symbol Window 15 Low */


#define ERAY_OSID01L    (*(_PAGE_081_MEM_TYPE(0x207170))) /* Odd Sync ID Symbol Window 01 Low */


#define ERAY_OSID02L    (*(_PAGE_081_MEM_TYPE(0x207174))) /* Odd Sync ID Symbol Window 02 Low */


#define ERAY_OSID03L    (*(_PAGE_081_MEM_TYPE(0x207178))) /* Odd Sync ID Symbol Window 03 Low */


#define ERAY_OSID04L    (*(_PAGE_081_MEM_TYPE(0x20717C))) /* Odd Sync ID Symbol Window 04 Low */


#define ERAY_OSID05L    (*(_PAGE_081_MEM_TYPE(0x207180))) /* Odd Sync ID Symbol Window 05 Low */


#define ERAY_OSID06L    (*(_PAGE_081_MEM_TYPE(0x207184))) /* Odd Sync ID Symbol Window 06 Low */


#define ERAY_OSID07L    (*(_PAGE_081_MEM_TYPE(0x207188))) /* Odd Sync ID Symbol Window 07 Low */


#define ERAY_OSID08L    (*(_PAGE_081_MEM_TYPE(0x20718C))) /* Odd Sync ID Symbol Window 08 Low */


#define ERAY_OSID09L    (*(_PAGE_081_MEM_TYPE(0x207190))) /* Odd Sync ID Symbol Window 09 Low */


#define ERAY_OSID10L    (*(_PAGE_081_MEM_TYPE(0x207194))) /* Odd Sync ID Symbol Window 10 Low */


#define ERAY_OSID11L    (*(_PAGE_081_MEM_TYPE(0x207198))) /* Odd Sync ID Symbol Window 11 Low */


#define ERAY_OSID12L    (*(_PAGE_081_MEM_TYPE(0x20719C))) /* Odd Sync ID Symbol Window 12 Low */


#define ERAY_OSID13L    (*(_PAGE_081_MEM_TYPE(0x2071A0))) /* Odd Sync ID Symbol Window 13 Low */


#define ERAY_OSID14L    (*(_PAGE_081_MEM_TYPE(0x2071A4))) /* Odd Sync ID Symbol Window 14 Low */


#define ERAY_OSID15L    (*(_PAGE_081_MEM_TYPE(0x2071A8))) /* Odd Sync ID Symbol Window 15 Low */


#define ERAY_NMV1L      (*(_PAGE_081_MEM_TYPE(0x2071B0))) /* Network Management Vector 1 Low */


#define ERAY_NMV2L      (*(_PAGE_081_MEM_TYPE(0x2071B4))) /* Network Management Vector 2 Low */


#define ERAY_NMV3L      (*(_PAGE_081_MEM_TYPE(0x2071B8))) /* Network Management Vector 3 Low */


#define ERAY_NMV1H      (*(_PAGE_081_MEM_TYPE(0x2071B2))) /* Network Management Vector 1 High */


#define ERAY_NMV2H      (*(_PAGE_081_MEM_TYPE(0x2071B6))) /* Network Management Vector 2 High */


#define ERAY_NMV3H      (*(_PAGE_081_MEM_TYPE(0x2071BA))) /* Network Management Vector 3 High */


#define ERAY_MRCL       (*(_PAGE_081_MEM_TYPE(0x207300))) /* Message RAM Configuration Low */


#define ERAY_MRCH       (*(_PAGE_081_MEM_TYPE(0x207302))) /* Message RAM Configuration High */


#define ERAY_FRFL       (*(_PAGE_081_MEM_TYPE(0x207304))) /* FIFO Rejection Filter Low */


#define ERAY_FRFH       (*(_PAGE_081_MEM_TYPE(0x207306))) /* FIFO Rejection Filter High */


#define ERAY_FRFML      (*(_PAGE_081_MEM_TYPE(0x207308))) /* FIFO Rejection Filter Mask Low */


#define ERAY_FCLL       (*(_PAGE_081_MEM_TYPE(0x20730C))) /* FIFO Critical Level Low */


#define ERAY_MHDSL      (*(_PAGE_081_MEM_TYPE(0x207310))) /* Message Handler Status Low */


#define ERAY_MHDSH      (*(_PAGE_081_MEM_TYPE(0x207312))) /* Message Handler Status High */


#define ERAY_LDTSL      (*(_PAGE_081_MEM_TYPE(0x207314))) /* Last Dynamic Transmit Slot Low */


#define ERAY_LDTSH      (*(_PAGE_081_MEM_TYPE(0x207316))) /* Last Dynamic Transmit Slot High */


#define ERAY_FSRL       (*(_PAGE_081_MEM_TYPE(0x207318))) /* FIFO Status Register Low */


#define ERAY_MHDFL      (*(_PAGE_081_MEM_TYPE(0x20731C))) /* Message Handler Constraints Flags Low */


#define ERAY_TXRQ1L     (*(_PAGE_081_MEM_TYPE(0x207320))) /* Transmission Request Register 1 Low */


#define ERAY_TXRQ1H     (*(_PAGE_081_MEM_TYPE(0x207322))) /* Transmission Request Register 1 High */


#define ERAY_TXRQ2L     (*(_PAGE_081_MEM_TYPE(0x207324))) /* Transmission Request Register 2 Low */


#define ERAY_TXRQ2H     (*(_PAGE_081_MEM_TYPE(0x207326))) /* Transmission Request Register 2 High */


#define ERAY_TXRQ3L     (*(_PAGE_081_MEM_TYPE(0x207328))) /* Transmission Request Register 3 Low */


#define ERAY_TXRQ3H     (*(_PAGE_081_MEM_TYPE(0x20732A))) /* Transmission Request Register 3 High */


#define ERAY_TXRQ4L     (*(_PAGE_081_MEM_TYPE(0x20732C))) /* Transmission Request Register 4 Low */


#define ERAY_TXRQ4H     (*(_PAGE_081_MEM_TYPE(0x20732E))) /* Transmission Request Register 4 High */


#define ERAY_NDAT1L     (*(_PAGE_081_MEM_TYPE(0x207330))) /* New Data Register 1 Low */


#define ERAY_NDAT1H     (*(_PAGE_081_MEM_TYPE(0x207332))) /* New Data Register 1 High */


#define ERAY_NDAT2L     (*(_PAGE_081_MEM_TYPE(0x207334))) /* New Data Register 2 Low */


#define ERAY_NDAT2H     (*(_PAGE_081_MEM_TYPE(0x207336))) /* New Data Register 2 High */


#define ERAY_NDAT3L     (*(_PAGE_081_MEM_TYPE(0x207338))) /* New Data Register 3 Low */


#define ERAY_NDAT3H     (*(_PAGE_081_MEM_TYPE(0x20733A))) /* New Data Register 3 High */


#define ERAY_NDAT4L     (*(_PAGE_081_MEM_TYPE(0x20733C))) /* New Data Register 4 Low */


#define ERAY_NDAT4H     (*(_PAGE_081_MEM_TYPE(0x20733E))) /* New Data Register 4 High */


#define ERAY_MBSC1L     (*(_PAGE_081_MEM_TYPE(0x207340))) /* Message Buffer Status Changed 1 Low */


#define ERAY_MBSC1H     (*(_PAGE_081_MEM_TYPE(0x207342))) /* Message Buffer Status Changed 1 High */


#define ERAY_MBSC2L     (*(_PAGE_081_MEM_TYPE(0x207344))) /* Message Buffer Status Changed 2 Low */


#define ERAY_MBSC2H     (*(_PAGE_081_MEM_TYPE(0x207346))) /* Message Buffer Status Changed 2 High */


#define ERAY_MBSC3L     (*(_PAGE_081_MEM_TYPE(0x207348))) /* Message Buffer Status Changed 3 Low */


#define ERAY_MBSC3H     (*(_PAGE_081_MEM_TYPE(0x20734A))) /* Message Buffer Status Changed 3 High */


#define ERAY_MBSC4L     (*(_PAGE_081_MEM_TYPE(0x20734C))) /* Message Buffer Status Changed 4 Low */


#define ERAY_MBSC4H     (*(_PAGE_081_MEM_TYPE(0x20734E))) /* Message Buffer Status Changed 4 High */


#define ERAY_CRELL      (*(_PAGE_081_MEM_TYPE(0x2073F0))) /* Core Release Register Low */


#define ERAY_CRELH      (*(_PAGE_081_MEM_TYPE(0x2073F2))) /* Core Release Register High */


#define ERAY_ENDNL      (*(_PAGE_081_MEM_TYPE(0x2073F4))) /* Endian Register Low */


#define ERAY_ENDNH      (*(_PAGE_081_MEM_TYPE(0x2073F6))) /* Endian Register High */


#define ERAY_WRDS01L    (*(_PAGE_081_MEM_TYPE(0x207400))) /* Write Data Section 01 Low */


#define ERAY_WRDS02L    (*(_PAGE_081_MEM_TYPE(0x207404))) /* Write Data Section 02 Low */


#define ERAY_WRDS03L    (*(_PAGE_081_MEM_TYPE(0x207408))) /* Write Data Section 03 Low */


#define ERAY_WRDS04L    (*(_PAGE_081_MEM_TYPE(0x20740C))) /* Write Data Section 04 Low */


#define ERAY_WRDS05L    (*(_PAGE_081_MEM_TYPE(0x207410))) /* Write Data Section 05 Low */


#define ERAY_WRDS06L    (*(_PAGE_081_MEM_TYPE(0x207414))) /* Write Data Section 06 Low */


#define ERAY_WRDS07L    (*(_PAGE_081_MEM_TYPE(0x207418))) /* Write Data Section 07 Low */


#define ERAY_WRDS08L    (*(_PAGE_081_MEM_TYPE(0x20741C))) /* Write Data Section 08 Low */


#define ERAY_WRDS09L    (*(_PAGE_081_MEM_TYPE(0x207420))) /* Write Data Section 09 Low */


#define ERAY_WRDS10L    (*(_PAGE_081_MEM_TYPE(0x207424))) /* Write Data Section 10 Low */


#define ERAY_WRDS11L    (*(_PAGE_081_MEM_TYPE(0x207428))) /* Write Data Section 11 Low */


#define ERAY_WRDS12L    (*(_PAGE_081_MEM_TYPE(0x20742C))) /* Write Data Section 12 Low */


#define ERAY_WRDS13L    (*(_PAGE_081_MEM_TYPE(0x207430))) /* Write Data Section 13 Low */


#define ERAY_WRDS14L    (*(_PAGE_081_MEM_TYPE(0x207434))) /* Write Data Section 14 Low */


#define ERAY_WRDS15L    (*(_PAGE_081_MEM_TYPE(0x207438))) /* Write Data Section 15 Low */


#define ERAY_WRDS16L    (*(_PAGE_081_MEM_TYPE(0x20743C))) /* Write Data Section 16 Low */


#define ERAY_WRDS17L    (*(_PAGE_081_MEM_TYPE(0x207440))) /* Write Data Section 17 Low */


#define ERAY_WRDS18L    (*(_PAGE_081_MEM_TYPE(0x207444))) /* Write Data Section 18 Low */


#define ERAY_WRDS19L    (*(_PAGE_081_MEM_TYPE(0x207448))) /* Write Data Section 19 Low */


#define ERAY_WRDS20L    (*(_PAGE_081_MEM_TYPE(0x20744C))) /* Write Data Section 20 Low */


#define ERAY_WRDS21L    (*(_PAGE_081_MEM_TYPE(0x207450))) /* Write Data Section 21 Low */


#define ERAY_WRDS22L    (*(_PAGE_081_MEM_TYPE(0x207454))) /* Write Data Section 22 Low */


#define ERAY_WRDS23L    (*(_PAGE_081_MEM_TYPE(0x207458))) /* Write Data Section 23 Low */


#define ERAY_WRDS24L    (*(_PAGE_081_MEM_TYPE(0x20745C))) /* Write Data Section 24 Low */


#define ERAY_WRDS25L    (*(_PAGE_081_MEM_TYPE(0x207460))) /* Write Data Section 25 Low */


#define ERAY_WRDS26L    (*(_PAGE_081_MEM_TYPE(0x207464))) /* Write Data Section 26 Low */


#define ERAY_WRDS27L    (*(_PAGE_081_MEM_TYPE(0x207468))) /* Write Data Section 27 Low */


#define ERAY_WRDS28L    (*(_PAGE_081_MEM_TYPE(0x20746C))) /* Write Data Section 28 Low */


#define ERAY_WRDS29L    (*(_PAGE_081_MEM_TYPE(0x207470))) /* Write Data Section 29 Low */


#define ERAY_WRDS30L    (*(_PAGE_081_MEM_TYPE(0x207474))) /* Write Data Section 30 Low */


#define ERAY_WRDS31L    (*(_PAGE_081_MEM_TYPE(0x207478))) /* Write Data Section 31 Low */


#define ERAY_WRDS32L    (*(_PAGE_081_MEM_TYPE(0x20747C))) /* Write Data Section 32 Low */


#define ERAY_WRDS33L    (*(_PAGE_081_MEM_TYPE(0x207480))) /* Write Data Section 33 Low */


#define ERAY_WRDS34L    (*(_PAGE_081_MEM_TYPE(0x207484))) /* Write Data Section 34 Low */


#define ERAY_WRDS35L    (*(_PAGE_081_MEM_TYPE(0x207488))) /* Write Data Section 35 Low */


#define ERAY_WRDS36L    (*(_PAGE_081_MEM_TYPE(0x20748C))) /* Write Data Section 36 Low */


#define ERAY_WRDS37L    (*(_PAGE_081_MEM_TYPE(0x207490))) /* Write Data Section 37 Low */


#define ERAY_WRDS38L    (*(_PAGE_081_MEM_TYPE(0x207494))) /* Write Data Section 38 Low */


#define ERAY_WRDS39L    (*(_PAGE_081_MEM_TYPE(0x207498))) /* Write Data Section 39 Low */


#define ERAY_WRDS40L    (*(_PAGE_081_MEM_TYPE(0x20749C))) /* Write Data Section 40 Low */


#define ERAY_WRDS41L    (*(_PAGE_081_MEM_TYPE(0x2074A0))) /* Write Data Section 41 Low */


#define ERAY_WRDS42L    (*(_PAGE_081_MEM_TYPE(0x2074A4))) /* Write Data Section 42 Low */


#define ERAY_WRDS43L    (*(_PAGE_081_MEM_TYPE(0x2074A8))) /* Write Data Section 43 Low */


#define ERAY_WRDS44L    (*(_PAGE_081_MEM_TYPE(0x2074AC))) /* Write Data Section 44 Low */


#define ERAY_WRDS45L    (*(_PAGE_081_MEM_TYPE(0x2074B0))) /* Write Data Section 45 Low */


#define ERAY_WRDS46L    (*(_PAGE_081_MEM_TYPE(0x2074B4))) /* Write Data Section 46 Low */


#define ERAY_WRDS47L    (*(_PAGE_081_MEM_TYPE(0x2074B8))) /* Write Data Section 47 Low */


#define ERAY_WRDS48L    (*(_PAGE_081_MEM_TYPE(0x2074BC))) /* Write Data Section 48 Low */


#define ERAY_WRDS49L    (*(_PAGE_081_MEM_TYPE(0x2074C0))) /* Write Data Section 49 Low */


#define ERAY_WRDS50L    (*(_PAGE_081_MEM_TYPE(0x2074C4))) /* Write Data Section 50 Low */


#define ERAY_WRDS51L    (*(_PAGE_081_MEM_TYPE(0x2074C8))) /* Write Data Section 51 Low */


#define ERAY_WRDS52L    (*(_PAGE_081_MEM_TYPE(0x2074CC))) /* Write Data Section 52 Low */


#define ERAY_WRDS53L    (*(_PAGE_081_MEM_TYPE(0x2074D0))) /* Write Data Section 53 Low */


#define ERAY_WRDS54L    (*(_PAGE_081_MEM_TYPE(0x2074D4))) /* Write Data Section 54 Low */


#define ERAY_WRDS55L    (*(_PAGE_081_MEM_TYPE(0x2074D8))) /* Write Data Section 55 Low */


#define ERAY_WRDS56L    (*(_PAGE_081_MEM_TYPE(0x2074DC))) /* Write Data Section 56 Low */


#define ERAY_WRDS57L    (*(_PAGE_081_MEM_TYPE(0x2074E0))) /* Write Data Section 57 Low */


#define ERAY_WRDS58L    (*(_PAGE_081_MEM_TYPE(0x2074E4))) /* Write Data Section 58 Low */


#define ERAY_WRDS59L    (*(_PAGE_081_MEM_TYPE(0x2074E8))) /* Write Data Section 59 Low */


#define ERAY_WRDS60L    (*(_PAGE_081_MEM_TYPE(0x2074EC))) /* Write Data Section 60 Low */


#define ERAY_WRDS61L    (*(_PAGE_081_MEM_TYPE(0x2074F0))) /* Write Data Section 61 Low */


#define ERAY_WRDS62L    (*(_PAGE_081_MEM_TYPE(0x2074F4))) /* Write Data Section 62 Low */


#define ERAY_WRDS63L    (*(_PAGE_081_MEM_TYPE(0x2074F8))) /* Write Data Section 63 Low */


#define ERAY_WRDS64L    (*(_PAGE_081_MEM_TYPE(0x2074FC))) /* Write Data Section 64 Low */


#define ERAY_WRDS01H    (*(_PAGE_081_MEM_TYPE(0x207402))) /* Write Data Section 01 High */


#define ERAY_WRDS02H    (*(_PAGE_081_MEM_TYPE(0x207406))) /* Write Data Section 02 High */


#define ERAY_WRDS03H    (*(_PAGE_081_MEM_TYPE(0x20740A))) /* Write Data Section 03 High */


#define ERAY_WRDS04H    (*(_PAGE_081_MEM_TYPE(0x20740E))) /* Write Data Section 04 High */


#define ERAY_WRDS05H    (*(_PAGE_081_MEM_TYPE(0x207412))) /* Write Data Section 05 High */


#define ERAY_WRDS06H    (*(_PAGE_081_MEM_TYPE(0x207416))) /* Write Data Section 06 High */


#define ERAY_WRDS07H    (*(_PAGE_081_MEM_TYPE(0x20741A))) /* Write Data Section 07 High */


#define ERAY_WRDS08H    (*(_PAGE_081_MEM_TYPE(0x20741E))) /* Write Data Section 08 High */


#define ERAY_WRDS09H    (*(_PAGE_081_MEM_TYPE(0x207422))) /* Write Data Section 09 High */


#define ERAY_WRDS10H    (*(_PAGE_081_MEM_TYPE(0x207426))) /* Write Data Section 10 High */


#define ERAY_WRDS11H    (*(_PAGE_081_MEM_TYPE(0x20742A))) /* Write Data Section 11 High */


#define ERAY_WRDS12H    (*(_PAGE_081_MEM_TYPE(0x20742E))) /* Write Data Section 12 High */


#define ERAY_WRDS13H    (*(_PAGE_081_MEM_TYPE(0x207432))) /* Write Data Section 13 High */


#define ERAY_WRDS14H    (*(_PAGE_081_MEM_TYPE(0x207436))) /* Write Data Section 14 High */


#define ERAY_WRDS15H    (*(_PAGE_081_MEM_TYPE(0x20743A))) /* Write Data Section 15 High */


#define ERAY_WRDS16H    (*(_PAGE_081_MEM_TYPE(0x20743E))) /* Write Data Section 16 High */


#define ERAY_WRDS17H    (*(_PAGE_081_MEM_TYPE(0x207442))) /* Write Data Section 17 High */


#define ERAY_WRDS18H    (*(_PAGE_081_MEM_TYPE(0x207446))) /* Write Data Section 18 High */


#define ERAY_WRDS19H    (*(_PAGE_081_MEM_TYPE(0x20744A))) /* Write Data Section 19 High */


#define ERAY_WRDS20H    (*(_PAGE_081_MEM_TYPE(0x20744E))) /* Write Data Section 20 High */


#define ERAY_WRDS21H    (*(_PAGE_081_MEM_TYPE(0x207452))) /* Write Data Section 21 High */


#define ERAY_WRDS22H    (*(_PAGE_081_MEM_TYPE(0x207456))) /* Write Data Section 22 High */


#define ERAY_WRDS23H    (*(_PAGE_081_MEM_TYPE(0x20745A))) /* Write Data Section 23 High */


#define ERAY_WRDS24H    (*(_PAGE_081_MEM_TYPE(0x20745E))) /* Write Data Section 24 High */


#define ERAY_WRDS25H    (*(_PAGE_081_MEM_TYPE(0x207462))) /* Write Data Section 25 High */


#define ERAY_WRDS26H    (*(_PAGE_081_MEM_TYPE(0x207466))) /* Write Data Section 26 High */


#define ERAY_WRDS27H    (*(_PAGE_081_MEM_TYPE(0x20746A))) /* Write Data Section 27 High */


#define ERAY_WRDS28H    (*(_PAGE_081_MEM_TYPE(0x20746E))) /* Write Data Section 28 High */


#define ERAY_WRDS29H    (*(_PAGE_081_MEM_TYPE(0x207472))) /* Write Data Section 29 High */


#define ERAY_WRDS30H    (*(_PAGE_081_MEM_TYPE(0x207476))) /* Write Data Section 30 High */


#define ERAY_WRDS31H    (*(_PAGE_081_MEM_TYPE(0x20747A))) /* Write Data Section 31 High */


#define ERAY_WRDS32H    (*(_PAGE_081_MEM_TYPE(0x20747E))) /* Write Data Section 32 High */


#define ERAY_WRDS33H    (*(_PAGE_081_MEM_TYPE(0x207482))) /* Write Data Section 33 High */


#define ERAY_WRDS34H    (*(_PAGE_081_MEM_TYPE(0x207486))) /* Write Data Section 34 High */


#define ERAY_WRDS35H    (*(_PAGE_081_MEM_TYPE(0x20748A))) /* Write Data Section 35 High */


#define ERAY_WRDS36H    (*(_PAGE_081_MEM_TYPE(0x20748E))) /* Write Data Section 36 High */


#define ERAY_WRDS37H    (*(_PAGE_081_MEM_TYPE(0x207492))) /* Write Data Section 37 High */


#define ERAY_WRDS38H    (*(_PAGE_081_MEM_TYPE(0x207496))) /* Write Data Section 38 High */


#define ERAY_WRDS39H    (*(_PAGE_081_MEM_TYPE(0x20749A))) /* Write Data Section 39 High */


#define ERAY_WRDS40H    (*(_PAGE_081_MEM_TYPE(0x20749E))) /* Write Data Section 40 High */


#define ERAY_WRDS41H    (*(_PAGE_081_MEM_TYPE(0x2074A2))) /* Write Data Section 41 High */


#define ERAY_WRDS42H    (*(_PAGE_081_MEM_TYPE(0x2074A6))) /* Write Data Section 42 High */


#define ERAY_WRDS43H    (*(_PAGE_081_MEM_TYPE(0x2074AA))) /* Write Data Section 43 High */


#define ERAY_WRDS44H    (*(_PAGE_081_MEM_TYPE(0x2074AE))) /* Write Data Section 44 High */


#define ERAY_WRDS45H    (*(_PAGE_081_MEM_TYPE(0x2074B2))) /* Write Data Section 45 High */


#define ERAY_WRDS46H    (*(_PAGE_081_MEM_TYPE(0x2074B6))) /* Write Data Section 46 High */


#define ERAY_WRDS47H    (*(_PAGE_081_MEM_TYPE(0x2074BA))) /* Write Data Section 47 High */


#define ERAY_WRDS48H    (*(_PAGE_081_MEM_TYPE(0x2074BE))) /* Write Data Section 48 High */


#define ERAY_WRDS49H    (*(_PAGE_081_MEM_TYPE(0x2074C2))) /* Write Data Section 49 High */


#define ERAY_WRDS50H    (*(_PAGE_081_MEM_TYPE(0x2074C6))) /* Write Data Section 50 High */


#define ERAY_WRDS51H    (*(_PAGE_081_MEM_TYPE(0x2074CA))) /* Write Data Section 51 High */


#define ERAY_WRDS52H    (*(_PAGE_081_MEM_TYPE(0x2074CE))) /* Write Data Section 52 High */


#define ERAY_WRDS53H    (*(_PAGE_081_MEM_TYPE(0x2074D2))) /* Write Data Section 53 High */


#define ERAY_WRDS54H    (*(_PAGE_081_MEM_TYPE(0x2074D6))) /* Write Data Section 54 High */


#define ERAY_WRDS55H    (*(_PAGE_081_MEM_TYPE(0x2074DA))) /* Write Data Section 55 High */


#define ERAY_WRDS56H    (*(_PAGE_081_MEM_TYPE(0x2074DE))) /* Write Data Section 56 High */


#define ERAY_WRDS57H    (*(_PAGE_081_MEM_TYPE(0x2074E2))) /* Write Data Section 57 High */


#define ERAY_WRDS58H    (*(_PAGE_081_MEM_TYPE(0x2074E6))) /* Write Data Section 58 High */


#define ERAY_WRDS59H    (*(_PAGE_081_MEM_TYPE(0x2074EA))) /* Write Data Section 59 High */


#define ERAY_WRDS60H    (*(_PAGE_081_MEM_TYPE(0x2074EE))) /* Write Data Section 60 High */


#define ERAY_WRDS61H    (*(_PAGE_081_MEM_TYPE(0x2074F2))) /* Write Data Section 61 High */


#define ERAY_WRDS62H    (*(_PAGE_081_MEM_TYPE(0x2074F6))) /* Write Data Section 62 High */


#define ERAY_WRDS63H    (*(_PAGE_081_MEM_TYPE(0x2074FA))) /* Write Data Section 63 High */


#define ERAY_WRDS64H    (*(_PAGE_081_MEM_TYPE(0x2074FE))) /* Write Data Section 64 High */


#define ERAY_WRHS1L     (*(_PAGE_081_MEM_TYPE(0x207500))) /* Write Header Section 1 Low */


#define ERAY_WRHS1H     (*(_PAGE_081_MEM_TYPE(0x207502))) /* Write Header Section 1 High */


#define ERAY_WRHS2L     (*(_PAGE_081_MEM_TYPE(0x207504))) /* Write Header Section 2 Low */


#define ERAY_WRHS2H     (*(_PAGE_081_MEM_TYPE(0x207506))) /* Write Header Section 2 High */


#define ERAY_WRHS3L     (*(_PAGE_081_MEM_TYPE(0x207508))) /* Write Header Section 3 Low */


#define ERAY_IBCML      (*(_PAGE_081_MEM_TYPE(0x207510))) /* Input Buffer Command Mask Low */


#define ERAY_IBCMH      (*(_PAGE_081_MEM_TYPE(0x207512))) /* Input Buffer Command Mask High */


#define ERAY_IBCRL      (*(_PAGE_081_MEM_TYPE(0x207514))) /* Input Buffer Command Request Low */


#define ERAY_IBCRH      (*(_PAGE_081_MEM_TYPE(0x207516))) /* Input Buffer Command Request High */


#define ERAY_RDDS01L    (*(_PAGE_081_MEM_TYPE(0x207600))) /* Read Data Section 01 Low */


#define ERAY_RDDS02L    (*(_PAGE_081_MEM_TYPE(0x207604))) /* Read Data Section 02 Low */


#define ERAY_RDDS03L    (*(_PAGE_081_MEM_TYPE(0x207608))) /* Read Data Section 03 Low */


#define ERAY_RDDS04L    (*(_PAGE_081_MEM_TYPE(0x20760C))) /* Read Data Section 04 Low */


#define ERAY_RDDS05L    (*(_PAGE_081_MEM_TYPE(0x207610))) /* Read Data Section 05 Low */


#define ERAY_RDDS06L    (*(_PAGE_081_MEM_TYPE(0x207614))) /* Read Data Section 06 Low */


#define ERAY_RDDS07L    (*(_PAGE_081_MEM_TYPE(0x207618))) /* Read Data Section 07 Low */


#define ERAY_RDDS08L    (*(_PAGE_081_MEM_TYPE(0x20761C))) /* Read Data Section 08 Low */


#define ERAY_RDDS09L    (*(_PAGE_081_MEM_TYPE(0x207620))) /* Read Data Section 09 Low */


#define ERAY_RDDS10L    (*(_PAGE_081_MEM_TYPE(0x207624))) /* Read Data Section 10 Low */


#define ERAY_RDDS11L    (*(_PAGE_081_MEM_TYPE(0x207628))) /* Read Data Section 11 Low */


#define ERAY_RDDS12L    (*(_PAGE_081_MEM_TYPE(0x20762C))) /* Read Data Section 12 Low */


#define ERAY_RDDS13L    (*(_PAGE_081_MEM_TYPE(0x207630))) /* Read Data Section 13 Low */


#define ERAY_RDDS14L    (*(_PAGE_081_MEM_TYPE(0x207634))) /* Read Data Section 14 Low */


#define ERAY_RDDS15L    (*(_PAGE_081_MEM_TYPE(0x207638))) /* Read Data Section 15 Low */


#define ERAY_RDDS16L    (*(_PAGE_081_MEM_TYPE(0x20763C))) /* Read Data Section 16 Low */


#define ERAY_RDDS17L    (*(_PAGE_081_MEM_TYPE(0x207640))) /* Read Data Section 17 Low */


#define ERAY_RDDS18L    (*(_PAGE_081_MEM_TYPE(0x207644))) /* Read Data Section 18 Low */


#define ERAY_RDDS19L    (*(_PAGE_081_MEM_TYPE(0x207648))) /* Read Data Section 19 Low */


#define ERAY_RDDS20L    (*(_PAGE_081_MEM_TYPE(0x20764C))) /* Read Data Section 20 Low */


#define ERAY_RDDS21L    (*(_PAGE_081_MEM_TYPE(0x207650))) /* Read Data Section 21 Low */


#define ERAY_RDDS22L    (*(_PAGE_081_MEM_TYPE(0x207654))) /* Read Data Section 22 Low */


#define ERAY_RDDS23L    (*(_PAGE_081_MEM_TYPE(0x207658))) /* Read Data Section 23 Low */


#define ERAY_RDDS24L    (*(_PAGE_081_MEM_TYPE(0x20765C))) /* Read Data Section 24 Low */


#define ERAY_RDDS25L    (*(_PAGE_081_MEM_TYPE(0x207660))) /* Read Data Section 25 Low */


#define ERAY_RDDS26L    (*(_PAGE_081_MEM_TYPE(0x207664))) /* Read Data Section 26 Low */


#define ERAY_RDDS27L    (*(_PAGE_081_MEM_TYPE(0x207668))) /* Read Data Section 27 Low */


#define ERAY_RDDS28L    (*(_PAGE_081_MEM_TYPE(0x20766C))) /* Read Data Section 28 Low */


#define ERAY_RDDS29L    (*(_PAGE_081_MEM_TYPE(0x207670))) /* Read Data Section 29 Low */


#define ERAY_RDDS30L    (*(_PAGE_081_MEM_TYPE(0x207674))) /* Read Data Section 30 Low */


#define ERAY_RDDS31L    (*(_PAGE_081_MEM_TYPE(0x207678))) /* Read Data Section 31 Low */


#define ERAY_RDDS32L    (*(_PAGE_081_MEM_TYPE(0x20767C))) /* Read Data Section 32 Low */


#define ERAY_RDDS33L    (*(_PAGE_081_MEM_TYPE(0x207680))) /* Read Data Section 33 Low */


#define ERAY_RDDS34L    (*(_PAGE_081_MEM_TYPE(0x207684))) /* Read Data Section 34 Low */


#define ERAY_RDDS35L    (*(_PAGE_081_MEM_TYPE(0x207688))) /* Read Data Section 35 Low */


#define ERAY_RDDS36L    (*(_PAGE_081_MEM_TYPE(0x20768C))) /* Read Data Section 36 Low */


#define ERAY_RDDS37L    (*(_PAGE_081_MEM_TYPE(0x207690))) /* Read Data Section 37 Low */


#define ERAY_RDDS38L    (*(_PAGE_081_MEM_TYPE(0x207694))) /* Read Data Section 38 Low */


#define ERAY_RDDS39L    (*(_PAGE_081_MEM_TYPE(0x207698))) /* Read Data Section 39 Low */


#define ERAY_RDDS40L    (*(_PAGE_081_MEM_TYPE(0x20769C))) /* Read Data Section 40 Low */


#define ERAY_RDDS41L    (*(_PAGE_081_MEM_TYPE(0x2076A0))) /* Read Data Section 41 Low */


#define ERAY_RDDS42L    (*(_PAGE_081_MEM_TYPE(0x2076A4))) /* Read Data Section 42 Low */


#define ERAY_RDDS43L    (*(_PAGE_081_MEM_TYPE(0x2076A8))) /* Read Data Section 43 Low */


#define ERAY_RDDS44L    (*(_PAGE_081_MEM_TYPE(0x2076AC))) /* Read Data Section 44 Low */


#define ERAY_RDDS45L    (*(_PAGE_081_MEM_TYPE(0x2076B0))) /* Read Data Section 45 Low */


#define ERAY_RDDS46L    (*(_PAGE_081_MEM_TYPE(0x2076B4))) /* Read Data Section 46 Low */


#define ERAY_RDDS47L    (*(_PAGE_081_MEM_TYPE(0x2076B8))) /* Read Data Section 47 Low */


#define ERAY_RDDS48L    (*(_PAGE_081_MEM_TYPE(0x2076BC))) /* Read Data Section 48 Low */


#define ERAY_RDDS49L    (*(_PAGE_081_MEM_TYPE(0x2076C0))) /* Read Data Section 49 Low */


#define ERAY_RDDS50L    (*(_PAGE_081_MEM_TYPE(0x2076C4))) /* Read Data Section 50 Low */


#define ERAY_RDDS51L    (*(_PAGE_081_MEM_TYPE(0x2076C8))) /* Read Data Section 51 Low */


#define ERAY_RDDS52L    (*(_PAGE_081_MEM_TYPE(0x2076CC))) /* Read Data Section 52 Low */


#define ERAY_RDDS53L    (*(_PAGE_081_MEM_TYPE(0x2076D0))) /* Read Data Section 53 Low */


#define ERAY_RDDS54L    (*(_PAGE_081_MEM_TYPE(0x2076D4))) /* Read Data Section 54 Low */


#define ERAY_RDDS55L    (*(_PAGE_081_MEM_TYPE(0x2076D8))) /* Read Data Section 55 Low */


#define ERAY_RDDS56L    (*(_PAGE_081_MEM_TYPE(0x2076DC))) /* Read Data Section 56 Low */


#define ERAY_RDDS57L    (*(_PAGE_081_MEM_TYPE(0x2076E0))) /* Read Data Section 57 Low */


#define ERAY_RDDS58L    (*(_PAGE_081_MEM_TYPE(0x2076E4))) /* Read Data Section 58 Low */


#define ERAY_RDDS59L    (*(_PAGE_081_MEM_TYPE(0x2076E8))) /* Read Data Section 59 Low */


#define ERAY_RDDS60L    (*(_PAGE_081_MEM_TYPE(0x2076EC))) /* Read Data Section 60 Low */


#define ERAY_RDDS61L    (*(_PAGE_081_MEM_TYPE(0x2076F0))) /* Read Data Section 61 Low */


#define ERAY_RDDS62L    (*(_PAGE_081_MEM_TYPE(0x2076F4))) /* Read Data Section 62 Low */


#define ERAY_RDDS63L    (*(_PAGE_081_MEM_TYPE(0x2076F8))) /* Read Data Section 63 Low */


#define ERAY_RDDS64L    (*(_PAGE_081_MEM_TYPE(0x2076FC))) /* Read Data Section 64 Low */


#define ERAY_RDDS01H    (*(_PAGE_081_MEM_TYPE(0x207602))) /* Read Data Section 01 High */


#define ERAY_RDDS02H    (*(_PAGE_081_MEM_TYPE(0x207606))) /* Read Data Section 02 High */


#define ERAY_RDDS03H    (*(_PAGE_081_MEM_TYPE(0x20760A))) /* Read Data Section 03 High */


#define ERAY_RDDS04H    (*(_PAGE_081_MEM_TYPE(0x20760E))) /* Read Data Section 04 High */


#define ERAY_RDDS05H    (*(_PAGE_081_MEM_TYPE(0x207612))) /* Read Data Section 05 High */


#define ERAY_RDDS06H    (*(_PAGE_081_MEM_TYPE(0x207616))) /* Read Data Section 06 High */


#define ERAY_RDDS07H    (*(_PAGE_081_MEM_TYPE(0x20761A))) /* Read Data Section 07 High */


#define ERAY_RDDS08H    (*(_PAGE_081_MEM_TYPE(0x20761E))) /* Read Data Section 08 High */


#define ERAY_RDDS09H    (*(_PAGE_081_MEM_TYPE(0x207622))) /* Read Data Section 09 High */


#define ERAY_RDDS10H    (*(_PAGE_081_MEM_TYPE(0x207626))) /* Read Data Section 10 High */


#define ERAY_RDDS11H    (*(_PAGE_081_MEM_TYPE(0x20762A))) /* Read Data Section 11 High */


#define ERAY_RDDS12H    (*(_PAGE_081_MEM_TYPE(0x20762E))) /* Read Data Section 12 High */


#define ERAY_RDDS13H    (*(_PAGE_081_MEM_TYPE(0x207632))) /* Read Data Section 13 High */


#define ERAY_RDDS14H    (*(_PAGE_081_MEM_TYPE(0x207636))) /* Read Data Section 14 High */


#define ERAY_RDDS15H    (*(_PAGE_081_MEM_TYPE(0x20763A))) /* Read Data Section 15 High */


#define ERAY_RDDS16H    (*(_PAGE_081_MEM_TYPE(0x20763E))) /* Read Data Section 16 High */


#define ERAY_RDDS17H    (*(_PAGE_081_MEM_TYPE(0x207642))) /* Read Data Section 17 High */


#define ERAY_RDDS18H    (*(_PAGE_081_MEM_TYPE(0x207646))) /* Read Data Section 18 High */


#define ERAY_RDDS19H    (*(_PAGE_081_MEM_TYPE(0x20764A))) /* Read Data Section 19 High */


#define ERAY_RDDS20H    (*(_PAGE_081_MEM_TYPE(0x20764E))) /* Read Data Section 20 High */


#define ERAY_RDDS21H    (*(_PAGE_081_MEM_TYPE(0x207652))) /* Read Data Section 21 High */


#define ERAY_RDDS22H    (*(_PAGE_081_MEM_TYPE(0x207656))) /* Read Data Section 22 High */


#define ERAY_RDDS23H    (*(_PAGE_081_MEM_TYPE(0x20765A))) /* Read Data Section 23 High */


#define ERAY_RDDS24H    (*(_PAGE_081_MEM_TYPE(0x20765E))) /* Read Data Section 24 High */


#define ERAY_RDDS25H    (*(_PAGE_081_MEM_TYPE(0x207662))) /* Read Data Section 25 High */


#define ERAY_RDDS26H    (*(_PAGE_081_MEM_TYPE(0x207666))) /* Read Data Section 26 High */


#define ERAY_RDDS27H    (*(_PAGE_081_MEM_TYPE(0x20766A))) /* Read Data Section 27 High */


#define ERAY_RDDS28H    (*(_PAGE_081_MEM_TYPE(0x20766E))) /* Read Data Section 28 High */


#define ERAY_RDDS29H    (*(_PAGE_081_MEM_TYPE(0x207672))) /* Read Data Section 29 High */


#define ERAY_RDDS30H    (*(_PAGE_081_MEM_TYPE(0x207676))) /* Read Data Section 30 High */


#define ERAY_RDDS31H    (*(_PAGE_081_MEM_TYPE(0x20767A))) /* Read Data Section 31 High */


#define ERAY_RDDS32H    (*(_PAGE_081_MEM_TYPE(0x20767E))) /* Read Data Section 32 High */


#define ERAY_RDDS33H    (*(_PAGE_081_MEM_TYPE(0x207682))) /* Read Data Section 33 High */


#define ERAY_RDDS34H    (*(_PAGE_081_MEM_TYPE(0x207686))) /* Read Data Section 34 High */


#define ERAY_RDDS35H    (*(_PAGE_081_MEM_TYPE(0x20768A))) /* Read Data Section 35 High */


#define ERAY_RDDS36H    (*(_PAGE_081_MEM_TYPE(0x20768E))) /* Read Data Section 36 High */


#define ERAY_RDDS37H    (*(_PAGE_081_MEM_TYPE(0x207692))) /* Read Data Section 37 High */


#define ERAY_RDDS38H    (*(_PAGE_081_MEM_TYPE(0x207696))) /* Read Data Section 38 High */


#define ERAY_RDDS39H    (*(_PAGE_081_MEM_TYPE(0x20769A))) /* Read Data Section 39 High */


#define ERAY_RDDS40H    (*(_PAGE_081_MEM_TYPE(0x20769E))) /* Read Data Section 40 High */


#define ERAY_RDDS41H    (*(_PAGE_081_MEM_TYPE(0x2076A2))) /* Read Data Section 41 High */


#define ERAY_RDDS42H    (*(_PAGE_081_MEM_TYPE(0x2076A6))) /* Read Data Section 42 High */


#define ERAY_RDDS43H    (*(_PAGE_081_MEM_TYPE(0x2076AA))) /* Read Data Section 43 High */


#define ERAY_RDDS44H    (*(_PAGE_081_MEM_TYPE(0x2076AE))) /* Read Data Section 44 High */


#define ERAY_RDDS45H    (*(_PAGE_081_MEM_TYPE(0x2076B2))) /* Read Data Section 45 High */


#define ERAY_RDDS46H    (*(_PAGE_081_MEM_TYPE(0x2076B6))) /* Read Data Section 46 High */


#define ERAY_RDDS47H    (*(_PAGE_081_MEM_TYPE(0x2076BA))) /* Read Data Section 47 High */


#define ERAY_RDDS48H    (*(_PAGE_081_MEM_TYPE(0x2076BE))) /* Read Data Section 48 High */


#define ERAY_RDDS49H    (*(_PAGE_081_MEM_TYPE(0x2076C2))) /* Read Data Section 49 High */


#define ERAY_RDDS50H    (*(_PAGE_081_MEM_TYPE(0x2076C6))) /* Read Data Section 50 High */


#define ERAY_RDDS51H    (*(_PAGE_081_MEM_TYPE(0x2076CA))) /* Read Data Section 51 High */


#define ERAY_RDDS52H    (*(_PAGE_081_MEM_TYPE(0x2076CE))) /* Read Data Section 52 High */


#define ERAY_RDDS53H    (*(_PAGE_081_MEM_TYPE(0x2076D2))) /* Read Data Section 53 High */


#define ERAY_RDDS54H    (*(_PAGE_081_MEM_TYPE(0x2076D6))) /* Read Data Section 54 High */


#define ERAY_RDDS55H    (*(_PAGE_081_MEM_TYPE(0x2076DA))) /* Read Data Section 55 High */


#define ERAY_RDDS56H    (*(_PAGE_081_MEM_TYPE(0x2076DE))) /* Read Data Section 56 High */


#define ERAY_RDDS57H    (*(_PAGE_081_MEM_TYPE(0x2076E2))) /* Read Data Section 57 High */


#define ERAY_RDDS58H    (*(_PAGE_081_MEM_TYPE(0x2076E6))) /* Read Data Section 58 High */


#define ERAY_RDDS59H    (*(_PAGE_081_MEM_TYPE(0x2076EA))) /* Read Data Section 59 High */


#define ERAY_RDDS60H    (*(_PAGE_081_MEM_TYPE(0x2076EE))) /* Read Data Section 60 High */


#define ERAY_RDDS61H    (*(_PAGE_081_MEM_TYPE(0x2076F2))) /* Read Data Section 61 High */


#define ERAY_RDDS62H    (*(_PAGE_081_MEM_TYPE(0x2076F6))) /* Read Data Section 62 High */


#define ERAY_RDDS63H    (*(_PAGE_081_MEM_TYPE(0x2076FA))) /* Read Data Section 63 High */


#define ERAY_RDDS64H    (*(_PAGE_081_MEM_TYPE(0x2076FE))) /* Read Data Section 64 High */


#define ERAY_RDHS1L     (*(_PAGE_081_MEM_TYPE(0x207700))) /* Read Header Section 1 Low */


#define ERAY_RDHS1H     (*(_PAGE_081_MEM_TYPE(0x207702))) /* Read Header Section 1 High */


#define ERAY_RDHS2L     (*(_PAGE_081_MEM_TYPE(0x207704))) /* Read Header Section 2 Low */


#define ERAY_RDHS2H     (*(_PAGE_081_MEM_TYPE(0x207706))) /* Read Header Section 2 High */


#define ERAY_RDHS3L     (*(_PAGE_081_MEM_TYPE(0x207708))) /* Read Header Section 3 Low */


#define ERAY_RDHS3H     (*(_PAGE_081_MEM_TYPE(0x20770A))) /* Read Header Section 3 High */


#define ERAY_MBSL       (*(_PAGE_081_MEM_TYPE(0x20770C))) /* Message Buffer Status Low */


#define ERAY_MBSH       (*(_PAGE_081_MEM_TYPE(0x20770E))) /* Message Buffer Status High */


#define ERAY_OBCML      (*(_PAGE_081_MEM_TYPE(0x207710))) /* Output Buffer Command Mask Low */


#define ERAY_OBCMH      (*(_PAGE_081_MEM_TYPE(0x207712))) /* Output Buffer Command Mask High */


#define ERAY_OBCRL      (*(_PAGE_081_MEM_TYPE(0x207714))) /* Output Buffer Command Request Low */


#define ERAY_OBCRH      (*(_PAGE_081_MEM_TYPE(0x207716))) /* Output Buffer Command Request High */


#define ERAY_KSCFG      (*(_PAGE_081_MEM_TYPE(0x207000))) /* Kernel State Control Configuration Register */


#define ERAY_NDIC1L     (*(_PAGE_081_MEM_TYPE(0x2073A8))) /* New Data Interrupt Control 1 Low */


#define ERAY_NDIC1H     (*(_PAGE_081_MEM_TYPE(0x2073AA))) /* New Data Interrupt Control 1 High */


#define ERAY_NDIC2L     (*(_PAGE_081_MEM_TYPE(0x2073AC))) /* New Data Interrupt Control 2 Low */


#define ERAY_NDIC2H     (*(_PAGE_081_MEM_TYPE(0x2073AE))) /* New Data Interrupt Control 2 High */


#define ERAY_NDIC3L     (*(_PAGE_081_MEM_TYPE(0x2073B0))) /* New Data Interrupt Control 3 Low */


#define ERAY_NDIC3H     (*(_PAGE_081_MEM_TYPE(0x2073B2))) /* New Data Interrupt Control 3 High */


#define ERAY_NDIC4L     (*(_PAGE_081_MEM_TYPE(0x2073B4))) /* New Data Interrupt Control 4 Low */


#define ERAY_NDIC4H     (*(_PAGE_081_MEM_TYPE(0x2073B6))) /* New Data Interrupt Control 4 High */


#define ERAY_MSIC1L     (*(_PAGE_081_MEM_TYPE(0x2073B8))) /* Message Buffer Status Changed Interrupt Control 1 Low */


#define ERAY_MSIC1H     (*(_PAGE_081_MEM_TYPE(0x2073BA))) /* Message Buffer Status Changed Interrupt Control 1 High */


#define ERAY_MSIC2L     (*(_PAGE_081_MEM_TYPE(0x2073BC))) /* Message Buffer Status Changed Interrupt Control 2 Low */


#define ERAY_MSIC2H     (*(_PAGE_081_MEM_TYPE(0x2073BE))) /* Message Buffer Status Changed Interrupt Control 2 High */


#define ERAY_MSIC3L     (*(_PAGE_081_MEM_TYPE(0x2073C0))) /* Message Buffer Status Changed Interrupt Control 3 Low */


#define ERAY_MSIC3H     (*(_PAGE_081_MEM_TYPE(0x2073C2))) /* Message Buffer Status Changed Interrupt Control 3 High */


#define ERAY_MSIC4L     (*(_PAGE_081_MEM_TYPE(0x2073C4))) /* Message Buffer Status Changed Interrupt Control 4 Low */


#define ERAY_MSIC4H     (*(_PAGE_081_MEM_TYPE(0x2073C6))) /* Message Buffer Status Changed Interrupt Control 4 High */
#endif /* REGXC2361E_NOERAY */
#endif /* REGXC2361E_INC */
